# DO NOT EDIT THIS FILE, CHANGES WILL BE OVERWRITTEN BY update_vendor.py
# From https://github.com/JetBrains/swot.git@bbdfe839

TLDS = frozenset(
    [
        "ac.be",
        "ac.gg",
        "ac.gn",
        "ac.il",
        "ac.in",
        "ac.jp",
        "ac.me",
        "ac.ni",
        "ac.om",
        "ac.pg",
        "ac.pr",
        "ac.rw",
        "ac.sz",
        "ac.yu",
        "ac.za",
        "ac.zm",
        "ed.ao",
        "ed.cr",
        "ed.jp",
        "edu.al",
        "edu.az",
        "edu.bb",
        "edu.bs",
        "edu.ck",
        "edu.cn",
        "edu.dz",
        "edu.ee",
        "edu.er",
        "edu.hk",
        "edu.kz",
        "edu.lr",
        "edu.ly",
        "edu.mg",
        "edu.ml",
        "edu.mo",
        "edu.mw",
        "edu.ni",
        "edu.pa",
        "edu.pr",
        "edu.pw",
        "edu.qa",
        "edu.sc",
        "edu.sd",
        "edu.sh",
        "edu.sl",
        "edu.sy",
        "edu.ws",
        "edu.ye",
        "edu.zm",
        "es.kr",
        "g12.br",
        "hs.kr",
        "k12.ak.us",
        "k12.ar.us",
        "k12.az.us",
        "k12.ct.us",
        "k12.de.us",
        "k12.fl.us",
        "k12.ga.us",
        "k12.hi.us",
        "k12.ia.us",
        "k12.il.us",
        "k12.in.us",
        "k12.ky.us",
        "k12.la.us",
        "k12.ma.us",
        "k12.md.us",
        "k12.me.us",
        "k12.mi.us",
        "k12.mn.us",
        "k12.mo.us",
        "k12.ms.us",
        "k12.mt.us",
        "k12.nc.us",
        "k12.nh.us",
        "k12.nj.us",
        "k12.ny.us",
        "k12.oh.us",
        "k12.ok.us",
        "k12.or.us",
        "k12.pa.us",
        "k12.sc.us",
        "k12.sd.us",
        "k12.tn.us",
        "k12.ut.us",
        "k12.va.us",
        "k12.vt.us",
        "k12.wi.us",
        "k12.wv.us",
        "k12.wy.us",
        "ms.kr",
        "ort.org.il",
        "sc.kr",
        "sch.ae",
        "sch.gg",
        "sch.je",
        "sch.jo",
        "sch.lk",
        "sch.ly",
        "sch.my",
        "sch.om",
        "sch.ps",
        "sch.sa",
        "school.za",
    ]
)
