# DO NOT EDIT THIS FILE, CHANGES WILL BE OVERWRITTEN BY update_vendor.py
# From https://github.com/JetBrains/swot.git@bbdfe839

STOPLIST = frozenset(
    [
        "2011.cqut.edu.cn",
        "2012.cqut.edu.cn",
        "2013.cqut.edu.cn",
        "2014.cqut.edu.cn",
        "2015.cqut.edu.cn",
        "2016.cqut.edu.cn",
        "2017.cqut.edu.cn",
        "2018.cqut.edu.cn",
        "2trom.com",
        "365.cute.edu.tw",
        "365.ghu.ac.kr",
        "365.ksu.ac.th",
        "365.ntcu.edu.tw",
        "365.pdaba.edu.ua",
        "365.pnru.ac.th",
        "365.reru.ac.th",
        "365.stucom.com",
        "90888.cc",
        "aa.edu.kg",
        "aa.seu.edu.cn",
        "aaedu.edu.pl",
        "aaks.dk",
        "acc.msu.ac.th",
        "actonlascruces.com",
        "acu.edu.kg",
        "ad1.nutc.edu.tw",
        "ae1odemira.edu.pt",
        "aealvalade.edu.pt",
        "agr.dmu.edu.eg",
        "ahlg.ac.cn",
        "ahyz.edu.cn",
        "ahzyygz.edu.cn",
        "aiit.edu.cn",
        "aik.edu.kg",
        "ailora.edu.kg",
        "aimu.edu.kg",
        "aip.edu.pa",
        "aitmofml.ru",
        "akshara.ac.in",
        "alanyauniversity.edu.tr",
        "alazhar.edu.ps",
        "ali.edu.pl",
        "allegany.edu",
        "almamater.si",
        "altinbas.edu.tr",
        "altoona.k12.wi.us",
        "alu.cdut.edu.cn",
        "alu.gxu.edu.cn",
        "alu.hdu.edu.cn",
        "alu.hit.edu.cn",
        "alu.uestc.edu.cn",
        "alu.xpu.edu.cn",
        "alum.ccu.edu.tw",
        "alum.cs.umass.edu",
        "alum.mit.edu",
        "alum.urmc.rochester.edu",
        "alum.utoronto.ca",
        "alumni.albany.edu",
        "alumni.altinbas.edu.tr",
        "alumni.anu.edu.au",
        "alumni.baylor.edu",
        "alumni.bentley.edu",
        "alumni.berklee.edu",
        "alumni.bham.ac.uk",
        "alumni.cmu.edu",
        "alumni.conncoll.edu",
        "alumni.cuhk.net",
        "alumni.edu.vn",
        "alumni.fh-campuswien.ac.at",
        "alumni.gsb.stanford.edu",
        "alumni.habib.edu.pk",
        "alumni.hust.edu.cn",
        "alumni.ied.edu",
        "alumni.imperial.ac.uk",
        "alumni.iu.edu",
        "alumni.manchester.ac.uk",
        "alumni.marymount.edu",
        "alumni.montclair.edu",
        "alumni.msoe.edu",
        "alumni.ncu.edu.tw",
        "alumni.ncyu.edu.tw",
        "alumni.nottingham.ac.uk",
        "alumni.npust.edu.tw",
        "alumni.pku.edu.cn",
        "alumni.princeton.edu",
        "alumni.rice.edu",
        "alumni.sjtu.edu.cn",
        "alumni.ssst.edu.ba",
        "alumni.stanford.edu",
        "alumni.stcl.edu",
        "alumni.stu.edu.cn",
        "alumni.tku.edu.tw",
        "alumni.ubc.ca",
        "alumni.uci.edu",
        "alumni.unc.edu",
        "alumni.unca.edu",
        "alumni.undip.ac.id",
        "alumni.uniba.it",
        "alumni.upenn.edu",
        "alumni.utoronto.ca",
        "alumni.vcu.edu",
        "alumni.virginia.edu",
        "alumni.zstu.edu.cn",
        "alumni365.dmu.ac.uk",
        "alumno.cch.unam.mx",
        "aluno.santamarcelina.edu.br",
        "alunoavemaria.g12.br",
        "america.edu",
        "aof.anadolu.edu.tr",
        "aoiu.edu.ci",
        "app",
        "apps.nmims.edu.in",
        "apps.ntpc.edu.tw",
        "aroy.edu.pl",
        "art.edu.lv",
        "aru.edu.eg",
        "aryacs.edu.in",
        "as.edu.sa",
        "aschool.edu.vn",
        "asu.edu.ph",
        "athenscollege.edu.gr",
        "atk.com.kg",
        "aue.ae",
        "aufe.edu.cn",
        "australia.edu",
        "axhu.edu.cn",
        "ayit.edu.cn",
        "aynu.me",
        "ayushkids.edu.in",
        "azeri.edu.az",
        "bannsai.com",
        "batmu.edu.kg",
        "bbc.edu.cn",
        "bdu.edu.et",
        "beng.bu.edu.eg",
        "bese.ac.cn",
        "bfsu.edu.cn",
        "bh.knu.ac.kr",
        "bit.edu.cn",
        "bitzh.edu.cn",
        "bjdx.ac.cn",
        "bjlg.ac.cn",
        "bjmu.edu.cn",
        "bkc.edu.vn",
        "blue.knue.ac.kr",
        "bnu.edu.eg",
        "bnu.kr",
        "bqu.ch",
        "buaa.edu.cn",
        "bucea.edu.cn",
        "bupt.cn",
        "busan.ac.kr",
        "c5.hk",
        "caa.columbia.edu",
        "caa.edu.cn",
        "campus-numerique-in-the-alps.com",
        "cantho.edu.vn",
        "cau.ac",
        "cau.edu.cn",
        "caugiay.edu.vn",
        "cc.ncu.edu.tw",
        "cc.ntut.edu.tw",
        "cccu.edu.hk",
        "ccnu.edu.cn",
        "ccu.edu.tw",
        "cczu.edu.cn",
        "cdmc.edu.cn",
        "cedara.ac.za",
        "centrotec.edu.pa",
        "cet.edu",
        "chc.edu.tw",
        "chd.edu.cn",
        "cheonho.sen.ms.kr",
        "chiba-c.ed.jp",
        "chntheatre.edu.cn",
        "chosun-g.gen.hs.kr",
        "chu.edu.cn",
        "cjlu.edu.cn",
        "cloud.isu.edu.tw",
        "cmtc.ac.th",
        "cnba.uba.ar",
        "codesra.cn",
        "correo.ux.edu.mx",
        "cpu.edu.kg",
        "cque.edu.cn",
        "cqwu.edu.cn",
        "csa.concordia.ab.ca",
        "csiriicb.in",
        "ctgu.edu.cn",
        "cug.ac.in",
        "cug.edu.cn",
        "cumt.edu.cn",
        "cumtb.edu.cn",
        "dent.tanta.edu.eg",
        "dilatatfmus.ru",
        "dkps.uniburgas.bg",
        "dlut.edu.cn",
        "dongeui.ms.kr",
        "ds.ac.kr",
        "ds.edu.kg",
        "ds.lib.uw.edu",
        "due.edu.vn",
        "duksung.kr",
        "dusit.ac.th",
        "dxss.ac.cn",
        "dzxy.ntu.edu.cn",
        "e.gzhu.edu.cn",
        "ea.ufpa.br",
        "ecas.cl",
        "ecit.edu.cn",
        "ecole404.fr",
        "ecupl.edu.cn",
        "ecut.edu.cn",
        "edisonschools.edu.vn",
        "edu.ac.kr",
        "edu.deal",
        "edu.kfs.edu.eg",
        "edu.kg",
        "edu.menofia.edu.eg",
        "educn.ac.cn",
        "edumail.edu.pl",
        "eksu.edu.ng",
        "email.cufe.edu.cn",
        "email.cugb.edu.cn",
        "email.ncu.edu.cn",
        "email.szu.edu.cn",
        "email.zzuli.edu.cn",
        "emds.edu.pt",
        "emlmuak.cn",
        "ena.edu.ci",
        "escoladotrabalhador40.com.br",
        "essat-gabes-elearning.com",
        "est.domingocomin.edu.ec",
        "estudiante.usat.edu.pe",
        "fafu.edu.cn",
        "fast.edu.pl",
        "fengshan.edu.kg",
        "fjys.edu.cn",
        "foundationuniversity.com",
        "foxespiece.org.uk",
        "fpm.dnulive.dp.ua",
        "fpz.hr",
        "fzs.unsa.ba",
        "fzu.edu.kg",
        "g.seoultech.ac.kr",
        "ga",
        "gagpk.ru",
        "gatewaycollege.lk",
        "gcu.ac.kr",
        "gduf.edu.cn",
        "gf.ukim.edu.mk",
        "global.ac.kr",
        "gmiv.onl",
        "gnnu.edu.cn",
        "go.edu.tw",
        "goldman.edu.kg",
        "gpraj.gujgov.edu.in",
        "graduate.hku.hk",
        "gsuite.unbosque.edu.co",
        "gydx.ac.cn",
        "gzhtcm.edu.cn",
        "gzhu.edu.cn",
        "h.edu.kg",
        "hainu.edu.cn",
        "hait.edu.cn",
        "hallgato.uni-szie.hu",
        "hanma.kr",
        "haust.edu.cn",
        "hbdx.ac.cn",
        "hbtcm.edu.cn",
        "hbu.edu.cn",
        "hbucm.edu.cn",
        "hbut.edu.cn",
        "hc.edu.tw",
        "hcc.edu.tw",
        "hcdsol.tech",
        "hendrix.edu",
        "henu.edu.cn",
        "hhu.edu.cn",
        "hiete.hu",
        "hncj.edu.cn",
        "hndx.ac.cn",
        "hnie.edu.cn",
        "hnit.ed.cn",
        "horizon.auvk.ch",
        "horizon.uoie.dk",
        "horizoncc.co.uk",
        "hqu.edu.cn",
        "hrbeu.edu.cn",
        "hs.taquangbuu-bk.edu.vn",
        "hsc.pku.edu.cn",
        "huanghuai.edu.cn",
        "huas.edu.cn",
        "huest.edu.kg",
        "hufe.edu.cn",
        "huiu.edu.vn",
        "hungyen.itrithuc.vn",
        "hunnu.edu.cn",
        "huse.edu.cn",
        "hust.edu.cn",
        "hut.edu.pa",
        "huttoisd.org",
        "huuc.edu.cn",
        "hwawon.sen.ms.kr",
        "hxu.ac.cn",
        "hyejeon.ac.kr",
        "hznu.edu.cn",
        "icbc.edu.kg",
        "iced.ufpa.br",
        "icprjc.edu",
        "ics.ufpa.br",
        "ict.ac.cn",
        "id.ac",
        "id.lv",
        "idea.edu.cn",
        "idueo.de",
        "iip.edu.kg",
        "ilford-school.co.uk",
        "imnu.edu.cn",
        "in.ac",
        "ind.suezuni.edu.eg",
        "infinity.edu.kg",
        "infochat.edu.pl",
        "ink",
        "innopolis.university",
        "intech-so.fr",
        "intech-sud.fr",
        "ipdbuu.com.cn",
        "ipe.buet.ac.bd",
        "ipp.cl",
        "ist.edu.pk",
        "itc.edu.kh",
        "itcalumnos.cl",
        "itsqmet.edu.ec",
        "itu.ac.tzbjtu.edu.cn",
        "iumafis.edu.co",
        "iut.edu.kg",
        "jasukg.me",
        "jj.edu.kg",
        "jlu.edu.cn",
        "jmu.edu.cn",
        "jnu.edu.cn",
        "jou.edu.cn",
        "joy.edu.kg",
        "jp.edu.kg",
        "jpu.edu.jo",
        "jsahvc.edu.cn",
        "jsust.edu.cn",
        "jsut.edu.cn",
        "just.edu.tw",
        "k.kkk.ac.nz",
        "k.tut.edu.pl",
        "kalama.k12.wa.us",
        "kana.edu.kg",
        "kbtu.me",
        "kbtut.tj",
        "kellerisd.com",
        "kfu.edu.cn",
        "khi.iba.edu.pk",
        "kit.edu.kg",
        "kjdx.ac.cn",
        "kk.edu.rs",
        "kkk.ac.nz",
        "kkk.school.nz",
        "kmust.edu.cn",
        "knau.edu.kg",
        "kojimachi.ed.jp",
        "kousat.org",
        "kousat.tech",
        "kr.ac",
        "kun.edu.kg",
        "kuosat.tech",
        "kust.edu.cn",
        "kvsroguwahati.in",
        "kzxy.edu.kg",
        "lanesville.k12.in.us",
        "languagesystems.edu",
        "lcu.edu.cn",
        "learner.hkuspace.hku.hk",
        "lems.edu.ph",
        "lfnu.edu.cn",
        "lhmc.edu.cn",
        "live",
        "live.fy.edu.tw",
        "live.hcu.ac.th",
        "live.kmu.edu.tw",
        "live.sau.ac.th",
        "lixin.edu.cn",
        "ljb.edu.hk",
        "lo2.wroc.pl",
        "lounle.lv",
        "lsts.edu.vn",
        "lvu.edu.vn",
        "lxiv.secondary.edu.pl",
        "lzjtu.edu.cn",
        "lzpcc.edu.cn",
        "m.fafu.edu.cn",
        "m.ldu.edu.cn",
        "m.stc.edu.hk",
        "m.uno.edu.gr",
        "m365.nycu.edu.tw",
        "mahemc.tu.edu.np",
        "mail.0du.win",
        "mail.aeust.edu.tw",
        "mail.bnuz.edu.cn",
        "mail.ccmu.edu.cn",
        "mail.centroeducativoinvironda.edu.do",
        "mail.chzu.edu.cn",
        "mail.dusit.ac.th",
        "mail.edu.tw",
        "mail.fhsstudents.ch",
        "mail.fmftsk.cn",
        "mail.hbut.edu.cn",
        "mail.imu.edu.cn",
        "mail.ncyu.edu.tw",
        "mail.ntou.edu.tw",
        "mail.ntust.edu.tw",
        "mail.nwpu.edu.cn",
        "mail.rmutt.ac.th",
        "mail.sbu.ac.ir",
        "mail.school3.mk.ua",
        "mail.scuec.edu.cn",
        "mail.sustc.edu.cn",
        "mail.uic.edu.cn",
        "mail.xjtu.edu.cn",
        "mail.ypu.edu.tw",
        "mail2.gdut.edu.cn",
        "mail4u.tnu.edu.tw",
        "mails.cqjtu.edu.cn",
        "mails.cust.edu.cn",
        "mails.hufe.edu.cn",
        "mails.imnu.edu.cn",
        "mails.jlau.edu.cn",
        "mails.jlu.edu.cn",
        "mails.mmnnsf.cn",
        "mails.qust.edu.cn",
        "mails.zstu.edu.cn",
        "man10jakartabarat.sch.id",
        "mapscollege.edu.mv",
        "mastc.edu.cn",
        "masu.edu.cn",
        "mc-class.gr",
        "mcleon.de",
        "mcu.edu.kg",
        "mdis.uz",
        "mdu.edu.rs",
        "me.mcu.edu.tw",
        "meduca.edu.pa",
        "member.scau.ac.kr",
        "metodista.br",
        "meve.lv",
        "mf.unsa.ba",
        "mfk.app",
        "mhzayt.online",
        "micschools.com",
        "mkhb.moe.gov.sa",
        "mona.edu.pl",
        "monaco.edu",
        "mpi.dk",
        "ms.edu.tw",
        "ms.srru.ac.th",
        "ms.tpk.edu.hk",
        "ms.uki.ac.id",
        "ms1.mcu.edu.tw",
        "msu.edu.kg",
        "mtmcollege.in",
        "mtu.kr",
        "mu.ac.kr",
        "muc.edu.cn",
        "mus.edu.rs",
        "must.edu.my",
        "my.lsco.edu",
        "myregent.ac.za",
        "nankai.edu.cn",
        "nbu.edu.cn",
        "nccu.edu.tw",
        "ncepu.cn",
        "ncepu.edu.cn",
        "ncist.edu.cn",
        "ncku.edu.tw",
        "ncwu.edu.cn",
        "nenu.edu.cn",
        "neu.edu.kg",
        "nfs.edu.rs",
        "nit.edu.cn",
        "niu.edu",
        "njau.edu.cn",
        "njit.edu.cn",
        "njnu.edu.cn",
        "njtc.edu.cn",
        "njtech.edu.cn",
        "njts.edu.cn",
        "nkdx.ac.cn",
        "nnu.edu.cn",
        "normaljujuy.edu.ar",
        "northfacing.ac.cn",
        "npcmstsfc.com",
        "ntnu.edu.tw",
        "ntpc.ufpa.br",
        "nuc.edu.kg",
        "nwafu.edu.cn",
        "nwnu.edu.cn",
        "nxmu.edu.cn",
        "nyfbox.hu",
        "nyist.edu.cn",
        "o365.cyut.edu.tw",
        "o365.lhu.edu.tw",
        "o365.msu.ac.th",
        "o365.ntou.edu.tw",
        "o365.nuu.edu.tw",
        "o365.prz.edu.pl",
        "o365.rmutp.ac.th",
        "o365st.cycu.edu.tw",
        "off365.ncku.edu.tw",
        "office.kaya.ac.kr",
        "office.khu.ac.kr",
        "office.knu.ac.kr",
        "office.ptu.ac.kr",
        "office.stust.edu.tw",
        "office.undip.ac.id",
        "office.yonam.ac.kr",
        "office365.kuas.edu.tw",
        "office365.ncu.edu.tw",
        "office365.nkust.edu.tw",
        "osdri.me",
        "oshsu.email",
        "oshsu.me",
        "oshtu.edu.kg",
        "oshtu.me",
        "otp39.ru",
        "ouc.edu.cn",
        "oueng.fr",
        "outlook.rmutr.ac.th",
        "outlook.up.edu.ph",
        "p4ed.com",
        "pccinternational.org",
        "pcjy.school",
        "pdsu.edu.cn",
        "phystech.edu",
        "poly.edu.rs",
        "poornima.ac.in",
        "posgrado.unp.edu.pe",
        "presbiteriano.g12.br",
        "profundity.com.tw",
        "psu.palawan.edu.ph",
        "pycharm.ac.cn",
        "qh.edu.kg",
        "qhnu.edu.cn",
        "qust.edu.cn",
        "qvtu.edu.cn",
        "qzit.edu.cn",
        "rhedu.org.il",
        "riceindia.org",
        "rsat.org.uk",
        "ruc.edu.cn",
        "s.hlju.edu.cn",
        "s.slcupc.edu.cn",
        "s.upc.edu.cn",
        "sagrado.edu",
        "sau16.org",
        "sbjacksonville.com",
        "sbu.ac.ir",
        "scnu.edu.cn",
        "scpc.edu.in",
        "scu.edu.cn",
        "scu.edu.tw",
        "scuec.edu.cn",
        "scun.edu.cn",
        "sdju.edu.cn",
        "sdnu.edu.cn",
        "sdufe.edu.cn",
        "sdut.edu.cn",
        "sem.tsinghua.edu.cn",
        "senacminas.edu.br",
        "sesgs.sckr.si",
        "sfu.edu.cn",
        "sgs.edu.co",
        "shafc.edu.cn",
        "sharif.ir",
        "shct.edu.om",
        "shisu.edu.cn",
        "shu.edu.tw",
        "sicau.edu.cn",
        "siit.edu.cn",
        "sisu.edu.cn",
        "sit.edu.cn",
        "skei.edu.in",
        "skhhcps.edu.hk",
        "smail.cczu.edu.cn",
        "smail.xtu.edu.cn",
        "smkmuhkarangmojo.com",
        "smpblbekasi.sch.id",
        "snnu.edu.cn",
        "social.helwan.edu.eg",
        "sol-du.ac.in",
        "sonoranschools.org",
        "southern-bd.info",
        "spbgut.com",
        "sqxy.edu.cn",
        "ssis.ac.in",
        "sspu.edu.cn",
        "sstu-edu.ru",
        "st.btbu.edu.cn",
        "st.gxu.edu.cn",
        "st.sandau.edu.cn",
        "st.tvu.edu.vn",
        "std.uestc.edu.cn",
        "stu.60edu.kz",
        "stu.ahbvc.edu.cn",
        "stu.ahu.edu.cn",
        "stu.bayburt.edu.tr",
        "stu.biticrak.ae",
        "stu.bzuu.edu.cn",
        "stu.ccit.edu.cn",
        "stu.ccsu.edu.cn",
        "stu.cdut.edu.cn",
        "stu.cpu.edu.cn",
        "stu.cqupt.edu.cn",
        "stu.csust.edu.cn",
        "stu.cute.edu.tw",
        "stu.cuz.edu.cn",
        "stu.edu.kg",
        "stu.fafu.edu.cn",
        "stu.fjmu.edu.cn",
        "stu.fynu.edu.cn",
        "stu.gzucm.edu.cn",
        "stu.hafu.edu.cn",
        "stu.haust.edu.cn",
        "stu.haut.edu.cn",
        "stu.hcnu.edu.cn",
        "stu.hebmu.edu.cn",
        "stu.hnie.edu.cn",
        "stu.hnucm.edu.cn",
        "stu.howardcollege.edu",
        "stu.huel.edu.cn",
        "stu.hunau.edu.cn",
        "stu.jhun.edu.cn",
        "stu.just.edu.cn",
        "stu.kust.edu.cn",
        "stu.lyceegalilee.fr",
        "stu.maol.fr",
        "stu.mdit.edu.cn",
        "stu.mju.edu.cn",
        "stu.nchu.edu.cn",
        "stu.ncwu.edu.cn",
        "stu.nmu.edu.cn",
        "stu.nsu.edu.cn",
        "stu.nthurston.k12.wa.us",
        "stu.nun.edu.cn",
        "stu.nwupl.edu.cn",
        "stu.owosso.k12.mi.us",
        "stu.peihua.edu.cn",
        "stu.qlu.edu.cn",
        "stu.scott.kyschools.us",
        "stu.scu.edu.cn",
        "stu.sdnu.edu.cn",
        "stu.sdp.edu.cn",
        "stu.shzu.edu.cn",
        "stu.siva.edu.cn",
        "stu.sqmc.edu.cn",
        "stu.sqxy.edu.cn",
        "stu.sumhs.edu.cn",
        "stu.suse.edu.cn",
        "stu.swun.edu.cn",
        "stu.sxau.edu.cn",
        "stu.sxit.edu.cn",
        "stu.sxpi.edu.cn",
        "stu.tjcu.edu.cn",
        "stu.ujn.edu.cn",
        "stu.usc.edu.cn",
        "stu.wxic.edu.cn",
        "stu.xaau.edu.cn",
        "stu.xhsysu.edu.cn",
        "stu.xhu.edu.cn",
        "stu.xidian.edu.cn",
        "stu.xjtu.edu.cn",
        "stu.yznu.cn",
        "stu.zjhu.edu.cn",
        "stu.zuel.edu.cn",
        "stud.acdt.edu.cn",
        "student.alvincollege.edu",
        "student.cgcc.edu",
        "student.cumtb.edu.cn",
        "student.cup.edu.cn",
        "student.guhsdaz.org",
        "student.haywood.k12.nc.us",
        "student.isf.edu.hk",
        "student.mf.ukim.edu.mk",
        "student.miyazaki-c.ed.jp",
        "student.ssc.edu",
        "student.umc.edu.dz",
        "students.panola.edu",
        "students.sdcsc.k12.in.us",
        "stumail.hbu.edu.cn",
        "stumail.nwu.edu.cn",
        "stumail.sdut.edu.cn",
        "stumail.sztu.edu.cn",
        "stumail.zcs.k12.in.us",
        "sues.edu.cn",
        "sufe.edu.cn",
        "supco-montpellier.fr",
        "sust.edu.cn",
        "swmich.edu",
        "swu.edu.cn",
        "sxdtdx.edu.cn",
        "sxlg.ac.cn",
        "sziit.edu.cn",
        "szjm.edu.cn",
        "t.odmail.cn",
        "takushoku-u.ac.jp",
        "tarbia.tn",
        "tcdsb.ca",
        "tdp.edu.kg",
        "tecnologicoismac.edu.ec",
        "thc.tu.edu.np",
        "theflightsims.edu.pl",
        "tiangong.edu.cn",
        "tijmu.edu.cn",
        "tjdx.ac.cn",
        "tju.edu.cn",
        "tkc.edu",
        "tmu.edu.cn",
        "tongji.edu.cn",
        "top",
        "tp.edu.tw",
        "tralu.hdu.edu.cn",
        "tss.edu.kg",
        "tusur.ru",
        "tut.edu.tw",
        "twzhhq.online",
        "tzc.edu.cn",
        "uaconcagua.cl",
        "uagraria.edu.ec",
        "uat.edu.ng",
        "ube.edu.ec",
        "uca.edu.kg",
        "ucass.edu.cn",
        "udsu.ru",
        "uest.edu.kg",
        "uibe.edu.cn",
        "uin-suska.ac.id",
        "ulive.pccu.edu.tw",
        "ulusiada.pt",
        "umak.edu.ph",
        "umut.edu.kg",
        "umy.ac.id",
        "unifacisa.edu.br",
        "univ-barackobama.com",
        "university-365.com",
        "universityofmanagement.sn",
        "uno-r.edu.ph",
        "unswalumni.com",
        "untre.ch",
        "uphsl.edu.ph",
        "upscmd.tech",
        "uqz.ch",
        "ust.edu.kg",
        "ustb.edu.cn",
        "ustc.edu.cn",
        "usx.edu.cn",
        "utesur.edu.do",
        "utmail.utexas.edu",
        "utxun.lv",
        "uva.br",
        "uvmx.onmicrosoft.com",
        "vicaria.edu.ar",
        "vip.hnist.edu.cn",
        "vjrq.cn",
        "vsavm.com",
        "vv.edu.kg",
        "wakai.edu.pl",
        "wauwatosa.k12.wi.us",
        "wawtech.edu.pl",
        "wcstudents.wc.edu",
        "wfl.sh.edu.cn",
        "whit.edu.cn",
        "whu.edu.cn",
        "wildbmail.com",
        "wmoenglishacademy.co.in",
        "wstkt.edu.pl",
        "wthurman.yourweb.csuchico.edu",
        "wust.edu.cn",
        "wxc.edu.kg",
        "wxic.edu.cn",
        "wxit.edu.cn",
        "wzu.edu.cn",
        "wzut.edu.cn",
        "x.pycharm.ac.cn",
        "xauat.edu.cn",
        "xbdx.ac.cn",
        "xhu.edu.cn",
        "xinfu.ac.cn",
        "xiyou.edu.cn",
        "xjdx.ac.cn",
        "xku.edu.rs",
        "xlike.edu.kg",
        "xmu.edu.cn",
        "xs.hnit.edu.cn",
        "xupt.edu.cn",
        "xy.dlpu.edu.cn",
        "xy.hbuas.edu.cn",
        "xzc.edu.pl",
        "xzyz.edu.cn",
        "yangtzeu.edu.cn",
        "ydu.edu.tw",
        "yourweb.csuchico.edu",
        "ysu.edu.kg",
        "yznu.edu.cn",
        "yzpc.edu.cn",
        "zcmu.edu.cn",
        "zjff.edu.cn",
        "zjgsu.edu.cn",
        "zjnu.edu.cn",
        "zjsru.edu.cn",
        "zju.edu.cn",
        "zjut.edu.cn",
        "zknu.edu.cn",
        "ztbu.edu.cn",
        "zucc.edu.cn",
        "zuel.edu.cn",
        "zut.edu.cn",
    ]
)
