# DO NOT EDIT THIS FILE, CHANGES WILL BE OVERWRITTEN BY update_vendor.py
# From https://github.com/JetBrains/swot.git@bbdfe839

DOMAINS: dict[str, list[str]] = {
    ".bii.ac": [
        "Bertha International Institute of Arts and Sciences",
        "Bertha International Institute of Arts and Sciences",
    ],
    ".daffodil.ac": ["Daffodil International Academy"],
    ".diu.ac": ["DIU", "Dhaka International University"],
    ".dpi.ac": [
        "Daffodil Polytechnic Institute",
        "Bangladesh Skill Development Institute",
    ],
    ".dti.ac": [
        "Daffodil Technical Institute (DTI)",
        "Daffodil Technical Institute (DTI)",
    ],
    ".uin-alauddin.id.ac": ["UIN ALAUDDIN MAKASSAR", "UIN ALAUDDIN MAKASSAR"],
    ".ecampus.ut.id.ac": ["Universitas Terbuka", "Indonesia Open University"],
    ".delhitechnicalcampus.in.ac": [
        "Delhi Technical Campus",
        "Delhi Technical Campus",
    ],
    ".jiu.ac": ["Jakarta International University"],
    ".kcu.ac": ["SOONGSIL CYBER UNIVERSITY"],
    ".lsst.ac": ["London School of Science and Technology"],
    ".myaie.ac": ["Academic institute of Excellence"],
    ".k12.scsd.ac": ["Stanwood High School"],
    ".ukh.ac": ["University of Kurdistan - Hawler"],
    ".unikam.ac": ["Université de Kamina"],
    ".unw.ac": ["University of NorthWest"],
    ".uod.ac": ["University of Dohuk (Kurdistan Region)"],
    ".upl-univ.ac": ["L'université protestante de Lubumbashi (UPL)"],
    ".yuhs.ac": ["Yonsei University Health System"],
    ".cti.za.ac": ["CTI Education Group"],
    ".business-school.academy": ["Business School campus du Beaujolais"],
    ".campus.academy": ["Campus Academy"],
    ".chungkang.academy": [
        "청강문화산업대학교",
        "ChungKang College of Cultural Industries",
    ],
    ".cloud-campus.academy": ["Cloud campus", "Cloud campus"],
    ".sc.coastandvale.academy": ["Scalby School"],
    ".explore.academy": ["Explore Academy"],
    ".greta-cfa-aquitaine.academy": [
        "GRETA-CFA Aquitaine",
        "GRETA-CFA Aquitaine",
    ],
    ".greta-sud-aquitaine.academy": ["GRETA Sud Aquitaine"],
    ".houghton.academy": ["Houghton Academy"],
    ".htk.academy": [
        "htk academy",
        "University of Applied Sciences Europe GmbH (ehem. BiTS/ btk) - Berlin, Hamburg, Iserlohn",
    ],
    ".kenzie.academy": ["Kenzie Academy"],
    ".lesallay.academy": ["Le Sallay Academy"],
    ".lincroft.academy": ["Lincroft Academy"],
    ".londonschool.academy": [
        "رياض ومدارس لندن العالمية",
        "London International Schools & Kindergarten",
    ],
    ".metis.academy": ["IT v kurze"],
    ".tn.mischok.academy": ["Mischok Academy"],
    ".stevejobs.academy": [
        "Fondazione Istituto Tecnico Superiore per le Tecnologie dell'Informazione e della Comunicazione Steve Jobs"
    ],
    ".nef.tynecoast.academy": ["North East Futures UTC"],
    ".uview.academy": ["University View Academy"],
    ".educand.ad": ["Centre de Formació Professional d'Andorra"],
    ".uda.ad": ["University of Andorra"],
    ".student.42abudhabi.ae": ["42 Abu Dhabi", "42 Abu Dhabi"],
    ".aau.ac.ae": ["Al Ain university", "AAU"],
    ".adu.ac.ae": ["Abu Dhabi University"],
    ".adveti.ac.ae": ["Abu Dhabi Vocational Education and Training Institute"],
    ".ajman.ac.ae": ["Ajman University of Science &amp; Technology"],
    ".alainuniversity.ac.ae": ["Alain University of Science and Technology"],
    ".aurak.ac.ae": ["American University of Ras Al Khaimah"],
    ".buid.ac.ae": ["British University in Dubai"],
    ".cu.ac.ae": ["جامعة المدينة عجمان", "City University Ajman"],
    ".students.cud.ac.ae": ["Canadian university Dubai"],
    ".gmu.ac.ae": ["Gulf Medical University"],
    ".hbmsu.ac.ae": ["Hamdan Bin Mohammed Smart University"],
    ".hct.ac.ae": ["Higher Colleges of Technology"],
    ".iat.ac.ae": ["Institute of Applied Technology"],
    ".ku.ac.ae": ["Khalifa University of Science, Technology and Research"],
    ".masdar.ac.ae": ["Masdar University Of Science And Technology"],
    ".mbzuai.ac.ae": [
        "Mohamed bin Zayed University of Artificial Intelligence"
    ],
    ".pi.ac.ae": ["The Petroleum Institute"],
    ".psa.ac.ae": [
        "أكاديمية العلوم الشرطية",
        "Sharjah Police Science Academy",
    ],
    ".rakmhsu.ac.ae": ["Ras Al Khaimah Medical & Health Sciences University"],
    ".sharjah.ac.ae": [
        "University of Sharjah",
        "College of Computing and Informatics",
    ],
    ".siu-dubai.ac.ae": ["Symbiosis International University", "Dubai, UAE"],
    ".skylineuniversity.ac.ae": ["Skyline University College"],
    ".uaeu.ac.ae": ["United Arab Emirates University"],
    ".ud.ac.ae": ["University Of Dubai"],
    ".uof.ac.ae": ["جامعة الفجيرة", "University of Fujairah"],
    ".uowdubai.ac.ae": ["University of Wollongong - Dubai Campus"],
    ".zu.ac.ae": ["Zayed University"],
    ".agu.ae": ["Al Ghurair University"],
    ".albasmaschool.ae": ["Al Basma British School"],
    ".aldurrahint.ae": ["Al Durrah International School", "ADIS Sharjah"],
    ".alhosnu.ae": ["Alhosn University"],
    ".amitydubai.ae": ["Amity University Dubai"],
    ".aue.ae": ["American University in the Emirates"],
    ".auschool.ae": ["Arab Unity School"],
    ".school.bips.ae": ["Brilliant International Private School"],
    ".biticrak.ae": ["Birla Institute of Technology, International Campus"],
    ".brightoncollegedubai.ae": ["Brighton College Dubai"],
    ".student.britishcollege.ae": ["British University College"],
    ".cranleigh.ae": ["Cranleigh Abu Dhabi"],
    ".cuca.ae": ["City University College of Ajman"],
    ".iiss.ae": ["India International School, Sharjah, UAE"],
    ".nasdubai.ae": ["Nord Anglia International School Dubai"],
    ".nisdubai.ae": [
        " Nibras International School Dubai",
        "Nibras International School Dubai",
    ],
    ".nlcsdubai.ae": ["North London Collegiate School Dubai"],
    ".sorbonne.ae": ["Paris-Sorbonne University Abu Dhabi"],
    ".tapschool.ae": ["Taryam American Private School"],
    ".uptownschool.ae": ["Uptown International School"],
    ".wschool.ae": ["Al Wahda Private School", "Al Wahda Private School"],
    ".mstuca.aero": ["Moscow State Technical University of Civil Aviation"],
    ".auaf.edu.af": ["American University of Afghanistan"],
    ".bakhtar.edu.af": ["Bakhtar University"],
    ".dawat.edu.af": ["پوهنتون دعوت", "Dawat University"],
    ".dunya.edu.af": ["Dunya University"],
    ".kardan.edu.af": ["Kardan University"],
    ".kateb.edu.af": ["Kateb University"],
    ".ku.edu.af": ["Kabul University"],
    ".salam.edu.af": ["Salam University", "Salam University"],
    ".spingharuniversity.edu.af": ["Spinghar University"],
    ".uhsa.ag": ["University of Health Sciences Antigua"],
    ".insait.ai": [
        'Institute for Computer Science, Artificial Intelligence and Technology at Sofia University "St. Kliment Ohridski"',
        "INSAIT",
    ],
    ".beder.edu.al": ["University College Bedër"],
    ".epoka.edu.al": ["Epoka University"],
    ".fshn.edu.al": ["Faculty of Natural Sciences at University of Tirana"],
    ".uat.edu.al": ["American University of Tirana"],
    ".ubt.edu.al": ["Agricultural University of Tirane"],
    ".umb.edu.al": ["Marin Barleti University"],
    ".uniel.edu.al": ["University of Elbasan Aleksander Xhuvani"],
    ".unipavaresia.edu.al": ["University “Pavaresia” Vlore"],
    ".unishk.edu.al": ["University of Shkodra Luigj Gurakuqi"],
    ".unitir.edu.al": ["University of Tirana"],
    ".univlora.edu.al": ["University of Vlora Ismail Qemali"],
    ".unkorce.edu.al": ["University of Korca Fan Noli"],
    ".uogj.edu.al": ["University of Gjirokstra Eqerem Cabej"],
    ".unizkm.al": ['Catholic University "Our Lady of Good Counsel"'],
    ".upt.al": ["Polytechnic University of Tirane"],
    ".student.42yerevan.am": ["42 Yerevan"],
    ".42yerevan.am": ["42 Երևանը", "42 Yerevan"],
    ".anau.am": [
        "ՀԱՅԱՍՏԱՆԻ ԱԶԳԱՅԻՆ ԱԳՐԱՐԱՅԻՆ ՀԱՄԱԼՍԱՐԱՆ",
        "Armenian National Agrarian University",
    ],
    ".armmed.am": ["Mehrabyan Medical Institute and Medical College"],
    ".aspu.am": ["Armenian State Pedagogical University"],
    ".asue.am": ["Armenian State University of Economics"],
    ".aua.am": ["American University of Armenia"],
    ".aybschool.am": ["Ayb School"],
    ".bryusov.am": ["Brusov State University"],
    ".eiu.am": ["Eurasia International University"],
    ".eriicta.am": ["European Regional Educational Academy of Armenia"],
    ".fizmat.am": [
        "Արտաշես Շահինյանի անվան ֆիզիկամաթեմատիկական հատուկ դպրոց",
        "Physical-Mathematical School",
    ],
    ".isec.am": [
        "International Scientific-Educational Center of the National Academy of Sciences of Republic of Armenia (ISEC)"
    ],
    ".meduni.am": [
        "Երևանի Պետական Բժշկական համալսարան",
        "Yerevan State Medical University",
    ],
    ".msu.am": [
        "Филиал МГУ в Ереване",
        "Moscow State University Branch in Yerevan",
    ],
    ".nuaca.am": [
        "NATIONAL UNIVERSITY OF ARCHITECTURE AND CONSTRUCTION OF ARMENIA"
    ],
    ".polytechnic.am": ["National Polytechnic University of Armenia"],
    ".student.rau.am": [
        "Russian - Armenian University (RAU)",
        "Russian - Armenian University (RAU)",
    ],
    ".rau.am": ["Russian-Armenian University"],
    ".seua.am": ["State Engineering University of Armenia"],
    ".shirakatsy.am": [
        "Շիրակացու Ճեմարան",
        "SHIRAKATSY LYCEUM INTERNATIONAL SCIENTIFIC-EDUCATIONAL COMPLEX",
    ],
    ".ufar.am": ["French University in Armenia (UFAR)"],
    ".yerphi.am": [
        "A. I. Alikhanian National Science Laboratory",
        "Yerevan Physics Institute",
    ],
    ".ysmu.am": ["Yerevan State Medical University"],
    ".ysu.am": ["Yerevan State University"],
    ".ysumail.am": ["Yerevan State University"],
    ".isptec.co.ao": [
        "Instituto Superior Politécnico de Tecnologias e Ciências"
    ],
    ".uma.co.ao": ["Universidade Metodista de Angola"],
    ".utanga.co.ao": ["Universidade Tecnica de Angola"],
    ".ugs.edu.ao": ["Universidade Gregório Semedo"],
    ".uan.ao": ["Univesidade Agostinho Neto"],
    ".unia.ao": ["Universidade Independente de Angola"],
    ".ianca.com.ar": [
        "Instituto Argentino de Negociación, Conciliación y Arbitraje"
    ],
    ".inaf27.com.ar": ["Instituto Nicolás Avellaneda F-27"],
    ".istea.com.ar": ["Instituto Superior Tecnológico Empresarial Argentino"],
    ".itbeltran.com.ar": [
        "INSTITUTO SUPERIOR DE FORMACIÓN TÉCNICA N° 197",
        "INSTITUTO SUPERIOR DE FORMACIÓN TÉCNICA N° 197",
    ],
    ".sistemas-utnfra.com.ar": ["UNIVERSIDAD TÉCNICA NACIONAL"],
    ".21.edu.ar": ["Universidad Empresarial Siglo 21"],
    ".aa.edu.ar": ["Academia Arguello", "Arguello Academy"],
    ".atlantida.edu.ar": ["Universidad Atlantida Argentina"],
    ".austral.edu.ar": ["Universidad Austral Buenos Aires"],
    ".bue.edu.ar": [
        "UNIVERSIDAD TECNOLÓGICA NACIONAL",
        "NATIONAL TECHNOLOGICAL UNIVERSITY",
    ],
    ".caece.edu.ar": ["Universidad CAECE, Buenos Aires"],
    ".cema.edu.ar": ["Instituto Universitario CEMA"],
    ".colegiocolinasverdes.edu.ar": ["Colegio Colinas Verdes"],
    ".colegioinmaculada.edu.ar": ["Colegio de la Inmaculada Concepción"],
    ".colegiosancirano.edu.ar": ["Colegio San Cirano"],
    ".colegiosanignaciotandil.edu.ar": ["Colegio San Ignacio Tandil"],
    ".davinci.edu.ar": ["Escuela de arte multimedia Da vinci"],
    ".dh.edu.ar": ["Digital House"],
    ".eaf.edu.ar": ["Escuela Argentina de Fotografía"],
    ".alumno.eestn4garin.edu.ar": [
        "Escuela Secundaria Tecnica 4, Garin, Argentina"
    ],
    ".empa.edu.ar": [
        "Escuela de Musica Popular de Avellaneda",
        "Public Avellaneda Music School",
    ],
    ".eim.esc.edu.ar": [
        "Escuela Superior de Turismo, Hotelería y Gastronomía",
        "Higher School of Tourism, Hospitality and Gastronomy",
    ],
    ".escuelasproa.edu.ar": ["ESCUELA PROA"],
    ".fecea.edu.ar": ["FECEA", "FECEA"],
    ".galileo.edu.ar": ['Escuela de Educacion Tecnica N°5 "Galileo Galilei"'],
    ".ib.edu.ar": ["Instituto Balseiro", "Balseiro Institute"],
    ".iese.edu.ar": ["Instituto de Enseñanza Superior del Ejército"],
    ".iesvu.edu.ar": ["Instituto de Educación Superior Nº 9-015 Valle de Uco"],
    ".ifts18.edu.ar": ["Instituto de Formación Técnica Superior N° 18"],
    ".ifts24.edu.ar": ["Instituto de Formación Técnica Superior N° 24"],
    ".imagecampus.edu.ar": ["Image Campus", "Image Campus"],
    ".incade.edu.ar": ["Instituto de capacitación y desarrollo empresarial"],
    ".isft38.edu.ar": ["Instituto Superior de Formación Técnica 38"],
    ".isp20.edu.ar": [
        'Instituto Superior de Profesorado Nº 20 "Senador Nestor J. Zamaro"'
    ],
    ".ispi4038.edu.ar": ["Instituto Superior Particular Incorporado Nº 4038"],
    ".ispn.edu.ar": ["Instituto San Pedro Nolasco"],
    ".issd.edu.ar": [
        "Instituto Superior Santo Domingo",
        "Santo Domingo Higher Institute",
    ],
    ".isvn.edu.ar": ["Instituto Santisima Virgen Niña"],
    ".itba.edu.ar": ["Instituto Tecnológico de Buenos Aires"],
    ".itec1misiones.edu.ar": ["ITEC N°1"],
    ".itsv.edu.ar": ["Instituto Técnico Salesiano Villada"],
    ".iua.edu.ar": ["Instituto Universitario Aeronáutico"],
    ".iuna.edu.ar": ["Instituto Universitario Nacional del Arte"],
    ".kennedy.edu.ar": ["Universidad Argentina John F. Kennedy"],
    ".lam.edu.ar": [
        "Liceo Aeronautico Militar",
        "Military Aeronautical High School",
    ],
    ".maimonides.edu.ar": ["Universidad Maimónides"],
    ".martinpescador.edu.ar": ["Colegio Martin Pescador"],
    ".mdp.edu.ar": ["Universidad Nacional de Mar del Plata"],
    ".ort.edu.ar": ["Instituto de Tecnologia ORT"],
    ".palermo.edu.ar": ["Universidad de Palermo"],
    ".poveda.edu.ar": ["Instituto Pedro Poveda"],
    ".salvador.edu.ar": ["Universidad del Salvador"],
    ".sanpedroapostol.edu.ar": ["San Pedro Apostol"],
    ".schweitzer.edu.ar": [
        "Institución Educativa Dr. Alberto Schweitzer – Mar del Plata"
    ],
    ".secundaria24sf.edu.ar": ["Escuela Secundaria Nº24"],
    ".taborin.edu.ar": ["Taborin College"],
    ".uade.edu.ar": ["Universidad Argentina de la Empresa"],
    ".uader.edu.ar": ["Universidad Autónoma de Entre Ríos"],
    ".uap.edu.ar": ["La Universidad Adventista del Plata"],
    ".ub.edu.ar": ["Universidad de Belgrano"],
    ".ucaecemdp.edu.ar": ["Universidad CAECE, Mar del Plata"],
    ".ucalp.edu.ar": ["Universidad Católica de La Plata"],
    ".ucalpvirtual.edu.ar": ["Universidad Católica de La Plata - Virtual"],
    ".ucasal.edu.ar": ["Universidad Catolica de Salta"],
    ".ucc.edu.ar": ["Universidad Católica de Córdoba"],
    ".uccor.edu.ar": ["Universidad Católica de Córdoba"],
    ".uccuyo.edu.ar": ["Universidad Católica de Cuyo"],
    ".ucel.edu.ar": [
        "Universidad del Centro Educativo Latinoamericano Rosario"
    ],
    ".ucema.edu.ar": ["Universidad del CEMA"],
    ".uch.edu.ar": ["Universidad Champagnat"],
    ".ucine.edu.ar": ["Universidad del Cine - Buenos Aires"],
    ".ucp.edu.ar": ["Universidad de la Cuenca del Plata"],
    ".ucse.edu.ar": ["Universidad Católica de Santiago del Estero"],
    ".ucu.edu.ar": ["Universidad de Concepción del Uruguay"],
    ".uda.edu.ar": ["Universidad del Aconcagua"],
    ".udc.edu.ar": ["Universidad del Chubut"],
    ".udemm.edu.ar": ["Universidad de la Marina Mercante"],
    ".udesa.edu.ar": ["Universidad de San Andres"],
    ".uesiglo21.edu.ar": ["Universidad Empresarial Siglio 21"],
    ".ufasta.edu.ar": [
        "Universidad de la Fraternidad de Agrupaciones Santo Tomas de Aquino (FASTA)"
    ],
    ".uflo.edu.ar": ["Universidad de Flores - Buenos Aires"],
    ".ugd.edu.ar": [
        "Universidad Gastón Dachary",
        "UGD",
        "Gaston Dachary University",
    ],
    ".ulp.edu.ar": ["Universidad de La Punta"],
    ".um.edu.ar": ["Universidad de Mendoza"],
    ".umaza.edu.ar": ["Universidad Juan Agustín Maza"],
    ".umet.edu.ar": [
        "Universidad Metropolitana para la Educación y el Trabajo"
    ],
    ".umsa.edu.ar": ["Universidad del Museo Social Argentino"],
    ".unab.edu.ar": ["Universidad Nacional Guillermo Brown"],
    ".estudiantes.unahur.edu.ar": ["Universidad Nacional De Hurlingham"],
    ".unahur.edu.ar": ["Universidad Nacional de Hurlingham"],
    ".unaj.edu.ar": [
        "Universidad Nacional Arturo Jauretche",
        "Arturo Jauretche National University",
    ],
    ".unam.edu.ar": ["Universidad Nacional de Misiones"],
    ".unc.edu.ar": ["Universidad Nacional de Córdoba"],
    ".unca.edu.ar": ["Universidad Nacional de Catamarca"],
    ".uncaus.edu.ar": ["Universidad Nacional del Chaco Austral"],
    ".uncoma.edu.ar": [
        "Instituto Universitario de Ciencias de la Salud - Buenos Aires",
        "Universidad Nacional del Comahue",
    ],
    ".uncu.edu.ar": ["Universidad Nacional de Cuyo"],
    ".uncuyo.edu.ar": ["Universidad Nacional de Cuyo (UNCuyo)"],
    ".undec.edu.ar": ["Universidad Nacional de Chilecito"],
    ".fie.undef.edu.ar": ["Facultad de Ingenieria del Ejercito"],
    ".uner.edu.ar": ["Universidad Nacional de Entre Ríos"],
    ".unf.edu.ar": ["Universidad Nacional de Formosa"],
    ".ungs.edu.ar": ["Universidad Nacional de General Sarmiento"],
    ".unibo.edu.ar": [
        "Universidad de Bologna - Representación en Buenos Aires"
    ],
    ".unicen.edu.ar": [
        "Universidad Nacional del Centro de la Provincia de Buenos Aires"
    ],
    ".universidad-policial.edu.ar": [
        "Instituto Universitario de la Policia Federal"
    ],
    ".universidadnotarial.edu.ar": ["Universidad Notarial Argentina"],
    ".unju.edu.ar": ["Universidad Nacional de Jujuy"],
    ".unl.edu.ar": ["Universidad Nacional del Littoral"],
    ".alumno.unlam.edu.ar": [
        "Departamento de Ingenieria - Universidad Nacional de la Matanza"
    ],
    ".unlam.edu.ar": ["Universidad Nacional de La Matanza"],
    ".unlar.edu.ar": ["Universidad Nacional de La Rioja"],
    ".unlp.edu.ar": ["Universidad Nacional de La Plata"],
    ".unlpam.edu.ar": ["Universidad Nacional de La Pampa"],
    ".unlu.edu.ar": [
        "Instituto Nacional de Educación Física General Manuel Belgrano",
        "Universidad Nacional de Luján",
    ],
    ".unlz.edu.ar": ["Universidad Nacional de Lomas de Zamora"],
    ".unne.edu.ar": ["Universidad Nacional del Nordeste"],
    ".unnoba.edu.ar": [
        "Universidad Nacional del Noroeste de la Provincia de Buenos Aires"
    ],
    ".uno.edu.ar": [
        "Universidad Nacional del Oeste",
        "National University of the West",
    ],
    ".unp.edu.ar": ["Universidad Nacional de la Patagonia San Juan Bosco"],
    ".unpa.edu.ar": ["Universidad Nacional de la Patagonia Austral"],
    ".unpaz.edu.ar": [
        "Universidad Nacional de José C. Paz",
        "José C. Paz National University",
    ],
    ".unq.edu.ar": ["Universidad Nacional de Quilmes"],
    ".unr.edu.ar": ["Universidad Nacional de Rosario"],
    ".unrc.edu.ar": ["Universidad Nacional de Río Cuarto"],
    ".unrn.edu.ar": [
        "Universidad Nacional de Rio Negro",
        "National University of Rio Negro",
    ],
    ".alu.uns.edu.ar": [
        "Universidad Nacional del Sur - Bahía Blanca, Argentina"
    ],
    ".uns.edu.ar": ["Universidad Nacional del Sur"],
    ".exa.unsa.edu.ar": [
        "Facultad de Ciencias Exactas - Universidad Nacional de Salta"
    ],
    ".unsa.edu.ar": ["Universidad Nacional de Salta"],
    ".unsada.edu.ar": ["Universidad Nacional de San Antonio de Areco"],
    ".unsam.edu.ar": ["Universidad Nacional de General San Martín"],
    ".unsanisidro.edu.ar": ["Universidad Nacional Raúl Scalabrini Ortíz"],
    ".unse.edu.ar": ["Universidad Nacional de Santiago del Estero"],
    ".unsj.edu.ar": ["Universidad Nacional de San Juan"],
    ".unsta.edu.ar": ["Universidad del Norte Santo Tomás de Aquino"],
    ".unt.edu.ar": ["Universidad Nacional de Tucumán"],
    ".untdf.edu.ar": [
        "Universidad Nacional de Tierra del Fuego",
        "IDEI - Instituto de Desarrollo Económico e Innovación",
        "Argentina",
    ],
    ".untref.edu.ar": ["Universidad Nacional de Tres de Febrero"],
    ".up.edu.ar": ["Universidad de Palermo, Argentina", "@palermo.edu"],
    ".upso.edu.ar": ["Universidad Provincial del Sudoeste"],
    ".usal.edu.ar": ["Universidad del Salvador"],
    ".frba.utn.edu.ar": [
        "Facultad Regional Buenos Aires - Universidad Tecnológica Nacional"
    ],
    ".frro.utn.edu.ar": [
        "Facultad Regional Rosario - Universidad Tecnológica Nacional"
    ],
    ".utn.edu.ar": ["Universidad Tecnológica Nacional"],
    ".uvq.edu.ar": ["Universidad Nacional de Quilmes"],
    ".vaneduc.edu.ar": ["Universidad Abierta Interamericana"],
    ".idicer-conicet.gob.ar": [
        "Instituto de Inmunología Clínica y Experimental de Rosario (IDICER)"
    ],
    ".igevet.gob.ar": [
        "Instituto de Genetica Veterinaria - Universidad nacional de la Plata",
        "Veterinary Genetics Institute - La Plata National University",
    ],
    ".irice-conicet.gov.ar": [
        "IRICE (CONICET/ UNR) - Instituto Rosario de Investigaciones en Ciencias de la Educación"
    ],
    ".cmb.org.ar": ["Colegio Manuel Belgrano"],
    ".educacionadventista.org.ar": ["Educación Adventista"],
    ".flacso.org.ar": [
        "FACULTAD LATINOAMERICANA DE CIENCIAS SOCIALES",
        "LATIN AMERICAN FACULTY OF SOCIAL SCIENCES",
    ],
    ".itecriocuarto.org.ar": [
        "Instituto Tecnologico Rio Cuarto",
        "Rio Cuarto's Tech Institute",
    ],
    ".dc.uba.ar": [
        "Departamento de Computación - Facultad de Ciencias Exactas y Naturales. UBA"
    ],
    ".df.uba.ar": [
        "Departamento de Física - Facultad de Ciencias Exactas y Naturales. UBA"
    ],
    ".fi.uba.ar": ["Facultad de Ingenieria de la Universidad de Buenos Aires"],
    ".uba.ar": [
        "Universidad de Buenos Aires - FCEN",
        "Universidad de Buenos Aires",
        "University of Buenos Aires",
    ],
    ".compasscollege.art": ["Compass College"],
    ".ait.asia": ["Asian Institute of Technology, Thailand"],
    ".mbu.asia": ["Mohan Babu University"],
    ".mit.asia": ["Maharashtra institute of Technology, Aurangabad"],
    ".uap.asia": ["University of Asia and the Pacific"],
    ".vidyanikethan.asia": ["Sree Vidyanikethan Engineering College"],
    ".aau.at": ["Alpen-Adria-Universität Klagenfurt"],
    ".abendgym.at": ["Abendgymnasium für Berufstätige"],
    ".stud.aim.ac.at": ["Austrian Institute of Management - FH Burgenland"],
    ".akbild.ac.at": ["Akademie der bildenden Künste Wien"],
    ".bgberndorf.ac.at": ["Bundesgymnasium und Bundesrealgymnasium Berndorf"],
    ".boku.ac.at": ["Universität für Bodenkultur Wien"],
    ".borgstpoelten.ac.at": ["BRG/BORG"],
    ".bs-linz2.ac.at": ["Berufsschule Linz 2"],
    ".donau-uni.ac.at": ["Donau-Universität Krems"],
    ".dp-uni.ac.at": [
        "Danube Private University",
        "Danube Private University",
    ],
    ".fernfh.ac.at": ["Ferdinand Porsche FernFH"],
    ".fh-campuswien.ac.at": [
        "FH Campus Wien - Verein zur Förderung des Fachhochschul-, Entwicklungs- und Forschungszentrums im Süden Wiens",
        "FH Campus Wien - University of Applied Sciences",
    ],
    ".fh-kaernten.ac.at": ["Fachhochschule Kärnten"],
    ".fh-krems.ac.at": ["Fachhochschule Krems"],
    ".fh-kufstein.ac.at": ["Fachhochschule Kufstein (Tirol)"],
    ".fh-salzburg.ac.at": [
        "Fachhochschule Salzburg",
        "University of Applied Sciences",
    ],
    ".fh-sbg.ac.at": ["Fachhochschule Salzburg"],
    ".fh-stpoelten.ac.at": ["Fachhochschule St. Pölten"],
    ".fh-vie.ac.at": ["Fachhochschule für Bank- und Finanzwirtschaft"],
    ".edu.fh-wien.ac.at": ["FHWien der WKW"],
    ".edu.fhg-tirol.ac.at": ["Health University of Applied Sciences"],
    ".stud.fhgooe.ac.at": ["FH Gesundheitsberufe OÖ GmbH"],
    ".fhgooe.ac.at": ["FH Gesundheitsberufe OÖ GmbH"],
    ".fhstp.ac.at": [
        "Fachhochschule St. Pölten",
        "St.Pölten University of Applied Sciences",
    ],
    ".fhwn.ac.at": ["Fachhochschule Wiener Neustadt"],
    ".gmi-tirol.ac.at": [
        "Medizinische Universität Innsbruck, Institut für Gerichtliche Medizin",
        "Medical University of Innsbruck, Institute of Legal Medicine",
    ],
    ".gym-hartberg.ac.at": [
        "Gymnasium Hartberg – BG/BRG/BORG",
        "High School Hartberg – BG/BRG/BORG",
    ],
    ".s.hakmistelbach.ac.at": ["Bundeshandelsakademie Mistelbach"],
    ".hakstpoelten.ac.at": ["HAK St. Pölten"],
    ".hakwr-neustadt.ac.at": [
        "Bundeshandelsakademie Wiener Neustadt",
        "College of Business Administration Wiener Neustadt",
    ],
    ".hblva17.ac.at": [
        "Höhere Bundes- Lehr- und Versuchsanstalt für chemische Industrie",
        "Federal College and research institute for chemical industry",
    ],
    ".htl-bregenz.ac.at": ["HTBLuVA Bregenz"],
    ".htl-hl.ac.at": ["HTL Hollabrunn"],
    ".htl-kaindorf.ac.at": [
        "Höhere Technische Bundeslehranstalt Kaindorf",
        "Federal Higher Technical Institute Kaindorf",
    ],
    ".htl-leonding.ac.at": ["HTL Leonding"],
    ".htl-perg.ac.at": ["Höhere technische Bundeslehranstalt Perg"],
    ".htl-salzburg.ac.at": ["HTBLuVA Salzburg"],
    ".htl-steyr.ac.at": [
        "HTL Steyr",
        "HTBLA Steyr",
        "Hoehere technische Bundeslehranstalt Steyr",
    ],
    ".htlmistelbach.ac.at": [
        "Höhere technische Lehranstalt Mistelbach für Biomedizin und Gesundheitstechnik",
        "HTL Mistelbach for biomedical engineering",
    ],
    ".htlstp.ac.at": ["HTBLuVA St.Pölten"],
    ".htlwrn.ac.at": ["HTBLuVA Wiener Neustadt"],
    ".htlwy.ac.at": ["HTL-Waidhofen at the Ybbs"],
    ".i-med.ac.at": ["Medizinische Universität Innsbruck"],
    ".iiasa.ac.at": [
        "International Institute for Applied Systems Analysis (IIASA)",
        "Schlossplatz 1 | A-2361 Laxenburg, Austria",
    ],
    ".imc-krems.ac.at": ["Fachhochschulstudiengänge Krems IMC"],
    ".ist.ac.at": ["Institute of Science and Technology Austria"],
    ".ista.ac.at": ["Institute of Science and Technology Austria"],
    ".kfunigraz.ac.at": ["Universität Graz"],
    ".kug.ac.at": ["Universität für Musik und darstellende Kunst Graz"],
    ".lbs-eibiswald.ac.at": ["Landesberufsschule Eibiswald"],
    ".lbs.ac.at": [
        "Lauder Business School",
        "FH Lauder Business School",
        "LBS",
    ],
    ".litec.ac.at": ["Litec - Linzer Technikum"],
    ".mdw.ac.at": ["Universität für Musik und darstellende Kunst  Wien"],
    ".meduniwien.ac.at": ["Medizinische Universität Wien"],
    ".modul.ac.at": ["MODUL Private University Vienna"],
    ".moz.ac.at": ["Universität Mozarteum Salzburg"],
    ".ndu.ac.at": ["New Design University - Privatuniversität St. Pölten"],
    ".ph-tirol.ac.at": ["Pädagogische Hochschule Tirol"],
    ".plus.ac.at": ["University of Salzburg"],
    ".rg18.ac.at": ["BRG 18"],
    ".sbg.ac.at": ["Universität Salzburg"],
    ".mail.sfu.ac.at": [
        "Sigmund Freud University Vienna",
        "Sigmund Freud University Vienna",
    ],
    ".sz-ybbs.ac.at": ["SZ-Ybbs"],
    ".tgm.ac.at": ["Technologisches Gewerbemuseum Wien"],
    ".tuwien.ac.at": ["Technische Universität Wien"],
    ".uibk.ac.at": ["Universität Innsbruck"],
    ".uni-ak.ac.at": ["Universität für angewandte Kunst Wien"],
    ".uni-klu.ac.at": ["Alpen-Adria-Universität Klagenfurt"],
    ".uni-linz.ac.at": ["Universität Linz"],
    ".unileoben.ac.at": ["Montanuniversität Leoben"],
    ".univie.ac.at": ["Universität Vienna"],
    ".vetmeduni.ac.at": [
        "Veterinärmedizinischen Universität Wien",
        "University of Veterinary Medicine, Vienna",
    ],
    ".vu-wien.ac.at": ["Veterinärmedizinische Universität Wien"],
    ".webster.ac.at": ["Webster University, Vienna"],
    ".wu-wien.ac.at": [
        "\ufeffWirtschaftsuniversität Wien",
        "Vienna University of Economics and Business",
    ],
    ".wu.ac.at": [
        "Wirtschaftsuniversität Wien",
        "Vienna University of Economics and Business",
    ],
    ".ais.at": ["American International School Vienna"],
    ".ams-wien.at": ["Albertus Magnus Schule"],
    ".antonkriegergasse.at": [" WMS/RG/ORG antonkriegergasse"],
    ".bbs-rohrbach.at": ["BBS-Rohrbach"],
    ".bgbrgwels.at": ["BG/BRG Wels Dr. Schauerstraße"],
    ".bgklosterneuburg.at": ["BG/BRG Klosterneuburg"],
    ".bhak-eisenerz.at": ["BHAK-Eisenerz Bundeshandelsakademie"],
    ".bhak.at": ["BHAK Fürstenfeld"],
    ".borg-birkfeld.at": ["BORG Birkfeld"],
    ".borg-eisenerz.at": ["Bundes-Oberstufenrealgymnasium Eisenerz"],
    ".borg-kindberg.at": ["BORG Kindberg"],
    ".borg1.at": ["BORG Monsbergergasse", "BORG Monsberger"],
    ".brgwels.at": ["BRG Wels Wallererstraße"],
    ".edu.brucknergym.at": ["Brucknergymnasium Wels"],
    ".bruckneruni.at": [
        "Anton Bruckner Privatuniversität",
        "Anton Bruckner University",
        "Bruckneruni",
    ],
    ".bulme.at": ["HTL BULME"],
    ".campus02.at": ["CAMPUS 02 Fachhochschule der Wirtschaft"],
    ".dachsberg.at": ["Gymnasium Dachsberg"],
    ".erlgasse.at": ["GRG XII Erlgasse"],
    ".europagym.at": ["Europagymnasium Auhof"],
    ".evgym.at": ["Evangelisches Gymnasium"],
    ".fadi.at": ["BRG Fadingerstraße Linz, Austria"],
    ".fbs-klagenfurt1.at": [
        "Fachberufsschule Klagenfurt1",
        "Vocational school Klagenfurt1",
        "https://www.fbs-klagenfurt1.at",
        "Long-term IT related Course: https://www.fbs-klagenfurt1.at/lehrberufe/applikationsentwicklung-coding/",
        "Students and Teachers are provided with an email address like firstname.lastname@fbs-klagenfurt1.at",
        "so my email is isolde.koelblinger@fbs-klagenfurt1.at (I'm the teacher for course 'Coding')",
    ],
    ".fh-burgenland.at": ["Fachhochschule Burgenland"],
    ".fh-hagenberg.at": ["Fachhochschulstudiengänge Hagenberg"],
    ".fh-joanneum.at": ["Fachhochschule JOANNEUM"],
    ".fh-kaernten.at": ["Fachhochschule Kärnten"],
    ".fh-steyr.at": ["Fachhochschulstudiengänge Steyr"],
    ".fh-wels.at": ["Fachhochschulstudiengänge Wels"],
    ".fhooe.at": [
        "Fachhochschule Oberösterreich",
        "University of Applied Science Upper Austria",
    ],
    ".fhv.at": ["Fachhochschule Vorarlberg"],
    ".fhw.at": ["Fachhochschulstudiengänge der Wiener Wirtschaft"],
    ".forstschule.at": ["HBLA für Forstwirtschaft Bruck an der Mur"],
    ".gym-nd.at": ["Bundesgymnasium und Bundesrealgymnasium Neusiedl am See"],
    ".gymgmunden.at": ["BG und BRG Gmunden"],
    ".gymnasium-saalfelden.at": ["BG/Sport-RG Saalfelden"],
    ".hak-althofen.at": ["HAK Althofen"],
    ".hak-bregenz.at": ["HAK Bregenz"],
    ".hak-frk.at": [
        "Bundeshandelsakademie und Bundeshandelsschule Frauenkirchen"
    ],
    ".hak-liezen.at": ["BHAK/BHAS Liezen"],
    ".hak-linz.at": [
        "HAK.HAS Linz International Business School",
        "HAK.HAS Linz International Business School",
    ],
    ".hak-op.at": [
        "HAK Oberpullendorf",
        "Commercial High School Oberpullendorf",
    ],
    ".hakneumarkt.at": [
        "Bundeshandelsakademie Neumarkt am Wallersee",
        "Commercial School in Neumarkt am Wallersee",
    ],
    ".hakspittal.at": ["HAK Spittal"],
    ".hakvb.at": ["Handelsakademie Vöcklabruck"],
    ".hakzell.at": ["BHAK/BHAS Zell am See"],
    ".hblfa-tirol.at": [
        "Höhere Bundeslehr- und Forschungsanstalt für Landwirtschaft und Ernährung, Lebensmittel- und Biotechnologie Tirol",
        "Higher Federal Education and Research Institute for Agriculture and Food, Food and Biotechnology Tyrol",
    ],
    ".hblw-saalfelden.at": ["HBLW Saalfelden"],
    ".hlw-freistadt.at": ["HLW Freistadt school"],
    ".hlw10.at": ["Höhere Bundeslehranstalt für wirtschaftliche Berufe"],
    ".hochschule-burgenland.at": [
        "Hochschule Burgenland",
        "University of Applied Sciences",
    ],
    ".holztechnikum.at": ["Holztechnikum Kuchl"],
    ".htl-braunau.at": ["HTBLA Braunau"],
    ".htl-donaustadt.at": ["HTL Donaustadt"],
    ".htl-grieskirchen.at": ["HTBLA Grieskirchen"],
    ".htl-hallein.at": ["HTBLA Hallein"],
    ".htl-kaindorf.at": [
        "Höhere Technische Bundeslehranstalt Kaindorf",
        "Federal Higher Technical Institute Kaindorf",
    ],
    ".htl-klu.at": ["HTL Mössingerstraße"],
    ".o365.htl-leoben.at": [
        "Höhere Technische Lehranstalt und Werkmeisterschule des Schulvereins der Berg- und Hüttenschule Leoben Privatschule mit Öffentlichkeitsrecht",
        "Higher Technical Education Institute Leoben, private school",
    ],
    ".htl-leoben.at": [
        "Higher Technical Education Institute Leoben, private school"
    ],
    ".htl-neufelden.at": ["HTL Neufelden"],
    ".htl-ottakring.at": ["HTL Ottakring"],
    ".htl-rankweil.at": [
        "Höhere Technische Bundeslehr- und Versuchsanstalt Rankweil",
        "Higher Technical Institute Rankweil",
    ],
    ".htl-saalfelden.at": [
        "Höhere Technische Bundeslehranstalt Saalfelden am Steinernen Meer"
    ],
    ".htl-villach.at": ["HTL Villach"],
    ".htl-wels.at": ["HTL Wels"],
    ".htl-wolfsberg.at": ["HTL Wolfsberg", "HTL Wolfsberg"],
    ".htldornbirn.at": ["HTL Dornbirn"],
    ".htleisenstadt.at": [
        "Höhere technische Bundeslehranstalt Eisenstadt",
        "HTBLA Eisenstadt",
        "HTL Eisenstadt",
    ],
    ".wi.htlhl.at": ["HTL Hollabrunn", "Higher Technical College Hollabrunn"],
    ".htlkrems.at": ["HTL Krems"],
    ".htlpinkafeld.at": ["HTL Pinkafeld"],
    ".htlstp.at": ["HTBLuVA St. Pölten"],
    ".htltraun.at": ["HTL Traun", "Higher technical college Traun"],
    ".htlvb.at": ["HTL Vöcklabruck"],
    ".htlweiz.at": ["HTL Weiz"],
    ".htlwienwest.at": ["Höhere Technische Lehranstalt Wien West"],
    ".htlwy.at": ["HTL-Waidhofen at the Ybbs"],
    ".isi-hagenberg.at": [
        "Universal Computing and Business - International School for Informatics"
    ],
    ".it-u.at": ["Interdisciplinary Transformation University Austria"],
    ".jku.at": ["Johannes Kepler University Linz"],
    ".johak.at": [
        "Bundeshandelsakademie St. Johann im Pongau",
        "Federal Business Academy St. Johann im Pongau",
    ],
    ".keimgasse.at": ["BG & BRG Keimgasse"],
    ".klostergasse.at": ["BG 18 Klostergasse"],
    ".fbs.ksn.at": [
        "Fachberufsschule 1 Klagenfurt - Applikationsentwicklung/Coding",
        "technical vocational school 1 klagenfurt - application development branch",
    ],
    ".kundmanngasse.at": [
        "GRg3 Kundmanngasse Bundesgymnasium und Bundesrealgymnasium"
    ],
    ".kunstuni-linz.at": ["University of Art and Design Linz"],
    ".lichtenfels.at": ["BG/BRG Lichtenfels Graz"],
    ".lyceefrancais.at": ["Lycée Français de Vienne"],
    ".mci4me.at": ["Management Center Innsbruck"],
    ".meduni-graz.at": ["Medizinische Universität Graz"],
    ".medunigraz.at": ["Medical University of Graz"],
    ".meduniwien.at": ["Medizinische Universität Wien"],
    ".htl.moedling.at": ["HTL Mödling"],
    ".nms-gruenburg.at": ["NMS Grünburg", "(new) middle-school Gruenburg"],
    ".klg.or.at": ["Konrad Lorenz Gymnasium"],
    ".ph-linz.at": ["Private Pädagogische Hochschule der Diözese Linz"],
    ".phst.at": [
        "University College of Teacher Education Styria",
        "Pädagogische Hochschule Steiermark",
    ],
    ".popperschule.at": ["Sir Karl Popper Schule"],
    ".qualifizierung.at": [
        "Berufliches Bildungs- und Rehabilitationszentrum Österreich",
        "Austrian Center for Professional Education and Rehabilitation",
        "www.bbrz.at",
        "(The @qualifizierung.at is the domain used for all students in an Austrian qualification program.)",
        "My course for software development (24 months):",
        "https://www.bbrz.at/fileadmin/user_upload/Produkblaetter/Reha-Ausbildung/Steiermark/Kapfenberg_REHA_Ausbildung_CODERSBAY.pdf",
        "https://www.whois.com/whois/qualifizierung.at",
    ],
    ".raumberg-gumpenstein.at": ["HBLFA Raumberg-Gumpenstein"],
    ".htl.rennweg.at": ["HTL Rennweg"],
    ".rg-schwaz.at": ["Real Gymnasium Schwaz", "Real Gymnasium Schwaz"],
    ".sacrecoeur-graz.at": ["Sacre Coeur Graz"],
    ".hak-stjo.salzburg.at": [
        "Bundeshandelsakademie St. Johann im Pongau",
        "Federal Business Academy St. Johann im Pongau",
    ],
    ".lbs4.salzburg.at": ["Landesberufsschule 4"],
    ".schottengymnasium.at": ["Schottengymnasium der Benediktiner in Wien"],
    ".schulzentrum-hall.at": ["NMS Schulzentrum Hall"],
    ".lbsfe1.snv.at": [
        "Landesberufsschule Feldkirch",
        "State Vocational School Feldkirch",
    ],
    ".spengergasse.at": ["HTL Spengergasse"],
    ".sti2.at": ["Semantic Technology Institute"],
    ".swale.at": ["The Sittingbourne School", "The Sittingbourne School"],
    ".szu.at": ["Schulzentrum HTL HAK Ungargasse"],
    ".technikum-wien.at": ["Technikum Wien"],
    ".tsn.at": [
        "Schulen des Tiroler Schulnetzes https://www.dvt.at/services/tsn-tiroler-schulnetz/"
    ],
    ".tugraz.at": ["Technische Universität Graz"],
    ".ufg.at": ["University of Art and Design Linz"],
    ".umit-tirol.at": [
        "UMIT TIROL – Private Universität für Gesundheitswissenschaften und -technologie GmbH"
    ],
    ".uni-graz.at": ["University of Graz"],
    ".edu.uni-seeburg.at": ["Pruvatuniversität Seeburg"],
    ".ursulinen.at": ["Schulverein der Grazer Ursulinen"],
    ".walz.at": ["W@lz Wiener Lernzentrum"],
    ".werkschulheim.at": ["Werkschulheim Felbertal"],
    ".wiednergymnasium.at": ["Wiedner Gymnasium (Sir-Karl-Popper-Schule)"],
    ".student.aiict.com.au": ["Australian Institute of ICT"],
    ".alkirasc.com.au": ["Alkira Secondary College"],
    ".churchie.com.au": ["Anglican Church Grammar School"],
    ".cqumail.com.au": ["CQUniversity [https://www.cqu.edu.au/]"],
    ".haileybury.com.au": [
        "Haileybury",
        "URL:",
        "https://www.haileybury.com.au/",
        "Course (shows VCE subject available to all secondary students):",
        "https://www.vcaa.vic.edu.au/curriculum/vce/vce-study-designs/appliedcomputing-softwaredevelopment/Pages/index.aspx",
        "Contact details provided show the URL:",
        "https://www.haileybury.com.au/contact",
    ],
    ".hotelschool.com.au": ["Blue Mountains Hotel School"],
    ".tigs.com.au": ["The Illawarra Grammar School"],
    ".wmac.com.au": [
        "West Moreton Anglican College",
        "West Moreton Anglican College",
    ],
    ".studentmail.academies.edu.au": ["Academies Australasia "],
    ".my.acap.edu.au": ["Australian College of Applied Professions"],
    ".accm.edu.au": ["Australian College of Commerce and Management"],
    ".acs.edu.au": ["Australian Correspondence Schools"],
    ".cgs.act.edu.au": ["Canberra Grammar School"],
    ".ed.act.edu.au": ["Lake Tuggeranong College"],
    ".student.mcc.act.edu.au": ["Marist College Canberra"],
    ".merici.act.edu.au": ["Merici College"],
    ".radford.act.edu.au": ["Radford College"],
    ".schoolsnet.act.edu.au": [
        "ACT Education Directorate",
        "Lake Tuggeranong College",
        ".group",
    ],
    ".tcs.act.edu.au": [
        "Trinity Christian School",
        "Trinity Christian School",
    ],
    ".acu.edu.au": ["Australian Catholic University"],
    ".adelaide.edu.au": ["University of Adelaide"],
    ".study.aib.edu.au": ["Australia Institute of Business"],
    ".aie.edu.au": ["The Academy of Interactive Entertainment"],
    ".students.aieinstitute.edu.au": ["AIE Institute"],
    ".students.aih.edu.au": ["Australian Institute of Higher Education"],
    ".aiict.edu.au": ["Australian Institute of ICT"],
    ".albrightinstitute.edu.au": [
        "Albright Institute of Business and Language"
    ],
    ".alc.edu.au": ["Australian Lutheran College"],
    ".amc.edu.au": ["Australian Maritime College"],
    ".angliss.edu.au": ["William Angliss Institute"],
    ".anu.edu.au": [
        "Australian National University",
        "The Australian National University",
    ],
    ".apc.edu.au": ["Australian Pacific College"],
    ".student.apicollege.edu.au": [
        "APIC - Asia Pacific International College",
        "APIC - Asia Pacific International College",
    ],
    ".atmc.edu.au": ["ATMC", "Australian Technical and Management College"],
    ".avondale.edu.au": ["Avondale College"],
    ".student.bhtafe.edu.au": ["BoxHill Institute"],
    ".bond.edu.au": ["Bond University"],
    ".brighton.edu.au": ["Brighton College"],
    ".bssc.edu.au": ["Bendigo Senior Secondary College"],
    ".burnet.edu.au": ["Burnet Institute"],
    ".canberra.edu.au": ["University of Canberra"],
    ".bne.catholic.edu.au": ["St Peter Claver College"],
    ".cabra.catholic.edu.au": ["Cabra Dominican College"],
    ".cardijn.catholic.edu.au": ["Cardijn Collage"],
    ".cnsstu.catholic.edu.au": [
        "St Andrews Catholic College",
        "(@cnsstu.catholic.edu.au)",
    ],
    ".dbb.catholic.edu.au": ["St Leo's Catholic College, Wahroonga"],
    ".dbbstu.catholic.edu.au": [
        "St Leo's Catholic College Wahroonga ",
        "St Leo's Catholic College Wahroonga",
    ],
    ".dowstu.catholic.edu.au": ["Catholic Education Diocese of Wollongong"],
    ".mybce.catholic.edu.au": ["Brisbane Catholic Education"],
    ".nazareth.catholic.edu.au": ["Nazareth Catholic College"],
    ".parrastu.catholic.edu.au": ["St Luke's Catholic College"],
    ".rokstu.catholic.edu.au": [
        "Catholic Education Diocese of Rockhampton",
        ".group",
    ],
    ".sctsv.catholic.edu.au": ["Southern Cross Catholic College Annandale"],
    ".sydstu.catholic.edu.au": ["De La Salle Catholic College"],
    ".cdu.edu.au": ["Charles Darwin University"],
    ".cem.edu.au": ["Melbourne Archdiocese Catholic Schools"],
    ".cewa.edu.au": ["Prendiville Catholic College"],
    ".ciom.edu.au": ["Canterbury Institute of Management"],
    ".students.cit.edu.au": ["Canberra institute of technology"],
    ".cit.edu.au": ["Canberra Institute of Technology"],
    ".coderacademy.edu.au": ["Coder Academy"],
    ".collarts.edu.au": ["Australian College of the Arts (Collarts)"],
    ".collegeforadultlearning.edu.au": [
        "College for adult learning",
        "College for adult learning",
    ],
    ".cqu.edu.au": ["Central Queensland University"],
    ".cs.edu.au": ["Education Services Australia"],
    ".csu.edu.au": ["Charles Sturt University"],
    ".curtin.edu.au": ["Curtin University of Technology"],
    ".danford.edu.au": ["Danford College "],
    ".deakin.edu.au": ["Deakin University"],
    ".learning.deakincollege.edu.au": ["Deakin College"],
    ".ecu.edu.au": ["Edith Cowan University"],
    ".ee.edu.au": ["ELITE EDUCATION "],
    ".eit.edu.au": ["Engineering Institute of Technology"],
    ".eq.edu.au": [
        "Queensland Academy of Science, Mathematics and Technology",
        "Helensvale State High School",
        ".group",
    ],
    ".federation.edu.au": ["Federation University Australia"],
    ".flinders.edu.au": ["Flinders University of South Australia"],
    ".gordontafe.edu.au": ["Gordon Institute Of Tafe"],
    ".griffith.edu.au": ["Griffith University"],
    ".griffithuni.edu.au": ["Griffith University"],
    ".hic.edu.au": [
        "Highgate International College",
        "Highgate International College",
    ],
    ".holmes.edu.au": ["Holmes Institute"],
    ".holmesglen.edu.au": ["Holmesglen Institute, Victoria, Australia"],
    ".student.ichm.edu.au": [
        "International College of Hotel Management",
        "International College of Hotel Management",
    ],
    ".students.icms.edu.au": ["International College of Management, Sydney"],
    ".imc.edu.au": [
        "Australian National Institute of Management and Commerce (IMC)",
        "Australian National Institute of Management and Commerce (IMC)",
    ],
    ".iota.edu.au": ["Institute Of Technology, Australia"],
    ".jcu.edu.au": ["James Cook University of North Queensland"],
    ".jmc.edu.au": ["JMC Academy"],
    ".kangan.edu.au": ["Kangan Institute"],
    ".kaplanstudent.edu.au": ["Kaplan Business School", "KBS"],
    ".kbs.edu.au": ["Kaplan Business School"],
    ".student.kent.edu.au": ["Kent Institute"],
    ".kent.edu.au": ["Kent Institute"],
    ".student.kii.edu.au": ["Kingsford international Institute (KII)"],
    ".kings.edu.au": ["kings.edu.au"],
    ".students.koi.edu.au": ["King’s Own Institute"],
    ".koi.edu.au": ["King’s Own Institute"],
    ".laneway.edu.au": ["Laneway Education"],
    ".latrobe.edu.au": ["La Trobe University"],
    ".laureate.edu.au": ["Torrens University"],
    ".students.ltu.edu.au": ["La Trobe"],
    ".ltu.edu.au": ["La Trobe University"],
    ".mcri.edu.au": ["Murdoch Children's Research Institute"],
    ".melbournepolytechnic.edu.au": ["Melbourne Polytechnic"],
    ".mercurycolleges.edu.au": ["Mercury Colleges"],
    ".mit.edu.au": ["Melbourne Institute of Technology"],
    ".monash.edu.au": ["Monash University"],
    ".monashcollege.edu.au": ["Monash College"],
    ".student.mp.edu.au": ["Melbourne Polytechnic"],
    ".mq.edu.au": ["Macquarie University"],
    ".murdoch.edu.au": ["Murdoch University"],
    ".myacu.edu.au": ["Australian Catholic University"],
    ".myangliss.edu.au": ["William Angliss Institute"],
    ".myune.edu.au": [
        "University of New England",
        "University of New England",
    ],
    ".nas.edu.au": ["National Art School"],
    ".nd.edu.au": ["University of Notre Dame Australia"],
    ".newcastle.edu.au": ["University of Newcastle"],
    ".nortwest.edu.au": ["Nortwest Pty Ltd."],
    ".aih.nsw.edu.au": ["Australian Institute of Higher Education"],
    ".ait.nsw.edu.au": ["Academy of Information Technology"],
    ".aitc.nsw.edu.au": ["AUSTRALIAN INSTITUTE OF TECHNOLOGY AND COMMERCE"],
    ".broughton.nsw.edu.au": ["Broughton Anglican College"],
    ".covenant.nsw.edu.au": ["Covenant Christian School"],
    ".cranbrook.nsw.edu.au": ["Cranbrook School"],
    ".det.nsw.edu.au": [
        "Tuggerah Lakes Secondary College Berkeley Vale Campus"
    ],
    ".emanuelschool.nsw.edu.au": ["Emanuel School"],
    ".giss.nsw.edu.au": ["German International School Sydney"],
    ".hillsgrammar.nsw.edu.au": ["The Hills Grammar School"],
    ".knox.nsw.edu.au": ["Knox Grammar School", "Knox Grammar School"],
    ".lindisfarne.nsw.edu.au": ["Lindisfarne Anglican Grammar School"],
    ".loreto.nsw.edu.au": ["Loreto Kirribilli"],
    ".student.masada.nsw.edu.au": ["Masada College"],
    ".mercurycolleges.nsw.edu.au": ["Mercury Colleges"],
    ".northholm.nsw.edu.au": ["Northholm Grammar School"],
    ".student.sbhs.nsw.edu.au": ["Sydney Boys High School"],
    ".scas.nsw.edu.au": ["St Columba Anglican School"],
    ".scholastica.nsw.edu.au": [
        "St Scholastica's College, Glebe",
        "https://www.scholastica.nsw.edu.au/",
    ],
    ".sec.nsw.edu.au": ["St Edward's College"],
    ".students.sgcs.nsw.edu.au": ["St George Christian School"],
    ".learning.sibt.nsw.edu.au": [
        "Sydney Institute of Business and Technology"
    ],
    ".stud.spi.nsw.edu.au": ["Sydney Polytechnic Institute"],
    ".stgregs.nsw.edu.au": ["St Gregory's College"],
    ".student.stlukes.nsw.edu.au": ["St Luke's Grammar School"],
    ".stpauls.nsw.edu.au": ["St Pauls Grammar School"],
    ".sydgram.nsw.edu.au": ["Sydney Grammar School"],
    ".student.tcc.nsw.edu.au": ["Toongabbie Christian College"],
    ".student.tigs.nsw.edu.au": ["The Illawarra Grammar Shool"],
    ".tigs.nsw.edu.au": ["The Illawarra Grammar School"],
    ".wcc-student.nsw.edu.au": [" William Clarke College "],
    ".wcc.nsw.edu.au": [" William Clarke College "],
    ".nvr.edu.au": ["NVR Education Australia", "NVR Education Australia"],
    ".opencolleges.edu.au": ["Open Colleges"],
    ".pac.edu.au": ["Prince Alfred College"],
    ".abpat.qld.edu.au": ["A.B. Paterson College"],
    ".bbc.qld.edu.au": ["Brisbane Boys' College"],
    ".cathedral.qld.edu.au": [
        "The Cathedral School of Saint Anne and Saint James"
    ],
    ".citipointe.qld.edu.au": ["Citipointe Christian College"],
    ".clayfield.qld.edu.au": ["Clayfield College"],
    ".cti.qld.edu.au": ["Canterbury Technical Institute"],
    ".faithlcs.qld.edu.au": ["Faith Lutheran Collage"],
    ".hillbrook.qld.edu.au": ["Hillbrook Anglican School"],
    ".icb.qld.edu.au": ["Islamic College Of Brisbane"],
    ".jpc.qld.edu.au": ["John Paul College"],
    ".msm.qld.edu.au": ["Mt St Michael's College"],
    ".mta.qld.edu.au": ["Mount Alvernia College"],
    ".students.northside.qld.edu.au": ["Northside Christian College"],
    ".student.poplc.qld.edu.au": ["Prince Of Peace Lutheran College"],
    ".riverside.qld.edu.au": ["Riverside Christian College"],
    ".saac.qld.edu.au": ["St Andrews's Anglican College"],
    ".somerset.qld.edu.au": ["Somerset College"],
    ".stmc.qld.edu.au": ["St Thomas More College"],
    ".stpatricks.qld.edu.au": ["St Patrick's College", "St Patrick's College"],
    ".stpauls.qld.edu.au": ["St Pauls School, Australia"],
    ".stpeters.qld.edu.au": [
        "St Peters Lutheran College",
        "St Peters Lutheran College",
    ],
    ".thelakes.qld.edu.au": ["The Lakes College"],
    ".tss.qld.edu.au": ["The Southport School"],
    ".vnc.qld.edu.au": [
        "Villanova College Coorparoo",
        "Villanova College Coorparoo",
    ],
    ".qut.edu.au": ["Queensland University of Technology"],
    ".rmit.edu.au": ["Royal Melbourne Institute of Technology"],
    ".ignatius.sa.edu.au": ["Saint Ignatius' College"],
    ".pedarecc.sa.edu.au": ["Pedare Christian College"],
    ".pembroke.sa.edu.au": ["Pembroke School"],
    ".rostrevor.sa.edu.au": ["Rostrevor College"],
    ".schools.sa.edu.au": [
        "Salisbury High School",
        "Department for Education | South Australia",
        ".group",
    ],
    ".smc.sa.edu.au": ["St Michaels College Adelaide"],
    ".stjohns.sa.edu.au": [
        "St John's Grammar",
        "St John's Grammar, 29 Gloucester Ave, Belair SA 5052",
    ],
    ".wws.sa.edu.au": ["Willunga Waldorf School", "Willunga Waldorf School"],
    ".sae.edu.au": ["SAE - Creative Media Institute"],
    ".scu.edu.au": ["Southern Cross University"],
    ".selc.edu.au": ["SELC Career College Australia"],
    ".studytafensw.edu.au": ["TAFE NSW"],
    ".swin.edu.au": ["Swinburne University of Technology"],
    ".uni.sydney.edu.au": ["University of Sydney"],
    ".sydney.edu.au": ["University of Sydney"],
    ".tafensw.edu.au": ["TAFE NSW"],
    ".tafeqld.edu.au": ["TAFE Queensland"],
    ".tafesa.edu.au": ["TAFE SA"],
    ".education.tas.edu.au": ["Department of Education Tasmania"],
    ".tarremah.tas.edu.au": ["Tarremah Steiner School"],
    ".tastafe.tas.edu.au": ["TasTAFE"],
    ".tascollege.edu.au": ["TasCollege"],
    ".tased.edu.au": ["Department of Education Tasmania"],
    ".top.edu.au": ["Top education Institute", "Top education Institute"],
    ".torrens.edu.au": ["Torrens University, Australia"],
    ".tqstudent.edu.au": ["Tafe Queensland"],
    ".student.tua.edu.au": ["Torrens University Australia"],
    ".une.edu.au": ["University of New England"],
    ".unimelb.edu.au": ["University of Melbourne"],
    ".unisa.edu.au": ["University of South Australia"],
    ".unsw.edu.au": ["University of New South Wales", "UNSW Sydney"],
    ".uon.edu.au": ["University of Newcastle", "example@uon.edu.au"],
    ".uow.edu.au": ["University of Wollongong"],
    ".uowmail.edu.au": [
        "University of Wollongong",
        "Faculty of Engineering and Information Sciences",
    ],
    ".uq.edu.au": ["University of Queensland"],
    ".uqconnect.edu.au": [
        "The University of Queensland",
        "The University of Queensland",
    ],
    ".usc.edu.au": ["University of the Sunshine Coast"],
    ".usq.edu.au": ["University of Southern Queensland"],
    ".usyd.edu.au": ["University of Sydney"],
    ".utas.edu.au": ["University of Tasmania"],
    ".uts.edu.au": ["University of Technology Sydney"],
    ".uwa.edu.au": ["University of Western Australia"],
    ".uws.edu.au": ["University of Western Sydney"],
    ".Werribeesc.vic.edu.au": ["Werribee Secondary College"],
    ".albertparkcollege.vic.edu.au": ["Albert Park College"],
    ".braemar.vic.edu.au": ["Braemar College"],
    ".camhigh.vic.edu.au": ["Camberwell High School"],
    ".columba.vic.edu.au": ["St Columba's College in Victoria, Australia"],
    ".crccs.vic.edu.au": ["Catholic Regional College Caroline Springs"],
    ".dandenong-hs.vic.edu.au": ["Dandenong High School"],
    ".education.vic.edu.au": [
        "Education and Training at the State of Victoria, Australia"
    ],
    ".elwood.vic.edu.au": ["Elwood College"],
    ".genazzano.vic.edu.au": ["Genazzano FCJ College"],
    ".gwsc.vic.edu.au": ["Glen Waverley Secondary College"],
    ".hamiltoncollege.vic.edu.au": [
        "The Hamilton and Alexandra College",
        "The Hamilton and Alexandra College",
    ],
    ".heathdale.vic.edu.au": [
        "Healthdale Christian College",
        "Healthdale Christian College",
    ],
    ".iona.vic.edu.au": ["Iona College Geelong"],
    ".ivanhoegirls.vic.edu.au": ["Ivanhoe Girls' Grammar School"],
    ".macs.vic.edu.au": ["Melbourne Archdiocese Catholic Schools"],
    ".marcusoldham.vic.edu.au": ["Marcus Oldham College"],
    ".mckinnonsc.vic.edu.au": ["Mckinnon Secondary College"],
    ".mentonegirls.vic.edu.au": ["Mentone Girls' Grammar"],
    ".millparksc.vic.edu.au": ["Mill Park Secondary College"],
    ".student.minaret.vic.edu.au": ["Minaret College", "Minaret College"],
    ".mthira.vic.edu.au": ["Mount Hira College"],
    ".nhs.vic.edu.au": ["Northcote High School"],
    ".pvcc.vic.edu.au": ["Plenty Valley Christian College"],
    ".ringwoodsc.vic.edu.au": ["Ringwood Secondary College"],
    ".rt.vic.edu.au": ["Ringwood Training"],
    ".salesian.vic.edu.au": ["Salesian College Chadstone"],
    ".schools.vic.edu.au": [
        "Education and Training at the State of Victoria, Australia"
    ],
    ".staughtoncollege.vic.edu.au": ["Staughton College"],
    ".stjohnspreston.vic.edu.au": ["Preston - St John's College"],
    ".stmichaels.vic.edu.au": ["St Michael's Grammar School"],
    ".swsc.vic.edu.au": ["Springside West Secondary College"],
    ".tintern.vic.edu.au": ["Tintern Grammar"],
    ".westbourne.vic.edu.au": ["Westbourne Grammar School"],
    ".student.vit.edu.au": ["Victoria Institute of Technology"],
    ".vu.edu.au": ["Victoria University"],
    ".carey.wa.edu.au": ["The Carey Baptist College"],
    ".student.ccgs.wa.edu.au": ["Christ Church Grammar School"],
    ".cgs.wa.edu.au": ["Court Grammar School"],
    ".eccs.wa.edu.au": [" Emmanuel Christian Community School"],
    ".student.education.wa.edu.au": [
        "Warnbro community high school",
        "Warnbro community high school",
    ],
    ".education.wa.edu.au": ["Belmont City College"],
    ".gegs.wa.edu.au": ["Geraldton Grammar School, Geraldton, WA, Australia"],
    ".nmtafe.wa.edu.au": ["North Metropolitan TAFE, Australia"],
    ".smtafe.wa.edu.au": ["South Metropolitan TAFE"],
    ".tafe.wa.edu.au": ["North Metropolitan TAFE, Australia"],
    ".trinity.wa.edu.au": ["Trinity College, East Perth"],
    ".wesley.wa.edu.au": ["Wesley College"],
    ".wesleycollege.edu.au": ["Wesley College, Melbourne"],
    ".student.westernsydney.edu.au": ["Western Sydney University"],
    ".westernsydney.edu.au": ["Western Sydney University"],
    ".wic.edu.au": [
        "WELLS INTERNATIONAL COLLEGE PTY LTD",
        "WELLS INTERNATIONAL COLLEGE PTY LTD",
    ],
    ".education.nsw.gov.au": ["NSW Education"],
    ".student.education.nt.gov.au": ["Casuarina Senior College"],
    ".www.nt.gov.au": ["Batchelor Institute of Indigenous Tertiary Education"],
    ".education.tas.gov.au": ["Department of Education Tasmania"],
    ".education.vic.gov.au": [
        "Department of Education and Training, Victoria, Australia for Teacher's accounts"
    ],
    ".edumail.vic.gov.au": ["Williamstown High School"],
    ".tafensw.net.au": ["TAFE NSW"],
    ".uq.net.au": ["University of Queensland"],
    ".onjcri.org.au": ["School of Cancer Medicine, La Trobe University "],
    ".rvts.org.au": ["Rural Vocational Training Scheme"],
    ".mu.oz.au": ["University of Melbourne"],
    ".gymnasium.ax": ["Ålands Gymnasium"],
    ".ha.ax": ["Åland University of Applied Sciences"],
    ".elev.mariehamn.ax": ["Mariehamns Stad Grundskolor"],
    ".aztu.az": ["Azerbaijan Technical University"],
    ".bsu.az": ["Baku State University"],
    ".ada.edu.az": ["Azerbaijan Diplomatic Academy"],
    ".adu.edu.az": ["Azerbaijan University ol Languages"],
    ".amu.edu.az": ["Azerbaijan Medical University"],
    ".au.edu.az": ["Azerbaijan University"],
    ".aztu.edu.az": ["Azerbaijan Technology University"],
    ".bbu.edu.az": ["Baki Business University"],
    ".beu.edu.az": ["Baku Engineering University"],
    ".dia.edu.az": ["Academy of Public Administration"],
    ".lsu.edu.az": ["Lankaran State University"],
    ".naa.edu.az": ["National Aviation Academy"],
    ".ndu.edu.az": ["Nakhchivan State University"],
    ".oyu.edu.az": ["Odlar Yurdu University"],
    ".pa.edu.az": ["Police Academy"],
    ".sdu.edu.az": ["Sumgait State University"],
    ".unec.edu.az": [
        "Azerbaijan State University of Economics",
        "Azərbaycan Dövlət İqtisad Universiteti",
    ],
    ".wcu.edu.az": ["Western Caspian University"],
    ".wu.edu.az": ["Western University"],
    ".gsu.az": ["Ganja State University "],
    ".jis.az": ["Azerbaijan State Oil Academy"],
    ".ufaz.az": [
        "French-Azerbaijani University",
        "Azərbaycan-Fransız Universiteti",
    ],
    ".blc.edu.ba": ["Banja Luka College"],
    ".bosnjackagim.edu.ba": [
        "Prva Bosnjacka Gimnazija",
        "First Bosniak Gymnasium",
    ],
    ".cetvrta-gimnazija.edu.ba": [
        "Cetvrta gimnazija Ilidza",
        "Fourth Gymnasium Ilidza",
    ],
    ".finra.edu.ba": ["FINra Tuzla"],
    ".ibu.edu.ba": ["International Burch University"],
    ".ius.edu.ba": ["International University of Sarajevo"],
    ".smts.edu.ba": [
        "Srednja Mašinska Tehnička Škola Sarajevo",
        "High School of Mechanical Engineering Sarajevo",
    ],
    ".ssst.edu.ba": ["Sarajevo School of Science and Technology"],
    ".treca-gimnazija.edu.ba": [
        "Treca gimnazija Sarajevo",
        "Third Gymnasium Sarajevo",
    ],
    ".unvi.edu.ba": ["University Vitez In Travnik"],
    ".fet.ba": ["Faculty of Electrical Engineering Tuzla"],
    ".fit.ba": ['Univerzitet "Džemal Bijedić" Mostar'],
    ".student.fsre.ba": [
        "Faculty of mechanical engineering and computing, Mostar, Bosnia and Herzegowina",
        "Faculty of mechanical engineering and computing, Mostar, Bosnia and Herzegowina",
    ],
    ".ipi-akademija.ba": [
        "Internacionalna poslovno-informaciona akademija Tuzla",
        "International business-informational academy Tuzla",
    ],
    ".ets.rs.ba": [
        'Elektrotehnička škola "Nikola Tesla" Banja Luka',
        'Electrotechnical school "Nikola Tesla" Banja Luka',
    ],
    ".student.etf.ues.rs.ba": [
        "The Faculty of Electrical Engineering of the University of East Sarajevo"
    ],
    ".unssa.rs.ba": ["University of East Srarajevo"],
    ".sfa.ba": ["Sarajevo Film Academy"],
    ".sinergija.ba": ["Univerzitet Sinergija", "Sinergija University"],
    ".size.ba": [
        "Politehnički fakultet Univerziteta u Zenici",
        "Faculty of Polytechnics - University of Zenica",
    ],
    ".spu.ba": ["Slobomir P Univerzitet"],
    ".fpmoz.sum.ba": ["Faculty of Science and Education"],
    ".sum.ba": ["University of Mostar"],
    ".sve-mo.ba": ["University of Mostar"],
    ".www.unbi.ba": ["University of Bihac"],
    ".unbi.ba": ["Univerzitet u Bihaću", "University of Bihać"],
    ".unmo.ba": ["Univerzitet u Mostaru Dzemal Bijedic"],
    ".www.unsa.ba": ["University of Sarajevo"],
    ".unsa.ba": ["University of Sarajevo"],
    ".untz.ba": ["University of Tuzla"],
    ".unze.ba": ["University of Zenica"],
    ".politecnics.barcelona": ["Centre d'Estudis Politècnics"],
    ".s.fosbos-neusaess.bayern": ["Beruflichen Oberschule Neusäß"],
    ".uwichill.edu.bb": ["University of the West Indies, Cave Hill"],
    ".aub.ac.bd": [
        "Asian University of Bangladesh",
        "Asian University of Bangladesh",
    ],
    ".baiust.ac.bd": [
        "Bangladesh Army International University of Science and Technology"
    ],
    ".bauet.ac.bd": ["Bangladesh Army University of Engineering & Technology"],
    ".bgctub.ac.bd": ["BGC Trust University Bangladesh(BGCTUB)"],
    ".bracu.ac.bd": ["BRAC University"],
    ".brur.ac.bd": ["Begum Rokeya University, Rangpur"],
    ".bsmmu.ac.bd": [
        "বঙ্গবন্ধু শেখ মুজিব মেডিক্যাল বিশ্ববিদ্যালয়, বাংলাদেশ",
        "Bangabandhu Sheikh Mujib Medical University, Bangladesh",
    ],
    ".bu.ac.bd": ["University of Barishal", "University of Barishal"],
    ".ugrad.cse.buet.ac.bd": [
        "Bangladesh University of Engineering and Technology (BUET)"
    ],
    ".cou.ac.bd": ["Comilla University"],
    ".cseku.ac.bd": [
        "Computer Science and Engineering Discipline, Khulna University"
    ],
    ".cstu.ac.bd": [
        "চাঁদপুর বিজ্ঞান ও প্রযুক্তি বিশ্ববিদ্যালয়",
        "Chandpur Science and Technology University",
    ],
    ".cu.ac.bd": ["University of Chittagong"],
    ".cuet.ac.bd": [
        "Chittagong University of Engineering and Technology (CUET)"
    ],
    ".du.ac.bd": ["University of Dhaka"],
    ".duet.ac.bd": ["Dhaka University of Engineering and Technology"],
    ".feniuniversity.ac.bd": ["Feni University", "Feni University"],
    ".hstu.ac.bd": [
        "Hajee Mohammad Danesh Science and Technology University",
        "Hajee Mohammad Danesh Science and Technology University (HSTU), Dinajpur, Bangladesh",
    ],
    ".iiuc.ac.bd": [
        "International Islamic University Chittagong",
        "International Islamic University Chittagong(IIUC)",
    ],
    ".isrt.ac.bd": ["Institute of Statistical Research and Training"],
    ".cse.jnu.ac.bd": ["Jagannath University", "Jagannath University"],
    ".ku.ac.bd": ["Khulna University"],
    ".kuet.ac.bd": ["Khulna University of Engineering And Technology"],
    ".lus.ac.bd": ["Leading University"],
    ".manarat.ac.bd": ["Manarat International University"],
    ".mbstu.ac.bd": ["Mawlana Bhashani Science And Technology University"],
    ".mist.ac.bd": ["Military Institute of Science and Technology (MIST)"],
    ".nu.ac.bd": ["National University, Bangladesh"],
    ".nub.ac.bd": ["Northern University Bangladesh"],
    ".cse.prstu.ac.bd": ["Pirojpur Science and Technology University"],
    ".pstu.ac.bd": ["Patuakhali Science and Technology University"],
    ".pust.ac.bd": ["Pabna University of Science And Technology"],
    ".student.rmstu.ac.bd": ["Rangamati Science and Technology University"],
    ".ru.ac.bd": ["University of Rajshahi"],
    ".ruet.ac.bd": ["Rajshahi University of Engineering And Technology"],
    ".sec.ac.bd": ["Sylhet Engineering College"],
    ".seu.ac.bd": ["Southeast University"],
    ".sub.ac.bd": [
        "State University Of Bangladesh",
        "State University Of Bangladesh",
    ],
    ".uiu.ac.bd": ["United International University (UIU)"],
    ".uset.ac.bd": ["University of Skill Enrichment and Technology (USET)"],
    ".dipti.com.bd": [
        "Daffodil International Professional Training Institute"
    ],
    ".dcc.netpoint.com.bd": ["Dhaka City College"],
    ".adust.edu.bd": ["Atish Dipankar University of Science & Technology"],
    ".agfuphs.edu.bd": ["Akkelpur Govt. Fazar Uddin (F.U) Pilot High School"],
    ".aiub.edu.bd": ["American International University - Bangladesh (AIUB)"],
    ".asaub.edu.bd": ["Asa University Bangladesh"],
    ".students.bau.edu.bd": [
        "বাংলাদেশ কৃষি বিশ্ববিদ্যালয়",
        "Bangladesh Agricultural University",
    ],
    ".bau.edu.bd": [
        "বাংলাদেশ কৃষি বিশ্ববিদ্যালয়",
        "Bangladesh Agricultural University",
    ],
    ".baust.edu.bd": [
        "Bangladesh Army University of Science and Technology (BAUST), Saidpur"
    ],
    ".bireswarpurghs.edu.bd": ["Bireswarpur Gov. High School"],
    ".bitschool.edu.bd": [
        "Bangladesh International Tutorial Limited",
        "Bangladesh International Tutorial Limited",
    ],
    ".bousst.edu.bd": ["School of Science and Technology, BOU"],
    ".bsikm.edu.bd": ["Bharella Shah Israil Kamil Madrasa"],
    ".bsmmu.edu.bd": [
        "বঙ্গবন্ধু শেখ মুজিব মেডিক্যাল বিশ্ববিদ্যালয়, বাংলাদেশ",
        "Bangabandhu Sheikh Mujib Medical University, Bangladesh",
    ],
    ".bsmrstu.edu.bd": [
        "Bangabandhu Sheikh Mujibur Rahman Science & Technology University, Gopalganj, Bangladesh"
    ],
    ".bu.edu.bd": ["Bangladesh University"],
    ".bubt.edu.bd": ["Bangladesh University of Business &amp; Technology"],
    ".buft.edu.bd": ["BGEMEA University Of Fashion & Technology"],
    ".tem.butex.edu.bd": ["Bangladesh University of Textiles"],
    ".cdcmn.edu.bd": ["Chakuli Degree College"],
    ".chongowngirlshighschool.edu.bd": ["chongowngirlshighschool"],
    ".cityuniversity.edu.bd": ["City University"],
    ".cub.edu.bd": ["Canadian University of Bangladesh"],
    ".daffodilvarsity.edu.bd": ["Daffodil International University"],
    ".diit.edu.bd": ["Daffodil Institute of IT"],
    ".dis.edu.bd": ["Daffodil International School"],
    ".diu.edu.bd": ["Daffodil Internation University"],
    ".dpsc.edu.bd": [
        "দাউদ পাবলিক স্কুল এন্ড কলেজ",
        "Daud Public School and College,Jashore Cantonment",
    ],
    ".dsti.edu.bd": [
        "Daffodil Science and Technology Institute",
        "Daffodil Science and Technology Institute",
    ],
    ".eastdelta.edu.bd": ["East Delta University"],
    ".easternuni.edu.bd": ["Eastern University"],
    ".fcub.edu.bd": ["First Capital University of Bangladesh"],
    ".fec.edu.bd": ["Faridpur Engineering College"],
    ".fiu.edu.bd": ["Fareast International University"],
    ".gccc.edu.bd": ["Government City College, Chattogram"],
    ".gems.edu.bd": ["Golgotha English Medium School"],
    ".gonouniversity.edu.bd": ["Gono Bishwabidwalay"],
    ".govtwcs.edu.bd": ["Sunamganj Govt. Women's College"],
    ".gpi.edu.bd": ["Genetic Polytechnic Institute"],
    ".green.edu.bd": ["Green University of Bangladesh"],
    ".gstu.edu.bd": ["Gopalganj Science and Technology University"],
    ".hamdarduniversity.edu.bd": ["Hamdard University Bangladesh"],
    ".ist.edu.bd": [
        "Institute of Science and Technology",
        "Institute of Science and Technology",
    ],
    ".iub.edu.bd": ["Independent University, Bangladesh"],
    ".jkkniu.edu.bd": ["Jatiya Kabi Kazi Nazrul Islam University"],
    ".student.just.edu.bd": ["Jashore University of Science and Technology"],
    ".manaratcollege.edu.bd": ["Manarat Dhaka International School & College"],
    ".metrouni.edu.bd": ["Metropolitan University"],
    ".mmacademy.edu.bd": ["মুসলিম মডার্ন একাডেমি", "Muslim Modern Academy"],
    ".nalbatahighschool.edu.bd": ["Nalbata High School"],
    ".niet.edu.bd": ["National Institute Of Engineering & Technology - NIET"],
    ".niter.edu.bd": [
        "National Institute of Textile Engineering and Research (NITER)"
    ],
    ".nstu.edu.bd": ["Noakhali University Of Science And Technology"],
    ".nu.edu.bd": ["National University"],
    ".portcity.edu.bd": ["Port City International University"],
    ".presidency.edu.bd": ["Presidency University"],
    ".primeuniversity.edu.bd": ["Prime University"],
    ".ranguniacollege.edu.bd": ["Rangunia Government College"],
    ".recr.edu.bd": ["Rangpur Engineering College"],
    ".royal.edu.bd": ["Royal University of Dhaka"],
    ".rtss.edu.bd": [
        "রাজ টেক্সটাইল মাধ্যমিক বিদ্যালয়",
        "RAZ TEXTILE HIGH SCHOOL",
    ],
    ".seu.edu.bd": ["Southeast University"],
    ".sgps.edu.bd": ["Saratnagar Goverment Primary School"],
    ".simecinstitute.edu.bd": ["SIMEC Institute of Technology"],
    ".siu.edu.bd": ["Sylhet International University"],
    ".sjs.edu.bd": [
        "St. Joseph Higher Secondary School",
        "St. Joseph Higher Secondary School",
    ],
    ".smrc.edu.bd": [
        "সরকারি শহীদ মশিয়ূর রহমান ডিগ্রি কলেজ",
        "Govt. Shahid Moshiur Rahman College",
    ],
    ".sshschool.edu.bd": [
        "শহীদ স্মৃতি উচ্চ বিদ্যালয়",
        "Shaheed Smrity High School",
    ],
    ".sss.edu.bd": ["সামন্তা মাধ্যমিক বিদ্যালয়", "Samonta High School"],
    ".stamforduniversity.edu.bd": ["Stamford University Bangladesh"],
    ".su.edu.bd": ["SONARGAON UNIVERSITY (SU)"],
    ".sunbeams.edu.bd": ["Sunbeams School", "Sunbeams School"],
    ".tec.edu.bd": ["TMSS Engineering College"],
    ".uits.edu.bd": ["University of Information Technology and Sciences"],
    ".ulab.edu.bd": ["University of Liberal Arts"],
    ".uttarauniversity.edu.bd": ["Uttara University"],
    ".wub.edu.bd": ["World University of Bangladesh"],
    ".fpms.ac.be": ["Faculté Polytechnique de Mons"],
    ".fsagx.ac.be": [
        "Faculté Universitaire des Sciences Agronomiques de Gembloux"
    ],
    ".fucam.ac.be": ["Facultés Universitaires Catholiques de Mons"],
    ".ful.ac.be": ["Fondation Universitaire Luxembourgeoise"],
    ".fundp.ac.be": ["Facultés Universitaires Notre-Dame de la Paix"],
    ".fusl.ac.be": ["Facultés Universitaires Saint-Louis"],
    ".kulak.ac.be": ["Katholieke Universiteit Leuven, Campus Kortrijk"],
    ".kuleuven.ac.be": ["Katholieke Universiteit Leuven"],
    ".rma.ac.be": ["Royal Military Academy"],
    ".ua.ac.be": ["Universiteit Antwerpen"],
    ".ucl.ac.be": ["Université Catholique de Louvain"],
    ".ufsia.ac.be": ["Universiteit Antwerpen, UFSIA"],
    ".ulb.ac.be": ["Université Libre de Bruxelles"],
    ".ulg.ac.be": ["Université de Liège"],
    ".umh.ac.be": ["Université de Mons-Hainaut"],
    ".umons.ac.be": ["University of Mons (merging of UMH and FPMS)."],
    ".vub.ac.be": ["Vrije Universiteit Brussel"],
    ".actournai.be": [
        "Official website : http://www.actournai.be/",
        "long term course on the official website (IT art, including game and web dev) : http://www.actournai.be/atelier/arts_numeriques",
    ],
    ".eduso.antwerpen.be": ["Stedelijk Onderwijs Antwerpen"],
    ".ap.be": ["AP Hogeschool Antwerpen"],
    ".ar-lessines.be": ["Athénée Royal René Magritte"],
    ".arjb.be": ["Athénée Royal Jules Bordet"],
    ".arteveldehs.be": ["Artevelde University College Ghent"],
    ".arvise.be": ["Athénée Royal de Visé"],
    ".assumpta.be": ["Lycée Maria Assumpta"],
    ".atlascollege.be": ["Atlas College"],
    ".avondschool.be": ["CVO Panta Rhei"],
    ".bastassart.be": ["Busleyden Atheneum"],
    ".bazandpoort.be": ["Busleyden Atheneum"],
    ".bcpop.be": ["LMC Poperinge"],
    ".bib-buellingen.be": ["Bischöfliches Institut Büllingen"],
    ".broeders.be": ["Broederscholen Hiëronymus"],
    ".campuskahalle.be": ["Atheneum Halle"],
    ".campussintursula.be": ["Campus Sint Ursula Lier"],
    ".cf2m.be": ["CF2m - Centre de Fomration TIC Bruxelles"],
    ".cidc.be": ["Centre IFAPME de Charleroi"],
    ".cnddinant.be": ["Collège Notre-Dame – Dinant"],
    ".cnldb.be": ["Haute Ecole Lucia de Brouckère"],
    ".collegehagelstein.be": [
        "College Hagelstein",
        "College Hagelstein",
        "collegehagelstein.be",
    ],
    ".condorcet.be": ["Haute Ecole Provinciale de Hainaut - Condorcet"],
    ".creo.be": ["Creo Secondary Adult Education Center"],
    ".cssm-student.be": ["Sainte-Marie Namur"],
    ".cvo-step.be": ["CVO STEP"],
    ".cvoantwerpen.be": ["CVO Antwerpen"],
    ".cvosemper.be": ["CVO Semper"],
    ".cylab.be": ["Cylab"],
    ".dbhaacht.be": ["Don Bosco Haacht"],
    ".dbz.be": ["Don Boscocollege Zwijnaarde"],
    ".digi4u.be": ["Syntra West"],
    ".donboscohoboken.be": ["Don Bosco Hoboken"],
    ".donboscosdw.be": ["Don Bosco Sint-Denijs-Westrem"],
    ".donboscoverviers.be": [
        "Institut Donbosco Verviers : Rue des Alliés 70, 4800 Verviers",
        "http://www.donboscoverviers.be/",
        "http://tqinfo.donboscoverviers.be/",
        "email adresse : XXX.XXXX@donboscoverviers.be",
    ],
    ".dvmhum.be": [
        "DvM Humaniora Aalst",
        "Mail domain for students.",
        'Main domain "dvmhumaniora.be"',
    ],
    ".dvmhumaniora.be": ["DvM Humaniora Aalst"],
    ".eafc-sudlux.be": ["EAFC Sud-Luxembourg"],
    ".eafc-uccle.be": ["EAFC-Uccle"],
    ".ecam.be": ["ECAM - Institut Supérieur Industriel"],
    ".eci-liege.be": ["ECI - École de commerce et d'informatique"],
    ".efpl.be": ["Enseignement de la Province de Liège", ".group"],
    ".ehb.be": ["Erasmushogeschool Brussel"],
    ".ehsal.be": ["EHSAL - Europese Hogeschool Brussel"],
    ".elmarche.be": ["Institut Saint-Laurent (Marche-en-Famenne)"],
    ".ephec.be": ["Economics and Technics School"],
    ".eps-marche.be": ["EPS Marche"],
    ".erce.be": ["Regina Caeli"],
    ".esa-namur.be": ["Ecole Supérieure des Affaires - Namur"],
    ".esmol.be": ["European School of Mol"],
    ".onderwijs.gent.be": ["Ziekenhuisschool Gent", "Hospital school Ghent"],
    ".leerling.gitokbovenbouw.be": ["Gitok bovenbouw"],
    ".groeipunt.be": ["CVO Groeipunt - Adult Education"],
    ".groept.be": ["Groep T Hogeschool Leuven"],
    ".gtibeveren.be": ["GTI Beveren"],
    ".gtil.be": ["Gemeentelijk Technisch Instituut Londerzeel", "GTIL"],
    ".ha.be": ["Hogeschool Antwerpen"],
    ".hainaut-ea.be": ["Enseignement pour Adultes de la Province de Hainaut"],
    ".hainaut-promsoc.be": [
        "Haute Ecole Provinciale de Hainaut -promotion sociale"
    ],
    ".student.hdcleuven.be": ["Heilige-Drievuldigheidscollege"],
    ".he-spaak.be": ["Haute Ecole Paul-Henri Spaak"],
    ".he2b.be": ["Haute École Bruxelles-Brabant"],
    ".heaj.be": ["Haute Ecole Albert Jacquard"],
    ".heb.be": ["Haute Ecole de Bruxelles"],
    ".hecfh.be": ["Haute École en Hainaut"],
    ".student.hech.be": ["Haute Ecole Charlemagne Les Rivageois"],
    ".heh.be": ["Haute École en Hainaut"],
    ".student.hel.be": [
        "Haute école de la ville de Liège",
        "High School of the City of Liège",
    ],
    ".helb-prigogine.be": ["HELB Iliya Prigogine"],
    ".helha.be": ["Haute École Louvain en Hainaut"],
    ".helmo.be": ["Haute Ecole Libre Mosane"],
    ".henallux.be": ["Haute ecole de namur-liege-luxembourg"],
    ".hepl.be": ["Haute Ecole de la Province de Liège"],
    ".hers.be": ["Haute École Robert Schuman"],
    ".hhscholen.be": ["Heilig Hartinstituut"],
    ".hik.be": ["hik - hogeschool der kempen"],
    ".hogent.be": ["University College Ghent"],
    ".howest.be": ["Hogeschool West-Vlaanderen (TU)"],
    ".hzs.be": ["Hogere Zeevaartschool - Maritime Academy"],
    ".etu.iad-arts.be": ["Institut des Arts de Diffusion"],
    ".ichec.be": ["Brussels Management School (ICHEC)"],
    ".icinstitute.be": ["IC Institute"],
    ".iepscf-uccle.be": ["EAFC-Uccle"],
    ".iepsevere.be": ["IEPS Evere"],
    ".apprenant.ifapme.be": [
        "IFAPME - Institut wallon de Formation en Alternance et des indépendants et Petites et Moyennes Entreprises",
        "IFAPME",
    ],
    ".formateur.ifapme.be": [
        "IFAPME - Institut wallon de Formation en Alternance et des indépendants et Petites et Moyennes Entreprises",
        "IFAPME",
    ],
    ".ifosupwavre.be": ["IFOSUP - Institute de Formation Superieure"],
    ".ihecs.be": [
        "Institut des Hautes Études des Communications Sociales (IHECS)",
        "https://www.ihecs.be/",
        "IT related course: https://www.ihecs.be/sites/default/files/uploads/docs/Programme/ihecs-programme2022-2023_web.pdf ",
        '                   Please take a look on page 10 of the .pdf, an IDE is required for the course entitled: "CODES & LANGAGES MÉDIATIQUES (CODE1101)" which means "CODES & MEDIA LANGUAGES".',
        "                    ",
        "Official email domain for students: @student.ihecs.be",
        "                       Proof of the academic regulations of the university :https://drive.google.com/file/d/1UfCDOQvY6izhM4RIhdIxogGClfa0Bgqj/view?usp=share_link",
        "                        ",
    ],
    ".ikorn.be": ["IKORN NINOVE"],
    ".immalle.be": ["Immaculata Instituut Oostmalle"],
    ".ind-thuin.be": ["Institut Notre-Dame de Thuin"],
    ".student.inda.be": [
        "Institut Notre-Dame d'Arlon",
        "Notre-Dame Institute of Arlon",
    ],
    ".indbg.be": ["Institut Notre-Dame de Beauraing"],
    ".intecbrussel.be": ["Intec Brussel (CVO)"],
    ".student.iram.be": ["Institut Reine Astrid Mons Promotion Sociale"],
    ".isagosselies.be": ["Institut Sainte-Anne"],
    ".isb.be": ["International School of Brussels"],
    ".isfce.be": ["Institut Superieur de Formation Continue d'Etterbeek"],
    ".isjlalouviere-ac.be": ["Institut Saint-Joseph"],
    ".isl-edu.be": ["Institut Saint-Laurent"],
    ".portail.itlg.be": ["Institut de Technologie de Liège"],
    ".itscm.be": ["Institut Technique supérieur Cardinal Mercier", "ITSCM"],
    ".ivobrugge.be": ["CVO Instituut voor volwassenenonderwijs Brugge"],
    ".katho.be": ["KATHO University of Applied Sciences"],
    ".kdg.be": ["Karel De Grote Hogeschool"],
    ".khbo.be": ["Catholic College Bruges-Ostend"],
    ".khk.be": ["Katholieke Hogeschool Kempen"],
    ".khleuven.be": ["Katholieke Hogeschool Leuven"],
    ".khlim.be": ["Katholieke Hogeschool Limburg"],
    ".student.kjhasselt.be": [
        "Scholen Kinsheid Jesu",
        "Schools Kinsheid Jesu",
    ],
    ".klein-seminarie.be": ["Klein Seminatie Hoogstraten"],
    ".kobos.be": ["KOBOS"],
    ".kogeka.be": ["Kogeka", "Kogeka"],
    ".kohamme.be": ["KOHa Sint Jozef"],
    ".ksdiest.be": ["Katholieke Scholen Diest"],
    ".hdc.ksleuven.be": ["Heilige-Drievuldigheidscollege"],
    ".min.ksleuven.be": ["Miniemeninstituut"],
    ".student.kta1-hasselt.be": ["GO! NEXT KTA1 Hasselt", "KTA1"],
    ".kuleuven.be": ["KU Leuven"],
    ".kvri.be": [
        "Kardinaal Van Roey-Instituut",
        "Cardinal Van Roey-Institute",
    ],
    ".leerling-ptsmechelen.be": ["PTS Mechelen"],
    ".leielandscholen.be": ["Scholengroep Leielandscholen VZW"],
    ".luca-arts.be": ["Luca School of Arts"],
    ".lyceefrancais.be": [
        "IT option at the French Lycée Jean Monnet in Brussels"
    ],
    ".mad-fac.be": [
        " Media, Arts and Design Faculty at University College of Limburg & Provincial University College Limburg"
    ],
    ".maerlantatheneum.be": ["Maerlant Atheneum"],
    ".maredschool.be": ["Collège Saint-Benoît de Maredsous"],
    ".miras.be": ["CVO Miras"],
    ".mobyus.be": ["Mobyus"],
    ".montfort.be": ["Montfort College Rotselaar"],
    ".myepse.be": ["Enseignement de Promotion Sociale d'Enghien"],
    ".eicpn.province.namur.be": [
        "École Industrielle et Commerciale de la Province de Namur"
    ],
    ".ipfs.province.namur.be": ["Institut Provincial de Formation Sociale"],
    ".odisee.be": ["University College Odisee"],
    ".olvp.be": ["Scholen Onze-Lieve-Vrouw-Presentatie, Sint-Niklaas"],
    ".openuniversiteit.be": ["Open University Belgium"],
    ".schueler.pds-eupen.be": ["Pater-Damian-Sekundarschule"],
    ".petrusenpaulus.be": ["Petrus en Paulus vzw"],
    ".student.ppsjo.be": ["Sint-Jozef Oostende", "Saint-Joseph Ostend"],
    ".staff.promsoc-arlon.be": ["Promotion Sociale Arlon"],
    ".student.promsoc-arlon.be": ["Promotion Sociale Arlon"],
    ".provilion.be": ["Provinciaal Instituut Lommel"],
    ".pti.be": [
        "provinciaal tichnisch instituut West-Vlaanderen",
        "provincial technical institute West Flanders",
    ],
    ".pxl.be": ["Hogeschool PXL"],
    ".qrios.be": ["Qrios"],
    ".reginacaeli.be": ["Regina Caeli"],
    ".ritacollege.be": ["Sint-Ritacollege Kontich"],
    ".student.romerocollege.be": ["Oscar. Romero. College. Belgium."],
    ".romerocollege.be": ["Óscar Romerocollege"],
    ".s19.be": ["Ecole 19"],
    ".student.saintstanislas.be": [
        "Centre scolaire Saint-Stanislas – Mons",
        "Saint-Stanislas School Center – Mons",
    ],
    ".scheppers.be": [
        "Scheppersinstituut Deurne & Antwerpen",
        "Scheppersinstituut Antwerpen",
        "Scheppersinstituut Deurne",
    ],
    ".scheppersinstituut.be": [
        "Scheppersinstituut Deurne & Antwerpen",
        "Scheppersinstituut Antwerpen",
        "Scheppersinstituut Deurne",
    ],
    ".sgclier.be": ["Sint-Gummaruscollege", "Sint-Gummaruscollege"],
    ".leerkracht.sgr20.be": ["GO! Atheneum Zottegem", "GO! Atheneum Zottegem"],
    ".leerling.sgr20.be": ["GO! Atheneum Zottegem", "GO! Atheneum Zottegem"],
    ".sgvw.be": ["College Veurne"],
    ".sibbo.be": ["SBSO SIBBO"],
    ".sint-michiel.be": ["Scholengroep Sint-Michiel"],
    ".sint-pietersinstituut.be": ["Sint-Pietersinstituut Turnhout"],
    ".sint-rembert.be": ["Sint-Rembert Scholengroep", ".group"],
    ".sintcordula.be": ["Sint-Cordula-instituut Schoten"],
    ".sintlievenscollege.be": [
        "Sint-Lievenscollege Business",
        "Website: slcb.be   ",
        "Location: Gent, Belgium",
        "Course: https://www.slcb.be/aanbod/niveau-5/it-en-netwerken",
        "We have students 17-18-19 years old who learn C#, Javascript, PHP, PowerShell, ... in two years at our school in the courses IT and Networking.",
        "Proof of @sintlievenscollege.be: https://www.slcb.be/contact",
        "Domains: @sintlievenscollege.be and @student.sintlievenscollege.be",
    ],
    ".sji.be": ["Sint-Jozef Instituut"],
    ".sjks.be": ["Sint-Jozef-Klein-Seminarie", "Sint-Jozef-Klein-Seminarie"],
    ".slcb.be": [
        "Sint-Lievenscollege Business",
        "Website: slcb.be   redirects to our old domain vhsj.be, we are creating at the moment a new website under our new name slcb.",
        "Location: Gent, Belgium",
        "Course: http://www.vhsj.be/sint-joris/index.php?p=130",
        "We have students 17-18-19 years old who learn C#, Javascript, PHP, PowerShell, ... in two years at our school in the courses IT and Networking.",
        "Proof of @slcb.be: http://www.vhsj.be/sint-joris/index.php?p=158",
    ],
    ".smsi.be": ["College IEPER"],
    ".snt.be": ["SNT CVO Centrum voor Volwassenenonderwijs Brugge"],
    ".spectrumcollege.be": ["Spectrumcollege Beringen"],
    ".spectrumstudent.be": ["spectrumcollege"],
    ".st-martinus.be": ["Sint-Martinusscholen Herk-de-Stad"],
    ".stben.be": ["Communauté scolaire Saint-Benoît"],
    ".steinerschoolleuven.be": ["Steinerschool Leuven"],
    ".sui.be": ["Sint-Ursula-Instituut"],
    ".syntrawest.be": ["SYNTRA West"],
    ".takeerbergen.be": ["Technisch Atheneum Keerbergen"],
    ".technischatheneumkeerbergen.be": [
        "Technisch Atheneum Keerbergen",
        "Technical Atheneum Keerbergen",
    ],
    ".thomasmore.be": ["Thomas More"],
    ".tihf.be": ["Technisch Instituut de Heilige Familie Brugge"],
    ".tsaam.be": ["'t Saam Diksmuide"],
    ".uams.be": ["Universiteit Antwerpen Management School"],
    ".uantwerpen.be": ["University of Antwerp"],
    ".ucll.be": ["University College Leuven-Limburg"],
    ".uclouvain.be": ["Catholic University of Louvain"],
    ".ugent.be": ["Ghent University"],
    ".uhasselt.be": ["Hasselt University"],
    ".ulb.be": [
        "Université Libre de Bruxelles",
        "Free University of Brussels",
    ],
    ".uliege.be": ["Université de Liège"],
    ".unamur.be": ["Université de Namur"],
    ".uzbrussel.be": [
        "UZBrussel",
        "University Hospital of the Free University Brussel (VUB)",
    ],
    ".vdabcampus.be": ["VDAB Campus", ".group"],
    ".viatienen.be": ["Via Tienen"],
    ".vibo.be": ["VIBO BuSO Het Kasteelpark"],
    ".vinci.be": ["Haute École Léonard de Vinci"],
    ".virgosapiens.be": ["Virgo Sapiens Institute", "Virgo Sapiens Institute"],
    ".vitaetpax.be": ["Vita et Pax-college"],
    ".vives.be": ["Katholieke hogeschool VIVES"],
    ".student.viveshbo5.be": ["VIVES University College"],
    ".vlekho.be": ["Hogeschool voor Wetenschap en Kunst (VLEKHO), Brussel"],
    ".vlerick.be": ["Vlerick Leuven Gent Management School"],
    ".vspw.be": [
        "PCVO Vormingsleergang voor Sociaal en Pedagogisch Werk Gent"
    ],
    ".vtibrugge.be": ["Vrij Technisch Instituut Brugge"],
    ".vtideinze.be": ["VTI Deinze"],
    ".vub.be": ["Vrije Universiteit Brussel"],
    ".ifosup.wavre.be": ["IFOSUP"],
    ".wenk.be": ["Hogeschool voor Wetenschap &amp; Kunst"],
    ".xios.be": ["XIOS Hogeschool Limburg"],
    ".afg-schule.berlin": ["Anne-Frank Gymnasium"],
    ".code.berlin": ["CODE University of Applied Sciences in Berlin"],
    ".gkbs.berlin": [
        "Integrierte Sekundarschule Georg-Klingenberg",
        "Georg-Klingenberg-School",
    ],
    ".iserv.kkg.berlin": ["Käthe-Kollwitz-Gymnasium Berlin"],
    ".edu.letteverein.berlin": ["Lette Verein Berlin"],
    ".ong.berlin": ["Otto-Nagel-Gymnasium"],
    ".rlg.berlin": ["Rosa-Luxemburg-Gymnasium"],
    ".esta.bf": ["Ecole Supérieure des Techniques Avancées (ESTA) "],
    ".u-naziboni.bf": ["Université Nazi BONI de Bobo-Dioulasso"],
    ".univ-ouaga.bf": ["Université de Ouagadougou"],
    ".student.51school.bg": [
        '51 СРЕДНО УЧИЛИЩЕ "ЕЛИСАВЕТА БАГРЯНА", София, България',
        '51 High School "Elisaveta Bagryana", Sofia, Bulgaria',
    ],
    ".acad.bg": [
        "Technical University of Varna",
        "University of National and World Economy",
        "University of Rousse",
    ],
    ".au-plovdiv.bg": ["Agricultural University of Plovdiv"],
    ".aubg.bg": ["American University in Bulgaria"],
    ".ir.bas.bg": [
        "Bulgarian Academy of Science",
        "Institute of robotics",
        "http://ir.bas.bg/",
    ],
    ".bfu.bg": ["Bourgas Free University"],
    ".btu.bg": ["Bourgas University Prof. Assen Zlatarov"],
    ".buditel.bg": [
        "ЧПГДН СофтУни БУДИТЕЛ",
        '"Private Professional High School of Digital Science SoftUni BUDITEL" Ltd.',
    ],
    ".codingburgas.bg": [
        "Професионална Гимназия по Компютърно Програмиране и иновации",
        "Vocational School for Computer Programming and Innovations",
    ],
    ".hit.bg": ["Academy of Music, Dance and Fine Arts"],
    ".ibsedu.bg": [
        "Международно Висше Бизнес Училище",
        "International Business School",
    ],
    ".itpg-varna.bg": [
        "High School of Computer Modeling and Computer Systems (Професионална гимназия по моделиране и компютърни системи)"
    ],
    ".ltu.bg": ["University of Forestry Sofia"],
    ".meduniversity-plovdiv.bg": ["Medical University Plovdiv"],
    ".mg-babatonka.bg": [
        'Математическа гимназия "Баба Тонка"',
        "Baba Tonka High School of Mathematics",
    ],
    ".mgu.bg": ["University of Mining and Geology St. Ivan Rils"],
    ".edu.mon.bg": ["Ministry of Education and Science - Bulgaria"],
    ".mu-plovdiv.bg": [
        "Medical University Plovdiv",
        "Medical University Plovdiv",
    ],
    ".mu-sofia.bg": ["Medical University of Sofia"],
    ".mu-varna.bg": ["Medical University Varna"],
    ".natfiz.bg": [
        "National Academy for Theatre and Film Arts Krustju Sarafov"
    ],
    ".naval-acad.bg": [
        'Висше Военноморско Училище "Никола Йонков Вапцаров"',
        "Nicola Vaptsarov Naval Academy",
    ],
    ".nbu.bg": ["New Bulgarian University"],
    ".nma.bg": ["National Academy of Music Pantcho Vladigerov"],
    ".nsa.bg": ["National Sports Academy Sofia"],
    ".ntbg.bg": ["National Trade and Banking High School"],
    ".nvu.bg": [
        'Национален Военен Университет „Васил Левски"',
        'National Military University "Vasil Levski"',
    ],
    ".pmggd.bg": [
        "Природо-математическа гимназия „Яне Сандански“",
        'High School of Natural Sciences and Mathematics "Yane Sandanski"',
    ],
    ".pv-ma.bg": ["Military University Shoumen"],
    ".rndc.bg": [
        "Rakovski National Defence College",
        "Rakovski National Defence College",
    ],
    ".shu.bg": ['Shumen University "Konstantin Preslavsky" (http://shu.bg)'],
    ".smg.bg": [
        'Софийска математическа гимназия "Паисий Хилендарски"',
        'Sofia Mathematics high school "Paisius of Hilendar"',
    ],
    ".softuni.bg": ["Software University", "Sofia", "Bulgaria"],
    ".swu.bg": ["South-West University Neofit Rilski"],
    ".trakia-uni.bg": ["Тракийски университет", "Trakia University"],
    ".tu-plovdiv.bg": [
        "Технически университет София - филиал Пловдив",
        "Technical University of Plovdiv",
    ],
    ".tu-sofia.bg": ["Technical University of Sofia"],
    ".tu-varna.bg": ["Technical University of Varna"],
    ".tugab.bg": ["Technical University of Gabrovo"],
    ".uacg.bg": ["University of Architecture, Civil Engineering and Geodesy"],
    ".ue-varna.bg": ["University of Economics Varna"],
    ".uft-plovdiv.bg": ["University of Food Technology"],
    ".uni-plovdiv.bg": ["University of Plovdiv"],
    ".uni-ruse.bg": ["University of Ruse"],
    ".uni-sofia.bg": ["Sofia University St. Kliment Ohridski"],
    ".uni-svishtov.bg": ["Academy of Economics Dimitur A. Tscenov"],
    ".uni-sz.bg": ["Trakia University Stara Zagora"],
    ".uni-vt.bg": ["Veliko Turnovo University Cyril and Methodius"],
    ".unibit.bg": [
        "University of Library Studies and Information Technologies"
    ],
    ".uniburgas.bg": [
        'Университет "Проф. Д-р Асен Златаров" гр. Бургас',
        "University prof. dr. Asen Zlatarov Burgas",
        "uniburgas.bg",
        "btu.bg",
    ],
    ".unwe.bg": ["University of National and World Economy"],
    ".utp.bg": ["University of Telecommunications and Posts"],
    ".uwekind.bg": ["International School Uwekind "],
    ".vfu.bg": ["Varna Free University"],
    ".vtu.bg": [
        "Висшето транспортно училище „Тодор Каблешков“",
        '"Todor Kableshkov" Higher Transport School',
    ],
    ".yovkovschoolvarna.bg": [
        "Secondary School Yordan Yovkov",
        "Secondary School Yordan Yovkov",
    ],
    ".stu.asb.bh": [
        "American School of Bahrain",
        "American School of Bahrain",
    ],
    ".agu.edu.bh": ["Arabian Gulf University"],
    ".amaiu.edu.bh": ["Ama International University"],
    ".asu.edu.bh": ["Applied Science University"],
    ".ku.edu.bh": ["The Kingdom University"],
    ".nyit.edu.bh": ["New York Instiute of Technology"],
    ".ucb.edu.bh": ["University College Bahrain"],
    ".uob.edu.bh": ["University of Bahrain"],
    ".indianschool.bh": ["The Indian School Bahrain"],
    ".aou.org.bh": ["Arab Open University"],
    ".polytechnic.bh": ["Bahrain Polytechnic"],
    ".ub.edu.bi": ["University of Burundi"],
    ".esgis.bj": [
        "École Supérieure de Gestion d'Informatique et des Sciences",
        "Higher School of Management, Computer Science and Sciences",
    ],
    ".uac.bj": ["Université d'Abomey-Calavi (UAC)"],
    ".unstim.bj": [
        "Université Nationale des Sciences Technologies Ingénieries et Mathématiques d'Abomey (UNSTIM)",
        "National University of Sciences, Engineering and Mathematics of Abomey",
    ],
    ".bercol.bm": ["Bermuda College"],
    ".laksamanacollege.edu.bn": ["Laksamana College of Business"],
    ".ubd.edu.bn": ["University of Brunei Darussalam"],
    ".unissa.edu.bn": ["Universiti Islam Sultan Sharif Ali"],
    ".udivirtual.com.bo": ["Universidad para el Desarrollo y la Innovación"],
    ".ccc.edu.bo": ["Colegio Cristiano Colcapirhua", "C.C.C"],
    ".dbp.edu.bo": [],
    ".donboscosucre.edu.bo": ["Don Bosco High School, Sucre, Bolivia"],
    ".ef-gipet.edu.bo": ["ESCUELA FINANCIERA GIPET"],
    ".emi.edu.bo": ["Escuela Militar de Ingeniería"],
    ".esam.edu.bo": ["Escuela de negocios ESAM", "Business School ESAM"],
    ".fcpn.edu.bo": [
        "Universidad Mayor de San Andres",
        "University Major of San Andres",
    ],
    ".fhumanidades-uagrm.edu.bo": [
        "Facultad de Humanidades, Gabriel Rene Moreno"
    ],
    ".incos-santacruz.edu.bo": [
        "Solicitud Incos Santa Cruz",
        "Correo dominio: incos-santacruz.edu.bo",
        "pagina web: https://incos-santacruz.edu.bo/",
    ],
    ".industrialmurillo.edu.bo": [
        "Escuela Industrial Superior Pedro Domingo Murillo"
    ],
    ".nur.edu.bo": ["NUR"],
    ".sanagustin.edu.bo": ["San Agustin", "San Agustin"],
    ".uab.edu.bo": ["Universidad Adventista de Bolivia"],
    ".uabjb.edu.bo": ["Universidad Autónoma del Beni José Ballivián"],
    ".uagrm.edu.bo": ["Universidad Autónoma Gabriel René Moreno"],
    ".uajms.edu.bo": [
        "Universidad Autónoma Juan Misael Saracho",
        "Universidad Juan Misael Saracho",
    ],
    ".uap.edu.bo": ["Universidad Amazónica de Pando"],
    ".uasb.edu.bo": ["Universidad Andina Simón Bolivar"],
    ".uatf.edu.bo": ["Universidad Autónoma Tomás Frías"],
    ".ubilapaz.edu.bo": [
        "Universidad Boliviana de Informatica",
        "Bolivian University of Informatica ",
    ],
    ".ucb.edu.bo": ["Universidad Católica Boliviana, La Paz"],
    ".ucbcba.edu.bo": ["Universidad Católica Boliviana, Cochabamba"],
    ".ucbscz.edu.bo": ["Universidad Católica Boliviana, Santa Cruz"],
    ".ucbtja.edu.bo": ["Universidad Católica Boliviana, Tarija"],
    ".udabol.edu.bo": ["Universidad de Aquino Bolivia"],
    ".udelosandes.edu.bo": ["Universidad Los Andes"],
    ".ueb.edu.bo": ["Universidad Evangélica Boliviana"],
    ".ulasalle.edu.bo": [
        "Universidad LaSalle Bolivia",
        "LaSalle Bolivia University",
    ],
    ".umss.edu.bo": ["Universidad Mayor de San Simón"],
    ".unefco.edu.bo": [
        "Unidad Especializada de Formación Continua - UNEFCO",
        "Unidad Especializada de Formación Continua - UNEFCO",
    ],
    ".unicen.edu.bo": ["Universidad Central"],
    ".unifranz.edu.bo": ["Universidad Privada Franz Tamayo (UNIFRANZ)"],
    ".unipol.edu.bo": ['Universidad Policial "Mcla. Antonio José de Sucre"'],
    ".unitepc.edu.bo": ["Universidad Técnica Privada Cosmos"],
    ".unslp.edu.bo": ["Universidad Nuestra Senora de La Paz"],
    ".unsxx.edu.bo": ["Universidad Nacional Siglo XX Llallagua"],
    ".upds.edu.bo": ["Universidad Domingo Savio"],
    ".upsa.edu.bo": ["Universidad Privada de Santa Cruz de la Sierra"],
    ".usfa.edu.bo": [
        "Universidad Privada San Francisco de Asís",
        "Universidad San Francisco de Asís",
    ],
    ".usfx.edu.bo": ["Universidad San Francisco Xavier de Chuquisaca"],
    ".usip.edu.bo": [
        "Universidad Simon I Patiño",
        "Simon I Patiño University",
    ],
    ".uto.edu.bo": ["Universidad Técnica de Oruro"],
    ".upds.net.bo": [
        "Universidad Privada Domingo Savio",
        "Domingo Savio Private University",
    ],
    ".umsa.bo": ["Universidad Mayor de San Andrés"],
    ".upea.bo": [
        "Universidad publica de El Alto",
        "Public University of El Alto",
    ],
    ".usfx.bo": [
        "Universidad Mayor Real y Pontificia de San Francisco Xavier de Chuquisaca",
        "San Francisco Xavier University",
    ],
    ".aedb.br": ["Associação Educacional Dom Bosco"],
    ".aiec.br": ["Faculdade AIEC"],
    ".alfa.br": ["Faculdades Alves Faria"],
    ".escolas.anchieta.br": ["Grupo Anchieta", "Anchieta's Group"],
    ".anhembi.br": ["Universidade Anhembi Morumbi"],
    ".baraodemaua.br": ["Centro Universitário Barao de Maua"],
    ".mail.bomjesus.br": ["Bom Jesus Carlos Démia"],
    ".brazcubas.br": ["Universidade Braz Cubas"],
    ".cairu.br": [
        "Fundação Visconde de Cairu",
        "Viscount of Cairu Foundation",
    ],
    ".candidomendes.br": ["Universidade Candido Mendes"],
    ".castelobranco.br": ["Universidade Castelo Branco"],
    ".cbpf.br": ["Centro Brasileiro de Pesquisas Físicas"],
    ".cefetmg.br": ["Centro Federal de Educação Tecnológica de Minas Gerais"],
    ".cesed.br": ["Centro de Ensino Superior e Desenvolvimento"],
    ".cesjf.br": ["Centro de Ensino Superior de Juiz de Fora"],
    ".cesuc.br": ["Centro de Ensino Superior de Catalão"],
    ".cesul.br": ["CESUL - Centro Sulamericano de Ensino Superior"],
    ".cesumar.br": ["Centro Universitário de Maringá"],
    ".aluno.cesupa.br": ["Centro Universitário do Estado do Pará"],
    ".prof.cesupa.br": [
        "Centro Universitário do Pará",
        "Cesupa",
        "Pará University Center",
    ],
    ".cnec.br": ["Campanha Nacional de Escolas da Comunidade (CNEC)"],
    ".academicougb.com.br": ["Centro Universitário Geraldo Di Biase"],
    ".acadunivag.com.br": ["Centro Universitário de Várzea Grande"],
    ".alunos.afya.com.br": ["UNIMA - Afya"],
    ".alfaunipac.com.br": ["AlfaUnipac", "AlfaUnipac"],
    ".alunocea.com.br": ["Colégio Espaço Aberto"],
    ".alunoesamc.com.br": [
        "Escola Superior de Administração, Marketing e Comunicação"
    ],
    ".alunofg.com.br": ["UNIFG - Centro Universitário dos Guararapes"],
    ".alunofoc.com.br": ["Faculdades Oswaldo Cruz"],
    ".alunofpb.com.br": [
        "Faculdade Internacional da Paraiba",
        "International Faculty of Paraiba",
    ],
    ".alunoimpacta.com.br": ["FIT - Faculdade Impacta de Tecnologia"],
    ".alunomelies.com.br": ["Faculdade Méliès"],
    ".alunosmaristas.com.br": ["Colégio Marista Arquidiocesano"],
    ".alunounyleya.com.br": ["Unyleya"],
    ".animaeducacao.com.br": ["Anima Educacao Group"],
    ".athonedu.com.br": ["ATHON Ensino Superior"],
    ".bandtec.com.br": ["Faculdade de Tecnologia Bandeirantes - BandTec"],
    ".beityaacov.com.br": ["Escola Beit Yaacov"],
    ".bilac.com.br": ["Faculdade Bilac"],
    ".alunos.bpkedu.com.br": ["Biopark Educação"],
    ".ceduphh.com.br": ["Centro de Educação Profissional Hermann Hering"],
    ".ceepcascavel.com.br": [
        "Centro Estadual de Educação Profissional Pedro Boaretto Neto",
        "CEEP - Pedro Boaretto Neto",
    ],
    ".celsoonline.com.br": ["Centro Universitario Celso Lisboa"],
    ".censupeg.com.br": ["Faculdade Censupeg"],
    ".ceuma.com.br": ["Centro Universitário do Maranhão - CEUMA", "CEUMA"],
    ".cogna.com.br": ["Cogna Educação", "Cogna Education"],
    ".colband.com.br": ["Colégio Bandeirantes"],
    ".colegioflama.com.br": ["Flama", "Flama"],
    ".colegiomercurio.com.br": ["Colégio Mercúrio"],
    ".colegionovo.com.br": ["Colégio Novo", "New College"],
    ".colegiopolitec.com.br": ["Colégio Politec"],
    ".colegioprovecto.com.br": ["Colégio Provecto", "Provecto College"],
    ".colegioresgate.com.br": ["Colégio Resgate"],
    ".colegiosantamonica.com.br": ["Colegio Santa Monica"],
    ".colegiosantanh.com.br": ["Colégio Santa Catarina"],
    ".colegiosmaristas.com.br": [
        "Colegio Marista Alexander Fleming",
        "College Marista Alexander Fleming",
    ],
    ".colmaster.com.br": ["Colégio Master Sul"],
    ".cotemig.com.br": ["Faculdade COTEMIG"],
    ".cscs.com.br": ["Colegio Santa Catarina de Sena"],
    ".descomplica.com.br": ["Faculdade Descomplica"],
    ".educarbiguacu.com.br": ["Colégio Educar Biguaçu"],
    ".educsi.com.br": ["Colégio Santo Inácio"],
    ".einsteinlimeira.com.br": ["Einstein Limeira"],
    ".escoladotrabalhador40.com.br": [
        "Caminho Digital — Ministério do Trabalho e Emprego"
    ],
    ".aluno.escolajaimealencar.com.br": ["EEEP Jaime Alencar de Oliveira"],
    ".escolamobile.com.br": ["Escola Móbile", "Móbile School"],
    ".escolatecnicaadelia.com.br": [
        "Escola Técnica Adélia",
        "Adelia Technical School",
    ],
    ".estacio.com.br": ["CENTRO UNIVERSITÁRIO ESTÁCIO DE SANTO ANDRÉ"],
    ".etecdeguaianazes.com.br": ["Etec de Guaianazes"],
    ".eterj.com.br": [
        "Escola Técnica do Rio de Janeiro",
        "Technical School of Rio de Janeiro",
    ],
    ".facamp.com.br": ["Facamp:  http://www.facamp.com.br", "Facamp"],
    ".edu.faccar.com.br": ["FACCAR - Faculdade Paranaense"],
    ".aluno.facthus.com.br": [
        "Faculdade de Talentos Humanos",
        "FACTHUS - Faculdade de Talentos Humanos",
        "Facthus",
    ],
    ".faculdadebarretos.com.br": ["Faculdade Barretos"],
    ".faculdadecci.com.br": ["Faculdade CCI", "CCI University"],
    ".aluno.faculdadedescomplica.com.br": [
        "Faculdade Descomplica",
        "Descomplica University",
    ],
    ".aluno.faculdadeimpacta.com.br": ["Faculdade Impacta de Tecnologia"],
    ".faculdadeimpacta.com.br": ["IMPACTA TECNOLOGIA ELETRONICA LTDA"],
    ".faculdadeporto.com.br": ["Faculdade Porto"],
    ".faculdadeprominas.com.br": ["Faculdade PROMINAS"],
    ".faculdadeserradourada.com.br": [
        "Faculdade Serra Dourada Lorena",
        "Faculdade Serra Dourada Altamira",
    ],
    ".faculdadesprominas.com.br": ["Faculdade PROMINAS"],
    ".faculdadeunica.com.br": ["Faculdade ÚNICA"],
    ".fadergs.com.br": ["Fadergs"],
    ".faespi.com.br": ["Faculdade de Ensino Superior do Piauí"],
    ".fai.com.br": [
        "Centro Universitário de Adamantina - UNIFAI",
        "University Center of Adamantina",
    ],
    ".fainor.com.br": ["Faculdade Independente do Nordeste"],
    ".fals.com.br": ["Faculdade do Litoral Sul Paulista - FALS"],
    ".fametro.com.br": ["Faculdade Metropolitana"],
    ".fap.com.br": ["FAP - Faculdade de Apucarana"],
    ".fasar.com.br": ["Faculdade Santa Rita - FASAR", "FASAR"],
    ".fasipe.com.br": ["Unifasipe Centro Educacional"],
    ".fecaf.com.br": ["Faculdade Capital Federal", "FECAF"],
    ".feituverava.com.br": ["Fundação Educacional de Ituverava"],
    ".femaf.com.br": [
        "Faculdade de Educação Memorial Adelaide Franco - FEMAF"
    ],
    ".fgp.com.br": ["Faculdade Genare & Peatre"],
    ".fia.com.br": ["FIA - Fundação Instituto de Administração"],
    ".fiap.com.br": ["Faculdade de Informatica e Administração Paulista"],
    ".fieg.com.br": ["Faculdade Senai Fatesg"],
    ".flucianofeijao.com.br": [
        "Faculdade Luciano Feijão",
        "Luciano Feijão College",
    ],
    ".ftec.com.br": ["Faculdade de Tecnologia TECBrasil"],
    ".grupoprominas.com.br": ["Grupo PROMINAS"],
    ".aluno.idealbsb.com.br": ["Colegio Ideal"],
    ".ideau.com.br": [
        "Instituto de Desenvolvimento Educacional do Alto Uruguai - IDEAU",
        "Alto Uruguay Educational Development Institute - IDEAU",
    ],
    ".ienh.com.br": [
        "Faculdade IENH - Instituição Evangélica de Novo Hamburgo"
    ],
    ".institutomix.com.br": [
        "Instituto Mix de Profissões",
        "Mix Institute of Professions",
    ],
    ".ises.com.br": ["Instituto de Socioeconomia Solidária"],
    ".jopers.com.br": ["João Paulo I"],
    ".kroton.com.br": ["Universidade Pitágoras", "University Pitagoras"],
    ".liberato.com.br": [
        "Fundação Escola Técnica Liberato Salzano Vieira da Cunha"
    ],
    ".liceusantista.com.br": ["Liceu Santista"],
    ".mackenzista.com.br": ["Mackenzie Presbyterian University"],
    ".maisunifacisa.com.br": ["Unifacisa", "Unifacisa"],
    ".marioquintana.com.br": ["Escola Mario Quintana, Pelotas / RS"],
    ".melies.com.br": [
        "Faculdade de Tecnologia Melies",
        "Website: https://www.melies.com ",
        "Email: melies.com.br",
    ],
    ".meuibgen.com.br": ["IBGEN Business School"],
    ".msofia.com.br": [
        "Colégio Santa Madalena Sofia",
        "https://msofia.com/",
        "Rede Damas Educacional",
    ],
    ".aluno.objetivolorena.com.br": ["Colégio Objetivo Lorena"],
    ".opet.com.br": [
        "CENTRO UNIVERSITÁRIO OPET - Uniopet",
        "OPET UNIVERSITY CENTER - Uniopet",
    ],
    ".portalunesc.com.br": [
        "CENTRO UNIVERSITARIO DO ESPIRITO SANTO",
        "Centro Universitário do Espirito Santo Unesc",
        "University Center of the Holy Spirit",
    ],
    ".prover.com.br": ["Universidade de Itaúna"],
    ".santoinacio-rio.com.br": ["Colégio Santo Inácio"],
    ".sapiens.com.br": ["Collegium Sapiens"],
    ".sempreung.com.br": ["UNIVERSIDADE GUARULHOS", "GUARULHOS UNIVERSITY"],
    ".sempreuni7.com.br": [
        "Centro Universitário 7 de Setembro",
        "University Center September 7",
    ],
    ".sempreuninassau.com.br": ["Uninassau"],
    ".senacrs.com.br": ["Faculdade Senac rs"],
    ".senaimgaluno.com.br": [
        "Senai CETEL César Rodrigues",
        "Senai CETEL César Rodrigues",
    ],
    ".sescgoon.com.br": ["Sesc Cidadania"],
    ".setrem.com.br": ["Sociedade Educacional Três de Maio"],
    ".soubraseducacional.com.br": ["soubraseducacional.com.br"],
    ".souenergia.com.br": ["FEAN - Faculdades Energia"],
    ".soulasalle.com.br": ["Centro Universitário La Salle do Rio de Janeiro"],
    ".sounidesc.com.br": [
        "CENTRO UNIVERSITÁRIO DE DESENVOLVIMENTO DO CENTRO-OESTE",
        "UNIVERSITY CENTER FOR WEST CENTER DEVELOPMENT",
    ],
    ".sounisuam.com.br": ["Universidade Augusto Motta"],
    ".souobjetivodf.com.br": ["Colégio Objetivo DF"],
    ".soupromove.com.br": ["Faculdade Promove"],
    ".souunigoias.com.br": [
        "UNIGOIÁS - Centro Universitário de Goiás",
        "UNIGOIÁS - University Center of Goiás",
    ],
    ".souunisales.com.br": ["Unisales", "Centro Universitário Salesiano"],
    ".souunisuam.com.br": ["UNISUAM", "UNISUAM"],
    ".souunit.com.br": ["Universidade Tiradentes"],
    ".studiumensinofundamental.com.br": [
        "Studium Pequeno Príncipe | Educação Infantil, Fundamental I e II"
    ],
    ".technet.com.br": ["Universidade Federal de Roraima"],
    ".tecpuc.com.br": ["TECPUC", "TECPUC"],
    ".estudante.ufscar.com.br": ["universidade federal de são carlos"],
    ".ulife.com.br": ["Anhembi Morumbi"],
    ".unialfa.com.br": ["UNIALFA"],
    ".uniara.com.br": ["Centro Universitário de Araraquara"],
    ".aluno.uniasselvi.com.br": [
        "UNIASSELVI: Graduações, Pós-graduações e Cursos Técnicos"
    ],
    ".uniasselvi.com.br": ["Centro Universitário Leonardo da Vinci"],
    ".unibrasil.com.br": ["Faculdades Integradas do Brasil - UNIBRASIL"],
    ".unicaipatinga.com.br": ["Faculdade Única"],
    ".aluno.uniceug.com.br": [
        "UNICEUG - Goiânia University Center",
        "Uniceug - Centro Universitário de Goiânia",
    ],
    ".uniciv.com.br": ["UNICIV - POS GRADUAÇÂO EAD EM TI."],
    ".al.unieduk.com.br": ["Centro Universitário de Jaguariúna - UniFAJ"],
    ".unieuro.com.br": ["Centro Universitário UNIEURO"],
    ".unifametro.com.br": ["Unifametro"],
    ".unifatecpr.com.br": ["UNIFATECPR Centro Universitário"],
    ".unifaveni.com.br": ["Centro Universitario Faveni"],
    ".unigranet.com.br": ["Universidade da Grande Dourados - UNIGRANET"],
    ".unijorge.com.br": ["UNIJORGE - Centro Universitário Jorge Amado"],
    ".unimes.com.br": ["Universidade Metropolitana de Santos"],
    ".unipacto.com.br": ["Faculdade Presidente Antônio Carlos"],
    ".unipli.com.br": ["Centro Universitário Plinio Leite"],
    ".unirp.com.br": ["Centro Universitário de Rio Preto"],
    ".unisalesiano.com.br": [
        "Centro Universitário Católico Salesiano Auxilium",
        "UniSALESIANO",
    ],
    ".unisantos.com.br": ["Universidade Católica de Santos"],
    ".uniseb.com.br": ["Centro Universitário Estácio UniSEB"],
    ".aluno.unisociesc.com.br": [
        "UniSociesc",
        "Sociedade Educacional de Santa Catarina",
        "Educational Society of Santa Catarina",
    ],
    ".unisociesc.com.br": ["Unisociesc", "Unisociesc"],
    ".unitau.com.br": ["Universidade de Taubaté"],
    ".univale.com.br": ["Faculdades Integradas do Vale do Ivaí"],
    ".univicosa.com.br": [
        "Centro Universitário de Viçosa - Univiçosa",
        "Univiçosa",
    ],
    ".unopar.com.br": ["Universidade Norte do Paraná"],
    ".unoparminas.com.br": ["Unopar Minas"],
    ".uscsonline.com.br": ["Universidade Municipal de São Caetano do Sul"],
    ".uvvnet.com.br": ["Sociedade de Ensino e Pesquisa America Latina"],
    ".vemprafam.com.br": ["FAM Centro Universitário das Américas"],
    ".viannasempre.com.br": ["Instituto Vianna Júnior"],
    ".vitru.com.br": ["Vitru Educação"],
    ".creupi.br": [
        "Centro Regional Universitário de Espiríto Santo do Pinhal"
    ],
    ".ime.eb.br": ["Instituto Militar de Engenharia"],
    ".alunosatc.edu.br": [
        "SATC - Educação e Tecnologia",
        "SATC - Education and Technology",
    ],
    ".anhanguera.edu.br": [
        "UNIGOIÁS - Centro Universitário de Goiás",
        "UNIGOIÁS - University Center of Goiás",
    ],
    ".anhembimorumbi.edu.br": ["ISCP - Sociedade Educacional Ltda"],
    ".atitus.edu.br": ["Atitus Educação"],
    ".auden.edu.br": ["Auden Educação", "Auden MFA"],
    ".bahiana.edu.br": [
        "Escola Bahiana de Medicina e Saúde Pública",
        "Bahiana School of Medicine and Public Health",
    ],
    ".baraodemaua.edu.br": [
        "Graduação e Pós-Graduação Presencial e a Distância - Barão de Mauá"
    ],
    ".cs.brazcubas.edu.br": ["Universidade Braz Cubas CST Empreendedorismo"],
    ".camporeal.edu.br": [
        "Centro Universitário Campo Real",
        "Campo Real University",
    ],
    ".al.casperlibero.edu.br": [
        "Faculdade Casper Libero",
        "Casper Libero Faculty",
    ],
    ".a.catolica-to.edu.br": [
        "Centro Universitário Católica do Tocantins: UniCatólica"
    ],
    ".catolica.edu.br": ["Universidade Catolica de Brasilia"],
    ".catolicasc.edu.br": ["Católica de Santa Catarina"],
    ".faculdade.cefsa.edu.br": ["Faculdade Engenheiro Salvador Arena"],
    ".ftt.cefsa.edu.br": ["Faculdade de Tecnologia Termomecânica"],
    ".celsolisboa.edu.br": ["Centro Universitário Celso Lisboa"],
    ".cest.edu.br": ["Faculdade de Santa Terezinha - Cest"],
    ".cesuca.edu.br": ["Centro Universitário Cesuca"],
    ".cesumar.edu.br": ["Centro Universitário Cesumar"],
    ".ceub.edu.br": ["Centro Universitário de Brasília"],
    ".cs.ceunsp.edu.br": ["Centro Universitário Nossa Senhora do Patrocínio"],
    ".claretiano.edu.br": ["Centro Universitário Claretiano"],
    ".cruzeirodosul.edu.br": ["Universidade Cruzeiro do Sul"],
    ".doctum.edu.br": ["Doctum"],
    ".domalberto.edu.br": ["Faculdade dom Alberto"],
    ".academico.domhelder.edu.br": [
        "Escola Superior Dom Helder Câmara",
        "Dom Helder Câmara Higher School",
    ],
    ".einstein.edu.br": [
        "Instituto Israelita de Ensino e Pesquisa Albert Einstein"
    ],
    ".academico.emge.edu.br": [
        "Escola de Engenharia de Minas Gerais - EMGE",
        " Engineering School of Minas Gerais",
    ],
    ".emge.edu.br": ["Escola de Engenharia de Minas Gerais"],
    ".eniac.edu.br": [
        "Eniac - Centro Universitário de Excelência em Guarulhos"
    ],
    ".esags.edu.br": ["CENTRO DE ENSINO SUPERIOR STRONG"],
    ".esbam.edu.br": [
        "Escola Superior Batista do Amazonas - ESBAM",
        "https://esbam.edu.br/",
    ],
    ".eseg.edu.br": ["Escola Superior de Engenharia e Gestão - ESEG"],
    ".esuda.edu.br": ["Faculdade de Ciências Humanas ESUDA"],
    ".etfbsb.edu.br": [
        "Instituto Federal de Educação, Ciência e Tecnologia de Brasília"
    ],
    ".facemp.edu.br": [
        "Centro Universitário de Ciências e Empreendedorismo",
        "UNIFACEMP",
    ],
    ".bsi.facet.edu.br": [
        "Facet - Faculdade de Ciencias e Tecnologia do Paraná",
        "Science and Technology College of Paraná",
    ],
    ".facimp.edu.br": ["Faculdade Facimp ", "Facimp School"],
    ".faculdadecesusc.edu.br": ["Faculdade CESUSC"],
    ".faculdadedamas.edu.br": ["Faculdade Damas da Instrução Cristã"],
    ".faculdadedetimbauba.edu.br": [
        "Faculdade de Timbaúba - Timbaúba - Pernambuco"
    ],
    ".faculdadedombosco.edu.br": ["Faculdade Dom Bosco de Porto Alegre"],
    ".faculdadefacec.edu.br": [
        "Faculdade de Administração e Ciências Econômicas, Facec"
    ],
    ".faculdadefama.edu.br": ["Faculdade Metropolitana de Anápolis"],
    ".faculdadefamart.edu.br": ["Faculdade Famart"],
    ".faculdadefia.edu.br": [
        "Fundação Instituto de Administração",
        "Administration Institute Foundation",
    ],
    ".faculdadegran.edu.br": ["Faculdade Gran"],
    ".alunos.faculdadeideal.edu.br": ["Faculdade Ideal Wyden", "Faci Wyden"],
    ".faculdademetropolitana.edu.br": [
        "faculdade metropolitana",
        "metropolitan college",
    ],
    ".faculdadepm.edu.br": ["Faculdade da Polícia Militar"],
    ".faculdadesapiens.edu.br": ["Faculdade Sapiens"],
    ".faculdadescearenses.edu.br": ["Faculdade Cearense", "Cearense Faculty"],
    ".faculdadesirius.edu.br": [
        "SIRIUS EDUCACAO INOVADORA LTDA",
        "sirius education",
    ],
    ".faculdadevincit.edu.br": ["Faculdade Vincit, Brazil"],
    ".fadam.edu.br": ["Faculdade das Américas - FADAM"],
    ".fadergs.edu.br": ["FADERGS"],
    ".fael.edu.br": ["FAEL – Faculdade Educacional da Lapa"],
    ".faeterj-petropolis.edu.br": ["Faeterj-Petrópolis"],
    ".faeterj-rio.edu.br": [
        "Resultados da pesquisa Resultados da Web  Faeterj-Rio - Faculdade de Educação Tecnológica do Estado do Rio de Janeiro"
    ],
    ".faex.edu.br": [
        "Faculdade de Ciências Sociais Aplicadas de extrema",
        "FAEX",
    ],
    ".acd.fag.edu.br": ["Centro Universitário FAG", "University Center FAG"],
    ".minha.fag.edu.br": ["Centro Universitário da Fundação Assis Gurgacz"],
    ".fag.edu.br": [
        "Centro Universitário da Fundação Assis Gurgacz",
        "Assis Gurgacz University Center",
    ],
    ".fagammon.edu.br": ["Fagammon", "Faculdade Presbiteriana Gammon"],
    ".faip.edu.br": ["FAIP"],
    ".fam.edu.br": ["FAM - Faculdade de Americana"],
    ".famec.edu.br": [
        "UniFamec Centro Universitário",
        "UniFamec University Center",
    ],
    ".famef.edu.br": ["Faculdade Metropolitana de Franca", "FAMEF"],
    ".fametro.edu.br": ["Fametro"],
    ".aluno.famper.edu.br": ["Famper Faculdade de Ampére "],
    ".professor.famper.edu.br": ["FAMPER - Faculdade de Ampére"],
    ".acad.fanese.edu.br": [
        "Faculdade de Administração e Negócios de Sergipe",
        " Sergipe School of Business and Administration",
    ],
    ".faosc.edu.br": ["FACULDADE DO OESTE DE SANTA CATARIA – FAOSC"],
    ".aluno.fapal.edu.br": [
        "FAPAL - Faculdade de Palmas",
        "FAPAL - Faculty of Palmas",
    ],
    ".fapce.edu.br": [
        "Centro Universitário Paraíso, Brasil",
        "Faculdade Paraíso do Ceará, Brasil",
        "FAPCE",
    ],
    ".fapi-pi.edu.br": ["FAPI - Centro Universitario do Piaui"],
    ".cs.fapipinhais.edu.br": ["FAPI | Centro Universitário de Pinhais"],
    ".faqi.edu.br": ["Faculdade QI, Brazil"],
    ".fasec.edu.br": ["Faculdade Serra do Carmo", "Serra do Carmo College"],
    ".fat-al.edu.br": [
        "Centro Universitário Mário Pontes Jucá",
        "Faculdade de Tecnologia de Alagoas",
    ],
    ".fateccarapicuiba.edu.br": ["Faculdade de Tecnologia de Carapicuiba"],
    ".fatecie.edu.br": ["UniFatecie Centro Universitário"],
    ".fatecourinhos.edu.br": ["Faculdade de Tecnologia de Ourinhos"],
    ".fatecrl.edu.br": [
        "Fatec Rubens Lara",
        "Fatec Baixada Santista - Rubens Lara",
        "Fatec Rubens Lara - Baixada Santista (SP)",
        ".group",
    ],
    ".aluno.fbuni.edu.br": ["Centro Universitário Farias Brito"],
    ".prof.fbuni.edu.br": [" Centro Universitário Farias Brito"],
    ".fcarp.edu.br": ["Faculdade Católica Rainha da Paz"],
    ".fdvmg.edu.br": ["Faculdade de Viçosa - FDV"],
    ".feap.edu.br": ["Fundação Educacional de Além Paraíba"],
    ".fef.edu.br": ["Fundação Educacional Fernandópolis"],
    ".fei.edu.br": ["Centro Universitário FEI", "University Center FEI"],
    ".feitep.edu.br": [
        "Faculdade de Engenharia e Inovação Técnico Profissional"
    ],
    ".fema.edu.br": ["FEMA - Fundação Educacional do Município de Assis"],
    ".fesppr.edu.br": ["Faculdade de Educação Superior de Parana – FESP"],
    ".fgp.edu.br": ["Faculdade Gennari & Peartree"],
    ".fgv.edu.br": [
        "Fundação Getúlio Vargas",
        "Getulio Vargas Foundation",
        "FGV",
    ],
    ".alunos.fho.edu.br": ["Fundação Hermínio Ometto"],
    ".fho.edu.br": ["Centro Universitário da Fundação Hermínio Ometto"],
    ".a.ficr.edu.br": ["Faculdade Imaculada Conceição do Recife"],
    ".fieb.edu.br": ["Fundação Instituto de Educação de Barueri"],
    ".fiec.edu.br": [
        "Fundação Indaiatubana de Educação e Cultura",
        "Culture and Education Indaiatuban Fundation",
    ],
    ".fipecafi.edu.br": ["FIPECAFI - Cultura Contábil, Atuarial e Financeira"],
    ".ads.fiponline.edu.br": [
        "Centro Universitário de Patos UNIFIP",
        "University Center of Patos UNIFIP",
    ],
    ".si.fiponline.edu.br": ["Unifip", "Unifip"],
    ".flf.edu.br": ["Faculdade Lourenço Filho"],
    ".aluno.fmpsc.edu.br": [
        "Faculdade Municipal de Palhoça",
        "Municipal College of Palhoca",
    ],
    ".fortec.edu.br": [
        "Escola e Faculdade Fortec",
        "Fortec School and College",
        "FATEF - Faculdade de Tecnologia de São Vicente",
        "FATEF - Faculty of Technology of São Vicente",
        ".group",
    ],
    ".fpp.edu.br": ["Faculdades Pequeno Príncipe"],
    ".cs.fsg.edu.br": ["CRUZEIRO DO SUL EDUCACIONAL S.A."],
    ".fsg.edu.br": ["Centro Universitário da Serra Gaúcha, FSG"],
    ".ftc.edu.br": ["Faculdade de Tecnologia e Ciência"],
    ".fumec.edu.br": ["Universidade FUMEC", "FUMEC University"],
    ".fumep.edu.br": ["Fundação Municipal de Ensino de Piracicaba"],
    ".funecsantafe.edu.br": [
        "Centro Universitário de Santa Fé do Sul",
        "University Centre of Santa Fe do Sul",
        "UNIFUNEC",
    ],
    ".univap.fve.edu.br": [
        "Universidade do Vale do Paraiba",
        "University of Vale do Paraiba",
    ],
    ".alunos.ibmec.edu.br": ["IBMEC"],
    ".professores.ibmec.edu.br": ["IBMEC"],
    ".idp.edu.br": [
        "\ufeffInstituto Brasileiro de Ensino, Desenvolvimento e Pesquisa (IDP)"
    ],
    ".aluno.ies.edu.br": [
        "Instituto de Ensino Superior da Grande Florianópolis",
        "Higher Education Institute of Greater Florianópolis",
    ],
    ".iesb.edu.br": ["IESB - Centro Universitário", "IESB University Center"],
    ".aluno.ieso.edu.br": [
        "IESO / FACCOR / FACIR - Instituto de Ensino Superior de Olinda.",
        "IESO/FACCOR/FACIR - Institute of Higher Education of Olinda.",
    ],
    ".iesp.edu.br": [
        "Centro Universitário UNIESP",
        "University Center UNIESP",
    ],
    ".ifac.edu.br": ["Instituto Federal do Acre - IFAC"],
    ".ifal.edu.br": [
        "Instituto Federal de Alagoas",
        "Federal Institute of Alagoas",
    ],
    ".ifam.edu.br": [
        "Instituto Federal de Educação, Ciência e Tecnologia do Amazonas"
    ],
    ".ifap.edu.br": [
        "Instituto Federal de Educação, Ciência e Tecnologia do Amapá"
    ],
    ".estudante.ifb.edu.br": ["Instituto Federal de Brasília"],
    ".ifb.edu.br": [
        "Instituto Federal de Educação, Ciência e Tecnologia de Brasília"
    ],
    ".ifba.edu.br": [
        "Instituto Federal de Educação, Ciência e Tecnologia da Bahia",
        "Federal Institute of Education, Science and Technology of Bahia",
    ],
    ".ifbaiano.edu.br": [
        "Instituto Federal de Educação, Ciência e Tecnologia Baiano"
    ],
    ".ifc.edu.br": ["Instituto Federal Catarinense"],
    ".aluno.ifce.edu.br": [
        "Instituto Federal de Educação, Ciência e Tecnologia do Ceará"
    ],
    ".lds.ifce.edu.br": [
        "Laboratório de Desenvolvimento de Software - Instituto Federal de Educação, Ciência e Tecnologia do Ceará"
    ],
    ".ifce.edu.br": ["Instituto Federal do Ceará"],
    ".estudante.ifes.edu.br": ["Instituto Federal de Educação"],
    ".ifes.edu.br": ["Instituto Federal do Espírito Santo"],
    ".iff.edu.br": [
        "Instituto Federal de Educação, Ciência e Tecnologia Fluminense"
    ],
    ".aluno.iffar.edu.br": [
        "Instituto Federal de Educação, Ciência e Tecnologia Farroupilha"
    ],
    ".iffarroupilha.edu.br": [
        "Instituto Federal de Educação, Ciência e Tecnologia Farroupilha - IF Farroupilha"
    ],
    ".ifg.edu.br": [
        "Instituto Federal de Educação, Ciência e Tecnologia de Goiás",
        "Instituto Federal de Goiás",
        "IFG",
    ],
    ".estudante.ifgoiano.edu.br": ["Instituto Federal Goiano"],
    ".ifgoiano.edu.br": ["Instituto Federal Goiano"],
    ".acad.ifma.edu.br": [
        "Instituto Federal de Educação Ciência e Tecnologia do Maranhão"
    ],
    ".ifma.edu.br": [
        "Instituto Federal do Maranhão",
        "Federal Institute of Maranhão",
    ],
    ".ifmg.edu.br": ["Instituto Federal de Minas Gerais"],
    ".ifms.edu.br": ["Federal Institute of Mato Grosso do Sul (IFMS)"],
    ".ifmt.edu.br": ["Instituto Federal de Mato Grosso"],
    ".ifnmg.edu.br": ["Instituto Federal do Norte de Minas Gerais"],
    ".ifpa.edu.br": ["Instituto Federal do Pará"],
    ".ifpb.edu.br": [
        "Instituto Federal de Educação, Ciência e Tecnologia da Paraíba"
    ],
    ".ifpe.edu.br": ["Instituto Federal de Pernambuco"],
    ".ifpi.edu.br": ["Instituto Federal do Piauí"],
    ".ifpr.edu.br": ["Instituto Federal de Instituto Federal do Paraná"],
    ".ifrj.edu.br": [
        "Instituto Federal do Rio de Janeiro",
        "Federal institute of Rio de Janerio",
    ],
    ".academico.ifrn.edu.br": ["Instituto Federal do Rio Grande do Norte"],
    ".ifrn.edu.br": [
        "Instituto Federal de Educação, Ciência e Tecnologia do Rio Grande do Norte"
    ],
    ".aluno.ifro.edu.br": [" Instituto Federal de Rondônia - Campus Vilhena"],
    ".ifro.edu.br": [
        "Instituto Federal de Educação, Ciência e Tecnologia de Rondônia"
    ],
    ".ifrr.edu.br": [
        "Instituto Federal de Roraima",
        "Federal Institute of Roraima",
    ],
    ".bento.ifrs.edu.br": [
        "Instituto Federal do Rio Grande do Sul - Campus Bento Gonçalves"
    ],
    ".aluno.canoas.ifrs.edu.br": [
        "Instituto Federal de Educação, Ciência e Tecnologia do Rio Grande do Sul - Campus Canoas",
        "Federal Institute of Rio Grande do Sul Canoas Campus",
    ],
    ".canoas.ifrs.edu.br": [
        "Instituto Federal de Educação, Ciência e Tecnologia do Rio Grande do Sul - Campus Canoas",
        "Federal Institute of Rio Grande do Sul Canoas Campus",
    ],
    ".erechim.ifrs.edu.br": ["IFRS Campus Erechim"],
    ".farroupilha.ifrs.edu.br": [
        "Instituto Federal de Educação, Ciência e Tecnologia do Rio Grande do Sul - Campus Farroupilha"
    ],
    ".aluno.feliz.ifrs.edu.br": [
        "Instituto Federal de Educação, Ciência e Tecnologia do Rio Grande do Sul - Campus Feliz"
    ],
    ".feliz.ifrs.edu.br": [
        "Instituto Federal de Educação, Ciência e Tecnologia do Rio Grande do Sul - Campus de Feliz"
    ],
    ".ibiruba.ifrs.edu.br": [
        "Instituto Federal do Rio Grande do Sul - Campus Ibiruba",
        "Federal Institute of Rio Grande do Sul - Campus Ibiruba",
    ],
    ".osorio.ifrs.edu.br": [
        "Instituto Federal de Educação, Ciência e Tecnologia do Rio Grande do Sul - Câmpus Osório",
        "Federal Institute of Education, Science and Technology of Rio Grande do Sul - Campus Osório",
    ],
    ".poa.ifrs.edu.br": [
        "Instituto Federal de Educação, Ciência e Tecnologia do Rio Grande do Sul - Campus Porto Alegre",
        "Federal Institute of Rio Grande do Sul Porto Alegre Campus",
    ],
    ".restinga.ifrs.edu.br": [
        "Instituto Federal do Rio Grande do Sul Campus Restinga",
        "Federal Institute of Rio Grande do Sul Restinga Campus",
    ],
    ".riogrande.ifrs.edu.br": [
        "Instituto Federal do Rio Grande do Sul - Campus Rio Grande"
    ],
    ".vacaria.ifrs.edu.br": [
        "Instituto Federal do Rio Grande do Sul - Campus Vacaria",
        "Federal Institute of Rio Grande do Sul - Campus Vacaria",
    ],
    ".ifrs.edu.br": [
        "Instituto Federal de Educação, Ciência e Tecnologia do Rio Grande do Sul",
        "Federal Institute of Rio Grande do Sul",
    ],
    ".ifs.edu.br": [
        "Instituto Federal de Educação, Ciência e Tecnologia de Sergipe",
        "Federal Institute of Education, Science and Technology of Sergipe",
    ],
    ".ifsc.edu.br": ["Federal Institute of Santa Catarina"],
    ".aluno.ifsertao-pe.edu.br": ["IF Sertão-PE Campus Petrolina"],
    ".ifsertao-pe.edu.br": ["Instituto Federal do Sertão Pernambucano"],
    ".ifsp.edu.br": [
        "Instituto Federal de Educação, Ciência e Tecnologia de São Paulo"
    ],
    ".ifsudestemg.edu.br": ["Instituto Federal Sudeste de Minas Gerais"],
    ".ifsul.edu.br": ["Instituto Federal Sul-Rio-Grandense "],
    ".ifsuldeminas.edu.br": ["Instituto Federal do Sul de Minas Gerais"],
    ".iftm.edu.br": [
        "Instituto Federal de Educação, Ciência e Tecnologia do Triângulo Mineiro"
    ],
    ".ifto.edu.br": [
        "Instituto Federal de Educação, Ciência e Tecnologia do Tocantins",
        "Federal Institute of Tocantins",
    ],
    ".igti.edu.br": ["Instituto de Gestão e Tecnologia da Informação"],
    ".imed.edu.br": ["Faculdade Meridional - IMED"],
    ".imepac.edu.br": [
        "Centro Universitário Imepac Araguari",
        "Imepac Araguari University Center",
    ],
    ".immes.edu.br": [
        "Instituto Matonense Municipal de Ensino Superior – IMMES"
    ],
    ".infnet.edu.br": ["Instituto Infnet"],
    ".insper.edu.br": ["Insper", "Institute of Education and Research"],
    ".insted.edu.br": ["Insted"],
    ".sou.inteli.edu.br": ["Inteli - Instituto de Tecnologia e Liderança"],
    ".ipog.edu.br": ["Instituto de Pós-Graduação e Graduação (IPOG)"],
    ".iscon.edu.br": ["Faculdade ISCON"],
    ".iscp.edu.br": ["Instituto Superior de Ciências Policiais - PMDF"],
    ".ite.edu.br": ["Instituição Toledo de Ensino"],
    ".libertas.edu.br": [
        "Libertas Faculdades Integradas",
        "Libertas Integrated Faculties",
    ],
    ".logatti.edu.br": ["Faculdades Logatti Araraquara"],
    ".ls.edu.br": ["Faculdade LS"],
    ".materdei.edu.br": ["Faculdade Mater Dei"],
    ".meta.edu.br": ["Grupo Meta"],
    ".aluno.multivix.edu.br": ["Faculdade Multivix"],
    ".novaroma.edu.br": ["Faculdade Nova Roma"],
    ".opet.edu.br": ["Centro Universitário OPET", "OPET University Center"],
    ".piodecimo.edu.br": ["Piodecimo Group"],
    ".pitagoras.edu.br": ["Faculdade Pitágoras", "Pitagoras College"],
    ".aluno.positivo.edu.br": ["Universidade Positivo"],
    ".projecao.edu.br": ["Centro Universitário e Faculdade Projeção"],
    ".puc-campinas.edu.br": ["Pontifical Catholic University of Campinas"],
    ".puccampinas.edu.br": [
        "Pontifícia Universidade Católica de Campinas",
        "Pontifical Catholic University of Campinas",
        "PUC Campinas",
        "PCU Campinas",
        "PUCC",
    ],
    ".pucgo.edu.br": ["PUC GOIAS"],
    ".pucgoias.edu.br": [
        "Pontifícia Universidade Católica de Goias",
        "Pontifical Catholic University of Goiás",
    ],
    ".pucpr.edu.br": [
        "Pontifícia Universidade Católica do Paraná",
        "Pontifical Catholic University of Paraná",
    ],
    ".pucsp.edu.br": [
        "PUC-SP - PontifÃcia Universidade CatÃ³lica de SÃ£o Paulo"
    ],
    ".redentor.edu.br": [
        "Centro Universitário Redentor",
        "Redentor University Center",
    ],
    ".aluno.santamarcelina.edu.br": ["faculdade santa marcelina"],
    ".satc.edu.br": ["Satc"],
    ".senacminas.edu.br": ["Serviço Nacional de Aprendizagem Comercial"],
    ".senacrs.edu.br": ["Senac RS", "SENAC RIO GRANDE DO SUL"],
    ".senacsp.edu.br": ["Centro Universitario Senac"],
    ".aln.senaicimatec.edu.br": ["Senai CIMATEC"],
    ".senaimt.edu.br": ["FATEC SENAI MT", "FATEC SENAI MT"],
    ".estudante.senairs.edu.br": ["senairs"],
    ".senaisp.edu.br": [
        "Escola e Faculdade de Tecnologia Senai Anchieta",
        "Senai Anchieta School and College of Technology",
        "Faculdade Senai de Tecnologia",
        ".group",
    ],
    ".sinergia.edu.br": ["Faculdade Sinergia"],
    ".souclaretiano.edu.br": [
        "Centro Universitário Claretiano",
        "Claretian University Center",
    ],
    ".sumare.edu.br": ["Faculdade Sumaré "],
    ".toledoprudente.edu.br": ["Toledo Prudente Centro Universitário"],
    ".ubec.edu.br": ["União Brasileira de Educação Católica"],
    ".uca.edu.br": ["Faculdade Católica Paulista"],
    ".aluno.ucam.edu.br": [
        "Universidade Candido Mendes",
        "Candido Mendes University",
    ],
    ".uceff.edu.br": [
        "UCEFF- UNIDADE CENTRAL DE EDUCAÇÃO FAI FACULDADES LTDA"
    ],
    ".ucpel.edu.br": [
        "Universidade Católica de Pelotas",
        "Catholic University of Pelotas",
    ],
    ".ucpparana.edu.br": ["Univale - Faculdades Integradas do Vale do Ivaí"],
    ".ucsal.edu.br": [
        "Universidade Católica de Salvador",
        "Salvador Catholic University",
    ],
    ".udc.edu.br": ["Centro Universitário Dinâmica Cataratas"],
    ".udf.edu.br": ["Centro de Ensino Unificado do Distrito Federal"],
    ".uea.edu.br": [
        "Universidade do Estado do Amazonas",
        "Amazonas State University",
    ],
    ".discente.uenp.edu.br": ["Universidade Estadual do Norte do Paraná"],
    ".uepb.edu.br": ["Universidade Estadual da Paraíba"],
    ".uergs.edu.br": ["Universidade Estadual do Rio Grande do Sul"],
    ".uerr.edu.br": ["Universidade Estadual de Roraima"],
    ".uesb.edu.br": [
        "Universidade Estadual do Sudoeste da Bahia",
        "State University of Southwest Bahia",
    ],
    ".uezo.edu.br": [
        "Fundação Centro Universitário da Zona Oeste do Rio de Janeiro"
    ],
    ".ufabc.edu.br": ["Universidade Federal do ABC"],
    ".ufam.edu.br": ["UNIVERSIDADE FEDERAL DO AMAZONAS"],
    ".ufape.edu.br": ["Universidade Federal do Agreste de Pernambuco"],
    ".ufca.edu.br": ["Universidade Federal do Cariri"],
    ".discente.ufcat.edu.br": ["Universidade Federal de Catalão"],
    ".ufcat.edu.br": [
        "Universidade Federal de Catalão",
        "Federal University of Catalão",
    ],
    ".ufcg.edu.br": ["Universidade Federal de Campina Grande"],
    ".ufcspa.edu.br": [
        "Universidade Federal de Ciências da Saúde de Porto Alegre"
    ],
    ".ufersa.edu.br": [
        "Universidade Federal Rural do Semi-Árido",
        "Federal Rural University of the Semi-Arid",
    ],
    ".uffs.edu.br": [
        "Universidade Federal da Fronteira Sul",
        "Federal University of Fronteira Sul",
    ],
    ".ufgd.edu.br": ["Universidade Federal da Grande Dourados"],
    ".ufj.edu.br": [
        "Universidade Federal de Jataí",
        "Federal University of Jatai",
    ],
    ".ufjf.edu.br": [
        "Universidade Federal de Juiz de Fora",
        "Federal University of Juiz de Fora",
    ],
    ".ufn.edu.br": ["Universidade Franciscana", "Franciscan University"],
    ".ufob.edu.br": [
        "Universidade Federal do Oeste da Bahia",
        "Federal University of Western Bahia",
    ],
    ".ufop.edu.br": [
        "Universidade Federal de Ouro Preto",
        "Federal University of Ouro Preto",
    ],
    ".discente.ufopa.edu.br": ["Universidade Federal do Oeste do Pará"],
    ".ufopa.edu.br": [
        "Universidade Federal do Oeste do Pará (UFOPA)",
        "Federal University of Western Pará",
    ],
    ".ufpel.edu.br": ["Universidade Federal de Pelotas"],
    ".ufpi.edu.br": [
        "Universidade Federal do Piauí",
        "Federal University of Piaui",
    ],
    ".ufr.edu.br": [
        "Universidade Federal de Rondonópolis",
        "Federal University of Rondonópolis",
    ],
    ".ufra.edu.br": ["Universidade Federal Rural da Amazônia - UFRA"],
    ".aluno.ufrb.edu.br": [
        "Universidade Federal do Recôncavo da Bahia",
        "Federal University of Recôncavo da Bahia",
    ],
    ".ufrn.edu.br": ["Universidade Federal do Rio Grande do Norte"],
    ".ufsb.edu.br": [
        "Universidade Federal do Sul da Bahia",
        "Federal University of Southern Bahia",
    ],
    ".aluno.ufsj.edu.br": ["Universidade Federal de São João del-Rei"],
    ".ufsj.edu.br": [
        "Universidade Federal de São João del-Rei",
        "Federal University of São João del-Rei",
    ],
    ".uft.edu.br": [
        "Universidade Federal do Tocantins",
        "Federal University of Tocantins",
    ],
    ".uftm.edu.br": [
        "Universidade Federal do Triângulo Mineiro",
        "Federal University of Triângulo Mineiro",
    ],
    ".ufvjm.edu.br": [
        "Universidade Federal dos Vales do Jequitinhonha e Mucuri"
    ],
    ".ugv.edu.br": ["Ugv - Centro Universitário"],
    ".ulbra.edu.br": ["Universidade Luterana do Brasil"],
    ".umfg.edu.br": ["Faculdade UMFG"],
    ".academico.umj.edu.br": [
        "Centro Universitário Mario Pontes Jucá",
        "Mario Pontes Jucá University Center",
        "UMJ",
    ],
    ".sou.unaerp.edu.br": [
        "UNAERP - Universidade de Ribeirão Preto",
        "UNAERP - University of Ribeirão Preto",
    ],
    ".unasp.edu.br": ["UNASP", "UNASP"],
    ".academico.uncisal.edu.br": [
        "Universidade Estadual de Ciências da Saude de Alagoas",
        "State University of Health Sciences of Alagoas",
        "UNCISAL",
    ],
    ".undb.edu.br": ["UNDB"],
    ".undf.edu.br": ["Universidade do Distrito Federal"],
    ".estudante.unespar.edu.br": [
        "Universidade Estadual do Paraná",
        "Paraná State University",
    ],
    ".unespar.edu.br": [
        "Universidade Estadual do Paraná",
        "State University of Paraná",
    ],
    ".aluno.unex.edu.br": ["unex", "unex"],
    ".uni9.edu.br": ["Universidade Nove de Julho"],
    ".uniabeu.edu.br": [
        "uniabeu",
        "https://www.uniabeu.edu.br",
        "https://www.uniabeu.edu.br/cursos/analise-de-sistemas",
    ],
    ".uniacademia.edu.br": ["UniAcademia Centro Universitário"],
    ".uniaeso.edu.br": ["UNIAESO", "Centro Universitário AESO-Barros Melo"],
    ".uniara.edu.br": ["Uniara - Universidade de Araraquara"],
    ".uniasselvi.edu.br": [
        "Sociedade Educacional Leonardo da Vinci - UNIASSELVI"
    ],
    ".aluno.uniateneu.edu.br": [
        "Centro Universitário UniAteneu",
        "UniAteneu University Center",
    ],
    ".professor.uniateneu.edu.br": [
        "Centro Universitário Ateneu",
        "Uniateneu",
    ],
    ".uniavan.edu.br": ["Centro Universitário Avantis", "Avantis University"],
    ".unibagozzi.edu.br": ["\ufeffCentro Universitário UniBagozzi"],
    ".unibalsas.edu.br": ["Unibalsas"],
    ".unibr.edu.br": ["UNIBR - UNIÃO BRASILEIRA EDUCACIONAL LTDA"],
    ".aluno.unicarioca.edu.br": ["Associação Carioca de Ensino Superior"],
    ".unicatolicaquixada.edu.br": [
        "Centro Universitário Católica de Quixadá",
        "Catholic University Center of Quixadá",
    ],
    ".unicep.edu.br": ["Unicep - Centro Universitário Central Paulista"],
    ".esoftware.uniceplac.edu.br": [
        "UNICEPLAC - Centro Universitário do Planalto Central Apparecido dos Santos"
    ],
    ".unicerrado.edu.br": ["UniCerrado"],
    ".unicesumar.edu.br": ["Centro de Ensino Superior de Maringá"],
    ".unichristus.edu.br": ["Centro Universitário Christus - Unichristus"],
    ".unicid.edu.br": ["Universidade Cidade de São Paulo"],
    ".unicv.edu.br": ["Centro Universitário Cidade Verde"],
    ".unidavi.edu.br": ["Unidavi"],
    ".unidesc.edu.br": [
        "Centro Universitário de Desenvolvimento do Centro-Oeste"
    ],
    ".unidombosco.edu.br": [
        "Centro Universitário Dom Bosco",
        "Dom Bosco University Center",
    ],
    ".unievangelica.edu.br": [
        "Centro Universitário de Anápolis - UniEVANGÉLICA",
        "University Center of Anápolis - UniEVANGÉLICA",
    ],
    ".unifacear.edu.br": ["Unifacear Centro Universitário"],
    ".unifacef.edu.br": ["Uni-FACEF Centro Universitário Municipal de Franca"],
    ".sempre.unifacig.edu.br": ["Centro Universitário UNIFACIG"],
    ".unifacisa.edu.br": ["Faculdade de Ciências Sociais Aplicadas"],
    ".unifacol.edu.br": [
        "UNIFACOL - Centro Universitário FACOL",
        "UNIFACOL - University Center FACOL",
    ],
    ".unifacs.edu.br": ["UNIFACS"],
    ".unifacvest.edu.br": ["centro universitário unifacvest"],
    ".aluno.unifafibe.edu.br": ["UNIFAFIBE UNIVERSITY CENTER"],
    ".unifagoc.edu.br": [
        "Centro Universitário Governador Ozanan Coelho - UniFagoc",
        "Governor Ozanam Coelho University Center - UniFagoc",
    ],
    ".bcc.unifal-mg.edu.br": ["Universidade Federal de Alfenas"],
    ".sou.unifal-mg.edu.br": ["Universidade Federal de Alfenas"],
    ".unifal-mg.edu.br": [
        "Universidade Federal de Alfenas",
        "Federal University of Alfenas",
    ],
    ".aluno.unifametro.edu.br": ["Unifametro"],
    ".alunos.unifanor.edu.br": ["unifanor", "Wyden Unifanor"],
    ".professores.unifanor.edu.br": ["Wyden Unifanor", "Wyden Unifanor"],
    ".aluno.unifapce.edu.br": ["Centro Universitário Paraíso - UniFAP"],
    ".alunos.unifavip.edu.br": ["UniFavip Wyden", "UniFavip Wyden"],
    ".alunos.unifbv.edu.br": ["Unifbv", "Wyden"],
    ".unifeb.edu.br": [
        "Unifeb",
        "Unifeb, Centro Universitário da Fundação Educacional de Barretos",
        "https://www.unifeb.edu.br/",
        "https://vestibular.unifeb.edu.br/curso.php?id=28",
    ],
    ".unifebe.edu.br": ["Centro Universitário de Brusque - UNIFEBE"],
    ".unifei.edu.br": ["Universidade Federal de Itajubá"],
    ".unifemm.edu.br": ["UNIFEMM - Centro Universitário de Sete Lagoas"],
    ".sou.unifeob.edu.br": [
        " UNIFEOB - Centro Universitário Fundação de Ensino Octávio Bastos"
    ],
    ".unifeso.edu.br": ["UNIFESO - Centro Universitário Serra dos Órgãos"],
    ".unifesspa.edu.br": ["Universidade Federal do Sul e Sudeste do Pará"],
    ".unifev.edu.br": ["Unifev - Centro Universitário de Votuporanga"],
    ".unifio.edu.br": [
        "Centro Universitário das Faculdades Integradas de Ourinhos"
    ],
    ".unifipmoc.edu.br": [
        "Centro Universitário UNIFipMoc",
        "University Center UNIFipMoc",
        "https://unifipmoc.edu.br",
    ],
    ".unifoa.edu.br": ["Centro Universitário de Volta Redonda - UniFOA"],
    ".unifran.edu.br": ["Universidade de Franca"],
    ".unifucamp.edu.br": ["Centro Universitário Mário Palmério", "unifucamp"],
    ".aluno.unig.edu.br": ["Universidade de Iguaçú"],
    ".unig.edu.br": ["Universidade de Iguaçú"],
    ".unigoyazes.edu.br": ["Centro Universitário Goyazes", "UniGoyazes"],
    ".unigran.edu.br": ["Centro Universitário da Grande Dourados"],
    ".unigranrio.edu.br": ["Universidade Unigranrio"],
    ".unijorge.edu.br": [
        "Centro Universitário Jorge Amado",
        "UNIJORGE",
        "UJ",
        "Jorge Amado University Center",
    ],
    ".aluno.unijuazeiro.edu.br": [
        "CENTRO UNIVERSITÁRIO DE JUAZEIRO DO NORTE",
        "UNIJUAZEIRO",
    ],
    ".sou.unijui.edu.br": [
        "Universidade Regional do Noroeste do Estado do Rio Grande do Sul"
    ],
    ".unijui.edu.br": [
        "Universidade Regional do Noroeste do Estado do Rio Grande do Sul",
        "UNIJUÍ",
        "FIDENE",
    ],
    ".unila.edu.br": [
        "Universidade Federal da Integração Latino-Americana",
        "Federal University for Latin American",
    ],
    ".aluno.unilab.edu.br": [
        "Universidade da Integração Internacional da Lusofonia Afro-Brasileira"
    ],
    ".unilab.edu.br": [
        "UNIVERSIDADE DA INTEGRAÇÃO INTERNACIONAL DA LUSOFONIA AFRO-BRASILEIRA",
        "UNIVERSITY OF INTERNATIONAL INTEGRATION OF AFRO-BRAZILIAN LUSOPHONIA",
    ],
    ".unilasalle.edu.br": ["Universidade La Salle"],
    ".a.unileste.edu.br": [
        "Centro Universitário Católica do Leste de Minas Gerais"
    ],
    ".aluno.unilins.edu.br": ["UNILINS"],
    ".unils.unils.edu.br": ["UniLS"],
    ".aluno.unimeta.edu.br": ["Unimeta"],
    ".unimetrocamp.edu.br": ["Centro Universitário UniMetrocamp"],
    ".unina.edu.br": ["Unina", "Unina"],
    ".uninabuco.edu.br": [
        "Centro Universitário Joaquim Nabuco (UNINABUCO) (UNINASSAU)",
        "University Center Nabucco",
    ],
    ".prof.uninassau.edu.br": [
        "Faculdade Mauricio de Nassau",
        "university Mauricio de Nassau",
    ],
    ".aluno.unincor.edu.br": ["UNIVERSIDADE VALE DO RIO VERDE - UNINCOR"],
    ".uninga.edu.br": ["Centro universitário Ingá - UNINGÁ"],
    ".uninorteac.edu.br": ["Centro Universitário Uninorte"],
    ".uninove.edu.br": ["Associacao Educacional Nove de Julho"],
    ".uninta.edu.br": [
        "Centro Universitário Inta - Uninta",
        "Inta University Center - Uninta",
    ],
    ".unipam.edu.br": [
        "Centro Universitário de Patos de Minas",
        "University Center of Patos de Minas",
    ],
    ".unipampa.edu.br": [
        "Fundação Universidade Federal do Pampa",
        "Federal University of Pampa Foundation",
    ],
    ".unipaulistana.edu.br": [
        "UniPaulistana- Centro Universitário Paulistana",
        "UniPaulistana - Paulistana University Center",
    ],
    ".unipe.edu.br": ["Centro Universitário de João Pessoa - UNIPÊ"],
    ".unipinterativa.edu.br": ["Universidade Paulista"],
    ".uniplaclages.edu.br": [
        "Universidade do Planalto Catarinense",
        "University of Planalto Catarinense",
    ],
    ".aluno.unirb.edu.br": ["Centro Universitário UNIRB"],
    ".unireal.edu.br": [
        "Faculdade Real (CENTRO EDUCACIONAL DE ENSINO SUPERIOR DE BRASILIA)"
    ],
    ".unirg.edu.br": ["Universidade Regional de Gurupi"],
    ".unirios.edu.br": [
        "Centro Universitário do Rio São Francisco",
        "University Center of São Francisco's River (UNIRIOS)",
    ],
    ".uniritter.edu.br": ["Uniritter University"],
    ".unirn.edu.br": ["Centro Universitário do Rio Grande do Norte"],
    ".alunos.uniruy.edu.br": [
        "Centro Universitário Ruy Barbosa",
        "University Center Ruy Barbosa",
    ],
    ".unirv.edu.br": [
        "Register of Universidade de Rio Verde",
        "http://www.unirv.edu.br/",
        "http://www.unirv.edu.br/graduacao_curso.php?id=42",
    ],
    ".alunos.unis.edu.br": ["CENTRO UNIVERSITÁRIO DO SUL DE MINAS - UNIS"],
    ".unis.edu.br": ["CENTRO UNIVERSITÁRIO DO SUL DE MINAS - UNIS"],
    ".alunos.unisagrado.edu.br": ["Unisagrado"],
    ".unisantanna.edu.br": ["Unisantanna"],
    ".unisecal.edu.br": ["SOCIEDADE EDUCATIVA E CULTURAL AMELIA S/C LTDA"],
    ".unisepe.edu.br": [
        "Unisepe Educacional",
        "Unisepe Educational University",
    ],
    ".unisuam.edu.br": [
        "Centro Universitário Augusto Motta",
        "Augusto Motta University Center",
    ],
    ".unitop.edu.br": ["CENTRO UNIVERSITÁRIO – ITOP"],
    ".unitri.edu.br": ["Unitri - Centro Universitário do Triângulo"],
    ".uniuv.edu.br": [
        "UNIUV - Centro Universitário da Cidade de União da Vitória"
    ],
    ".univag.edu.br": ["Univag Centro Universitário"],
    ".univas.edu.br": ["\ufeffUniversidade do Vale do Sapucaí"],
    ".univasf.edu.br": ["Universidade Federal do Vale do São Francisco"],
    ".univassouras.edu.br": ["Universidades de Vassouras", "Univassouras"],
    ".univem.edu.br": ["Centro Universitário Eurípides de Marília"],
    ".universidadedevassouras.edu.br": ["Universidade de Vassouras"],
    ".bh.universo.edu.br": [
        "Universidade Salgado de Oliveira",
        "University Salgado de Oliveira",
    ],
    ".univille.edu.br": ["Universidade da Região de Joinville - UNIVILLE(c)"],
    ".univinte.edu.br": [
        "UNIVINTE CENTRO TECNOLOGICO LTDA",
        "UNIVINTE CENTRO TECNOLOGICO LTDA",
    ],
    ".univisa.edu.br": [
        "CENTRO UNIVERSITÁRIO DA VITÓRIA DE SANTO ANTÃO - UNIVISA"
    ],
    ".unochapeco.edu.br": [
        "Universidade Comunitária da Região de Chapecó - Unochapecó",
        "Community University of Chapecó Region - Unochapecó",
    ],
    ".unoesc.edu.br": ["Universidade do Oeste de Santa Catarina"],
    ".unoeste.edu.br": ["Universidade do Oeste Paulista"],
    ".unp.edu.br": ["Universidade Potiguar"],
    ".cs.up.edu.br": ["Universidade Positivo", "Positivo University"],
    ".urcamp.edu.br": ["Centro Universitário da Região da Campanha - URCAMP"],
    ".saoluiz.uri.edu.br": ["URI São Luiz Gonzaga"],
    ".aluno.uricer.edu.br": [
        "Universidade Regional Integrada do Alto Uruguai e das Missões",
        "URI ERECHIM",
    ],
    ".uscs.edu.br": ["Universidade Municipal de São Caetano do Sul"],
    ".mail.usf.edu.br": ["Universidade São Francisco"],
    ".utfpr.edu.br": ["Universidade Tecnológica Federal do Paraná"],
    ".utp.edu.br": ["Set Sociedade Civil Educacional Tuiuti Limitada"],
    ".veigadealmeida.edu.br": ["Universidade Veiga de Almeida"],
    ".vianna.edu.br": ["Instituto Vianna Júnior", "Vianna Júnior Institute"],
    ".estudante.xpe.edu.br": ["XP Educação"],
    ".eep.br": ["Escola de Engenharia de Piracicaba"],
    ".einstein.br": [
        "Faculdade Israelita de Ciências da Saúde Albert Einstein",
        "Albert Einstein Israeli College of Health Sciences",
    ],
    ".emescam.br": [
        "EMESCAM - Escola Superior de Ciências da Santa Casa de Misericórdia de Vitória"
    ],
    ".epm.br": ["Universidade Federal de São Paulo"],
    ".esamc.br": ["Escola Superior de Administração, Marketing e Comunicação"],
    ".acad.espm.br": ["Escola Superior de Propaganda e Marketing"],
    ".espm.br": ["Escola Superior de Propaganda e Marketing"],
    ".faap.br": ["FAAP - Fundação Armando Alvares Penteado"],
    ".facape.br": ["Faculdade de Ciências Aplicadas e Sociais de Petrolina"],
    ".faccat.br": ["Faculdades Integradas de Taquara"],
    ".facens.br": ["Engineering College of Sorocaba"],
    ".facol.br": [
        "Facol Faculdade Orígenes Lessa - Lençóis Paulista / São Paulo"
    ],
    ".aluno.faculdadecotemig.br": ["Faculdade COTEMIG"],
    ".faculdadescuritiba.br": ["Faculdades Integradas Curitiba"],
    ".fadipa.br": [
        "Faculdade de Ipatinga - FADIPA",
        "Ipatinga Faculty - Fadipa",
    ],
    ".sou.fae.br": [
        "UNIFAE - Centro Universitário das Faculdades Associadas de Ensino - FAE"
    ],
    ".faesa.br": ["FAESA Centro Universitário"],
    ".grad.fafire.br": ["Faculdade Frassinetti do Recife"],
    ".fagoc.br": ["Faculdade Governador Ozanam Coelho"],
    ".fai-mg.br": [
        "\ufeffCentro de Ensino Superior em Gestão, Tecnologia e Educação"
    ],
    ".faj.br": ["Universidade de Jaguaríuna"],
    ".falec.br": ["Faculdade Doutor Leocádio José Correia"],
    ".famerp.br": ["Faculdade de Medicina de São José do Rio Preto"],
    ".fasp.br": ["FASP - Faculdades Associadas de Sao Paulo"],
    ".faspmail.br": ["FASP - Faculdades Associadas de Sao Paulo"],
    ".edu.fecap.br": [
        "Fundação Escola de Comércio Álvares Penteado (FECAP)",
        "FECAP",
    ],
    ".fecap.br": [
        "Fundação Escola de Comércio Álvares Penteado (FECAP)",
        "FECAP",
    ],
    ".feevale.br": ["Universidade Feevale"],
    ".fgv.br": ["Getulio Vargas Foundation"],
    ".fgvmail.br": ["Fundação Getúlio Vargas"],
    ".alunos.fibbauru.br": ["FIB - Faculdades Integradas de Bauru"],
    ".fiocruz.br": ["Fundação Oswaldo Cruz"],
    ".fmu.br": ["Faculdade Metropolitanas Unidas"],
    ".fsa.br": ["Centro Universitário Fundação Santo André"],
    ".fsg.br": ["Faculdade da Serra Gaúcha"],
    ".fua.br": ["Universidade do Amazonas"],
    ".fucapi.br": ["Faculdade FUCAPI"],
    ".fumec.br": ["Universidade FUMEC", "FUMEC University"],
    ".funcesi.br": ["Fundacao Comunitaria de Ensino Superior de Itabira"],
    ".inf.furb.br": [
        "Fundação Universidade Regional de Blumenau - http://www.furb.br",
        "DSC - Departamento de Sistemas e Computação - http://dsc.inf.furb.br/",
        "Domain: user@inf.furb.br",
    ],
    ".furb.br": ["Fundação Universidade Regional de Blumenau"],
    ".furg.br": ["Universidade do Rio Grande"],
    ".aluno.enova.educacao.ba.gov.br": [
        "e-Nova Educacao Project by the Government of the State of Bahia, Brazil"
    ],
    ".aluno.ce.gov.br": ["EEEP PADRE JOÃO BOSCO DE LIMA"],
    ".escola.ce.gov.br": ["EEEP Professora Luíza De Teodoro Vieira"],
    ".prof.ce.gov.br": ["EEEP PROFESSOR GUSTAVO AUGUSTO LIMA"],
    ".tc.df.gov.br": [
        "Escola de Contas do Tribunal de Contas do Distrito Federal"
    ],
    ".enap.gov.br": ["Escola Nacional de Administração Pública"],
    ".educacao.itumbiara.go.gov.br": [
        "Secreteria da Educacao de Itumbiara - GO",
        ".group",
    ],
    ".inmetro.gov.br": [
        "Instituto Nacional de Metrologia, Qualidade e Tecnologia",
        "National Institute of Metrology, Quality and Technology",
    ],
    ".aluno.mg.gov.br": ["Escola Estadual São Geraldo"],
    ".educacao.mg.gov.br": ["Secretaria de Educação de Minas Gerais"],
    ".pc.ms.gov.br": [
        "Academia da Polícia Civil do Estado de Mato Grosso do Sul"
    ],
    ".edu.tangaradaserra.mt.gov.br": [
        "Secretaria de Educação do Município de Tangará da Serra",
        "Tangará da Serra City Secretary of Education ",
    ],
    ".educacao.pe.gov.br": ["Secretaria Estadual de Educação"],
    ".escola.pr.gov.br": [
        "Pedro Macedo High School",
        "Colégio Estadual Pedro Macedo",
    ],
    ".aluno.educa.rj.gov.br": ["Colégio Estadual Paulino Barbosa"],
    ".prof.educa.rj.gov.br": ["Instituto de educação Carmela Dutra"],
    ".aluno.faeterj-prc.faetec.rj.gov.br": [
        "Faculdade de Educação Tecnológica do Estado do Rio de Janeiro (FAETERJ-Paracambi)"
    ],
    ".educar.rs.gov.br": ["State Education Network of Rio Grande do Sul"],
    ".estudante.rs.gov.br": [
        "Escola Estadual de Ensino Médio Reinaldo Vaccari"
    ],
    ".estudante.sed.sc.gov.br": ["SED - Secretaria de Estado da Educação"],
    ".alunosjc.sp.gov.br": ["EMEF. ILDETE M. BARBOSA"],
    ".cpspos.sp.gov.br": [
        "Unidade de Pós Graduação, Extensão e Pesquisa do Centro Paula Souza"
    ],
    ".aluno.educacao.sp.gov.br": ["E.E Amadeu Amaral"],
    ".etec.sp.gov.br": ["Paula Souza Center"],
    ".fatec.sp.gov.br": ["Faculdade de Tecnologia de Sorocaba"],
    ".paulinia.sp.gov.br": [
        '\ufeffCEMEP-Municipal Vocational Education Center "Osmar Passarelli Silveira"'
    ],
    ".edu.santoandre.sp.gov.br": [
        "Escola Municipal Professora Esther Moura Barreto",
        "County School Professor Esther Moura Barreto",
    ],
    ".grupointegrado.br": ["Faculdade Integrado de Campo Mourão"],
    ".gvmail.br": ["Fundação Getúlio Vargas"],
    ".ielusc.br": ["Associação Educacional Luterana Bom Jesus - IELUSC"],
    ".iesb.br": [
        "Instituto de Educação Superior de Brasília",
        "Superior Education Institute of Brasília",
    ],
    ".impa.br": ["Instituto Nacional de Matemática Pura e Aplicada - IMPA"],
    ".inatel.br": ["Instituto Nacional de Telecomunicações"],
    ".ulbra.inf.br": [
        "Universidade Luterana do Brasil - Computação",
        "Lutheran University of Brazil - Computing",
    ],
    ".inpe.br": [
        "Instituto Nacional de Pesquisas Espaciais",
        "National Institute for Space Research",
    ],
    ".ensino.ipt.br": ["IPT Instituto de Pesquisa e Tecnologia"],
    ".ita.br": ["Instituto Tecnológico de Aeronáutica"],
    ".italo.br": ["Faculdade Italo Brasileira"],
    ".itpac.br": ["ITPAC"],
    ".lncc.br": ["Laboratório Nacional de Computação Científica"],
    ".mackenzie.br": ["Universidade Mackenzie"],
    ".maua.br": ["Instituto Maua de Tecnologia"],
    ".metodista.br": ["Universidade Metodista de Sao Paulo"],
    ".fab.mil.br": [
        "Escola de Especialistas de Aeronáutica (EEAR) - Força Aérea Brasileira (FAB)"
    ],
    ".on.br": ["Observatório Nacional", "National Observatory of Brazil"],
    ".student.42sp.org.br": ["42 São Paulo"],
    ".catolicasc.org.br": [
        "Centro Universitário - Católica de Santa Catarina"
    ],
    ".educadventista.org.br": [
        "Centro universitário adventista de São Paulo",
        "Adventist University Center of São Paulo",
    ],
    ".faculdadedaindustriaiel.org.br": [
        "Faculdade da Indústria - Campus Afonso Pena",
        "faculdade da Indústria",
        "instituto euvaldo lodi - IEL",
    ],
    ".fatcursos.org.br": [
        "Fundação FAT - Cursos a distância em São Paulo",
        "FAT Foundation - Distance learning courses in São Paulo",
    ],
    ".fieb.org.br": ["Federação das Indústrias do Estado da Bahia - Senai"],
    ".fmm.org.br": [
        "Fundação Matias Machline",
        "Faculdade do Amazonas de Ensino, Pesquisa e Inovação - Famepi",
    ],
    ".fundacaofemar.org.br": ["Fundação de Estudos do Mar"],
    ".germinare.org.br": ["Escola Germinare"],
    ".ibfc.org.br": [
        "Instituto Brasileiro de Formação e Capacitação",
        "Brazilian Institute of Training and Capacity Building",
    ],
    ".impatech.org.br": ["IMPA Tech"],
    ".edu.isd.org.br": [
        "Instituto Internacional de Neurociências Edmond e Lily Safra",
        "Edmond and Lily Safra International Institute of Neurosciences",
    ],
    ".lasalle.org.br": ["Centro Universitário Unilasalle do Rio de Janeiro"],
    ".maristavirtual.org.br": ["Colégio Marista rosário"],
    ".senairs.org.br": ["Faculdade de Tecnologia Senai Porto Alegre "],
    ".sesidf.org.br": ["Sesi - Sistema Fibra DF"],
    ".estudante.sesisenai.org.br": [
        "Industry Social Service - SESI",
        "National Learning Service - SENAI",
    ],
    ".sesisenaipr.org.br": ["Faculdade da Industria Senai Parana"],
    ".sistemafieg.org.br": ["Faculdade SENAI Fatesg", "SENAI Fatesg College"],
    ".sistemafiep.org.br": [
        "Faculdades da Indústria - Sistema FIEP",
        "Industry College - FIEP System",
    ],
    ".sociesc.org.br": [
        "Centro Universitário - Sociedade Educacional de Santa Catarina"
    ],
    ".ecomp.poli.br": [
        "Engenharia da Computação",
        "Escola Politécnica de Pernambuco",
    ],
    ".poli.br": ["Escola Politécnica de Pernambuco"],
    ".portovelho.br": ["Faculdade Porto"],
    ".uni9.pro.br": ["Universidade Nove de Julho"],
    ".puc-rio.br": ["Pontifícia Universidade Católica do Rio de Janeiro"],
    ".puccamp.br": ["Pontifícia Universidade Católica de Campinas"],
    ".pucminas.br": ["Pontifícia Universidade Católica de Minas Gerais"],
    ".pucpr.br": ["Pontificia Universidade Católica do Paraná"],
    ".pucrs.br": ["Pontifícia Universidade Católica do Rio Grande do Sul"],
    ".pucsp.br": ["Pontifícia Universidade Católica de São Paulo"],
    ".rct-sc.br": [
        "Universidade do Extremo Sul Catarinense",
        "Universidade do Vale do Itajaí",
        "Universidade para o Desenvolvimento do Alto Vale do Itajaí",
        "Universidade Regional de Blumenau",
    ],
    ".rnp.br": ["Universidade de Tocantins"],
    ".aluno.etip.santoandre.br": ["Centro Educacional ETIP"],
    ".etip.santoandre.br": ["Centro Educacional ETIP"],
    ".saocamilo-sp.br": ["Centro Universitário São Camilo"],
    ".aluno.saojose.br": [
        "Centro Universitário São José",
        " São José University Center",
    ],
    ".saojose.br": ["UniSãoJosé", "UniSãoJosé"],
    ".saojudas.br": ["Universidade São Judas Tadeu"],
    ".fac.pe.senac.br": ["Faculdade Senac Pernambuco"],
    ".senac.br": ["Centro Universitário Senac"],
    ".al.senai.br": [
        "Serviço Nacional de Aprendizagem Industrial",
        "National Service for Industrial Apprenticeship",
    ],
    ".aluno.senai.br": ["Senai - DF"],
    ".educacao.cetiqt.senai.br": ["Senai Cetiqt"],
    ".docente.senai.br": ["Firjan Senai", "Firjan Senai"],
    ".ba.estudante.senai.br": ["SENAI"],
    ".df.estudante.senai.br": ["SENAI"],
    ".es.estudante.senai.br": ["Senai"],
    ".go.estudante.senai.br": ["Faculdade Senai Fatesg"],
    ".mt.estudante.senai.br": ["Faculdade de Tecnologia SENAI Mato Grosso."],
    ".sc.estudante.senai.br": ["SENAI"],
    ".estudante.firjan.senai.br": ["Firjan Senai", "Firjan Senai"],
    ".pe.senai.br": ["Serviço Nacional de Aprendizagem Industrial - SENAI"],
    ".estudante.sc.senai.br": ["SENAI"],
    ".sc.senai.br": ["Serviço Nacional de Aprendizagem Industrial"],
    ".sp.senai.br": [
        "Serviço Nacional de Aprendizagem Industrial - São Paulo"
    ],
    ".simonsen.br": ["Faculdades Integradas Simonsen"],
    ".smarcos.br": ["Universidade São Marcos"],
    ".souzamarques.br": ["Faculdade Tecnico-Educacional Souza Marques"],
    ".stcecilia.br": ["Universidade Santa Cecília dos Bandeirantes"],
    ".tcero.tc.br": ["Escola de Contas do Tribunal de Contas de Rondônia"],
    ".tche.br": [
        "Universidade Católica de Pelotas",
        "Universidade da Região da Campanha",
        "Universidade de Caxias do Sul",
        "Universidade de Cruz Alta",
        "Universidade de Passo Fundo",
        "Universidade Federal de Pelotas",
        "Universidade Regional do Noroeste do Estado do Rio Grande do Sul",
    ],
    ".toledo.br": ["Faculdades Integradas Toledo"],
    ".ucam-campos.br": ["Universidade Candido Mendes - Campos dos Goytacazes"],
    ".a.ucb.br": ["União Brasileira de Educação Católica - UBEC"],
    ".ucb.br": ["Universidade Católica de Brasília"],
    ".ucdb.br": ["Universidade Catolica Dom Bosco"],
    ".ucl.br": ["Faculdade UCL"],
    ".ucp.br": ["Universidade Católica de Petrópolis"],
    ".ucs.br": ["Universidade de Caxias do Sul - UCS"],
    ".ucsal.br": ["Universidade Católica de Salvador"],
    ".edu.udesc.br": ["UDESC - Universidade do Estado de Santa Catarina"],
    ".udesc.br": ["Universidade do Estado de Santa Catarina"],
    ".aluno.uece.br": ["UECE"],
    ".uefs.br": ["Universidade Estadual de Feira de Santana"],
    ".ueg.br": ["Universidade Estadual de Goiás"],
    ".uel.br": ["Universidade Estadual de Londrina"],
    ".uem.br": ["Universidade Estadual de Maringá"],
    ".uema.br": ["Universidade Estadual do Maranhão"],
    ".comp.uems.br": [
        "Universidade Estadual de Mato Grosso do Sul - Ciência da Computação"
    ],
    ".uems.br": ["Universidade Estadual de Mato Grosso do Sul"],
    ".uenf.br": ["Universidade Estadual do Norte Fluminense"],
    ".uepa.br": ["UEPa - Universidade do Estado do Para"],
    ".uepg.br": ["Universidade Estadual de Ponta Grossa"],
    ".uerj.br": ["Universidade do Estado do Rio de Janeiro"],
    ".uern.br": ["Universidade do Estado do Rio Grande do Norte"],
    ".uesb.br": ["Universidade Estadual Sudoeste da Bahia"],
    ".uesc.br": ["Universidade Estadual de Santa Cruz"],
    ".uespi.br": ["Universidade Estadual do Piauí"],
    ".ufac.br": ["Universidade Federal do Acre"],
    ".ufal.br": ["Universidade Federal de Alagoas"],
    ".ufba.br": ["Universidade Federal da Bahia"],
    ".ufc.br": ["Universidade Federal do Ceará"],
    ".ufes.br": ["Universidade Federal do Espírito Santo"],
    ".uff.br": ["Universidade Federal Fluminense"],
    ".ufg.br": ["Universidade Federal de Goiás"],
    ".ufjf.br": ["Universidade Federal de Juiz de Fora"],
    ".ufla.br": ["Universidade Federal de Lavras"],
    ".ufma.br": ["Universidade Federal do Maranhão"],
    ".ufmg.br": ["Universidade Federal de Minas Gerais"],
    ".ufms.br": ["Universidade Federal de Mato Grosso do Sul"],
    ".ufmt.br": ["Universidade Federal de Mato Grosso"],
    ".decom.ufop.br": [
        "Universidade Federal de Ouro Preto",
        "Departamento de Computação",
    ],
    ".ufop.br": ["Universidade Federal de Ouro Preto"],
    ".ufpb.br": ["Universidade Federal da Paraíba"],
    ".cin.ufpe.br": [
        "Centro de Informática",
        "Universidade Federal de Pernambuco",
    ],
    ".ufpe.br": ["Universidade Federal de Pernambuco"],
    ".ufpi.br": ["Universidade Federal do Piauí"],
    ".ufrgs.br": ["Universidade Federal do Rio Grande do Sul"],
    ".ufrj.br": ["Universidade Federal do Rio de Janeiro"],
    ".ufrn.br": ["Universidade Federal do Rio Grande do Norte"],
    ".ufrpe.br": ["Universidade Federal Rural de Pernambuco"],
    ".ufrr.br": ["Universidade Federal de Roraima"],
    ".ufrrj.br": ["Universidade Federal Rural do Rio de Janeiro"],
    ".ufs.br": ["Universidade Federal de Sergipe"],
    ".ufsc.br": ["Universidade Federal de Santa Catarina"],
    ".ufscar.br": ["Universidade Federal de São Carlos"],
    ".ufsm.br": ["Universidade Federal de Santa Maria"],
    ".ufu.br": ["Universidade Federal de Uberlândia"],
    ".ufv.br": ["Universidade Federal de Viçosa"],
    ".uit.br": ["Universidade de Itaúna", "Itaúna University"],
    ".ulbra.br": ["Universidade Luterana do Brasil"],
    ".umc.br": ["Universidade de Mogi das Cruzes"],
    ".una.br": ["Centro Universitário UNA"],
    ".unaerp.br": ["Universidade de Ribeirão Preto"],
    ".unama.br": ["Universidade da Amazônia"],
    ".unb.br": ["Universidade de Brasília"],
    ".unc.br": ["Universidade do Contestado - UnC"],
    ".uneb.br": ["Universidade do Estado da Bahia"],
    ".unemat.br": ["Universidade do Estado de Mato Grosso"],
    ".unescnet.br": ["UNESC – Faculdades Integradas de Cacoal"],
    ".unesp.br": ["Universidade Estadual Paulista"],
    ".ung.br": ["Universidade de Guarulhos"],
    ".uniamerica.br": ["Uniamérica Centro Universitário"],
    ".uniandrade.br": ["Uniandrade", "Centro universitario campos de andrade"],
    ".uniararas.br": ["Uniararas - Fundação Hermínio Ometto"],
    ".unib.br": ["Universidade Ibirapuera"],
    ".uniban.br": ["Universidade Bandeirante de São Paulo"],
    ".unibh.br": ["Centro Universitário de Belo Horizonte"],
    ".unibosco.br": ["Universidade Católica Dom Bosco"],
    ".lasca.ic.unicamp.br": ["Unicamp", "University of Campinas"],
    ".unicap.br": ["Universidade Católica de Pernambuco"],
    ".unicastelo.br": ["Universidade Camilo Castelo Branco"],
    ".unicentro.br": ["Universidade Estadual do Centro-Oeste"],
    ".uniceub.br": ["Centro Universitário de Brasília"],
    ".unicid.br": ["Universidade Cidade de São Paulo"],
    ".unicsul.br": ["Universidade Cruzeiro do Sul"],
    ".uniderp.br": [
        "Universidade para o Desenvolvimento do Estado e da Região do Pantanal"
    ],
    ".unifacs.br": ["Universidade Salvador"],
    ".unifap.br": ["Universidade Federal do Amapá"],
    ".unifenas.br": ["Universidade de Alfenas"],
    ".unifesp.br": ["Universidade Federal de São Paulo"],
    ".unifieo.br": ["CENTRO UNIVERSITÁRIO FIEO"],
    ".edu.unifil.br": ["UniFil - Centro Universitário Filadélfia "],
    ".unifil.br": ["Centro Universitário Filadélfia", "UniFil"],
    ".unifor.br": ["Universidade de Fortaleza"],
    ".unifran.br": ["Universidade de Franca"],
    ".unig.br": ["Universidade de Nova Iguaçu"],
    ".alunos.unigran.br": [
        "UNIGRAN - Centro Universitário da Grande Dourados",
        "UNIGRAN - University Centre of the Grande Dourados Region",
    ],
    ".unigranrio.br": ["Universidade do Grande Rio"],
    ".unimar.br": ["Universidade de Marília"],
    ".unimep.br": ["Universidade Metodista de Piracicaba"],
    ".unimes.br": ["Universidade Metropolitana de Santos"],
    ".unimonte.br": ["Centro Universitário Monte Serrat"],
    ".unimontes.br": ["Universidade Estadual de Montes Claros"],
    ".uninga.br": ["Centro Universitário Ingá"],
    ".uninter.br": ["UNINTER - Centro Universitário Internacional"],
    ".unioeste.br": ["Universidade Estadual do Oeste do Paraná"],
    ".unip-objetivo.br": ["Universidade Paulista"],
    ".unip.br": ["Universidade Paulista - UNIP"],
    ".aluno.unipac.br": [
        "UNIPAC Barbacena - Centro Universitário Presidente Antônio Carlos",
        "UNIPAC Barbacena - University President Antônio Carlos",
    ],
    ".unipar.br": ["Universidade Paranaense"],
    ".unipe.br": ["Centro Universitário de João Pessoa"],
    ".unir.br": ["Universidade Federal de Rondônia"],
    ".unirio.br": ["Universidade Federal do Estado do Rio de Janeiro"],
    ".uniriotec.br": ["Universidade Federal do Estado do Rio de Janeiro"],
    ".unirondon.br": ["Centro Universitario Candido Rondon"],
    ".unisa.br": ["Universidade de Santo Amaro"],
    ".aluno.unisal.br": [
        "UNISAL - Centro Universitário Salesiano de São Paulo"
    ],
    ".lo.unisal.br": [
        "UNISAL - Centro Universitário Salesiano de São Paulo - Unidade Lorena"
    ],
    ".sj.unisal.br": [
        "UNISAL - Centro Universitário Salesiano de São Paulo - Unidade Campinas São José"
    ],
    ".alunos.unisanta.br": ["Universidade Santa Cecilia"],
    ".unisantos.br": ["Universidade Católica de Santos"],
    ".unisc.br": ["Universidade de Santa Cruz do Sul"],
    ".edu.unisinos.br": [
        "Universidade do Vale do Rio dos Sinos",
        "UNISINOS",
        "Vale do Rio do Sinos University",
    ],
    ".unisinos.br": ["Universidade Vale do Rio dos Sinos"],
    ".edu.uniso.br": ["Universidade de Sorocaba - UNISO"],
    ".uniso.br": ["Universidade de Sorocaba - Uniso"],
    ".unisul.br": ["Universidade do Sul de Santa Catarina"],
    ".unit.br": ["Universidade Tiradentes"],
    ".unitau.br": ["Universidade de Taubaté"],
    ".unitins.br": ["Fundação Universidade do Tocantins"],
    ".unitoledo.br": ["UniToledo"],
    ".uniube.br": ["Universidade de Uberaba"],
    ".univale.br": ["Universidade Vale do Rio Doce"],
    ".univali.br": ["Univali"],
    ".univap.br": ["Universidade Vale do Paraiba"],
    ".univates.br": ["Universidade do Vale do Taquari"],
    ".univel.br": ["Univel - União Educacional de Cascavel"],
    ".universo.br": ["Universidade Salgado de Oliveira"],
    ".univesp.br": ["Universidade Virtual do Estado de São Paulo"],
    ".univille.br": ["Univille - Universidade da sua vida"],
    ".unoeste.br": ["Universidade do Oeste Paulista"],
    ".unopar.br": ["Universidade Norte do Paraná"],
    ".unorp.br": ["Centro Universitário do Norte Paulista", "UNORP"],
    ".unp.br": ["Universidade Potiguar"],
    ".ecomp.poli.upe.br": [
        "Engenharia da Computação",
        "Escola Politécnica de Pernambuco",
        "Universidade de Pernambuco",
    ],
    ".poli.upe.br": [
        "Escola Politécnica de Pernambuco",
        "Universidade de Pernambuco",
    ],
    ".upe.br": ["Universidade de Pernambuco"],
    ".upf.br": ["Universidade de Passo Fundo"],
    ".upis.br": ["Faculdades Integradas UPIS"],
    ".urca.br": ["Universidade Regional do Cariri"],
    ".uri.br": [
        "Universidade Regional Integrada do Alto Uruguai e das Missões"
    ],
    ".urisantiago.br": [
        "Universidade Regional Integrada do Alto Uruguai e das Missões (URI)"
    ],
    ".usc.br": ["Universidade do Sagrado Coração"],
    ".usf.br": ["Universidade São Francisco"],
    ".usjt.br": ["Universidade São Judas Tadeu"],
    ".usp.br": ["Universidade de São Paulo"],
    ".uss.br": ["Universidade Severino Sombra"],
    ".usu.br": ["Universidade Santa Úrsula"],
    ".utp.br": ["Universidade Tuiuti do Paraná"],
    ".uva.br": ["Universidade Veiga de Almeida"],
    ".uvanet.br": ["Universidade Estadual do Vale do Acaraú"],
    ".uvv.br": ["Universidade Vila Velha"],
    ".ub.edu.bs": ["University of The Bahamas"],
    ".gaming.bs": ["Gaming Campus Paris"],
    ".jnec.edu.bt": ["Jigme Namgyel Engineering College"],
    ".rub.edu.bt": ["Royal University of Bhutan"],
    ".bac.ac.bw": ["Botswana Accountancy College"],
    ".biust.ac.bw": [
        "Botswana  International University of Science & Technology"
    ],
    ".ub.ac.bw": ["University Botswana"],
    ".bca.bw": ["Botswana College of Agriculture"],
    ".mopipi.ub.bw": ["University of Botswana"],
    ".ub.bw": ["University of Botswana"],
    ".baa.by": ["Belarusian State Agricultural Academy"],
    ".belstu.by": ["Belarusian State Technological University"],
    ".bgam.by": [
        "Белорусская Государственная Академия Музыки",
        "Belarusian State Academy of Music",
    ],
    ".bkatk.by": ["Буда-Кошелевский аграрно-технический колледж"],
    ".bntu.by": ["Belarusian National Technical University"],
    ".brest.by": ["Brest State University"],
    ".brsu.by": [
        "\ufeffБрестский государственный университет имени А.С. Пушкина"
    ],
    ".bru.by": ["Belarusian-Russian University"],
    ".bsac.by": ["Belarusian State Academy of Telecommunications"],
    ".bseu.by": ["Belarusian State Economic University"],
    ".bsmu.by": ["Belarusian State Medical University"],
    ".bspu.by": [
        "Белорусский Государственный Педагогический Университет им. Максима Танка",
        " Belarusian State Pedagogical University Named After Maxim Tank",
    ],
    ".bstu.by": ["Brest State Technical University"],
    ".bsu.by": ["Belarusian State University"],
    ".bsuir.by": [
        "Belarusian State University of Informatics and Radioelectronics"
    ],
    ".bsut.by": [
        "Белорусский государственный университет транспорта",
        "Belarusian State University of Transport",
    ],
    ".buk.by": ["Belarusian State University of Culture and Arts"],
    ".edu.by": [
        "Belarusian State Academy of Music",
        "Belarusian State Agrarian Technical University",
    ],
    ".fksis.by": [
        "Faculty of Computer Systems and Networks (Belarusian State University of Informatics and Radioelectronics)"
    ],
    ".ggkttd.by": [
        "Гродненский государственный колледж техники, технологий и дизайна",
        "Hrodno state college of technic, technologies and design",
    ],
    ".ggplp.by": ["Gomel State Professional Lyceum of Instrumentation"],
    ".gomel.by": [
        "Belarusian State University of Transport",
        "Gomel State Medical University",
        "Gomel State Technical University Pavel Sukhoi",
        "Mozyr State Pedagogical Institute",
    ],
    ".kii.gov.by": [
        "Institute for Command Engineers of The Ministry for Emergency Situations"
    ],
    ".grodno.by": ["Grodno State Agrarian University"],
    ".grsmu.by": ["Grodno State Medical University"],
    ".grsu.by": ["Grodno State University Yanka Kupaly"],
    ".gstu.by": ["Gomel State Technical University Pavel Sukhoi"],
    ".gsu.by": ["Francisk Skorina Gomel State University"],
    ".iseu.by": ["International Sakharov Environmental University"],
    ".lyceum.by": ["Lyceum of Belarusian State University"],
    ".mcb.by": [
        "Минский колледж предпринимательства",
        "Minsk college of business",
    ],
    ".mia.by": [
        "Academy of the Ministry of Internal Affairs of the Republic of Belarus"
    ],
    ".minsk.by": ["European Humanities University"],
    ".mitso.by": [
        'Международный Университет "МИТСО"',
        'International University "MITSO"',
    ],
    ".miu.by": ["Minsk Institute of Management"],
    ".mogilev.by": [
        "Belarusian-Russian University",
        "Mogilev State University A.A. Kuleshov",
    ],
    ".mrk-bsuir.by": [
        '"Belarusian State University of Informatics and Radio Electronics" Affiliate "Minsk Radio Engineering College"'
    ],
    ".mslu.by": ["Minsk State Linguistic University"],
    ".mspu.by": [
        "Мозырьский государственный универстит имени И.П. Шамякина",
        "Mozyr State Pedagogical University named after I.P.Shamyakin",
    ],
    ".msu.by": ["Mogilev State University A.A. Kuleshov"],
    ".mtp.by": [
        "Минский Колледж Предпринимательства",
        "Minsk College Of Bisenes",
    ],
    ".pac.by": [
        "The Academy of Public Administration under the aegis of the President of the Republic of Belarus",
        "Академия управления при Президенте Республики Беларусь",
        "http://www.pac.by/en",
        "http://www.pac.by/ru/general-information/structure/institut-upr-kadrov/fakultet-innovacionnoi-podgotovki/1-stupen/",
        "http://oi67.tinypic.com/2zeb0n8.jpg",
    ],
    ".pdu.by": ["Polotsk State University"],
    ".polessu.by": ["Polessky State University"],
    ".psu.by": ["Polotsk State University"],
    ".reu.by": [
        "Российский экономический УНИВЕРСИТЕТ имени Г.В. Плеханова",
        "PLEKHANOV Russian University of Economics",
    ],
    ".unibel.by": [
        "Belarusian State Pedagogical University M. Tanka",
        "Belarusian State Polytechnical Academy",
        "Belarusian State Technological University",
        "Gomel State University Francisk Scarnia",
    ],
    ".uoggmk.by": [
        "Gomel State Machine-Building College",
        "Educational Institution «Gomel State College of Mechanical Engineering»",
        "Учреждение образования «Гомельский государственный машиностроительный колледж»",
    ],
    ".vfbsac.by": [
        'Витебский филиал УО "Белорусская государственная академия связи"',
        'Vitebsk branch of the educational establishment "Belarusian State Academy of Telecommunications"',
    ],
    ".vitebsk.by": [
        "Vitebsk State Medical University",
        "Vitebsk State Technological University",
    ],
    ".vstu.by": ["Vitebsk State Technological Univercity"],
    ".vsu.by": ["Vitebsk State University"],
    ".ub.edu.bz": ["University of Belize"],
    ".sjc.bz": ["Saint John's College University"],
    ".assomption.bzh": [
        "Collège, Lycée, Prépa Assomption",
        "Lycée Assomption",
    ],
    ".esna.bzh": ["Ecole Supérieure du Numérique Appliqué"],
    ".ozanam.bzh": ["Lycée Frederic Ozanam"],
    ".5565.ca": [
        "St. Albert Public Schools",
        ".group",
        "http://www.spschools.org/",
    ],
    ".augustana.ab.ca": ["Augustana University College"],
    ".cbe.ab.ca": ["Calgary Board of Education"],
    ".student.concordia.ab.ca": ["Concordia University of Edmonton"],
    ".learn.cssd.ab.ca": ["St.John Henry Newman School"],
    ".mtroyal.ab.ca": ["Mount Royal University"],
    ".rvschools.ab.ca": ["Springbank Community High School"],
    ".wolfcreek.ab.ca": ["Ponoka Secondary Campus", "Ponoka Secondary Campus"],
    ".acadiau.ca": ["Acadia University"],
    ".algomau.ca": ["Algoma University"],
    ".arsdayschool.ca": [
        "ARS Armenian Private School",
        "ARS Armenian Private School",
    ],
    ".ashbury.ca": ["Ashbury"],
    ".assumptionu.ca": ["Assumption University"],
    ".athabascau.ca": ["Athabasca University"],
    ".bart.ca": ["Collège Bart", "Bart College"],
    ".bayviewglen.ca": ["Bayview Glen Independent School"],
    ".camosun.bc.ca": ["Camosun College"],
    ".capcollege.bc.ca": ["Capilano College"],
    ".cnc.bc.ca": ["College of New Caledonia"],
    ".cotr.bc.ca": ["College of the Rockies"],
    ".csf.bc.ca": ["Conseil scolaire francophone de la C.-B."],
    ".douglas.bc.ca": ["Douglas College"],
    ".kwantlen.bc.ca": ["Kwantleen University College"],
    ".langara.bc.ca": ["Langara College"],
    ".mala.bc.ca": ["Malaspina University College"],
    ".meadowridge.bc.ca": ["Meadowridge School"],
    ".mylangara.bc.ca": ["Langara College"],
    ".myokanagan.bc.ca": ["Okanagan College"],
    ".nic.bc.ca": ["North Island College"],
    ".nlc.bc.ca": ["Northern Lights College"],
    ".nvit.bc.ca": ["Nicola Valley Institute of Technology"],
    ".okanagan.bc.ca": ["Okanagan University College"],
    ".sd23.bc.ca": ["Central Okanagan School District 23"],
    ".sd33.bc.ca": ["School District 33"],
    ".sd36.bc.ca": ["Surrey School District 36"],
    ".sd38.bc.ca": ["Steveston-London Secondary School"],
    ".sd43.bc.ca": ["Coquitlam School District 43"],
    ".sd45.bc.ca": ["West Vancouver School District 45"],
    ".sd57.bc.ca": ["School District #57 Prince George"],
    ".sd61.bc.ca": ["Greater Victoria School District #61"],
    ".sd63.bc.ca": ["Saanich School District #63"],
    ".sd64.bc.ca": ["Gulf Islands Secondary School"],
    ".sd72.bc.ca": ["School District No 72 (Campbell River)"],
    ".southridge.bc.ca": ["Southridge School"],
    ".stgeorges.bc.ca": ["St. George's School"],
    ".vsb.bc.ca": ["School District 39 (Vancouver)"],
    ".bccis.ca": [
        "(BCCIS) British Columbia Canadian International School",
        "British Columbia Canadian International School",
    ],
    ".bcit.ca": ["British Columbia Institute of Technology"],
    ".bialik.ca": ["Bialik Hebrew Day School"],
    ".boothcollege.ca": ["William and Catherine Booth College"],
    ".bowvalleycollege.ca": ["Bow Valley College"],
    ".brandonu.ca": ["Brandon University"],
    ".brocku.ca": ["Brock University"],
    ".edu.burnabyschools.ca": ["Burnaby North Secondary School"],
    ".cambriancollege.ca": ["Cambrian College of Applied Arts and Technology"],
    ".online.camosun.ca": ["Camosun College"],
    ".canctb.ca": [
        "Canadian College of Technology and Business",
        "Canadian College of Technology and Business",
    ],
    ".capilanou.ca": ["Capilano University"],
    ".carleton.ca": ["Carleton University"],
    ".cbu.ca": ["Cape Breton University"],
    ".ccbc.ca": ["Canadian College of Business &amp; Computers"],
    ".etu.cchic.ca": ["Cégep de Chicoutimi"],
    ".cdicollege.ca": ["CDI College"],
    ".cegepdrummond.ca": ["Cégep de Drummondville"],
    ".edu.cegepgarneau.ca": ["Cégep Garneau"],
    ".cegepgarneau.ca": ["Cégep Garneau"],
    ".cegepgim.ca": ["Cégep de la Gaspésie et des Îles"],
    ".cegepjonquiere.ca": ["Cégep de Jonquière"],
    ".cegeplevis.ca": ["Cégep de Lévis"],
    ".etudiant.cegeplimoilou.ca": ["Cégep de Limoilou"],
    ".cegeplimoilou.ca": ["Cégep Limoilou"],
    ".cegepmontpetit.ca": ["Cégep Édouard-Montpetit"],
    ".cegepmv.ca": ["New Cégep Marie-Victorin domains"],
    ".cegepsi.ca": ["Cégep de Sept-Îles"],
    ".cegepstfe.ca": ["Cegep Saint-Félicien"],
    ".cegepvicto.ca": ["Cégep de Victoriaville"],
    ".centennialcollege.ca": ["Centennial College"],
    ".cimf.ca": ["Collège international Marie de France"],
    ".citicollege.ca": ["CITI COLLEGE", "CITI COLLEGE"],
    ".cmu.ca": ["Canadian Mennonite University"],
    ".collegealma.ca": ["Collège d'Alma"],
    ".collegeboreal.ca": ["Collège Boréal"],
    ".collegecdi.ca": ["College CDI"],
    ".edu.collegelacite.ca": ["La cité collégial"],
    ".collegelacite.ca": ["La Cité College, Canada"],
    ".collegeshawinigan.ca": ["Collège Shawinigan"],
    ".columbiacollege.ca": ["Columbia College"],
    ".concordia.ca": ["Concordia University"],
    ".confederationcollege.ca": ["Confederation College"],
    ".cscprovidence.ca": ["Conseil scolaire catholique Providence"],
    ".csda.ca": ["Centre de services scolaire des Affluents"],
    ".csdmedu.ca": [
        "École des métiers de l'informatique, du commerce et de l'administration",
        "EMICA | CSSDM",
    ],
    ".csfoy.ca": ["Cégep de Sainte-Foy"],
    ".cshawi.ca": ["CEGEP Shawinigan"],
    ".csjv.ca": ["Collège St-Jean-Vianney"],
    ".csjvedu.ca": ["Collège St-Jean-Vianney"],
    ".ele.cssda.ca": ["Centre de services scolaire des Affluents"],
    ".cus.ca": ["University of Moncton, Shippagan"],
    ".cuslm.ca": ["University of Moncton, Edmundston"],
    ".dal.ca": ["Dalhousie University"],
    ".dclive.ca": ["Durham Catholic District School Board"],
    ".dcmail.ca": ["Durham College"],
    ".delasalle.ca": ['De La Salle College "Oaklands"'],
    ".devry.ca": ["DeVry Institute of Technology"],
    ".douglascollege.ca": ["Douglas College"],
    ".durhamcollege.ca": ["Durham College", "https://durhamcollege.ca/"],
    ".easternstudent.ca": ["Eastern College", "Eastern College"],
    ".ecolecatholique.ca": ["Franco-Cité", "Franco-Cite"],
    ".ecuad.ca": ["Emily Carr University of Art and Design"],
    ".educbe.ca": ["Sir John A. MacDonald Junior High"],
    ".enap.ca": ["Ecole Nationale d'Administration Publique"],
    ".epsb.ca": ["Vernon Barford Junior High School", ".group"],
    ".etsmtl.ca": ["École de technologie supérieure, Université du Québec"],
    ".fanshawec.ca": ["Fanshawe College"],
    ".fanshaweonline.ca": ["Fanshawe College"],
    ".firstnationsuniversity.ca": ["First Nations University of Canada"],
    ".flemingcollege.ca": ["Fleming College"],
    ".learning.fraseric.ca": ["Simon Fraser University"],
    ".georgebrown.ca": ["George Brown College"],
    ".georgiancollege.ca": ["Georgian College"],
    ".gnspes.ca": ["Nova Scotia English School Board"],
    ".hdsb.ca": ["Halton District School Board"],
    ".hec.ca": ["École des Hautes Études Commerciales"],
    ".mtl.herzing.ca": ["Herzing College Montreal"],
    ".otw.herzing.ca": ["Herzing college"],
    ".herzing.ca": ["Herzing College"],
    ".humber.ca": ["Humber College"],
    ".humbermail.ca": ["Humber College"],
    ".hwcdsb.ca": ["Cathedral High School"],
    ".learning.icmanitoba.ca": ["International College Of Manitoba"],
    ".inrs.ca": ["Institut Armand-Frappier, Université du Québec"],
    ".itas.ca": [
        "Vancouver Island University - Information Technology Applied Systems"
    ],
    ".itdcanada.ca": ["Institute of Technology Development of Canada"],
    ".ivey.ca": ["Ivey Busines School"],
    ".keyanomail.ca": ["Keyano College"],
    ".kingschristian.ca": ["King's Christian Collegiate"],
    ".kingsu.ca": ["The Kings University"],
    ".kpu.ca": ["Kwantlen Polytechnic University"],
    ".kuperacademy.ca": ["Kuper Academy"],
    ".kwantlen.ca": ["Kwantlen Polytechnic University"],
    ".lakeheadschools.ca": ["Superior Collegiate & Vocational Institute"],
    ".lakeheadu.ca": ["Lakehead University"],
    ".lambtoncollege.ca": ["Lambton College"],
    ".langara.ca": ["Langara College"],
    ".langleyschools.ca": ["Langley School District 35"],
    ".laurentian.ca": ["Laurentian University of Sudbury"],
    ".lbpearson.ca": ["Lester B. Pearson School Board"],
    ".lethpolytech.ca": ["Lethbridge College"],
    ".lgca.ca": ["Lions Gate Christian Academy"],
    ".lssd.ca": [
        "Lord Selkirk School Division",
        "Lord Selkirk Regional Comprehensive Secondary School",
        ".group",
    ],
    ".macewan.ca": ["MacEwan University"],
    ".maristes.ca": ["Collège mariste de Québec"],
    ".ustboniface.mb.ca": ["University College of Saint-Boniface"],
    ".mcgill.ca": ["McGill University"],
    ".mcmaster.ca": ["McMaster University"],
    ".meadowridge.ca": ["Meadowridge School"],
    ".mitt.ca": ["Manitoba Institute of Trades and Technology"],
    ".monboreal.ca": ["Collège Boréal"],
    ".monccnb.ca": ["CCNB", "Community College of New Brunswick"],
    ".montrealcollege.ca": [
        "Montreal College of Information Technology",
        "Montreal College of Information Technology",
    ],
    ".monusb.ca": ["Université de Saint Boniface"],
    ".msvu.ca": ["Mount Saint Vincent University"],
    ".mta.ca": ["Mount Allison University"],
    ".mtroyal.ca": ["Mount Royal University"],
    ".mun.ca": ["Memorial University of Newfoundland"],
    ".myasm.ca": ["Acsenda School of Management"],
    ".mybvc.ca": ["Bow Valley College"],
    ".mycambrian.ca": ["Cambrian College"],
    ".mycanctb.ca": ["Canadian College of Technology and Business"],
    ".mycdi.ca": ["College CDI"],
    ".myciticollege.ca": ["Citi College, Canada"],
    ".myflemingcollegetoronto.ca": ["Fleming College Toronto"],
    ".mygeorgian.ca": ["Georgian College"],
    ".mylambton.ca": ["Lambton College"],
    ".mylangara.ca": ["Langara College"],
    ".mylaurier.ca": ["Wilfrid Laurier University"],
    ".mylfabc.ca": ["Little Flower Academy", "Little Flower Academy"],
    ".mymacewan.ca": ["MacEwan University"],
    ".mymhc.ca": ["Medicine Hat College"],
    ".mynbcc.ca": ["New Brunswick Community College"],
    ".mynorquest.ca": ["Norquest College"],
    ".myscc.ca": [
        "St. Clair College",
        "official website URL: http://www.stclaircollege.ca/",
        "long-term IT related course: https://scweb.ca/ &&  http://www.stclaircollege.ca/programs/postsec/mobile_app_dev/",
    ],
    ".myseneca.ca": ["Seneca Polytechnic"],
    ".mytru.ca": ["Thomson Rivers University"],
    ".mytsom.ca": [
        "Toronto School of Management",
        "Toronto School of Management",
    ],
    ".mytwu.ca": ["Trinity Western University"],
    ".mytyndale.ca": ["Tyndale University College & Seminary"],
    ".myucw.ca": ["University Canada West"],
    ".myucwest.ca": ["University Canada West"],
    ".myumanitoba.ca": ["University of Manitoba"],
    ".myunfc.ca": ["University of Niagara Falls Canada"],
    ".nait.ca": ["Northern Alberta Institute of Technology"],
    ".nbcc.ca": ["New Brunswick Community College"],
    ".newwestschools.ca": [],
    ".niagaracollege.ca": ["Niagara College"],
    ".niagaracollegetoronto.ca": ["Niagara College Toronto"],
    ".nipissingu.ca": ["Nipissing University"],
    ".cna.nl.ca": ["College of the North Atlantic"],
    ".nlesd.ca": ["Gander Collegiate"],
    ".norquest.ca": ["NorQuest College"],
    ".northislandcollege.ca": ["North Island College"],
    ".ednet.ns.ca": ["St. Anne University"],
    ".nscad.ns.ca": ["Nova Scotia College of Art and Design"],
    ".uccb.ns.ca": ["University College of Cape Breton"],
    ".ukings.ns.ca": ["University of King's College"],
    ".nscc.ca": ["Nova Scotia Community College"],
    ".nwpolytech.ca": ["Northwestern Polytechnic"],
    ".ocad.ca": ["Ontario College of Art and Design"],
    ".ocadu.ca": ["OCAD(Ontario College of Art and Design) University"],
    ".ocdsb.ca": ["Ottawa-Carleton District School Board"],
    ".ocsbconted.ca": ["St Patrick School ", "St Patrick School - Ottawa"],
    ".ocsbstudent.ca": ["Ottawa Catholic School Board"],
    ".oldsuncollege.ca": ["Old Sun Community College"],
    ".borealc.on.ca": ["Collège Boréal"],
    ".gx.cds.on.ca": ["The Country Day School"],
    ".conestogac.on.ca": ["Conestoga College"],
    ".confederationc.on.ca": ["Confederation College"],
    ".crestwood.on.ca": ["Crestwood Prepatory College"],
    ".durhamc.on.ca": ["Durham College"],
    ".georgianc.on.ca": ["Georgian College"],
    ".hsc.on.ca": ["Hillfield Strathallan College"],
    ".huronuc.on.ca": ["Huron University College"],
    ".hwdsb.on.ca": ["Hamilton-Wentworth District School Board"],
    ".lacitec.on.ca": ["La Cité College, Canada"],
    ".lambton.on.ca": ["Lambton College"],
    ".limestone.on.ca": ["Limestone district school board"],
    ".loyalistc.on.ca": ["Loyalist College"],
    ".northernc.on.ca": ["Northern College"],
    ".student.rcdsb.on.ca": [
        "renfrew county district school board student emails"
    ],
    ".rcdsb.on.ca": ["renfrew county district school board"],
    ".rsgc.on.ca": ["Royal St. George's College"],
    ".scdsb.on.ca": ["Banting Memorial High School"],
    ".scs.on.ca": ["St. Clement's School, Toronto"],
    ".senecac.on.ca": ["Seneca College"],
    ".sheridanc.on.ca": ["Sheridan College"],
    ".sl.on.ca": ["St. Lawrence College"],
    ".smcdsb.on.ca": ["Simcoe Muskoka Catholic District School Board"],
    ".tdsb.on.ca": ["Toronto District School Board"],
    ".ucc.on.ca": ["Upper Canada College"],
    ".wrdsb.on.ca": ["Waterloo Region District School Board"],
    ".cloud.edu.pe.ca": ["Three Oaks High School"],
    ".netmail.edu.pe.ca": ["Three Oaks High School"],
    ".pearsoncollege.ca": ["Lester B. Pearson College UWC"],
    ".pembinatrails.ca": [
        "Pembina Trails Collegiate",
        "Pembina Trails Collegiate",
    ],
    ".perimeterinstitute.ca": [
        "Perimeter Institute for Theoretical Physics",
        "Perimeter Institute for Theoretical Physics",
    ],
    ".petrelcollege.ca": ["Petrel College of Technology"],
    ".polymtl.ca": ["École Polytechnique de Montréal, Université de Montréal"],
    ".publicboard.ca": ["Greater Essex County District School Board"],
    ".purescollege.ca": ["Pures College"],
    ".bdeb.qc.ca": ["Collège de Bois-de-Boulogne"],
    ".brebeuf.qc.ca": ["Collège Jean-De-Brébeuf "],
    ".cegep-chicoutimi.qc.ca": ["Cégep de Chicoutimi"],
    ".cegep-heritage.qc.ca": ["Cegep Heritage"],
    ".etu.cegep-lanaudiere.qc.ca": [
        "Cégep de Lanaudière à Joliette",
        "Cegep of Lanaudière at Joliette",
    ],
    ".cegep-lanaudiere.qc.ca": ["Cégep de Lanaudière à Joliette"],
    ".cegep-rimouski.qc.ca": ["\ufeffCégep de Rimouski"],
    ".cegep-ste-foy.qc.ca": ["Cégep de Sainte-Foy"],
    ".cegepat.qc.ca": [
        "Cégep de l'Abitibi Témiscamingue",
        "Cégep of Abitibi Témiscamingue",
    ],
    ".cegepba.qc.ca": ["CÉGEP Beauce-Appalaches"],
    ".cegepgranby.qc.ca": ["Cégep de Granby"],
    ".cegeplapocatiere.qc.ca": ["Cegep de la Pocatière "],
    ".cegepoutaouais.qc.ca": ["Cégep de l'Outaouais"],
    ".cegepsherbrooke.qc.ca": ["Le Cégep de Sherbrooke"],
    ".cegepsl.qc.ca": ["Cégep de Saint-Laurent"],
    ".cegepst.qc.ca": ["Cégep de Sorel-Tracy"],
    ".cegepsth.qc.ca": ["Cégep de Saint-Hyacinthe"],
    ".cegeptr.qc.ca": ["Cégep de Trois-Rivières"],
    ".cgmatane.qc.ca": ["Cégep de Matane"],
    ".cgodin.qc.ca": ["Cégep Gérald-Godin"],
    ".champlaincollege.qc.ca": ["Champlain Regional College"],
    ".claurendeau.qc.ca": ["Cégep André-Laurendeau"],
    ".clg.qc.ca": ["Collège Lionel-Groulx"],
    ".cmaisonneuve.qc.ca": ["Collège de Maisonneuve"],
    ".cmontmorency.qc.ca": ["Collège Montmorency"],
    ".college-em.qc.ca": ["Cégep Édouardp-Montpetit"],
    ".educ.college-montreal.qc.ca": ["Collège de Montréal"],
    ".collegeahuntsic.qc.ca": ["Collège Ahuntsic"],
    ".collegemv.qc.ca": ["\ufeffCégep Marie-Victorin college"],
    ".collegeshawinigan.qc.ca": ["Collège Shawinigan", "Shawinigan College"],
    ".colval.qc.ca": ["Collège de Valleyfield"],
    ".crc-lennox.qc.ca": ["Champlain Regional College Lennoxville"],
    ".crosemont.qc.ca": ["Collège de Rosemont", "College of Rosemont"],
    ".educ.cscapitale.qc.ca": ["La Camaradière"],
    ".csdessommets.qc.ca": ["CEA Memphremagog"],
    ".edu.csdraveurs.qc.ca": ["École polyvalente De l'Érablière"],
    ".cslsj.qc.ca": ["École Jean-Gautier "],
    ".csmb.qc.ca": ["Commission scolaire Marguerite-Bourgeoys"],
    ".csnavigateurs.qc.ca": ["\ufeffÉcole Secondaire Les Etchemins"],
    ".cssmi.qc.ca": ["Centre de Services Scolaire des Mille-Îles"],
    ".cstj.qc.ca": ["Cégep de Saint-Jérôme"],
    ".cstjean.qc.ca": ["Cégep Saint-Jean-sur-Richelieu"],
    ".etu.cvm.qc.ca": ["Cégep du Vieux-Montréal"],
    ".cvm.qc.ca": ["Cégep du Vieux-Montréal"],
    ".dawsoncollege.qc.ca": ["Dawson College CEGEP"],
    ".cssdn.gouv.qc.ca": [
        "Centre d'Education aux Adultes des Navigateurs",
        "Education Center for Adults of Navigateurs",
    ],
    ".grasset.qc.ca": ["Institut Grasset"],
    ".johnabbott.qc.ca": ["John Abbott College"],
    ".osullivan-quebec.qc.ca": ["Collège O'Sullivan de Québec"],
    ".psnm.qc.ca": [
        "Pensionnat du Saint-Nom-de-Marie",
        "Boarding School Du Saint-nom-de-Marie",
    ],
    ".rsb.qc.ca": ["Riverside School Board"],
    ".slc.qc.ca": ["Cegep Champlain St. Lawrence"],
    ".stanislas.qc.ca": ["Collège Stanislas de Montréal"],
    ".teccart.qc.ca": [
        "institut teccart",
        "https://www.teccart.qc.ca/",
        "https://www.teccart.qc.ca/it-management-dec.php",
    ],
    ".vaniercollege.qc.ca": ["Vanier College"],
    ".queensu.ca": ["Queen's University"],
    ".questu.ca": ["Quest University"],
    ".rcsd.ca": ["Regina Catholic Schools"],
    ".rdcrs.ca": [
        "École Secondaire Notre Dame High School",
        "Red Deer Catholic Regional Schools",
        ".group",
    ],
    ".rdpolytech.ca": ["Red Deer Polytechnic"],
    ".redeemer.ca": ["Redeemer College"],
    ".retsdstudent.ca": ["River East Collegiate"],
    ".rmc-cmr.ca": ["Royal Military College of Canada"],
    ".rmc.ca": ["Royal Military College of Canada"],
    ".royalroads.ca": ["Royal Roads University"],
    ".rrc.ca": ["Red River College"],
    ".rubika-edu.ca": [
        "Rubika, école supérieure de création numérique appliquée à l'animation, au design et au jeu vidéo inc."
    ],
    ".ryerson.ca": ["Ryerson Polytechnic University"],
    ".sainteanne.ca": ["Collège Sainte-Anne de Lachine"],
    ".sait.ca": ["Southern Alberta Institute of Technology"],
    ".saskpolytech.ca": ["Saskatchewan Polytechnic"],
    ".saultcollege.ca": ["Sault College of Applied Arts & Technology"],
    ".sd33online.ca": ["School District 33"],
    ".sd61learn.ca": ["Gordon Head Middle School"],
    ".selkirk.ca": ["Selkirk College"],
    ".selwyn.ca": ["Selwyn House School"],
    ".senecacollege.ca": ["Seneca Polytechnic"],
    ".senecapolytechnic.ca": ["Seneca Polytechnic", "Seneca Polytechnic"],
    ".sfu.ca": ["Simon Fraser University"],
    ".shawnigan.ca": ["Shawnigan Lake School"],
    ".sheridancollege.ca": ["Sheridan College"],
    ".rbe.sk.ca": ["Allan Blakeney Adult Campus"],
    ".spsd.sk.ca": ["Saskatoon Public Schools", "Saskatoon Public Schools"],
    ".smu.ca": ["Saint Mary's University"],
    ".stclaircollege.ca": ["St.Clair College"],
    ".stclairconnect.ca": ["St.Clair College"],
    ".stfx.ca": ["St. Francis Xavier University"],
    ".stmarys.ca": ["St. Mary's University"],
    ".stmu.ca": ["St Mary's University"],
    ".stthomasu.ca": ["St. Thomas University"],
    ".stu.ca": ["St. Thomas University"],
    ".surreyschools.ca": ["Surrey School District 36"],
    ".tav.ca": ["Tav College"],
    ".teluq.ca": ["TÉLUQ"],
    ".tfs.ca": ["Toronto French School"],
    ".thecdm.ca": ["Centre for Digital Media"],
    ".thecea.ca": ["Langara Centre for Entertainment Arts"],
    ".torontofilmschool.ca": ["Toronto Film School"],
    ".torontomu.ca": ["Toronto Metropolitan University"],
    ".trentu.ca": ["Trent University"],
    ".tru.ca": ["Thompson Rivers University"],
    ".tvdsb.ca": ["Thames Valley District School Board"],
    ".twu.ca": ["Trinity Western University"],
    ".tyndale.ca": ["Tyndale University College & Seminary"],
    ".ualberta.ca": ["University of Alberta"],
    ".ubc.ca": [
        "Sauder School of Business",
        "University of British Columbia",
        "The University of British Columbia",
    ],
    ".ubishops.ca": ["Bishop's University"],
    ".ucalgary.ca": ["University of Calgary"],
    ".my.ucdsb.ca": ["Russell High School"],
    ".ufv.ca": ["University of the Fraser Valley"],
    ".ugcloud.ca": ["Center Wellington District High School"],
    ".ulaval.ca": ["Université Laval"],
    ".uleth.ca": ["University of Lethbridge"],
    ".umanitoba.ca": ["University of Manitoba"],
    ".umoncton.ca": ["University of Moncton"],
    ".umontreal.ca": ["Université de Montréal"],
    ".unb.ca": ["University of New Brunswick"],
    ".unbc.ca": ["University of Northern British Columbia"],
    ".unbsj.ca": ["University of New Brunswick, Saint John"],
    ".uofguelph.ca": ["University of Guelph (Ontario, Canada)"],
    ".uoguelph.ca": ["University of Guelph"],
    ".uoit.ca": ["University of Ontario Institute of Technology"],
    ".uottawa.ca": ["University of Ottawa"],
    ".upei.ca": ["University of Prince Edward Island"],
    ".uqac.ca": ["Université du Québec à Chicoutimi"],
    ".uqam.ca": ["Université du Québec à Montréal"],
    ".uqar.ca": ["Université du Québec à Rimouski"],
    ".uqat.ca": ["Université du Québec en Abitibi-Témiscamingue"],
    ".uqo.ca": ["Université du Québec en Outaouais"],
    ".uqtr.ca": ["Université du Québec à Trois-Rivières"],
    ".uquebec.ca": [
        "École nationale d'administration publique, Université du Québec",
        "Institut National de la Recherche Scientifique, Université du Québec",
        "Télé-université, Université du Québec",
        "Université du Québec à Rimouski",
        "Université du Québec à Trois-Rivières",
        "Université du Québec en Abitibi-Témiscamingue",
        "University of Québec",
    ],
    ".uregina.ca": ["University of Regina"],
    ".usask.ca": ["University of Saskatchewan"],
    ".usherb.ca": ["Université de Sherbrooke"],
    ".usherbrooke.ca": ["Université de Sherbrooke"],
    ".ustboniface.ca": ["Université de Saint-Boniface"],
    ".ustpaul.ca": ["St. Paul University"],
    ".utoronto.ca": [
        "University of St. Michael's College",
        "University of Toronto",
        "University of Toronto, Mississauga",
        "University of Toronto, Scarborough",
        "University of Trinity College",
        "Victoria University Toronto, University of Toronto",
    ],
    ".utschools.ca": ["University of Toronto Schools"],
    ".uvic.ca": ["University of Victoria"],
    ".edu.uwaterloo.ca": [
        "University of St. Jerome's College",
        "University of Waterloo",
    ],
    ".uwaterloo.ca": [
        "University of St. Jerome's College",
        "University of Waterloo",
    ],
    ".uwindsor.ca": ["University of Windsor"],
    ".uwinnipeg.ca": ["University of Winnipeg"],
    ".uwo.ca": [
        "Brescia College",
        "King's College",
        "University of Western Ontario",
    ],
    ".vanas.ca": ["Vancouver Animation School"],
    ".vcc.ca": ["Vancouver Community College"],
    ".visii.ca": ["Vancouver Island School of Innovation and Inquiry"],
    ".viu.ca": ["Vancouver Island University"],
    ".wicmtl.ca": ["West Island College (Montreal)"],
    ".wlu.ca": ["Wilfrid Laurier University"],
    ".wpga.ca": ["West Point Grey Academy"],
    ".googleapps.wrdsb.ca": ["Waterloo Region District School Board"],
    ".wrdsb.ca": ["Waterloo Region District School Board"],
    ".ycdsbk12.ca": ["York Catholic District School Board"],
    ".yukoncollege.yk.ca": ["Yukon College"],
    ".yorkhouse.ca": ["York House School"],
    ".yorku.ca": ["York University"],
    ".yorkvilleu.ca": ["Yorkville University in Canada"],
    ".google.yrdsb.ca": ["Michael Cranny Elementary School"],
    ".maristes.alumne.cat": ["Maristes Valldemia"],
    ".autonoma.cat": [
        "Universitat Autònoma de Barcelona",
        "Autonomous University of Barcelona",
    ],
    ".student.bau.cat": [
        "BAU College of Arts and Design of Barcelona",
        "BAU College of Arts and Design of Barcelona",
    ],
    ".bemen3.cat": ["Bemen 3"],
    ".bernatelferrer.cat": ["INS Bernat el Ferrer"],
    ".boscdelacoma.cat": ["INS Bosc de la Coma"],
    ".ceroca.cat": ["Centre d'Estudis Roca, Barcelona"],
    ".cingle.cat": ["Escola Cingle"],
    ".cirvianum.cat": ["Institut Cirviànum de Torelló"],
    ".alumnat.copernic.cat": ["Nicolau Copernic"],
    ".costaillobera.cat": ["Institut Escola Costa i Llobera"],
    ".enti.cat": ["Escola de Noves Tecnologies Interactives"],
    ".epiaedu.cat": ["Escola Pia de Catalunya"],
    ".escolesfreta.cat": ["Freta Educació Maresme"],
    ".escolesnuria.cat": ["CEFP Núria"],
    ".fedac.cat": ["Escoles FEDAC"],
    ".fep.cat": ["Fundació Escoles Parroquials"],
    ".ibadia.cat": ["INS Badia del Vallès"],
    ".ies-sabadell.cat": ["Institut Sabadell"],
    ".iesbernatelferrer.cat": ["INS Bernat el Ferrer"],
    ".iescarlesvallbona.cat": ["IES CARLES VALLBONA", "IES CARLES VALLBONA"],
    ".iesdecelra.cat": ["Institut de Celrà"],
    ".iesesteveterradas.cat": ["IES Esteve Terradas i Illa"],
    ".iesjoanalcover.cat": ["IES Joan Alcover"],
    ".ieslaroca.cat": ["IES La Roca"],
    ".iessablancadona.cat": ["IES Sa Blanca Dona"],
    ".iesterrassa.cat": ["Institut de Terrassa"],
    ".ilg.cat": ["Institut La Guinaueta"],
    ".insabatoliba.cat": ["Institut Abat Oliba"],
    ".insalfonscostafreda.cat": ["institut alfons costafreda"],
    ".insbaixcamp.cat": ["Ins Baxi Camp"],
    ".inscamidemar.cat": ["Institut Públic Camí De Mar"],
    ".insernestlluch.cat": ["Institut Ernest Lluch"],
    ".insgabrielamistral.cat": ["Institut Gabriela Mistral"],
    ".insjaumemimo.cat": ["Institut Jaume Mimó"],
    ".fp.insjoaquimmir.cat": ["Institut Joaquim Mir", "Joaquim Mir Institute"],
    ".inslaferreria.cat": ["institut la ferreria"],
    ".inslaguineueta.cat": ["INS La Guineueta"],
    ".inslapineda.cat": ["Institut La Pineda"],
    ".inslasinia.cat": ["Institut la Sinia"],
    ".inspalamos.cat": ["INS Palamós"],
    ".inspauvila.cat": ["Institut Pau Vila"],
    ".inspedralbes.cat": ["Institut Pedralbes"],
    ".inspladelestany.cat": ["Institut Pla de l'Estany"],
    ".institutb7.cat": ["Institut Badalona VII"],
    ".institutgiligaya.cat": [
        "Institut Samuel Gili i Gaya",
        "Samuel Gili i Gaya High School",
    ],
    ".instituticaria.cat": ["Institut Icària"],
    ".institutjaumehuguet.cat": ["Institut Jaume Huguet"],
    ".institutlasegarra.cat": ["Institut La Segarra"],
    ".institutvidreres.cat": ["Institut Vidreres"],
    ".itb.cat": [
        "Institut Tecnològic de Barcelona",
        "Technological Institute of Barcelona",
    ],
    ".iticbcn.cat": ["Institut TIC de Barcelona"],
    ".jviladoms.cat": [
        "Jaume Viladoms  Estudis Profesionals",
        "Jaume Viladoms Professional Estudies",
    ],
    ".gracia.lasalle.cat": ["LaSalle Gràcia"],
    ".mollerussa.lasalle.cat": ["La Salle Mollerussa"],
    ".lasalle.cat": ["La Salle"],
    ".martipous.cat": ["Instituto Martí Pous"],
    ".palcam.cat": ["Escola Palcam"],
    ".paucasesnovescifp.cat": ["CIFP Pau Casesnoves"],
    ".office.proven.cat": ["Institut públic Provençana"],
    ".salesians.cat": ["Salesians"],
    ".sapalomera.cat": ["Institut Sa Palomera (polytechnic High School)"],
    ".tecnocampus.cat": ["TecnoCampus"],
    ".teknos.cat": ["Teknós"],
    ".uab.cat": [
        "Universitat Autónoma de Barcelona",
        "Autonomous University of Barcelona",
    ],
    ".udl.cat": ["University of Lleida"],
    ".uib.cat": ["Universitat de les Illes Balears"],
    ".umedicina.cat": [
        "Universitat de Vic - Universitat Central de Catalunya",
        "University of Vic",
    ],
    ".uoc.cat": ["Universitat oberta de Catalunya"],
    ".urv.cat": ["Universitat Rovira i Virgili"],
    ".uvic.cat": ["University of Vic - Central University of Catalonia"],
    ".vedrunavall.cat": ["Vedruna Vall"],
    ".xtec.cat": ["Departament d'Ensenyament de la Generalitat de Catalunya"],
    ".cwidaho.cc": ["College of Western Idaho"],
    ".mycwi.cc": ["College of Western Idaho"],
    ".rns.cc": ["Rothesay Netherwood School"],
    ".tvcc.cc": ["Treasure Valley Community College"],
    ".ac.cd": ["Université de Lubumbashi"],
    ".unikin.cd": ["Université de Kinshasa"],
    ".student.42lausanne.ch": ["42 Lausanne"],
    ".abbts.ch": ["ABB Technikerschule"],
    ".schulen.ai.ch": [" Gymnasium St. Antonius"],
    ".stud.altekanti.ch": ["Alte Kantonsschule Aarau "],
    ".altekanti.ch": ["Alte Kantonsschule Aarau"],
    ".arches.ch": ["Ecole des Arches, Lausanne"],
    ".auvk.ch": ["Alpine Universitat Vallis Konstanz"],
    ".stud.bbbaden.ch": ["Berufsfachschule BBB"],
    ".bbbaden.ch": ["Berufsfachschule BBB"],
    ".bbcag.ch": ["ICT Berufsbildungscenter AG "],
    ".bbw.ch": ["Berufsbildungsschule Winterthur"],
    ".bbz-cfp.ch": ["BBZ Biel / CFP Bienne"],
    ".bbz-sh.ch": ["Berufsbildungszentrum des Kantons Schaffhausens"],
    ".bbzbl-it.ch": ["BBZBL IT Pratteln"],
    ".bbzsogr.ch": ["Berufsbildungszentrum Solothurn-Grenchen"],
    ".bene-edu.ch": ["Benedict Schule Luzern"],
    ".bfh.ch": ["Bern University of Applied Sciences"],
    ".bhms.ch": ["Business and Hotel Management School"],
    ".bict-edu.ch": ["BiCT AG, Die Berufsbildner"],
    ".bict.ch": ["BiCT AG, Die Berufsbildner"],
    ".bks-campus.ch": ["Bündner Kantonschule Chur"],
    ".stud.bms-zuerich.ch": ["BMZ - Berufsmaturitätsschule Zürich"],
    ".brueggli.ch": ["Brüggli"],
    ".bsl-lausanne.ch": ["Business School Lausanne (BSL)"],
    ".bttok.ch": ["BTTok Technische Hochschule Biel"],
    ".bwdbern.ch": ["Bildungszentrum für Wirtschaft und Dienstleistung"],
    ".bwz-rappi.ch": ["Berufs- und Weiterbildungszentrum Rapperswil-Jona"],
    ".stud.bzbs.ch": ["Berufs- und Weiterbildungszentrum Buchs Sargans"],
    ".bzbs.ch": ["Berufs- und Weiterbildungszentrum Buchs Sargans"],
    ".bzbuchs.ch": ["Berufs- und Weiterbildungszentrum Buchs"],
    ".bztf.ch": ["Bildungszentrum für Technik, Frauenfeld"],
    ".stud.bzu.ch": ["Berufsfachschule Uster"],
    ".bzwu.ch": ["Berufs- und Weiterbildungszentrum Wil-Uzwil"],
    ".bzz.ch": ["Bildungszentrum Zürichsee"],
    ".ceff.ch": ["CENTRE DE FORMATION PROFESSIONNELLE BERNE FRANCOPHONE"],
    ".cifom.ch": ["Centre interrégional des montagnes neuchâteloises"],
    ".cpnv.ch": ["Centre professionnel du Nord vaudois"],
    ".csbe.ch": ["Computerschule Bern"],
    ".dct.ch": ["DCT International Hotel &amp; Business Management School"],
    ".divart.ch": ["Division Artisanale du CEJEF"],
    ".divcom.ch": ["Ecole professionnelle commerciale du canton du Jura"],
    ".divlyc.ch": ["Lycée cantonal Porrentruy"],
    ".divtec.ch": ["Ecole des Métiers Techniques de Porrentruy"],
    ".dsgenf.ch": ["Deutsche Schule Genf", "German School of Geneva"],
    ".ecal.ch": ["Ecole cantonale d'art de Lausanne ECAL"],
    ".ecolint.ch": ["International School of Geneva"],
    ".edu-vd.ch": ["Gymnase cantonal de Lausanne"],
    ".ksz.edu-zg.ch": ["Kantonschule Zug (Gymnasium)"],
    ".edubs.ch": ["Basler Bildungsserver"],
    ".edueptm.ch": ["Ecole professionnelle technique des métiers"],
    ".edufr.ch": ["Education et formation dans le canton de Fribourg"],
    ".eduge.ch": ["Département de l'Instruction Publique du Canton de Genève"],
    ".edulu.ch": [
        "Berufsbildungszentrum Wirtschaft, Informatik und Technik (Kanton Luzern)"
    ],
    ".eduvaud.ch": [
        "Toutes les personnes en formation, ainsi que le personnel enseignant du Département de la formation, de la jeunesse et de la culture.",
        "All trainees, as well as the teaching staff of the Department of Training, Youth and Culture.",
        ".group",
    ],
    ".eduvs.ch": [
        "Colleges in Switzerland, including Lycée-Collège des Creusets de Sion",
        ".group",
    ],
    ".ehl.ch": ["EHL Hospitality Business School"],
    ".ehsm.ch": ["Eidgenössische Hochschule für Sport Magglingen EHSM"],
    ".epfl.ch": ["Swiss Federal Institute of Technology, Lausanne"],
    ".epsic.ch": ["EPSIC - Ecole Professionnelle Lausanne"],
    ".eptsion.ch": ["Ecole professionnelle technique de Sion"],
    ".eracom.ch": ["Eracom - Ecole romande d'arts et communication, Lausanne"],
    ".ethz.ch": [
        "Swiss Federal Institute of Technology, Zurich",
        "ETH Zürich",
    ],
    ".etml-es.ch": [
        "École technique des métiers de Lausanne - École supérieure"
    ],
    ".fernfachhochschule.ch": ["Fernfachhochschule Schweiz"],
    ".fernuni.ch": [
        "Universitare Fernstudien Schweiz",
        "Distance learning University Switzerland",
    ],
    ".ffhs.ch": ["Fernfachhochschule Switzerland"],
    ".fgb.ch": ["Freies Gymnasium Bern"],
    ".fh-aargau.ch": ["University of Applied Sciences Aargau"],
    ".fh-hwz.ch": ["Hochschule für Wirtschaft Zürich"],
    ".fhbb.ch": ["University of Applied Sciences Basel (FHBB )"],
    ".fhgr.ch": ["University of Applied Sciences of the Grisons"],
    ".students.fhnw.ch": [
        "Fachhochschule Nordwestschweiz FHNW",
        "University of Applied Sciences and Arts Northwestern Switzerland",
    ],
    ".fhnw.ch": [
        "University of Applied Sciences and Arts Northwestern Switzerland"
    ],
    ".fhso.ch": [
        "University of Applied Sciences Solothurn Northwestern Switzerland"
    ],
    ".fhsstudents.ch": ["University of Applied Sciences St.Gallen"],
    ".fmi.ch": ["Friedrich Miescher Institute for Biomedical Research"],
    ".gbchur.ch": ["Gewerbliche Berufsschule Chur (GBC)"],
    ".gbs-ge.ch": ["Geneva Business School"],
    ".gbssg.ch": ["Gewerbliches Berufs- und Weiterbildungszentrum St. Gallen"],
    ".edu.ge.ch": [
        "Département de l'Instruction Publique du Canton de Genève"
    ],
    ".edu.gfbienne.ch": ["Gymnase Français de Bienne"],
    ".gibb.ch": ["Gewerblich-Industrielle Berufsschule Bern"],
    ".gibz.ch": ["Gewerblich-industrielle Bildungszentrum Zug"],
    ".glion.ch": ["Glion Institute of Higher Education"],
    ".graduateinstitute.ch": [
        "Graduate Institute of international and development studies",
        "Institut de hautes études internationales et du développement",
    ],
    ".gymburgdorf.ch": ["Gymnasium Burgdorf, Switzerland"],
    ".gymkirchenfeld.ch": ["Gymnasium Kirchenfeld, Switzerland"],
    ".gymneufeld.ch": ["Gymnasium Neufeld, Switzerland"],
    ".gymo.ch": ["Gymnasium Oberaargau, Switzerland"],
    ".stud.gymthun.ch": ["Gymnasium Thun, Switzerland"],
    ".he-arc.ch": ["Haute Ecole Arc"],
    ".hefr.ch": [
        "University of Applied Sciences and Arts Western Switzerland // Fribourg"
    ],
    ".heig-vd.ch": ["The School of Engineering and Business Vaud"],
    ".hepl.ch": ["University of Teacher Education, State of Vaud"],
    ".hepvs.ch": [
        "Haute école pédagogique du Valais",
        "University of Teacher Training of Valais",
    ],
    ".hes-so.ch": [
        "University of Applied Sciences and Arts Western Switzerland"
    ],
    ".hesge.ch": ["University of Applied Sciences (HES-SO)"],
    ".hevs.ch": [
        "University of Applied Sciences and Arts Western Switzerland // Valais"
    ],
    ".hf-ict.ch": [
        "Höhere Fachschule für Informations- und Kommunikationstechnologie"
    ],
    ".hftm.ch": [
        "Höhere Fachschule für Technik Mittelland",
        "école supérieure technique Mittelland",
    ],
    ".hfu.ch": ["Höhere Fachschule Uster"],
    ".hgkz.ch": ["Hochschule für Gestaltung und Kunst Zürich"],
    ".hslu.ch": ["Lucerne University of Applied Sciences and Arts "],
    ".hsr.ch": ["University of Applied Sciences Rapperswil"],
    ".htwchur.ch": ["University of Applied Sciences (HTW) Chur"],
    ".ibw-cloud.ch": ["ibW Höhere Fachschule Südostschweiz"],
    ".ibw-schule.ch": ["Hohere Fachschule Sudostschweiz"],
    ".ibw.ch": ["Hohere Fachschule Sudostschweiz"],
    ".icsz.ch": ["Inter-Community School Zurich"],
    ".ict-bz.ch": ["ICT Berufsbildung Zentralschweiz"],
    ".students.idm.ch": ["Berufsbildungszentrum IDM"],
    ".iet-gibb.ch": [
        "Gewerblich-Industrielle Berufsschule Bern Abteilung IET"
    ],
    ".ifa.ch": ["IFA - Höhere Fachschule für Wirtschaft und Informatik"],
    ".informatikschuleolten.ch": ["Informatikschule Olten"],
    ".ini.ch": ["Institute of Neuroinformatics"],
    ".ipso.ch": ["ipso Bildung AG"],
    ".isb-sib.ch": ["SIB Swiss Institute of Bioinformatics"],
    ".iscs-zug.ch": ["International School of Central Switzerland"],
    ".ispl.ch": ["Lucerne International School"],
    ".isr.ch": ["International School Rheintal"],
    ".iun.ch": ["International University in Geneva"],
    ".kantisargans.ch": ["Kantonsschule Sargans"],
    ".kantiwattwil.ch": ["Kantonsschule Wattwil"],
    ".kantiwil.ch": ["Kantonsschule Wil"],
    ".kbw.ch": ["Kantonsschule Büelrain Winterthur"],
    ".kbz-zug.ch": ["KBZ Zug"],
    ".kbzsg.ch": ["KBZ", "KBZSG", "St.Gallen 9000"],
    ".stud.kefikon.ch": ["Schule Schloss Kefikon"],
    ".ken.ch": ["Kantonsschule Enge Zurich"],
    ".kftg.ch": ["Kantonsschule Frauenfeld"],
    ".stud.kks.ch": ["Kantonsschule Kollegium Schwyz"],
    ".kme.ch": ["Kantonale Maturitätsschule für Erwachsene Zürich"],
    ".kollegistans.ch": ["Kollegium St. Fidelis"],
    ".ksb-sg.ch": ["Kantonsschule am Brühl"],
    ".students.ksba.ch": ["Kantonsschule Baden"],
    ".ksbg.ch": ["Kantonsschule am Burggraben St. Gallen"],
    ".kshp.ch": ["Kantonsschule Hohe Promenade"],
    ".stud.ksimlee.ch": ["Kantonsschule Im Lee Winterthur"],
    ".ksk.ch": [
        "Kantonsschule Kreuzlingen",
        "state college of higher educations",
        "ksk.ch",
    ],
    ".ksmenzingen.ch": ["Kantonsschule Menzingen, Switzerland"],
    ".ksobwalden.ch": ["Kantonsschule Obwalden"],
    ".ksuster.ch": ["Kantonsschule Uster"],
    ".kswe.ch": ["Kantonsschule Wettingen"],
    ".kvbl.ch": ["Schulen kvBL"],
    ".stud.kvlu.ch": ["KV Luzern Berufsfachschule"],
    ".kzn.ch": ["Kantonsschule Zürich Nord"],
    ".kzo.ch": ["Kantonsschule Zurcher Oberland"],
    ".kzu.ch": ["Kantonsschule Zurcher Unterland"],
    ".learnhfh.ch": [
        "Interkantonale Hochschule für Heilpädagogik",
        "University of Teacher Education in Special Needs",
    ],
    ".lerbermatt.ch": ["Gymnasium Lerbermatt, Switzerland"],
    ".stud.lgr.ch": [
        "Literargymnasium Rämibühl",
        "literary high school rämibühl",
    ],
    ".liceolugano.ch": ["Liceo di Lugano 1"],
    ".lilu2.ch": ["Liceo di Lugano 2, Savosa"],
    ".lrguas.ch": ["Les Roches Gruyère University of Applied Sciences"],
    ".mcleon.ch": ["Mcleon International Business Institute"],
    ".mng.ch": [
        "Mathematisch-Naturwissenschaftliches Gymnasium Rämibühl Zürich"
    ],
    ".montana-zug.ch": ["Institut Montana Zugerberg"],
    ".mpaschule.ch": ["MPA Schule Buchs"],
    ".mygymer.ch": ["Gymnasium Kirchenfeld, Switzerland"],
    ".noseryoung.ch": ["Noser Young"],
    ".ntb.ch": ["NTB Interstate University of Applied Sciences of Technology"],
    ".orif.ch": [
        "Organisation romande pour la formation et l'intégration professionnelle (Orif)",
        "Orif",
    ],
    ".ost.ch": ["OST Ostschweizer Fachhochschule"],
    ".phbern.ch": [
        "Pädagogische Hochschule Bern (University of Teacher Education Bern)"
    ],
    ".phgr.ch": ["Padagogischen Hochschule Graubunden"],
    ".phlu.ch": ["PH Luzern - University of Teacher Education Lucerne"],
    ".phsg.ch": ["Pädagogische Hochschule St.Gallen"],
    ".phsz.ch": [
        "Pädagogische Hochschule Schwyz, Goldau",
        "Schwyz University of Teacher Education, Goldau",
    ],
    ".phtg.ch": [
        "Pädagogische Hochschule Thurgau (Thurgau School of Education)"
    ],
    ".phzh.ch": [
        "Pädagogische Hochschule Zürich (Zurich School of Education)"
    ],
    ".psi.ch": ["Paul Scherrer Institute"],
    ".qdul.ch": ["Quality Design University of Lake Regions"],
    ".rafisa.ch": ["Rafisa Informatik GmbH"],
    ".regentschool.ch": ["Régent International School Crans-Montana"],
    ".rgzh.ch": ["Realgymnasium Rämibühl Zürich"],
    ".stu.rosey.ch": ["Institut Le Rosey"],
    ".rpn.ch": ["Réseau pédagogique neuchâtelois"],
    ".saint-charles.ch": [
        "Collège et Lycée Saint-Charles",
        "Saint-Charles international school Swizerland",
    ],
    ".samtrevano.ch": ["Scuola Arti e Mestieri di Trevano"],
    ".santiskurs.ch": ["SANTIS Training AG"],
    ".santismail.ch": ["SANTIS Training AG"],
    ".sbl.ch": ["gymnasium liestal"],
    ".schule-eschenbach.ch": ["Schule Eschenbach"],
    ".schule-ettiswil.ch": ["Schule Ettiswil", "Ettiswil School"],
    ".schule-uznach.ch": ["Schule Uznach", "School Uznach"],
    ".schulegl.ch": ["Kantonsschule Glarus"],
    ".shms-mail.ch": ["Swiss Hotel Management School"],
    ".sluz.ch": [
        "Berufsbildungszentrum Wirtschaft, Informatik und Technik (Kanton Luzern)"
    ],
    ".ssbm.ch": [
        "Swiss School of Business and Management Geneva",
        "Swiss School of Business and Management Geneva",
    ],
    ".ssseco.ch": [
        "Scuola specializzata superiore di economia",
        "State School of Applied Computer Sciences and Economics",
        "https://www.ssseco.ch/",
    ],
    ".stiftsschule-engelberg.ch": ["Stiftsschule Engelberg"],
    ".studentfr.ch": ["Education et formation dans le canton de Fribourg"],
    ".supsi.ch": [
        "University of Applied Sciences and Arts of Southern Switzerland"
    ],
    ".swissinternationalschool.ch": [
        "SIS Swiss International Schools Schweiz AG"
    ],
    ".swissmc.ch": ["Swiss Management Center"],
    ".tbz.ch": ["Technische Berufsschule Zürich"],
    ".teko.ch": ["Schweizerische Fachschule TEKO"],
    ".tfbern.ch": ["Technische Fachschule Bern"],
    ".edu.ti.ch": [
        "TI-EDU è il nome della rete d'attività di insegnamento superiore e di ricerca scientifica nella Svizzera italiana (Cantone Ticino)"
    ],
    ".uekk.ch": ["Universität für Ethik und Kulturwissenschaften"],
    ".unibas.ch": ["University of Basel"],
    ".unibe.ch": ["University of Berne"],
    ".etu.unidistance.ch": ["Unidistance / FernUni", "Unidistance"],
    ".unifr.ch": ["University of Fribourg"],
    ".unige.ch": ["University of Geneva"],
    ".unil.ch": ["University of Lausanne"],
    ".unilu.ch": ["University of Lucerne"],
    ".uniludes.ch": [
        "Libera Università degli Studi di Scienze Umane e Tecnologiche"
    ],
    ".unine.ch": ["University of Neuchatel"],
    ".unisg.ch": ["University of St. Gallen"],
    ".unisi.ch": ["University of the Italian-speaking Part of Switzerland"],
    ".unizh.ch": ["University of Zürich"],
    ".uome.ch": [
        "University of Marist Eastbay",
        "University of Marist Eastbay",
    ],
    ".uqz.ch": ["University of Quentin Zurich"],
    ".usb.ch": ["Universitätsspital Basel"],
    ".usi.ch": ["Università della Svizzera italiana"],
    ".uzh.ch": ["University of Zurich"],
    ".bvs.stud.vantage.ch": ["BVS St.Gallen / Vantage Group"],
    ".edu.vs.ch": ["éducation valaisanne"],
    ".webster.ch": ["Webster University Geneva"],
    ".wibilea.ch": ["Ausbildungszentrum des Kantons Schaffhausens"],
    ".wiss-edu.ch": [
        "Wirtschaftsinformatikschule Schweiz WISS (Stiftung WISS)"
    ],
    ".wsl.ch": [
        "Swiss Federal Institute for Forest, Snow and Landscape Research WSL"
    ],
    ".zbw-online.ch": ["Zentrum für Berufliche Weiterbildung"],
    ".stud.edu.zh.ch": [
        "Kantonsschule Zürich Nord",
        "Zurich North Cantonal School",
    ],
    ".edu.zh.ch": [
        "Kantonsschule Zürich Nord",
        "Zurich North Cantonal School",
    ],
    ".students.zhaw.ch": [
        "Zürcher Hochschule für Angewandte Wissenschaften",
        "Zurich University of Applied Sciences",
    ],
    ".zhaw.ch": ["Zurich University of Applied Sciences"],
    ".zhdk.ch": ["Zurich University of Arts"],
    ".zis.ch": ["Zurich International School"],
    ".ena.edu.ci": ["Ecole Nationale d'Administration"],
    ".esatic.edu.ci": ["ECOLE SUPERIEUR AFRICAINE DES TICS(ESATIC)"],
    ".iugb.edu.ci": ["International University of Grand Bassam"],
    ".ujlg.edu.ci": ["Université Jean Lourougnon Guédé"],
    ".uvci.edu.ci": ["Université Virtuelle de Côte d'Ivoire"],
    ".esatic.ci": ["ESATIC", "ESATIC"],
    ".inphb.ci": [
        "INP-HB (Institut National Polytechnique Félix Houphouët-Boigny)"
    ],
    ".ita-education.ci": [
        "ITA Ingenierie SA",
        "Abidjan Institute of Technology",
    ],
    ".nan.ci": ["NaN"],
    ".uabobo.ci": ["Université d'Abobo-Adjamé"],
    ".ubouake.ci": ["Université de Bouaké"],
    ".univ-cocody.ci": ["Université de Cocody"],
    ".univ-na.ci": ["Université Nangui Abrogoua"],
    ".univmetiers.ci": [
        "School actual website is http://www.pigierci.com/, Mails are hosted by microsoft but via http://univmetiers.onmicrosoft.com/."
    ],
    ".academia.cl": ["Universidad Academia de Humanismo Cristiano"],
    ".aiep.cl": ["Instituto Profesional AIEP (Administrativos)"],
    ".alperit.cl": ["Alperit"],
    ".alumnosuls.cl": ["Universidad de La Serena"],
    ".arquitecturaucv.cl": ["Escuela de Arquitectura y Diseño"],
    ".a.cesantarosa.cl": [
        "Centro Educacional Santa Rosa",
        "Santa Rosa Educational Center",
    ],
    ".cesantarosa.cl": [
        "Centro Eduacional Santa Rosa",
        "Santa Rosa Educational Center",
    ],
    ".cftpucv.cl": [
        "Centro de formación técnica Pontificia Universidad Católica de Valparaíso"
    ],
    ".cftsa.cl": ["Centro Formación Técnica San Agustín"],
    ".ciisa.cl": ["Instituto de Ciencias Tecnológicas CIISA"],
    ".cinv.cl": [
        "Centro Interdisciplinario de Neurociencia (Universidad de Valparaiso)"
    ],
    ".colegionsr.cl": ["COLEGIO NUESTRA SEÑORA DEL ROSARIO LAS CONDES"],
    ".csangabrielcoquimbo.cl": ["Colegio San Gabriel Arcangel"],
    ".duoc.cl": ["Fundación Instituto Profesional Duoc UC"],
    ".duocuc.cl": [
        "Departamento Universitario Obrero y Campesino de la Pontificia Universidad Católica de Chile",
        "Duoc UC",
        "www.duoc.cl",
        "FUNDACIÓN INSTITUTO PROFESIONAL DUOC UC",
        "@duocuc.cl",
    ],
    ".ecas.cl": [
        "Escuela de Capacitación ECAS - Chile",
        "English > ECAS Training School - Chile",
        "Official Web Site > https://ecas-otec.cl/",
        "TI Course > https://ecas-otec.cl/curso/desarrollo-de-aplicaciones-fullstack-python-trainee/",
    ],
    ".edupro.cl": ["Liceo José Victorino Lastarria"],
    ".estudiantes.iacc.cl": [
        "Instituto Profesional IACC",
        "IACC Professional Institute",
    ],
    ".inacapmail.cl": ["Universidad Tecnológica de Chile"],
    ".ipchile.cl": ["instituto profesional de chile"],
    ".ipciisa.cl": ["Instituto de Ciencias Tecnológicas IP CIISA"],
    ".alumno.iplacex.cl": ["Iplacex", "Iplacex"],
    ".alumnos.ipleones.cl": ["Instituto Profesional Los Leones", "IPLeones"],
    ".docentes.ipleones.cl": ["Instituto Profesional Los Leones", "IPLeones"],
    ".ipp.cl": ["Instituto Profesional Providencia"],
    ".estudiante.ipss.cl": ["Instituto Profesional San Sebastián"],
    ".irfe.cl": ["Instituto Regional Federico Errazuriz"],
    ".itcalumnos.cl": ["Instituto Tecnologico de Chile"],
    ".alumnos.juanbohon.cl": ["C.F.T Juan Bohon"],
    ".mayor.cl": ["Universidad Mayor Temuco"],
    ".miuandes.cl": ["Universidad de los Andes"],
    ".puc.cl": ["Pontificia Universidad Catolica de Chile"],
    ".pucv.cl": ["Pontificia Universidad Católica de Valparaíso"],
    ".santotomas.cl": ["Universidad Santo Tomás"],
    ".twk.cl": ["CFT Teodoro Wickel K."],
    ".ua.cl": ["Universidad de Antofagasta"],
    ".uach.cl": ["Universidad Austral de Chile"],
    ".uaconcagua.cl": ["Universidad de Aconcagua"],
    ".uahurtado.cl": ["Universidad Alberto Hurtado"],
    ".uai.cl": ["Universidad Adolfo Ibañez", "Universidad Adolfo Ibáñez"],
    ".uamericas.cl": ["Universidad de Las Américas"],
    ".uandes.cl": ["Universidad de Los Andes"],
    ".uantof.cl": ["Universidad de Antofagasta"],
    ".uas.cl": ["Universidad Autonoma del Sur"],
    ".uautonoma.cl": ["Universidad Autonoma de Chile"],
    ".uaysen.cl": ["Universidad de Aysen"],
    ".ubiobio.cl": ["Universidad del Bío-Bío"],
    ".pregrado.ubo.cl": ["Universidad Bernardo O'Higgins"],
    ".ubo.cl": [
        "Universidad Bernardo O'Higgins",
        "Bernardo O'Higgins University",
    ],
    ".ubohiggins.cl": ["Universidad Bernardo O'Higgins"],
    ".ubolivariana.cl": ["Universidad Bolivariana"],
    ".ubritanica.cl": ["Universidad Chileno Britanica de Cultura"],
    ".uc.cl": ["Pontificia Universidad Católica de Chile"],
    ".ucentral.cl": ["Universidad Central"],
    ".dcc.uchile.cl": [
        "Departamento de Ciencias de la Computación",
        "Universidad de Chile",
    ],
    ".u.uchile.cl": ["Universidad de Chile"],
    ".ug.uchile.cl": ["Universidad de Chile"],
    ".uchile.cl": ["Universidad de Chile"],
    ".ucinf.cl": ["Universidad de Ciencias de la Informatica"],
    ".ucm.cl": ["Universidad Catolica del Maule"],
    ".ucn.cl": ["Universidad Catolica del Norte"],
    ".ucsc.cl": ["Universidad Catolica de La Santísima Concepción"],
    ".ucsh.cl": ["Universidad Católica Cardenal Raúl Silva Henríquez"],
    ".uct.cl": ["Universidad Catolica de Temuco"],
    ".uctemuco.cl": ["Universidad Católica de Temuco"],
    ".ucv.cl": ["Universidad Catolica de Valparaiso"],
    ".uda.cl": ["Universidad de Atacama"],
    ".ingenieros.udd.cl": ["Universidad del Desarrollo"],
    ".udec.cl": ["Universidad de Concepción", "University of Concepcion"],
    ".udelmar.cl": ["Universidad del Mar"],
    ".udesarrollo.cl": ["Universidad del Desarrollo"],
    ".edu.udla.cl": ["Universidad de Las Américas"],
    ".udla.cl": ["Universidad de Las Américas"],
    ".udp.cl": ["Universidad Diego Portales"],
    ".ufinis.cl": ["Universidad Finis Terrae"],
    ".ufromail.cl": ["Universidad de La Frontera"],
    ".ufrontera.cl": ["Universidad de La Frontera"],
    ".ugm.cl": ["Universidad Gabriela Mistral"],
    ".uisek.cl": ["Universidad International SEK, Santiago"],
    ".ulagos.cl": ["Universidad de Los Lagos"],
    ".ulare.cl": ["Universidad La Republica"],
    ".umag.cl": ["Universidad de Magallanes"],
    ".umaritima.cl": ["Universidad Maritima de Chile"],
    ".umayor.cl": ["Universidad Mayor"],
    ".umce.cl": ["Universidad Metropolitana de Ciencias de la Educación"],
    ".ume.cl": ["Universidad Mariano Egaña"],
    ".unab.cl": ["Universidad Andrés Bello"],
    ".unach.cl": ["Universidad Adventista de Chile"],
    ".unap.cl": ["Universidad Arturo Prat"],
    ".unfa.cl": ["Universidad Francisco de Aguirre"],
    ".uniacc.cl": ["Universidad de Artes, Ciencias y Comunicación"],
    ".unicit.cl": ["Universidad Iberoamericana de Ciencias y Tecnologia"],
    ".universidadarcis.cl": ["Universidad Arcis"],
    ".uoh.cl": ["Universidad de O'Higgins"],
    ".upa.cl": ["Universidad de Playa Ancha de Ciencias de la Educacion"],
    ".upla.cl": ["Universidad de Playa Ancha"],
    ".usach.cl": ["Universidad de Santiago de Chile"],
    ".usek.cl": ["Universidad SEK Chile ", "SEK University of Chile"],
    ".userena.cl": ["Universidad de La Serena"],
    ".usm.cl": ["Federico Santa María Technical University"],
    ".uss.cl": ["Universidad San Sebastian"],
    ".ust.cl": ["Universidad Santo Tomás"],
    ".uta.cl": ["Universidad de Tarapacá"],
    ".utalca.cl": ["Universidad de Talca"],
    ".utem.cl": ["Universidad Tecnológica Metropolitana"],
    ".utfsm.cl": ["Universidad Técnica Federico Santa María"],
    ".uv.cl": ["Universidad de Valparaiso"],
    ".uvm.cl": ["Universidad de Viña del Mar"],
    ".virginiogomez.cl": ["Instituto Profesional Virginio Gómez"],
    ".myise.cloud": ["international school of milan"],
    ".tsbw.cloud": [
        "Theodor-Schäfer-Berufsbildungswerk",
        "Theodor-Schäfer-Berufsbildungswerk Husum",
    ],
    ".ictuniversity.edu.cm": [
        "ICT-UNIVERSITY",
        "ICT-U USA Cameroon Campus (ICT University)",
    ],
    ".enspd-udo.cm": [
        "Ecole Nationale Supérieure Polytechnique de Douala (ENSPD)",
        "National Higher Polytechnic School of Douala",
    ],
    ".enspy-uy1.cm": [
        "Ecole Nationale Supérieure Polytechnique de Yaoundé",
        "National Advanced School of Engineering Yaounde",
    ],
    ".facsciences-uy1.cm": [
        "Université de Yaoundé I",
        "University of Yaounde I",
    ],
    ".iut-douala.cm": [
        "Institut Universitaire des Technologies",
        "Univesity Institute Of Technologies",
    ],
    ".polytechnique.cm": [
        "Ecole National Supérieure Polytechnique de Yaounde"
    ],
    ".ubuea.cm": ["University of Buea"],
    ".udm.cm": ["\ufeffUniversité des Montagnes"],
    ".uniba.cm": ["The University of Bamenda "],
    ".uninet.cm": ["Université de Yaoundé I"],
    ".univ-maroua.cm": ["The University of Maroua"],
    ".univ-ndere.cm": [
        "ENSAI Ngaoundéré",
        "Higher National Agro-Industrial science college Ngaoundéré",
    ],
    ".aircas.ac.cn": [
        "中国科学院空天信息创新研究院",
        "Aerospace Information Research Institute,Chinese Academy of Sciences",
    ],
    ".amss.ac.cn": [
        "中国科学院数学与系统科学研究院",
        "Academy of Mathematics and Systems Science, Chinese Academy of Sciences",
    ],
    ".big.ac.cn": [
        "中国科学院北京基因组研究所",
        "Beijing Institute of Genomics, Chinse Academy of Sciences",
    ],
    ".caf.ac.cn": ["中国林业科学研究院", "Chinese Academy of Forestry"],
    ".cea-igp.ac.cn": [
        "中国地震局地球物理研究所",
        "Institute of Geophysics, China Earthquake Administration",
    ],
    ".cigit.ac.cn": [
        "中国科学院重庆绿色智能技术研究院",
        "Chongqing Institute of Green and Intelligent Technology, Chinese Academy of Sciences",
    ],
    ".csu.ac.cn": [
        "中国科学院空间应用工程与技术中心",
        "Technology and Engineering Center for Space Utilization, Chinese Academy of Sciences",
    ],
    ".genetics.ac.cn": [
        "Institute of Genetics and Developmental Biology, Chinese Academy of Sciences",
        "Institute of Genetics and Developmental Biology, Chinese Academy of Sciences",
    ],
    ".gibh.ac.cn": [
        "中国科学院广州生物医药与健康研究院",
        "Guangzhou Institutes of Biomedicine and Health,Chinese Academy of Sciences",
    ],
    ".gscaep.ac.cn": [
        "中国工程物理研究院研究生院",
        "Graduate School of China Academy of Engineering Physics",
    ],
    ".ia.ac.cn": [
        "中国科学院大学，中国科学院自动化研究所",
        "University of Chinese Academy of Sciences，Institute of Automation Chinese Academy of Sciences",
    ],
    ".ibp.ac.cn": ["Institute of Biophysics Academia Sinica"],
    ".iccas.ac.cn": [
        "中国科学院化学研究所",
        "Institute of Chemistry Chinese Academy of Sciences",
    ],
    ".ict.ac.cn": [
        "中国科学院计算技术研究所",
        "Institute of Computing Technology, Chinese Academy of Sciences",
    ],
    ".mail.iee.ac.cn": [
        "中国科学院电工研究所",
        "Institute of Electrical Engineering of the Chinese Academy of Sciences",
    ],
    ".mail.iggcas.ac.cn": [
        "中国科学院地质与地球物理研究所",
        "Institute of Geology and Geophysics, Chinese Academy of Sciences",
    ],
    ".igsnrr.ac.cn": [
        "中国科学院地理科学与资源研究所",
        "INSTITUTE OF GEOGRAPHIC SCIENCES AND NATURAL RESOURCES RESEARCH",
    ],
    ".ihep.ac.cn": [
        "\ufeff中国科学院高能物理研究所",
        "The Institute of High Energy Physics of the Chinese Academy of Sciences",
    ],
    ".iie.ac.cn": [
        "中国科学院大学",
        "University of Chinese Academy of Sciences",
    ],
    ".ime.ac.cn": [
        "中国科学院微电子研究所",
        "Institute of Microelectronics，Chinese Academy of Sciences",
    ],
    ".imicams.ac.cn": [
        "\ufeff中国医学科学院/北京协和医学院医学信息研究所/图书馆",
        "The Institute of Medical Information (IMI) & Library, Chinese Academy of Medical Sciences and Peking Union Medical College (CAMS & PUMC)",
    ],
    ".mail.ioa.ac.cn": [
        "中国科学院大学",
        "Institute of Acoustics, Chinese Academy of Sciences",
    ],
    ".ios.ac.cn": [
        "中国科学院软件研究所",
        "Institute of Software, Chinese Academy of Sciences",
    ],
    ".iphy.ac.cn": [
        "中国科学院物理研究所, 中国科学院",
        "Institute of Physics, Chinese Academy of Sciences",
    ],
    ".iscas.ac.cn": [
        "中国科学院软件研究所，中国科学院大学",
        "Institute of Software, Chinese Academy of Sciences/University of Chinese Academy of Sciences",
    ],
    ".mail.kib.ac.cn": [
        "中国科学院昆明植物研究所",
        "Kunming Institute of Botany, Chinese Academy of Sciences",
    ],
    ".nibs.ac.cn": [
        "北京生命科学研究所",
        "National Institute of Biological Sciences, Beijing",
    ],
    ".nssc.ac.cn": [
        "中国科学院国家空间科学中心",
        "National Space Science Center, Chinese Academy of Sciences",
    ],
    ".picb.ac.cn": [
        "中国科学院-马普学会计算生物学伙伴研究院",
        "CAS-MPG Partner Institute for Computational Biology (PICB)",
    ],
    ".psych.ac.cn": ["中国科学院大学"],
    ".rcees.ac.cn": [
        "中国科学院生态环境研究中心",
        "Research Center for Eco-environmental Sciences",
    ],
    ".sari.ac.cn": [
        "中国科学院上海高等研究院",
        "Shanghai Advanced Research Institute, Chinese Academy of Sciences",
    ],
    ".semi.ac.cn": [
        "中科院半导体研究所",
        "Institute of Semiconductor Institute of the Chinese Academy of Sciences",
    ],
    ".shao.ac.cn": [
        "中国科学院上海天文台",
        "Shanghai Astronomical Observatory, Chinese Academy of Sciences",
    ],
    ".siat.ac.cn": [
        "中国科学院大学深圳先进技术研究院",
        "Shenzhen Institutes of Advanced Technology，Chinese Academy of Sciences",
    ],
    ".sict.ac.cn": [
        "中国科学院沈阳计算技术研究所",
        "Shenyang institute of computing technology, Chinese Academy of Sciences",
    ],
    ".mail.sim.ac.cn": [
        "中国科学院上海微系统与信息技术研究所",
        "Shanghai Institute of Microsystem and Information Technology, Chinese Academy of Sciences",
    ],
    ".simm.ac.cn": [
        "中国科学院上海药物研究所",
        "Shanghai Institute of Metria and Medica, Chinese Academy of Sciences",
    ],
    ".ucas.ac.cn": ["University of Chinese Academy of Sciences"],
    ".wipm.ac.cn": [
        "中国科学院武汉物理与数学研究所",
        "Wuhan Institute of Physics and Mathematics Chinese Academy of Science",
    ],
    ".stu.aurora-college.cn": [
        "上海震旦职业技术学院",
        "Shanghai Aurora Vocational College",
    ],
    ".bcis.cn": ["Beijing City International School"],
    ".bowenedu.cn": [
        "兰州博文科技学院",
        "Lanzhou Bowen University of Science and Technology",
    ],
    ".bttc.cn": ["包头师范学院", "Baotou Teachers College"],
    ".ccbupt.cn": [
        "北京邮电大学世纪学院",
        "Century College,Beijing University of Posts and Telecommunications",
    ],
    ".cduestc.cn": ["电子科技大学成都学院"],
    ".alevel.com.cn": ["Shenzhen College of International Education"],
    ".bibs.com.cn": [
        "Beanstalk International Bilingual School in China (Chengdu campus)"
    ],
    ".cvit.com.cn": ["Changchun Vocational Institute Of Technology"],
    ".jxhlxy.com.cn": [
        "江西卫生职业学院",
        "jiangxi health vocational college",
    ],
    ".njude.com.cn": [
        "南京大学网络教育学院",
        "NANJING UNIVERSITY School of Distance Education",
    ],
    ".nou.com.cn": ["Dalian Neusoft University of Information"],
    ".qypt.com.cn": ["Qingyuan Polytechnic"],
    ".schxmvc.com.cn": [
        "四川华新现代职业学院",
        "Sichuan Huaxin Modern Vocational College",
    ],
    ".scie.com.cn": [
        "Shenzhen College of Internation Education",
        "深圳国际交流学院",
        "URL: http://www.alevel.com.cn/",
    ],
    ".scse.com.cn": [
        "South China Institute Of Software Engineering, Guangzhou University"
    ],
    ".sise.com.cn": [
        "South China Institute of Software Engineering of Guangzhou University"
    ],
    ".wy.suis.com.cn": [
        "上海市民办万源城协和双语学校",
        "Shanghai United International School, Wanyuan Campus",
    ],
    ".czu.cn": ["Changzhou Institute of Technology"],
    ".dehong.cn": ["德闳学校", "Dehong International Chinese School"],
    ".deshengzx.cn": ["德胜中学", "学校网址：http://www.deshengzx.cn/main"],
    ".dulwich-suzhou.cn": ["Dulwich College Suzhou", "苏州德威学校"],
    ".ecnu.cn": ["East China Normal University"],
    ".ah.edu.cn": [
        "Anhui Technical College of Water Resources and Hydroelectric Power"
    ],
    ".ahau.edu.cn": ["Anhui Agriculture University"],
    ".ahjzu.edu.cn": ["Anhui JianZhu University", "安徽建筑大学"],
    ".ahmu.edu.cn": ["Anhui Medical University"],
    ".ahnu.edu.cn": ["Anhui Normal University"],
    ".ahpu.edu.cn": ["Anhui Polytechnic University", "安徽工程大学"],
    ".ahtcm.edu.cn": ["Anhui University of Traditional Chinese Medicine"],
    ".ahu.edu.cn": ["Anhui University"],
    ".ahut.edu.cn": ["Anhui University of Technology"],
    ".ayit.edu.cn": ["Anyang Institute of Technology", "安阳工学院"],
    ".stu.aynu.edu.cn": ["Anyang Normal University"],
    ".bac.edu.cn": ["Beijing University of Agriculture"],
    ".bbc.edu.cn": ["Bengbu University"],
    ".bfa.edu.cn": ["Beijing Film Academy"],
    ".bfsu.edu.cn": ["Beijing Foreign Studies University"],
    ".bhu.edu.cn": ["Bohai University"],
    ".bistu.edu.cn": ["Beijing Information Science & Technology University"],
    ".bit.edu.cn": ["Beijing Institute of Technology"],
    ".bj.edu.cn": ["Beijing New Asia University"],
    ".bjfu.edu.cn": ["Beijing Forestry University"],
    ".bjmu.edu.cn": ["Beijing Medical University"],
    ".bjtu.edu.cn": ["Beijing Jiaotong University"],
    ".emails.bjut.edu.cn": ["Beijing University of Technology"],
    ".bjut.edu.cn": ["Beijing University of Technology"],
    ".blcu.edu.cn": ["Beijing Language and Culture University"],
    ".bnu.edu.cn": ["Beijing Normal University"],
    ".bnuz.edu.cn": ["BEIJING NORMAL UNIVERSITY ZHUHAI"],
    ".btbu.edu.cn": ["Beijing Technology and Business University"],
    ".buaa.edu.cn": ["Beihang University"],
    ".stu.bucea.edu.cn": [
        "BEIJING UNIVERSITY OF CIVITL ENGINEERING AND ARCHITECTURE"
    ],
    ".buct.edu.cn": ["Beijing University of Chemical Technology"],
    ".bupt.edu.cn": ["Beijing University of Posts and Telecommunications"],
    ".buu.edu.cn": ["Beijing Union University", "北京联合大学"],
    ".bwu.edu.cn": ["Beijing Wuzi University", "北京物资学院"],
    ".cafa.edu.cn": ["Central Academy of  Fine Art"],
    ".cafuc.edu.cn": [
        "中国民用航空飞行学院",
        "Civil Aviation Flight University of China",
    ],
    ".cau.edu.cn": ["China Agricultural University"],
    ".ccdgut.edu.cn": ["City College of Dongguan University of Technology"],
    ".ccmu.edu.cn": ["Capital Medical University", "首都医科大学"],
    ".ccnu.edu.cn": ["Central China Normal University"],
    ".ccsu.edu.cn": ["Changsha Unversity"],
    ".mails.ccu.edu.cn": ["Changchun University"],
    ".ccu.edu.cn": ["Changchun University"],
    ".ccut.edu.cn": ["Changchun University of Technology"],
    ".smail.cczu.edu.cn": ["Changzhou University"],
    ".cdmc.edu.cn": ["Chengde Medical University", "承德医学院"],
    ".cdu.edu.cn": ["Chengdu University"],
    ".cduestc.edu.cn": [
        "Chengdu College of University of Electronic Science and Technology"
    ],
    ".cdut.edu.cn": ["Chengdu University of Technology"],
    ".chd.edu.cn": ["Chang'an University"],
    ".chu.edu.cn": [
        "Official website: http://www.chu.edu.cn/",
        "Student mailbox login page: http://mail.chu.edu.cn/",
    ],
    ".chzu.edu.cn": ["Chuzhou University", "滁州学院"],
    ".stu.cjlu.edu.cn": ["China Jiliang University", "中国计量大学(学生邮箱)"],
    ".cjlu.edu.cn": ["China Jiliang University", "中国计量大学"],
    ".cmu.edu.cn": ["China Medical University Shenyang"],
    ".cncnc.edu.cn": ["Changchun Teachers College"],
    ".cnu.edu.cn": ["Capital Normal University"],
    ".cpu.edu.cn": ["China Pharmaceutical University Nanjing"],
    ".cqie.edu.cn": ["Chongqing Institute of Engineering", "重庆工程学院"],
    ".cqmu.edu.cn": ["Chongqing Medical University", "重庆医科大学"],
    ".cqnu.edu.cn": ["Chongqing Normal University"],
    ".cqu.edu.cn": ["Chongqing University"],
    ".stu.cque.edu.cn": [
        "重庆第二师范学院",
        "ChongQing Unversity Of Education",
    ],
    ".cqupt.edu.cn": ["Chongqing University of Post and Telecommunications"],
    ".cqust.edu.cn": ["Chongqing University Of Science and Technology"],
    ".2014.cqut.edu.cn": ["Chongqing University of Technology"],
    ".crtvu.edu.cn": ["Central Radio and TV University"],
    ".cslg.edu.cn": ["ChangShu Institute of Technology "],
    ".csmu.edu.cn": ["长沙医学院", "Changsha Medical University"],
    ".csu.edu.cn": ["Central South University"],
    ".csuft.edu.cn": ["Central South University of Forestry and Technology"],
    ".stu.csust.edu.cn": ["Changsha University of Science and Technology"],
    ".csust.edu.cn": ["Changsha University of Science & Technology"],
    ".ctbu.edu.cn": ["Chongqing Technology and Business University"],
    ".ctgu.edu.cn": ["China Three Gorges University"],
    ".cuc.edu.cn": ["Communication University of China"],
    ".cueb.edu.cn": ["Capital University of Economics and Business"],
    ".cufe.edu.cn": ["Central University of Finance and Economics"],
    ".cug.edu.cn": ["China University of Geosciences Wuhan"],
    ".cugb.edu.cn": ["China University of Geoscience Beijing"],
    ".link.cuhk.edu.cn": ["The Chinese University of Hong Kong, Shenzhen"],
    ".cuhk.edu.cn": ["The Chinese University of Hong Kong, Shenzhen"],
    ".cuit.edu.cn": ["Chengdu University of Information Technology"],
    ".cumt.edu.cn": ["China University of Mining Technology - Xuzhou"],
    ".cumtb.edu.cn": ["China University of Mining Technology - Beijing"],
    ".student.cup.edu.cn": ["China University of Petroleum-Beijing"],
    ".cup.edu.cn": ["China University of Petroleum-Beijing"],
    ".cupk.edu.cn": [
        "China University of Petroleum-Beijing at Karamay",
        "中国石油大学（北京）克拉玛依校区",
    ],
    ".cupl.edu.cn": ["China University of Political Science and Law"],
    ".cust.edu.cn": ["Changchun University of Science and Technology"],
    ".email.cwu.edu.cn": ["CHINA WOMEN'S UNIVERSITY", "中华女子学院"],
    ".cyc.edu.cn": ["China youth college for political science"],
    ".dgut.edu.cn": ["Dongguan University Of Technology"],
    ".dhu.edu.cn": ["Donghua University, Shanghai"],
    ".dlmedu.edu.cn": ["Dalian Medical University"],
    ".dlmu.edu.cn": ["Dalian Martime University"],
    ".dlnu.edu.cn": ["Dalian Minzu University", "大连民族大学"],
    ".dlpu.edu.cn": ["大连工业大学", "Dalian Polytechnic University"],
    ".s.dlu.edu.cn": ["Dalian University"],
    ".dlu.edu.cn": ["Dalian University"],
    ".student.dlufl.edu.cn": ["Dalian University Of Foreign Languages"],
    ".dlufl.edu.cn": ["Dalian University Of Foreign Languages"],
    ".dlut.edu.cn": ["Dalian University of Technology"],
    ".dufe.edu.cn": ["Dongbei University of Finance And Economics"],
    ".student.ecnu.edu.cn": ["East China Normal University"],
    ".ecnu.edu.cn": ["East China Normal University"],
    ".ecupl.edu.cn": [
        "华东政法大学",
        "East China University of Political Science and Law",
    ],
    ".ecust.edu.cn": ["East China University of Science and Technology"],
    ".ecut.edu.cn": ["East China University of Technology"],
    ".fjau.edu.cn": ["Fujian Agricultural University"],
    ".fjmu.edu.cn": ["Fujian Medical University"],
    ".fjnu.edu.cn": ["Fujian Normal University"],
    ".fjtcm.edu.cn": ["Fujian University of Traditional Chinese Medicine"],
    ".fjut.edu.cn": ["Fujian University of Technology"],
    ".fmmu.edu.cn": ["4th Military Medical University"],
    ".fosu.edu.cn": ["Foshan University"],
    ".fudan.edu.cn": ["Fudan University"],
    ".fynu.edu.cn": ["Fuyang Normal University", "阜阳师范大学"],
    ".fzfu.edu.cn": ["fuzhou university of international studies and trade"],
    ".fzu.edu.cn": ["Fuzhou University"],
    ".stu.gdgm.edu.cn": [
        "广东工贸职业技术学院",
        "Guangdong Polytechnic of Industry and Commerce",
        "the university official website URL: https://www.gdgm.edu.cn/",
    ],
    ".gdou.edu.cn": ["Guangdong Ocean University"],
    ".gdpu.edu.cn": ["Guangdong Pharmaceutical University"],
    ".gdqy.edu.cn": ["Guangdong Industry Technical College"],
    ".gdrtvu.edu.cn": ["Guangdong Radio &amp; TV University"],
    ".gduf.edu.cn": ["Guangdong University Of Finance"],
    ".gdufs.edu.cn": ["Guangdong University of Foreign Studies"],
    ".gdut.edu.cn": ["Guangdong University of Technology"],
    ".gench.edu.cn": ["Shanghai Jian Qiao University"],
    ".gist.edu.cn": [
        "Global Institute of Software Technology",
        "苏州高博软件技术职业学院",
    ],
    ".glmc.edu.cn": ["Guilin Medical University"],
    ".glut.edu.cn": ["Guilin university of technology"],
    ".gpnu.edu.cn": [
        "Guangdong Polytechnic Normal University",
        "广东技术师范大学",
    ],
    ".gsau.edu.cn": ["Gansu Agricultural University"],
    ".gsli.edu.cn": [" GanSu Political Science And Law Institute"],
    ".gsut.edu.cn": ["Gansu University of Technology"],
    ".mails.guet.edu.cn": ["Guilin University Of Electronic Technology"],
    ".gupt.edu.cn": [
        "广东邮电职业技术学院",
        "GuangDong Vocational College of Post and Telecom",
    ],
    ".gxnu.edu.cn": ["Guangxi Normal University"],
    ".gxtcmu.edu.cn": ["Guangxi Traditional Chinese Medical University"],
    ".xingjian.gxu.edu.cn": [
        "Guangxi University Xingjian College of Science and Liberal Arts"
    ],
    ".gxu.edu.cn": ["Guangxi University"],
    ".gxun.edu.cn": ["Guangxi University for Nationalities"],
    ".gzhu.edu.cn": ["Guangzhou University"],
    ".gznu.edu.cn": ["Guizhou Normal University"],
    ".gzu.edu.cn": ["Guizhou University"],
    ".stu.gzucm.edu.cn": ["Guangzhou University of Chinese Medicine"],
    ".hainanu.edu.cn": ["Hainan University"],
    ".hainnu.edu.cn": ["Hainan Normal University"],
    ".haue.edu.cn": ["add Henan University of Engineering"],
    ".haust.edu.cn": ["Henan University of Science and Technology"],
    ".haut.edu.cn": ["Henan University of Technology"],
    ".hbhgkj.edu.cn": [
        "黄冈科技职业学院",
        "Huanggang College Of Science and Technology",
    ],
    ".hbpu.edu.cn": ["Hubei Polytechnic University", "湖北理工学院"],
    ".hbu.edu.cn": ["Hebei University"],
    ".hbuas.edu.cn": ["HUBEI UNIVERSITY OF ARTS AND SCIENCE", "湖北文理学院"],
    ".hbut.edu.cn": ["Hubei University of Technology"],
    ".hdu.edu.cn": ["Hangzhou Dianzi University"],
    ".hebau.edu.cn": ["Hebei Agricultural University"],
    ".hebmu.edu.cn": ["Hebei Medical University"],
    ".hebnu.edu.cn": ["Hebei Normal University"],
    ".hebust.edu.cn": ["Hebei University of Science and Technology"],
    ".hebut.edu.cn": ["Hebei University of Technology"],
    ".henannu.edu.cn": ["Henan Normal University"],
    ".henau.edu.cn": ["Henan Agriculture University"],
    ".henu.edu.cn": ["Henan Univeristy"],
    ".heuet.edu.cn": ["Hebei University of Economics and Trade"],
    ".hezeu.edu.cn": ["Heze University"],
    ".hfut.edu.cn": ["Hefei University of Technology"],
    ".hhit.edu.cn": ["HuaiHai Institute of Technology"],
    ".hhstu.edu.cn": ["Huanghe Science &amp; Technology University"],
    ".hhtc.edu.cn": ["Huaihua University"],
    ".hhu.edu.cn": ["Hehai University"],
    ".hhuc.edu.cn": ["Hohai University Changzhou"],
    ".hit.edu.cn": ["Harbin Institute of Technology"],
    ".stmail.hitsz.edu.cn": ["Harbin Institute of Technology, Shenzhen"],
    ".hlju.edu.cn": ["Heilongjiang University"],
    ".hnfnu.edu.cn": ["湖南第一师范学院", "Hunan First Normal University"],
    ".hnnu.edu.cn": ["淮南师范学院", "Huainan Normal University"],
    ".hnu.edu.cn": ["Hunan University"],
    ".hnuahe.edu.cn": ["Henan University of Animal Husbandry and Economy"],
    ".hnuit.edu.cn": [
        "湖南信息学院",
        "Hunan University of Information Technology",
    ],
    ".hnust.edu.cn": ["Hunan University of Science and Technology"],
    ".hpu.edu.cn": ["Henan Polytechnic University"],
    ".hqu.edu.cn": ["Huaqiao University Quanzhuo"],
    ".hrbeu.edu.cn": ["Harbin Engineering University"],
    ".hrbmu.edu.cn": ["Harbin Medical University"],
    ".hrbnu.edu.cn": ["Harbin Normal University"],
    ".hrbust.edu.cn": ["Harbin University of Science and Technology"],
    ".hsu.edu.cn": ["Huang Shan University"],
    ".htu.edu.cn": ["河南师范大学", "Henan Normal University"],
    ".huat.edu.cn": ["Hubei University of Automotive Industry"],
    ".hubu.edu.cn": ["Hubei University"],
    ".huel.edu.cn": ["Henan University of Economics and Law"],
    ".huhst.edu.cn": [
        "湖南人文科技学院",
        "Hunan University of Humanities, Science and Technology",
    ],
    ".hunau.edu.cn": ["Hunan Agricultural University"],
    ".hunnu.edu.cn": ["Hunan Normal University"],
    ".hust.edu.cn": ["Huazhong University of Science and Technology"],
    ".hut.edu.cn": ["HuNan University of Technology"],
    ".hyit.edu.cn": ["Huaiyin Institute Of Technology"],
    ".hytc.edu.cn": ["Huaiyin Normal University", "淮阴师范学院"],
    ".hzau.edu.cn": ["Huazhong Agricultural University"],
    ".hznu.edu.cn": ["Hangzhou Normal University"],
    ".hzu.edu.cn": ["Huizhou University"],
    ".imau.edu.cn": ["Inner Mongolia Agricultural University"],
    ".imnu.edu.cn": ["Inner Mongolia Normal University"],
    ".imu.edu.cn": ["Inner Mongolia University"],
    ".jgsu.edu.cn": ["Jinggangshan University", "井冈山大学"],
    ".jiangnan.edu.cn": ["Jiangnan University"],
    ".stu.jit.edu.cn": ["Jinling Institute Of Technology (Student Used)"],
    ".jit.edu.cn": ["Jinling Institute of Technology"],
    ".jlau.edu.cn": ["Jilin Agricultural University"],
    ".jlnu.edu.cn": ["Jilin Normal University"],
    ".jlu.edu.cn": ["Jilin University"],
    ".jmu.edu.cn": ["Jimei University"],
    ".jnu.edu.cn": ["Jinan University"],
    ".jou.edu.cn": ["Jiangsu Ocean University", "江苏海洋大学"],
    ".jsu.edu.cn": ["Jishou University"],
    ".jsust.edu.cn": ["Jiangsu University of Science and Technology"],
    ".stu.just.edu.cn": ["Jiangsu University of Science and Technology"],
    ".jxau.edu.cn": ["Jiangxi Agricultural University"],
    ".jxnu.edu.cn": ["Jiangxi Normal University"],
    ".jxufe.edu.cn": ["Jiangxi University of Finance and Economics"],
    ".mail.jxust.edu.cn": ["JiangXi University of Science and Technology"],
    ".jyu.edu.cn": ["Jiaying University"],
    ".kfu.edu.cn": ["Kaifeng University"],
    ".kmust.edu.cn": ["Kunmimg University of Science and Technology"],
    ".lcu.edu.cn": ["Liaocheng University", "聊城大学"],
    ".ldu.edu.cn": ["鲁东大学", "Ludong University"],
    ".ldzy.edu.cn": [
        "娄底职业技术学院",
        "Loudi Vocational and Technical College",
    ],
    ".lixin.edu.cn": ["Shanghai Lixin University of Accounting and Finance"],
    ".lnnu.edu.cn": ["Liaoning Normal University"],
    ".stu.lnpu.edu.cn": [
        "辽宁石油化工大学",
        "Liaoning University of Petroleum and Chemical Technology",
    ],
    ".lntu.edu.cn": ["Liaoning Technical University"],
    ".lnu.edu.cn": ["Liaoning University"],
    ".lzjtu.edu.cn": ["Lanzhou Jiaotong University", "兰州交通大学"],
    ".lzu.edu.cn": ["Lanzhou University"],
    ".muc.edu.cn": ["Minzu University of China"],
    ".mail.nankai.edu.cn": ["Nankai University"],
    ".nankai.edu.cn": ["Nankai University"],
    ".nanshan.edu.cn": ["Yantai Nanshan University"],
    ".nau.edu.cn": ["Nanjing Audit University"],
    ".nbpt.edu.cn": ["Ningbo Polytechnic"],
    ".nbu.edu.cn": ["Ningbo University"],
    ".nchu.edu.cn": ["Nanchang Hangkong University"],
    ".nciae.edu.cn": ["North China Institute of Aerospace Engineering"],
    ".ncist.edu.cn": ["North China Institute of Science and Technology"],
    ".ncst.edu.cn": [
        "North China University of Science and Technology",
        "华北理工大学",
    ],
    ".ncu.edu.cn": ["Nanchang University"],
    ".ncut.edu.cn": ["North China University of Technology"],
    ".neau.edu.cn": ["Northeast Agricultural University"],
    ".nenu.edu.cn": ["Northeast Normal University"],
    ".neu.edu.cn": [
        "Northeastern University",
        "Northeastern University (China)",
    ],
    ".neuq.edu.cn": ["Northeast University at Qinhuangdao Campus"],
    ".neusoft.edu.cn": ["Dalian Neusoft Institute Of Information"],
    ".stu.nfu.edu.cn": ["广州南方学院", "Nanfang College, Guangzhou"],
    ".nit.edu.cn": ["Nanchang Institute Of Technology"],
    ".njau.edu.cn": ["Nanjing Agricultural University"],
    ".njfu.edu.cn": ["Nanjing Forestry University"],
    ".njit.edu.cn": ["Nanjing Institute of Technology"],
    ".njmu.edu.cn": ["Nanjing Medical University"],
    ".njnu.edu.cn": ["Nanjing Normal University"],
    ".njtech.edu.cn": ["Nanjing Tech University"],
    ".njtu.edu.cn": ["Northern Jiaotong University"],
    ".nju.edu.cn": ["Nanjing University"],
    ".njupt.edu.cn": ["Nanjing University of Posts and Telecommunications"],
    ".njust.edu.cn": ["Nanjing University of Science and Technology"],
    ".njutcm.edu.cn": ["Nanjing University of Traditional Chinese Medicine"],
    ".st.njxzc.edu.cn": ["Nanjing Xiaozhuang University"],
    ".njxzc.edu.cn": ["Nanjing Xiaozhuang University"],
    ".nnct.edu.cn": ["Nanning College of Technology", "南宁理工学院"],
    ".nottingham.edu.cn": ["University of Nottingham Ningbo China"],
    ".ntu.edu.cn": ["nantong university"],
    ".nuaa.edu.cn": ["Nanjing University of Aeronautics and Astronautics"],
    ".nuc.edu.cn": ["North University of China"],
    ".nudt.edu.cn": ["National University of Defense Technology"],
    ".nufe.edu.cn": [
        "Nanjing University of Finance and Economics",
        "南京财经大学",
    ],
    ".nuist.edu.cn": [
        "Nanjing University of Information Science and Technology",
        "南京信息工程大学",
    ],
    ".nuit.edu.cn": ["Neusoft Institute Guangdong"],
    ".stu.nun.edu.cn": ["北方民族大学", "North Minzu University"],
    ".nwafu.edu.cn": ["Northwest A&F University"],
    ".nwnu.edu.cn": ["Northwest Normal University Lanzhou"],
    ".mail.nwpu.edu.cn": [
        "西北工业大学",
        "Northwestern Polytechnical University",
    ],
    ".nwpu.edu.cn": ["Northwest Polytechnical University Xi'an"],
    ".nwsuaf.edu.cn": ["Northwest A&F University"],
    ".nwu.edu.cn": ["Northwest University Xi'an"],
    ".nxu.edu.cn": ["Ningxia University"],
    ".ouc.edu.cn": ["Ocean University of China"],
    ".stu.pku.edu.cn": ["北京大学"],
    ".pku.edu.cn": ["Peking University"],
    ".qau.edu.cn": ["Qingdao Agricultural University"],
    ".qdu.edu.cn": ["Qingdao University"],
    ".qfnu.edu.cn": ["Qufu Normal University"],
    ".qhnu.edu.cn": ["Qinghai Normal University"],
    ".qhu.edu.cn": ["Qinghai University"],
    ".qlu.edu.cn": ["Qilu university of Technology"],
    ".qust.edu.cn": ["Qingdao University of Science and Technology"],
    ".ruc.edu.cn": ["Renmin University of China"],
    ".sandau.edu.cn": ["Shanghai Sanda University"],
    ".sbs.edu.cn": ["Shanghai Business School"],
    ".scau.edu.cn": ["South China Agricultural University"],
    ".scnu.edu.cn": ["South China Normal University"],
    ".scu.edu.cn": ["Sichuan University"],
    ".scuec.edu.cn": ["South-Central University for Nationalities"],
    ".mail.scut.edu.cn": [
        "华南理工大学",
        "South China University of Technology",
    ],
    ".scut.edu.cn": ["South China University of Technology"],
    ".sdau.edu.cn": ["Shandong Agricultural University"],
    ".sdcit.edu.cn": [
        "Shandong College of Information Technology",
        "山东信息职业技术学院",
    ],
    ".sdjtu.edu.cn": ["Shandong Jiaotong University"],
    ".sdju.edu.cn": ["Shanghai Dainji University"],
    ".sdmu.edu.cn": ["Shandong Medical University"],
    ".sdnu.edu.cn": ["Shandong Normal University"],
    ".sdpt.edu.cn": ["顺德职业技术学院", "ShundePolyTechnic"],
    ".sdu.edu.cn": ["Shandong University"],
    ".mail.sdua.edu.cn": [
        "山东航空学院",
        "Shan Dong University Of Aeronautics",
    ],
    ".sdust.edu.cn": [
        "Shandong University of Science and Technology",
        "山东科技大学",
    ],
    ".sdut.edu.cn": ["Shandong University of Technology"],
    ".sdutcm.edu.cn": ["Shandong University of Triaditional Chinese Medicine"],
    ".sdyu.edu.cn": ["SHANDONG YOUTH UNIVERITY OF POLITICAL SCIENCE"],
    ".seu.edu.cn": ["Southeast University"],
    ".sgu.edu.cn": ["Shaoguan University"],
    ".shafc.edu.cn": [
        "Shanghai Vocational College of Agriculture and Forestry"
    ],
    ".shanghaitech.edu.cn": ["ShanghaiTech University"],
    ".shcc.edu.cn": ["上海海关学院", "Shanghai Customs College"],
    ".shfu.edu.cn": ["Shanghai Fisheries University"],
    ".shiep.edu.cn": ["Shanghai University of Electric Power"],
    ".shisu.edu.cn": ["Shanghai International Studies University"],
    ".shjgu.edu.cn": ["Shanghai Jiguang Vocational Technology College"],
    ".shmtu.edu.cn": ["Shanghai Maritime University"],
    ".shmu.edu.cn": ["Shanghai Medical University"],
    ".smail.shnu.edu.cn": ["Shanghai Normal University"],
    ".shou.edu.cn": ["ShangHai Ocean University"],
    ".shsmu.edu.cn": ["Shanghai Second Medical University"],
    ".shtu.edu.cn": ["Shanghai Normal University"],
    ".shtvu.edu.cn": ["Shanghai Television University"],
    ".shu.edu.cn": ["Shanghai University"],
    ".shufe.edu.cn": ["Shanghai University of Finance and Economics"],
    ".shupl.edu.cn": ["Shanghai University of Political Science and Law"],
    ".shutcm.edu.cn": [
        "Shanghai University of Traditional Chinese Medicine and Pharmacology"
    ],
    ".sicau.edu.cn": ["Sichuan Agricultural University"],
    ".sicnu.edu.cn": ["Sichuan Normal University"],
    ".sie.edu.cn": ["Shenyang Institute of Engineering"],
    ".sisu.edu.cn": ["Sichuan International Studies University"],
    ".sjtu.edu.cn": [
        "Shanghai Jiaotong University",
        "Shanghai Jiao Tong University",
    ],
    ".sjzu.edu.cn": ["Shenyang Jianzhu University"],
    ".smbu.edu.cn": ["ShenZhen MSU-BIT University", "深圳北理莫斯科大学"],
    ".smmu.edu.cn": ["2nd Military Medical University"],
    ".smu.edu.cn": [
        "Official website: http://www.smu.edu.cn/",
        "Student mailbox login page: http://mail.smu.edu.cn/",
    ],
    ".snnu.edu.cn": ["Shaanxi Normal University", "Shanxi Normal University"],
    ".sru.edu.cn": ["上饶师范学院"],
    ".stu.sspu.edu.cn": ["Shanghai Second Polytechnic University"],
    ".stu.edu.cn": ["Shantou University"],
    ".suda.edu.cn": ["Suzhou University"],
    ".sues.edu.cn": ["Shanghai University of Engineering Science"],
    ".163.sufe.edu.cn": ["Shanghai University of Finance and Economics"],
    ".live.sufe.edu.cn": ["Shanghai University of Finance and Economics"],
    ".suibe.edu.cn": [
        "Shanghai University of International Business and Economics"
    ],
    ".sustc.edu.cn": [
        "南方科技大学",
        "Southern University of Science and Technology",
        "SUSTech",
        "South University of Science and Technology of China",
    ],
    ".sustech.edu.cn": [
        "南方科技大学",
        "Southern University of Science and Technology",
        "SUSTech",
        "South University of Science and Technology of China",
    ],
    ".swjtu.edu.cn": ["Southwest Jiaotong University"],
    ".swpu.edu.cn": ["Southwest Petroleum University"],
    ".swu.edu.cn": ["Southwest University"],
    ".swufe.edu.cn": ["Southwest University of Finance and Economics"],
    ".swun.edu.cn": ["Southwest Minzu University", "西南民族大学"],
    ".swupl.edu.cn": ["Southwest University of Political Science and Law"],
    ".swust.edu.cn": ["Southwest University of Science and Technology"],
    ".sxau.edu.cn": ["Shanxi Agricultural University"],
    ".sxie.edu.cn": ["山西能源学院", "Shanxi Institute of Energy"],
    ".sxu.edu.cn": ["Shanxi University"],
    ".syphu.edu.cn": ["Shenyang Pharmaceutical University"],
    ".mail.sysu.edu.cn": ["Sun Yat-sen University"],
    ".mail2.sysu.edu.cn": ["Sun Yat-sen University"],
    ".mail3.sysu.edu.cn": ["Sun Yat-Sen University"],
    ".sysu.edu.cn": ["Sun Yat-Sen University"],
    ".syu.edu.cn": ["Shenyang University"],
    ".st.sziit.edu.cn": ["Shenzhen Institute of Information Technology"],
    ".mail.szpt.edu.cn": ["Shenzhen Polytechnic"],
    ".szu.edu.cn": ["Shenzhen University"],
    ".tfswufe.edu.cn": [
        "西南财经大学天府学院",
        "Tianfu Southwest University of Finance and Economics",
    ],
    ".tijmu.edu.cn": ["Tianjin Medical University"],
    ".tjcu.edu.cn": ["Tianjin University of Commerce"],
    ".tjmu.edu.cn": ["Tongji Medical University"],
    ".tjnu.edu.cn": ["Tianjin Normal University"],
    ".tjpu.edu.cn": ["Tianjin Polytechnic University"],
    ".tjrtvu.edu.cn": ["Tianjin Open University"],
    ".tju.edu.cn": ["Tianjin University"],
    ".tjufe.edu.cn": ["Tianjin University of Finance &amp; Economics"],
    ".tjut.edu.cn": ["Tianjin University of Technology"],
    ".tmmu.edu.cn": ["3rd Military Medical University"],
    ".tmu.edu.cn": ["Tianjin Medical University"],
    ".tongji.edu.cn": ["Tongji University"],
    ".tsinghua.edu.cn": ["Tsinghua University"],
    ".mail.tust.edu.cn": ["Tianjin University of Science&Technology"],
    ".tynu.edu.cn": ["Taiyuan Normal University."],
    ".stu.tyust.edu.cn": ["Taiyuan University of Science and Technology"],
    ".tyut.edu.cn": ["Taiyuan University of Technology"],
    ".ucas.edu.cn": ["University of Chinese Academy of Sciences"],
    ".ucass.edu.cn": ["University of Chinese Academy of Social Sciences"],
    ".uestc.edu.cn": [
        "University of Electronic Science and Technology of China"
    ],
    ".uibe.edu.cn": ["University of International Business and Economics"],
    ".uic.edu.cn": [
        "北京师范大学-香港浸会大学联合国际学院",
        "Beijing Normal University & Hong Kong Baptist University United International College",
    ],
    ".mail.ujn.edu.cn": ["University of Jinan", "ujn.edu.cn", "济南大学"],
    ".ujn.edu.cn": ["University of Jinan"],
    ".stmail.ujs.edu.cn": ["Jiangsu University"],
    ".ujs.edu.cn": ["Jiangsu University"],
    ".s.upc.edu.cn": ["China University of Petroleum-Huadong"],
    ".upc.edu.cn": ["China University of Petroleum-Huadong"],
    ".usc.edu.cn": ["South China University"],
    ".usst.edu.cn": ["Shanghai University of Science and Technology"],
    ".ustb.edu.cn": [
        "Beijing University of Science and Technology",
        "University of Science and Technology Beijing",
    ],
    ".mail.ustc.edu.cn": ["University of Science and Technology of China"],
    ".ustc.edu.cn": ["University of Science and Technology of China"],
    ".usth.edu.cn": ["Heilongjiang University of science and technology"],
    ".usts.edu.cn": ["Suzhou University of Science and Technology"],
    ".utibet.edu.cn": ["Tibet University"],
    ".uvu.edu.cn": ["Urumqi Vocational University"],
    ".whu.edu.cn": [
        "Wuhan University",
        "Computer School of Wuhan University",
        "Wuhan University School of Medicine",
    ],
    ".whut.edu.cn": ["Wuhan University of Technology"],
    ".wmu.edu.cn": ["Wenzhou Medical University"],
    ".wsyu.edu.cn": [
        "Wuchang Shouyi University",
        "武昌首义学院",
        "华中科技大学武昌分校",
    ],
    ".wtu.edu.cn": ["Wuhan Textile University"],
    ".wust.edu.cn": ["Wuhan University of Science and Technology"],
    ".wyu.edu.cn": ["Wuyi University"],
    ".xaau.edu.cn": ["Xi’an Aeronautical University", "西安航空学院"],
    ".xahu.edu.cn": ["Xi'an Highway University"],
    ".xauat.edu.cn": ["Xi'an University of Architecture and Technology"],
    ".xaufe.edu.cn": [
        "西安财经大学",
        "Xi'An University of Finance and Economics",
    ],
    ".xaut.edu.cn": ["Xi'an University of Technology"],
    ".xhcom.edu.cn": ["Xinghai Conservatory of Music"],
    ".xhu.edu.cn": ["Xihua University"],
    ".stu.xidian.edu.cn": ["Xidian University"],
    ".xidian.edu.cn": [
        "Xi'an University of Electronic Science and Technology"
    ],
    ".xiyou.edu.cn": ["Xi’an University of Posts and Telecommunications"],
    ".xjau.edu.cn": ["Xinjiang Agriculture University"],
    ".xjnu.edu.cn": ["Xinjiang Normal University"],
    ".student.xjtlu.edu.cn": ["Xi'an Jiaotong Liverpool University"],
    ".xjtu.edu.cn": ["Xi'an Jiaotong University"],
    ".xju.edu.cn": ["Xinjiang University"],
    ".stu.xmu.edu.cn": ["Xiamen University"],
    ".xmu.edu.cn": ["Xiamen University"],
    ".stu.xmut.edu.cn": ["Xiamen University Of Technology"],
    ".xpu.edu.cn": ["Xi’an Polytechnic University", "西安工程大学"],
    ".xsyu.edu.cn": ["西安石油大学", "Xi’an Shiyou University "],
    ".xtit.edu.cn": ["湘潭理工学院", "Xiangtan Institute of Technology"],
    ".xtu.edu.cn": ["Xiangtan University"],
    ".stu.xupt.edu.cn": ["Xi’an University of Posts and Telecommunications"],
    ".xupt.edu.cn": ["Xi’an University of Posts and Telecommunications"],
    ".xust.edu.cn": ["Xi'an University of Science and Technology"],
    ".xxu.edu.cn": ["Xinxiang University"],
    ".yau.edu.cn": ["延安大学", "Yanan University"],
    ".ynit.edu.cn": [
        "Yunnan Industry & Trade Vocational College",
        "云南工贸职业技术学院",
    ],
    ".ynu.edu.cn": ["Yunnan University"],
    ".ysu.edu.cn": ["Yanshan University"],
    ".ytu.edu.cn": ["YANTAI UNIVERSITY"],
    ".365.yzu.edu.cn": ["Yangzhou University"],
    ".stu.yzu.edu.cn": ["Yangzhou University"],
    ".yzu.edu.cn": ["Yangzhou University"],
    ".zafu.edu.cn": [
        "Zhejiang Agriculture & Forest University",
        "浙江农林大学",
    ],
    ".zbti.edu.cn": ["Zhejiang Business Technology Institute"],
    ".zisu.edu.cn": [
        "Zhejiang International Studies University",
        "浙江外国语学院",
    ],
    ".zjgsu.edu.cn": ["Zhejiang Gongshang University"],
    ".zjnu.edu.cn": ["Zhejiang Normal University"],
    ".zju.edu.cn": [
        "Zhejiang University, Hangzhou, China",
        "浙江大学，中国杭州",
        "Zhejiang University",
    ],
    ".zjut.edu.cn": ["ZheJiang University of Technology"],
    ".zjvtit.edu.cn": [
        "Zhejiang Institute of Communications",
        "浙江交通职业技术学院",
    ],
    ".stu.zjweu.edu.cn": [
        "\ufeffZhejiang University of Water Resources and Electric Power",
        "浙江水利水电学院",
    ],
    ".zknu.edu.cn": ["ADD Zhoukou Normal University"],
    ".zqu.edu.cn": ["ZHAOQING UNIVERSITY", "肇庆学院"],
    ".zsc.edu.cn": [
        "\ufeffUniversity of Electronic Science and Technology of China，Zhongshan Institute"
    ],
    ".zstu.edu.cn": ["Zhejiang Sci-Tech University", "浙江理工大学"],
    ".stu.zucc.edu.cn": [
        "Zhejiang University City College",
        "浙江大学城市学院",
    ],
    ".zucc.edu.cn": ["Zhejiang University City College", "浙江大学城市学院"],
    ".zuel.edu.cn": ["Zhongnan University of Economics and Law"],
    ".zufe.edu.cn": [
        "Zhejiang University of Finance & Economic, Hangzhou, China"
    ],
    ".zust.edu.cn": [
        "Zhejiang University of Science & Technology",
        "浙江科技学院(浙江科技大学)",
    ],
    ".zut.edu.cn": ["  Zhongyuan University of Technology (ZUT)"],
    ".zyufl.edu.cn": ["ZheJiang YueXiu University", "浙江越秀外国语学院"],
    ".zzu.edu.cn": ["Zhengzhou University"],
    ".zzuli.edu.cn": ["Zhengzhou University of light industry"],
    ".fdfz.cn": [
        "复旦大学附属中学",
        "High School Affiliated to Fudan University",
    ],
    ".fvti.cn": ["福州职业技术学院"],
    ".gdcp.cn": ["Guangdong Communication Polytechnic"],
    ".gnnu.cn": ["Gannan Normal University"],
    ".gdedu.gov.cn": ["广东省教育研究院"],
    ".gyu.cn": ["Guiyang University"],
    ".xs.gzcc.cn": ["广州商学院", "Guangzhou College of  Commerce"],
    ".gzmhxy.cn": ["贵州民用航空职业学院"],
    ".harrowbeijing.cn": [
        "北京哈罗国际学校",
        "Harrow International School Beijing",
    ],
    ".hbeu.cn": ["湖北工程学院", "Hubei Engineering University"],
    ".hbjhart.cn": ["江汉艺术职业学院"],
    ".mail.hniu.cn": ["湖南信息职业技术学院", "Hunan College of Information"],
    ".hsefz.cn": [
        "华东师范大学第二附属中学",
        "No.2 High School of East China Normal University",
    ],
    ".huilieducation.cn": [
        "上海浦东新区民办惠立学校",
        "Huili School Shanghai",
    ],
    ".hzvtc.cn": [
        "汉中职业技术学院",
        "Hanzhong Vocational and Technical College",
    ],
    ".ccit.ccit.js.cn": [
        "常州信息职业技术学校",
        "Cangzhou College of Information Technology",
    ],
    ".stu.ccit.js.cn": [
        "常州信息职业技术学院",
        "ChangZhou College Of Information Technology",
    ],
    ".ecjtu.jx.cn": ["East China Jiao Tong University"],
    ".jxvc.jx.cn": [
        "江西财经职业学院",
        "Jiangxi Vocational College of Finance and Economis",
    ],
    ".stu.jxufe.cn": ["Jiangxi University of Finance and Economics"],
    ".student.keystoneacademy.cn": ["Keystone Academy"],
    ".lncu.cn": ["辽宁传媒学院"],
    ".lut.cn": ["LanZhou University Of Technology"],
    ".mail.lzjtu.cn": ["兰州交通大学", "Lanzhou Jiaotong University"],
    ".nbcc.cn": ["NingBo City College Of Vacational Technology"],
    ".baafs.net.cn": [
        "北京市农林科学院",
        "Beijing Academy of Agriculture and Forestry Science",
    ],
    ".nit.net.cn": ["Ningbo Institute of Technology. Zhejiang University"],
    ".tjbhzy.net.cn": ["TIANJIN BOHAI VOCATIONAL TECHNOLOGY COLLEGE"],
    ".zjbti.net.cn": ["Zhejiang Business Technology Institute"],
    ".nj13z.cn": ["南京市第十三中学", "Nanjing No.13 Middle School"],
    ".njcit.cn": ["Nanjing Collage Of Information Technology"],
    ".bsg.org.cn": ["广州英国人学校", "The British School of Guangzhou"],
    ".cass.org.cn": [
        "中国社会科学院大学",
        "University Of Chinese Academy Of Social Sciences",
    ],
    ".sis.org.cn": [
        "Shekou International School",
        "蛇口国际学校",
        "URL: https://www.sis-shekou.org/",
    ],
    ".sdcet.cn": [
        "山东电子职业技术学院",
        "SHANDONG COLLEGE OF ELECTRONIC TECHNOLOGY",
    ],
    ".shvfs.cn": ["上海温哥华电影学院", "Shanghai Vancouver Film School"],
    ".sia.cn": [
        "中国科学院沈阳自动化研究所",
        "SHENYANG INSTITUTE OF AUTOMATION, CHINESE ACADEMY OF SCIENCES",
    ],
    ".snnu.cn": ["Shaanxi Normal University", "陕西师范大学"],
    ".swis.cn": [
        "Shen Wai International School 深圳外国语（国际部）",
        "Shen Wai International School",
    ],
    ".thisdl.cn": ["北京稻香湖学校"],
    ".mail.tust.cn": ["Tianjin University of Science and Technology"],
    ".ulink.cn": ["领科教育", "ULink College"],
    ".wxpoly.cn": ["杭州万向职业技术学院"],
    ".xjtlu.cn": ["Xi'an Jiaotong-Liverpool University"],
    ".xmcu.cn": ["厦门城市职业学院", "XIAMEN CITY UNIVERSITY"],
    ".mail.xzcit.cn": ["徐州工业职业技术学院"],
    ".ybzy.cn": ["YiBin Vocational And Technical College"],
    ".ykpaoschool.cn": ["YK Pao School", "YK Pao School"],
    ".yznu.cn": ["Yangtze Normal University"],
    ".zimc.cn": ["Zhejiang International Maritime College"],
    ".zjnu.cn": ["浙江师范大学", "Zhejiang Normal University"],
    ".bootcode.co": ["Bootcode"],
    ".cyberacademy.co": ["Cyber Academy"],
    ".dallam.co": [],
    ".alumnoeseit.edu.co": [
        "ESEIT - Higher School of Business, Engineering and Technology, Colombia",
        "Higher School of Business, Engineering and Technology",
    ],
    ".americana.edu.co": ["corporación universitaria americana"],
    ".amigo.edu.co": ["Universidad Católica Luis Amigó"],
    ".estudiantes.areandina.edu.co": [
        "Fundación Universitaria del Área Andina"
    ],
    ".artesyletras.edu.co": [
        "Escuela de Artes y Letras",
        "School of Arts and Letters",
    ],
    ".asys.edu.co": ["Corporacion Universitaria Remington "],
    ".aunarcali.edu.co": [
        "Corporación Universitaria Autónoma de Nariño",
        "Autonomous University Corporation of Nariño",
    ],
    ".aunarvillavicencio.edu.co": [
        "Corporación Universitaria Autónoma de Nariño Villavicencio"
    ],
    ".autonoma.edu.co": ["Universidad Autónoma de Manizales"],
    ".bellasartes.edu.co": ["Universidad Bellas Artes"],
    ".berakahacademyschool.edu.co": ["Berakaha Academy School"],
    ".campestrehorizontes.edu.co": ["Colegio Campestre Horizontes"],
    ".campusucc.edu.co": ["Universidad Cooperativa de Colombia"],
    ".cecar.edu.co": ["Coorporacion Universitaria del Caribe - CECAR"],
    ".virtual.ceipa.edu.co": ["Ceipa Business School"],
    ".ces.edu.co": ["Universidad CES"],
    ".cesa.edu.co": [
        "Colegio de Estudios Superiores de Administración - CESA"
    ],
    ".cesde.edu.co": [
        "Cesde - Centro de Estudios Especializados",
        "Cesde - Centro de Estudios Especializados",
    ],
    ".cgb.edu.co": ["\ufeffColegio Gran Bretaña"],
    ".ciaf.edu.co": [
        "CIAF Educacion Superior",
        "https://www.ciaf.edu.co/inicio",
        "https://www.ciaf.edu.co/software",
    ],
    ".colcolon.edu.co": ["Colegio Colón"],
    ".colegioanamariajaner.edu.co": ["Colegio Ana María Janer"],
    ".colegionuevocampestre.edu.co": [
        "colegio nuevo campestre",
        "new country school",
    ],
    ".colegiorefous.edu.co": ["colegiorefous", "colegiorefous"],
    ".colmabrija.edu.co": [
        "Instituto Técnico Padre Manuel Briceño Jauregui Fe y Alegría"
    ],
    ".coreducacion.edu.co": [
        "Coreducación – Patrimonio Educativo Regional Honda Tolima"
    ],
    ".corhuila.edu.co": ["Corporación Universitaria del Huila - Corhuila"],
    ".correounivalle.edu.co": ["Universidad del Valle"],
    ".coruniamericana.edu.co": ["Corporación Universitaria Americana"],
    ".cotecnova.edu.co": [
        "Corporación de Estudios Tecnológicos del Norte del Valle",
        "North Valley Technological Studies Corporation",
    ],
    ".cue.edu.co": [
        "Corporación Universitaria Empresarial Alexander Von Humboldt"
    ],
    ".cues.edu.co": ["Corporacion Universitaria Empresarial de Salamanca"],
    ".cun.edu.co": [
        "Corporación Unificada Nacional de Educación Superior CUN"
    ],
    ".curnvirtual.edu.co": [
        "Corporacion Universitaria Rafael Nuñez",
        "Universitary Coporation Rafael Nunez",
    ],
    ".eam.edu.co": ["EAM", "EAM"],
    ".ean.edu.co": ["Escuela de Administración de Negocios"],
    ".ecci.edu.co": ["Escuela Colombiana de Carreras Industriales"],
    ".ecr.edu.co": ["Fundacion Escuela Colombiana de Rehabiliación"],
    ".eia.edu.co": ["Escuela de Ingeniería de Antioquia"],
    ".elpoli.edu.co": [
        "Institución universitaria Politécnico Colombiano Jaime Isaza Cadavid"
    ],
    ".escuelaing.edu.co": ["Escuela Colombiana de Ingeniería Julio Garavito"],
    ".estudiantesunibague.edu.co": ["Universidad de Ibague"],
    ".esumer.edu.co": [
        "Institucion universitaria ESUMER",
        "ESUMER university institution",
    ],
    ".fesc.edu.co": ["FESC (Fundación de Estudios Superiores Comfanorte)"],
    ".fet.edu.co": [
        'FET Fundación Escuela Tecnológica De Neiva "Jesús Oviedo Perez"'
    ],
    ".fuac.edu.co": ["Universidad Autónoma de Colombia"],
    ".fumc.edu.co": ["FUNDACIÓN UNIVERSITARIA MARIA CANO"],
    ".funlam.edu.co": ["Fundación Universitaria Luis Amigó"],
    ".funsanmateo.edu.co": ["Fundación Universitaria San Mateo"],
    ".estudiante.fup.edu.co": [
        "Fundación Universitaria de Popayán",
        "Fundacion Universitaria de Popayán",
    ],
    ".gimnasiodelnorte.edu.co": ["Gimnasio del Norte"],
    ".gimnasioloscerezos.edu.co": ["GIMNASIO CAMPESTRE LOS CEREZOS"],
    ".granadino.edu.co": ["Colegio Granadino"],
    ".iberoamericana.edu.co": ["Institución Universitaria Iberoamericana"],
    ".icesi.edu.co": ["Universidad ICESI"],
    ".idem.edu.co": ["Institución Educativa Diego Echavarría Misas"],
    ".iepuenes.edu.co": ["INSTITUCION EDUCATIVA PUENES", "I.E. PUENES"],
    ".iesevilla.edu.co": ["Institución Educativa Sevilla"],
    ".inalde.edu.co": ["INALDE Business School"],
    ".inemjose.edu.co": ["Institucion Educativa INEM Jose Felix de Restrepo"],
    ".institutocenis.edu.co": ["Instituto cenis de colombia"],
    ".institutosanrafael.edu.co": ["Instituto Técnico San Rafael"],
    ".intep.edu.co": [
        "Instituto de Educación Técnica Profesional de Roldanillo, Valle - INTEP"
    ],
    ".isc.edu.co": [
        "Instituto San Carlos de la Salle",
        "Institut San Carlos de la Salle",
    ],
    ".iser.edu.co": ["Instituto Superior de Educación Rural - ISER", "ISER"],
    ".isjdelasalle.edu.co": [
        "IESJ De La Salle",
        "Educational Institution San José De La Salle",
    ],
    ".itfip.edu.co": [
        "Instituto Tolimense de Formación Técnica Profesional ITFIP"
    ],
    ".itm.edu.co": ["Instituto Tecnológico Metropolitano"],
    ".itp.edu.co": ["Instituto Tecnológico del Putumayo"],
    ".itsa.edu.co": ["Institucion Universitaria ITSA"],
    ".est.iudigital.edu.co": [
        "IUDigital De Antioquia",
        "Website: https://www.iudigital.edu.co/Paginas/default.aspx",
        "Software Development: https://www.iudigital.edu.co/OfertaEducativa/Paginas/Tecnologia-en-Desarrollo-de-Software.aspx",
    ],
    ".iue.edu.co": ["Institucion Universitaria de Envigado"],
    ".iumafis.edu.co": [
        "Institución Universitaria Marco Fidel Suárez",
        "IUMAFIS",
    ],
    ".javeriana.edu.co": ["Pontificia Universidad Javeriana"],
    ".javerianacali.edu.co": ["Pontificia Universidad Javeriana Cali"],
    ".jdc.edu.co": ["Fundación Universitaria Juan De Castellanos"],
    ".jefferson.edu.co": ["Colegio Jefferson", "Jefferson school"],
    ".josema.edu.co": ["José María Berrío"],
    ".konradlorenz.edu.co": [],
    ".laarboleda.edu.co": ["Colegio La Arboleda", "La Arboleda School"],
    ".lakhumbre.edu.co": ["GLK Gimnasio la Khumbre", "Khumbre"],
    ".lasalle.edu.co": ["Universidad de La Salle"],
    ".lasallezipaquira.edu.co": ["I.E.M. San Juan Bautista De la Salle"],
    ".lasierra.edu.co": ["Fundación Instituto Técnico de la Sierra"],
    ".meicol.edu.co": ["Centro de estudios e investigacion meicol"],
    ".miremington.edu.co": [
        "Corporación Universitaria Remington",
        "University Corporation Remington",
    ],
    ".misena.edu.co": ["Servicio Nacional de Aprendizaje SENA"],
    ".pascualbravo.edu.co": ["Institución universitaria Pascual Bravo"],
    ".pca.edu.co": ["Politécnico de la costa atlántica"],
    ".pedagogica.edu.co": ["Universidad Pedagogica Nacional"],
    ".pi.edu.co": ["Politécnico internacional", "Politecnico internacional"],
    ".poli.edu.co": ["Institución Universitaria Politécnico Grancolombiano"],
    ".poligran.edu.co": ["Politecnico Grancolombiano"],
    ".politecnicomayor.edu.co": ["Politécnico Mayor"],
    ".sagradocorazon74.edu.co": ["Colegio del Sagrado Corazón Calle 74"],
    ".sanmartin.edu.co": ["Fundación Universitaria San Martín"],
    ".sanmateo.edu.co": [
        " Fundación Universitaria San Mateo",
        " Fundación Universitaria San Mateo",
    ],
    ".sena.edu.co": [
        "Servicio Nacional de Aprendizaje SENA",
        "National Learning Service SENA",
    ],
    ".sgs.edu.co": ["Saint George School"],
    ".soyucn.edu.co": ["Universidad Católica del Norte"],
    ".soyudemedellin.edu.co": [
        "Universidad De Medellín",
        "University of Medellín",
    ],
    ".systemplus.edu.co": [
        "SystemPlus - Red Nacional de Educación ",
        "SystemPlus - National Education Network ",
    ],
    ".taller5.edu.co": ["Corporación Universitaria Taller 5"],
    ".tdea.edu.co": ["Tecnológico de Antioquia"],
    ".tecnologicadeloriente.edu.co": [
        "Tecnológica del Oriente",
        "Tecnológica del Oriente",
    ],
    ".tecnologicocomfenalco.edu.co": [
        "Fundación Universitaria Tecnológico Comfenalco"
    ],
    ".teinco.edu.co": [
        "Corporación Tecnológica Industrial Colombiana – TEINCO"
    ],
    ".uamerica.edu.co": ["Universidad de América Bogotá"],
    ".uan.edu.co": ["Universidad Antonio Narino"],
    ".uao.edu.co": [
        "Universidad Autonoma de Occidente",
        "Universidad Autonoma de Occidente",
    ],
    ".ucaldas.edu.co": ["Universidad de Caldas"],
    ".ucatolica.edu.co": ["Universidad Católica de Colombia"],
    ".ucauca.edu.co": ["Universidad del Cauca"],
    ".ucc.edu.co": ["Universidad Cooperativa de Colombia"],
    ".ucentral.edu.co": ["Universidad Central"],
    ".uces.edu.co": ["Universidad CES"],
    ".uceva.edu.co": ["Universidad Central del Valle del Cauca"],
    ".ucn.edu.co": ["Universidad Católica del Norte"],
    ".uco.edu.co": ["Universidad Católica del Oriente"],
    ".ucompensar.edu.co": ["Fundación Universitaria Compensar"],
    ".ucp.edu.co": [
        "Universidad Católica de Pereira",
        "https://www.ucp.edu.co/",
    ],
    ".ucundinamarca.edu.co": [
        "Universidad de Cundianamarca",
        "University of Cundinamarca",
    ],
    ".udea.edu.co": ["Universidad de Antioquia", "Universidad de Antioquía"],
    ".udem.edu.co": ["Universidad de Medellín"],
    ".udes.edu.co": ["universidad de Santander"],
    ".udi.edu.co": ["Universidad de investigación y desarrollo - UDI"],
    ".udistrital.edu.co": ["Universidad Distral Francisco José de Caldas"],
    ".uexternado.edu.co": ["Universidad Externado de Colombia"],
    ".ufps.edu.co": ["Universidad Francisco de Paula Santander"],
    ".ufpso.edu.co": [
        "\ufeffUniversidad Francisco de Paula Santander Ocaña, Norte de Santander - Colombia"
    ],
    ".uis.edu.co": ["Universidad Industrial de Santander"],
    ".ulibertadores.edu.co": ["Fundación Universitaria Los Libertadores"],
    ".umanizales.edu.co": ["Universidad de Manizales"],
    ".umariana.edu.co": ["Universidad Mariana"],
    ".umb.edu.co": ["Fundación Universitaria Manuela Beltrán"],
    ".umng.edu.co": ["Universidad Militar Nueva Granada"],
    ".unab.edu.co": ["Universidad Autónoma de Bucaramanga"],
    ".unac.edu.co": ["Universidad Adventista de Colombia"],
    ".unad.edu.co": ["Universidad Nacional Abierta y a Distancia"],
    ".unaula.edu.co": ["Universidad Autónoma Latinoamericana"],
    ".unbosque.edu.co": ["Universidad El Bosque"],
    ".unesam.edu.co": ["Fundación Unidad Educativa San Marcos"],
    ".uniagraria.edu.co": ["Fundación Universitaria Agraria de Colombia"],
    ".uniagustiniana.edu.co": ["Uniagustiniana"],
    ".uniamazonia.edu.co": ["Universidad de La Amazonia"],
    ".uniandes.edu.co": ["Universidad de Los Andes"],
    ".uniatlantico.edu.co": ["Universidad del Atlántico"],
    ".uniautonoma.edu.co": ["Corporacion Universitaria Autonoma del Cauca"],
    ".unibague.edu.co": ["Universidad de Ibagué "],
    ".uniboyaca.edu.co": ["Fundación Universitaria de Boyacá"],
    ".unicartagena.edu.co": [
        "Universidad de Cartagena",
        "University of Cartagena",
    ],
    ".unicatolica.edu.co": ["unicatolica", "unicatolica"],
    ".unicauca.edu.co": ["Universidad del Cauca"],
    ".unicesar.edu.co": ["Universidad Popular del Cesar"],
    ".unicesmag.edu.co": ["Universidad Cesmag"],
    ".uniciencia.edu.co": [
        "Corporación Universitaria de Ciencia y Desarrollo"
    ],
    ".unicienciabga.edu.co": [
        "Corporación Universitaria de Ciencia y Desarrollo UNICIENCIA"
    ],
    ".unicolmayor.edu.co": [
        "Universidad Colegio Mayor de Cundinamarca ",
        "University College of Cundinamarca",
    ],
    ".unicolombo.edu.co": [
        "Fundacion Universitaria Colombo Internacional",
        "Colombo International University Foundation",
    ],
    ".unicomfacauca.edu.co": ["Corporación Universitaria Comfacauca"],
    ".unicordoba.edu.co": ["Universidad de Córdoba"],
    ".uniempresarial.edu.co": [
        "Fundacion Universitaria de la Camara de Comercio de Bogota",
        "Uniempresarial",
    ],
    ".uniguajira.edu.co": ["Universidad de La Guajira"],
    ".unihorizonte.edu.co": [
        "Fundacion Universitaria Horizonte",
        "Fundacion Universitaria Horizonte",
    ],
    ".unihumboldt.edu.co": [
        "Corporación Universitaria Empresarial Alexander von Humboldt"
    ],
    ".unilasallista.edu.co": ["Unilasallista Corporación Universitaria"],
    ".unilatina.edu.co": ["Institución Universitaria Latina Unilatina"],
    ".unilibre.edu.co": ["Universidad Libre de Colombia"],
    ".unilibrebog.edu.co": ["Universidad Libre de Colombia Bogota"],
    ".unilibrepereira.edu.co": ["Universidad Libre, Pereira"],
    ".unillanos.edu.co": ["Universidad de Los Llanos"],
    ".unimagdalena.edu.co": ["Universidad del Magdalena"],
    ".unimayor.edu.co": ["Institución Universitaria Colegio Mayor del Cauca"],
    ".academia.unimeta.edu.co": ["Corporación universitaria del Meta"],
    ".unimetro.edu.co": ["Universidad Metropolitana"],
    ".unimilitar.edu.co": [
        "Universidad Militar Nueva Granada",
        "Universidad Militar Nueva Granada",
    ],
    ".unimonserrate.edu.co": [
        "Fundación Universitaria Monserrate - Unimonserrate"
    ],
    ".unincca.edu.co": ["Universidad INCCA de Colombia"],
    ".alumnos.unincol.edu.co": [
        "Fundación Universitaria Internacional de Colombia UNINCOL"
    ],
    ".uninpahu.edu.co": [
        "UNINPAHU - Fundación Universitaria Para El Desarrollo Humano"
    ],
    ".unipanamericana.edu.co": ["Fundación Universitaria Unipanamericana"],
    ".unipaz.edu.co": ["Instituto Universitario de La Paz"],
    ".unipiloto.edu.co": ["Universidad Piloto de Colombia"],
    ".uniquindio.edu.co": ["Universidad del Quindío"],
    ".unireformada.edu.co": [
        "Corporación Universitaria Reformada",
        "Reformed University Corporation",
    ],
    ".uniremington.edu.co": ["uniremingtonmanizales", "uniremingtonmanizales"],
    ".uniremingtonmanizales.edu.co": ["Uniremington Manizales"],
    ".unisabana.edu.co": ["Universidad de La Sabana"],
    ".unisabaneta.edu.co": [
        "Corporación Universitaria de Sabaneta - UNISABANETA"
    ],
    ".unisangil.edu.co": [
        "Fundación Universitaria de San gil - Unisangil",
        "University Foundation of San Gil - Unisangil",
    ],
    ".unisanitas.edu.co": [
        "Fundación Universitaria Sanitas",
        "Sanitas University Foundation",
    ],
    ".unisarc.edu.co": [
        "Corporación Universitaria Santa Rosa de Cabal (UNISARC)"
    ],
    ".unisimon.edu.co": ["universidad simón bolívar "],
    ".unisimonbolivar.edu.co": [
        "Corporación Educativa Mayor del Desarrollo Simón Bolivar"
    ],
    ".unisinucartagena.edu.co": ["Universidad del Sinú"],
    ".unisucre.edu.co": ["Universidad de Sucre"],
    ".unisucrevirtual.edu.co": [
        "Universidad de sucre (Sincelejo, Sucre)",
        "university of sucre",
    ],
    ".unitec.edu.co": ["Corporación Universitaria UNITEC"],
    ".unitecnar.edu.co": ["Unitecnar"],
    ".unitropico.edu.co": [
        "Fundación Universitaria Internacional del Trópico Americano UNITRÓPICO",
        "International University Foundation of the American Tropics UNITRÓPICO",
    ],
    ".univalle.edu.co": ["Universidad del Valle del Cauca"],
    ".universidadean.edu.co": [
        "Universidad Ean",
        "Emprendiendo un mundo mejor",
        "Escuela de Administración de Negocios",
    ],
    ".upc.edu.co": ["Universidad Piloto de Colombia Students email"],
    ".upn.edu.co": ["Universidad Pedagógica Nacional"],
    ".uqvirtual.edu.co": ["\ufeffUniversidad del Quindío"],
    ".urosario.edu.co": ["Universidad del Rosario"],
    ".correo.usa.edu.co": ["Sergio Arboleda", "Sergio Arboleda"],
    ".usa.edu.co": ["Universidad sergio arboleda"],
    ".usanjose.edu.co": ["Fundacion de educacion superior San Jose"],
    ".usantoto.edu.co": ["Universidad Santo Tomás"],
    ".usantotomas.edu.co": ["Universidad Santo Tomás"],
    ".usb.edu.co": ["Universidad de San Buenaventura"],
    ".academia.usbbog.edu.co": ["Universidad de san buenaventura Bogotá"],
    ".usbcali.edu.co": ["Universidad de San Buenaventura Cali"],
    ".usc.edu.co": ["Universidad Santiago de Cali"],
    ".usco.edu.co": ["Universidad Surcolombiana", "Surcolombian university"],
    ".usergioarboleda.edu.co": ["Universidad Sergio Arboleda"],
    ".usta.edu.co": ["Universidad Santo Tomás", "Santo Tomas University"],
    ".ustadistancia.edu.co": [
        "Universidad Santo Tomas",
        "Santo Tomas University",
    ],
    ".ut.edu.co": ["Universidad del Tolima"],
    ".utadeo.edu.co": ["Universidad de Bogotá Jorge Tadeo Lozano"],
    ".utap.edu.co": ["Universidad Tecnológica Autónoma del Pacífico", " "],
    ".utb.edu.co": [
        "Universidad Tecnológica de Bolivar",
        "Technological University of Bolivar",
    ],
    ".utede.edu.co": [
        "Utedé - Unidad Técnica para el Desarrollo Profesional",
        "Utedé - Technical Unit for Professional Development",
    ],
    ".utp.edu.co": ["Universidad Tecnológica de Pereira"],
    ".uvirtual.edu.co": ["Universidad Virtual Internacional"],
    ".uco.net.co": ["Universidad Católica de Oriente"],
    ".simplon.co": ["Simplon.co"],
    ".barker.college": ["Barker College"],
    ".cdi.college": ["CDI College"],
    ".scots.college": ["The Scots College Sydney"],
    ".thespires.college": ["The Spires College"],
    ".uckfield.college": ["Uckfield College", "www.uckfield.college"],
    ".125su.com": ['125 СУ "Боян Пенев"', '125 SU "Boqn Penev"'],
    ".2els.com": [
        'Second English Language School "Thomas Jefferson"',
        'Second English Language School "Thomas Jefferson"',
    ],
    ".2isa.com": [
        "Institut Informatique Sud Aveyron",
        "Website: http://www.2isa.com/",
        "trainers emails at @2isa.com for example gg@2isa.com",
        "student emails at @2isa.org for example sergey.epifanov@2isa.org",
    ],
    ".student.42amman.com": ["42Amman"],
    ".42bangkok.com": ["42 บางกอก", "42 Bangkok"],
    ".42barcelona.com": ["42 Barcelona"],
    ".42lisboa.com": ["42 Lisboa"],
    ".42london.com": ["42 London"],
    ".42madrid.com": ["42 Madrid"],
    ".42malaga.com": ["42 Málaga"],
    ".student.42prague.com": ["42 Prague"],
    ".42prague.com": ["42 Prague"],
    ".42quebec.com": ["42 Québec"],
    ".42urduliz.com": ["42 Urduliz"],
    ".a-s-b.com": ["American School of Barcelona"],
    ".abmcollege.com": ["ABM College"],
    ".academia-ciberseguridad.com": ["Academia de Ciberseguridad"],
    ".academialuisvives.com": ["Academia Luis Vives"],
    ".accitesz.com": [
        "Instituto Tecnologico de Estudios Superiores de Zamora",
        "Technological Institute of Superior Studies of Zamora",
    ],
    ".acdeducation.com": ["Assumption College of Davao"],
    ".aclcbukidnon.com": [
        "ACLC Bukidnon",
        "AMA Computer Learning Center Bukidnon",
    ],
    ".acs-schools.com": ["ACS International School"],
    ".actonlascruces.com": ["Acton Academy Mesilla Valley"],
    ".adenformations.com": ["ADEN Formations"],
    ".aditanarcollege.com": ["Aditanar College of Arts and Science"],
    ".adithyatech.com": ["Adithya Institute Of Technology"],
    ".adygimi.com": ["Debreceni Ady Endre Gimnázium"],
    ".aeasofia.com": ["American English Academy", "American English Academy"],
    ".aecarcavelos.com": [
        "Escola Secundária de Carcavelos",
        "Carcavelos High School",
    ],
    ".aemaia.com": ["Escola Secundária da Maia"],
    ".aescolasalpendorada.com": [
        "Agrupamento de Escolas de Alpendorada",
        "Alpendorada School Cluster",
    ],
    ".afip-formations.com": ["AFIP FORMATIONS", "AFIP FORMATIONS"],
    ".agenlaacademy.com": [
        "Agenla Academy Institute",
        "Agenla Academy Institute",
    ],
    ".agk88.com": ["Adana Gündoğdu Koleji", "Adana Gundogdu College"],
    ".agmrcet.com": ["A G M R College of Engineering and Technology"],
    ".ahlulbaitonline.com": ["Ahlulbait International University"],
    ".ahschool.com": ["American Heritage School"],
    ".albertschool.com": ["Albertschool"],
    ".algonquincollege.com": ["Algonquin College"],
    ".algonquinlive.com": ["Algonquin College"],
    ".algosup.com": ["algosup"],
    ".almaarifah.com": ["Knowledge International University"],
    ".alorubaschools.com": ["Al Oruba International Schools"],
    ".alterecole.com": ["Alter Ecole"],
    ".stu.altusps.com": ["Altus High School"],
    ".alueducation.com": ["African Leadership University"],
    ".alunocesul.com": ["CESUL - Centro Sulamericano de Ensino Superior"],
    ".alunouninter.com": ["Centro Universitário Internacional Uninter"],
    ".alustudent.com": ["African Leadership University"],
    ".alwadischool.com": [
        "مدارس الوادي العالمية",
        "Alwadi International School",
    ],
    ".alzago.com": ["Alzago, Escuela de Nuevas Tecnologías"],
    ".amarillocollege.com": [
        "Name: Amarillo College",
        "Address: 2011 South Washington Street, Amarillo, TX 79109",
        "ZIP Code: 79109",
        "Website: www.actx.edu",
    ],
    ".amityonline.com": ["Amity University"],
    ".amrolicollege.com": ["AMROLI COLLEGE"],
    ".anangpuria.com": [
        "B.S. ANANGPURIA INSTITUTE OF TECHNOLOGY AND MANAGEMENT"
    ],
    ".andalusiaquranicschool.com": ["Andalusia Quranic School"],
    ".andela.com": ["Andela"],
    ".anhanguera.com": ["Universidade Anhanguera"],
    ".animashighschool.com": ["Animas High School"],
    ".aoltoronto.com": [
        "Academy of Learning Bay/Queen",
        "Academy of Learning Bay/Queen",
    ],
    ".armypublicschoolagra.com": ["Army Public School"],
    ".artidisseny.com": ["Escola Municipal d'Art de Terrassa"],
    ".ashtoncollege.com": ["Ashton College"],
    ".asoiu.com": ["ASIPM department, Omsk State Technical University"],
    ".aston-ecole.com": ["Aston Ecole", "Aston School"],
    ".atc2u.com": ["Advance Tertiary College"],
    ".atlasschool.com": ["Atlas School"],
    ".audencia.com": ["Audencia Nantes - School of management"],
    ".students.aula-ee.com": ["Aula Escola Europea Students"],
    ".aula-ee.com": ["Aula Escola Europea"],
    ".ausiasmarch.com": [
        "Colegio Internacional Ausias March",
        "https://www.ausiasmarch.com",
    ],
    ".b-zvi.com": ['ביה"ס התיכון ע"ש בן צבי', "Ben Zvi High School"],
    ".bakliwaltutorials.com": ["Bakliwal Tutorials"],
    ".basischina.com": ["Basis International Shenzhen"],
    ".basised.com": ["BASIS San Antonio - Shavano Campus"],
    ".basisindependent.com": ["Basis Independent Silicon Valley"],
    ".bbailigan.com": [
        "Bethany Baptist Academy, Iligan City",
        "Bethany Baptist Academy, Iligan City",
    ],
    ".st.bcc1852.com": ["Bangkok Christian College"],
    ".berkeleycr.com": ["BERKELEY ACADEMY FOR MULTICULTURAL STUDIES"],
    ".students.berlinsbi.com": [
        "Berlin School of Business and Innovation (BSBI)"
    ],
    ".bernardsboe.com": ["Bernards Township School District"],
    ".bic-benal.com": ["The Benalmádena International College"],
    ".bis-school.com": ["Bavarian International School"],
    ".bishanoi.com": [
        "British International School, Hanoi (Trường Quốc Tế Đa Cấp Anh - Hà Nội)"
    ],
    ".bishopstopford.com": ["Bishop Stopford School"],
    ".bisspuxi.com": [
        "The British International School Shanghai, Puxi (Nord Anglia Education)"
    ],
    ".bisvietnam.com": [
        "British International School, Ho Chi Minh City (Trường Quốc Tế Đa Cấp Anh - Thành phố Hồ Chí Minh)"
    ],
    ".bj35.com": ["No.35 high school of Beijing"],
    ".bloomtech.com": ["bloomtech"],
    ".bluecoatschool.com": ["Blue Coat C of E School Coventry"],
    ".bmcmedcollege.com": ["Al-Batterjee Medical College"],
    ".bohunthorsham.com": ["Bohunt Horsham"],
    ".bohuntwokingham.com": ["Bohunt School Wokingham"],
    ".bonsecours66.com": ["Lycée notre dame de bon secours"],
    ".bosworthcollege.com": ["Bosworth Independent College"],
    ".bothouniversity.com": ["Botho Univerisity"],
    ".bpitindia.com": ["Bhagwan Parshuram Institute of Technology"],
    ".bpp.com": ['"BPP" '],
    ".bramptoncollege.com": ["Brampton College"],
    ".brantfordcollege.com": ["Brantford College of Technology"],
    ".brest-opencampus.com": ["brest-opencampus"],
    ".breyerstate.com": ["Breyer State University (Virtual University)"],
    ".my.browardschools.com": [
        "West Broward High School",
        "West Broward High School",
    ],
    ".brownsburgstudents.com": ["Brownsburg High School"],
    ".bsb-education.com": ["Burgundy School of Business"],
    ".buchananschools.com": ["Buchanan Community Schools"],
    ".buraouniversity.com": ["University of Burao"],
    ".burntwoodschool.com": ["Burntwood School"],
    ".burygrammar.com": ["Bury Grammar School"],
    ".bvishanoi.com": [
        "British Vietnamese International School, Hanoi (Trường Quốc Tế Đa Cấp Anh Việt - Hà Nội)"
    ],
    ".bvisvietnam.com": [
        "British Vietnamese International School, Ho Chi Minh City (Trường Quốc Tế Đa Cấp Anh Việt - Thành phố Hồ Chí Minh)"
    ],
    ".bwscampus.com": ["Brentwood School"],
    ".c-isd.com": ["Cleburne Independent School District"],
    ".caistorgrammar.com": ["Caistor Grammar School"],
    ".campioncollege.com": ["Campion College"],
    ".campus-cd.com": ["EPSI", "EPSI"],
    ".campus-id.com": ["Campus Id"],
    ".campusaula.com": ["Aula Campus"],
    ".campuscamarafp.com": ["Campus Cámara FP", "Campus Cámara FP"],
    ".campusdigitalfp.com": ["Campus Digital FP"],
    ".canadahanson.com": ["Hanson College"],
    ".canadiancollege.com": ["Canadian College"],
    ".canford.com": [
        "Independent Co-educational Boarding Dorset UK | Canford School"
    ],
    ".careerdevs.com": [
        "CareerDevs Computer Science University",
        "CareerDevs",
    ],
    ".carfax-college.com": ["Carfax Education"],
    ".carfax-education.com": ["Carfax Education"],
    ".carrollwooddayschool.com": ["Carrollwood Day School"],
    ".cchsrams.com": ["Central Catholic High School"],
    ".ccndpr.com": ["Colegio Cat�lico Notre Dame"],
    ".ccsdschools.com": ["Charleston County School District, South Carolina"],
    ".cdsantodomingo.com": ["Colegio Diocesano Santo Domingo"],
    ".centralcatholichs.com": [
        "Central Catholic High School, Pittsburgh Pennsylvania"
    ],
    ".centrosanluis.com": ["Centro San Luis"],
    ".ceste.com": ["CESTE, Escuela Internacional de Negocios"],
    ".cesurformacion.com": ["CESUR FORMACIÓN"],
    ".cesurg.com": ["Cesurg"],
    ".cev.com": ["CEV"],
    ".cfedundrum.com": ["Dundrum College of Further Education"],
    ".cfpj.com": [
        "Centre de Formation et de Perfectionnement des Journalistes"
    ],
    ".chapeltownacademy.com": ["Chapeltown Academy"],
    ".chethams.com": ["Chetham's School of Music"],
    ".chippingsodburyschool.com": ["Chipping Sodbury School"],
    ".chrysalis-school.com": ["Chrysalis School"],
    ".churchdownschool.com": ["Churchdown School"],
    ".churcherscollege.com": ["  Churcher's College"],
    ".cic-cairo.com": ["Canadian International College"],
    ".ciclosmontecastelo.com": ["Formación Profesional Montecastelo"],
    ".cieep.com": ["Centro de formación Profesional Progresa Formación"],
    ".cifacom.com": ["Cifacom"],
    ".cinnaminson.com": [
        "Board of Education of the Township of Cinnaminson",
        "Cinnaminson Township Public Schools",
        ".group",
    ],
    ".alu.cipfpvalledeelda.com": ["CIPFP Valle de Elda"],
    ".clarendonacademy.com": ["Clarendon Academy"],
    ".cmscbe.com": ["CMS College of Science & Commerce"],
    ".codecool.com": ["Code Cool", "Code Cool"],
    ".colegioanamariamatute.com": ["Ana María Matute"],
    ".alumnos.colegiobrains.com": ["Brains International Schools"],
    ".colegioirlandesas.com": ["Colegio irlandesas", "Irish school "],
    ".colegiolitterator.com": ["Colegio Litterator"],
    ".aluno.colegionos.com": ["Colegio Nós"],
    ".colegiosja.com": ["Colegio San Juan Apostol y Evangelista"],
    ".colegiovivas.com": ["Colegio Vivas "],
    ".colfes.com": ["Colfe's School"],
    ".collegecanada.com": ["Canada College / Collège Canada"],
    ".collegelasalle.com": ["LaSalle College / Collège LaSalle"],
    ".collierschools.com": ["Collier County Schools"],
    ".columbushs.com": ["Christopher Columbus High School"],
    ".columbusu.com": ["Columbus University"],
    ".colytongrammar.com": ["Colyton Grammar School"],
    ".comcave.com": ["Comcave College"],
    ".confetti-live.com": ["Confetti Institute of Creative Technologies"],
    ".coppellisd.com": [
        "Coppell Independent School District",
        "Coppell High School",
    ],
    ".coresteam.com": ["Core School"],
    ".coursdiderot.com": ["Cours Diderot, France"],
    ".cpilosenlaces.com": [
        "Centro Público Integrado de Formación Profesional Los Enlaces",
        "Integrated Public Vocational Training Center",
    ],
    ".cpschools.com": ["Chesapeake Public Schools", ".group"],
    ".cpsglobalschool.com": [
        "CPS GS ANNANAGAR",
        "CPS Global School Annanagar",
    ],
    ".cqumail.com": ["Central Queensland University (CQU) "],
    ".crescent.com": [
        "B.S.Abdur Rahman Crescent Institute of Science and Technology"
    ],
    ".crsmu.com": ["Crimea State Medical University"],
    ".cs2i-bourgogne.com": ["CS2I Bourgogne"],
    ".csafa.com": [
        "Colegio Sagrada Familia Zaragoza",
        "Sagrada Familia School, Zaragoza",
    ],
    ".cse-strasbourg.com": ["Collège Episcopal Saint-Etienne"],
    ".csgrammar.com": ["Chiselhurst and Sidcup Grammar School"],
    ".csioviedo.com": ["Colegio \xa0San Ignacio"],
    ".csist.com": ["四川成都软件技术专修学院"],
    ".cusd80.com": ["Chandler Unified School District"],
    ".cusdstudent.com": ["Clovis North High School"],
    ".d4university.com": ["D4 University", "D4 University"],
    ".daarululuumlido.com": ["MA Daarul Uluum Lido", "MA Daarul Uluum Lido"],
    ".davjalandhar.com": ["DAV College Jalandhar"],
    ".dcmschoolambala.com": ["DCM Senior Secondary School"],
    ".debhiss.com": [
        "DEBHIS School",
        "Daunne English Boarding Secondary School, Bardaghat, Nawalparasi, Lumbini, Nepal",
    ],
    ".desheng-school.com": [
        "广东顺德德胜学校",
        "Guangdong Shunde Desheng School",
    ],
    ".dgg-gz.com": ["Dossenberger-Gymnasium Günzburg"],
    ".digitalartschool.com": [
        "Create digitalartschool.txt",
        "http://www.digitalartschool.com",
        "100-1632 Dickson Avenue • Kelowna, British Columbia • V1Y 7T2",
    ],
    ".digitechfp.com": ["Digitech FP", "Digitech FP"],
    ".dijonformation.com": ["Dijon Formation"],
    ".dixonsba.com": ["Dixons Broadgreen Academy"],
    ".dlevh.com": [
        "Lev Hasharon Democratic School",
        "בית הספר הדמוקרטי לב השרון",
    ],
    ".dnsalbarsha.com": ["Dubai national school", "Dubai National School"],
    ".docchula.com": ["Faculty of Medicine, Chulalongkorn University"],
    ".doonschool.com": ["The Doon School"],
    ".doverbroecks.com": ["D'Overbroecks School "],
    ".dpsgfaridabad.com": [
        "Delhi Public School Greater Faridabad",
        "Delhi Public School Greater Faridabad",
    ],
    ".dpsjaipur.com": ["Delhi Public School"],
    ".dpsmisdoha.com": ["DPS-Modern Indian School"],
    ".dpssrinagar.com": ["Delhi Public School Srinagar"],
    ".drgitr.com": ["Dr. Rajendra Gode Institute of Technology and Research"],
    ".dsbarcelona.com": [
        "Deutsche Schule Barcelona",
        "German School of Barcelona",
    ],
    ".dsisdconnect.com": ["Dripping Springs High School"],
    ".dstoulouse.com": [
        "Deutsche Schule Toulouse",
        "German School of Toulouse",
    ],
    ".e-cdp.com": ["Collège de Paris"],
    ".eastbarnetschool.com": ["East Barnet School"],
    ".edu.ebs-paris.com": ["European Business School"],
    ".ecam-rennes.com": ["ECAM Rennes"],
    ".ecccomp.com": [
        "ECCコンピュータ専門学校",
        "ECC College of Computer & Multimedia",
    ],
    ".eccoschool.com": ["Ecclesfield School"],
    ".ece-france.com": ["BBA INSEEC - Ecole de Commerce Européenne"],
    ".ecnudec.com": [
        "华东师范大学开放教育学院",
        "School of Open Learning and Education",
    ],
    ".ecole-artcom.com": ["Artcom - Ecole de Design", "Artcom Design Scool"],
    ".ecole-hexagone.com": ["École Hexagone"],
    ".ecole-ipssi.com": [
        "IPSSI - École d’Informatique, Web et Design Graphique"
    ],
    ".ecole-multimedia.com": ["Ecole Multimédia"],
    ".ecole-webstart.com": ["Webstart"],
    ".ecole2600.com": ["École 2600"],
    ".lyn.ecolescreatives.com": ["CinéCréatis"],
    ".ecolescreatives.com": [
        "Ecoles Creatives",
        "ESMA",
        "Ecole Supérieure Des Métiers Artistiques",
        "CinéCréatis",
        "Icône",
        ".group",
    ],
    ".ecolesourphagop.com": ["L'École arménienne Sourp Hagop"],
    ".edhec.com": ["Ecole des Hautes Etudes Commerciales du Nord"],
    ".eemi.com": ["École Européenne des Métiers de l'Internet"],
    ".eep-igroup.com": [
        "eep igroup",
        "Escuela de Estudios Profesionales iGroup",
    ],
    ".efficom-lille.com": ["Efficom Lille"],
    ".eg-plovdiv.com": ["Plovdiv Language School"],
    ".eieonline.com": ["European Institute of Education"],
    ".eitiedu.com": [
        "Ekibastuz technical and engineering institute (Kazakshstan, Pavlodar Province, Ekibastuz)"
    ],
    ".ekyaschools.com": ["Ekya Schools, Bangalore"],
    ".eleve-istp.com": ["Institut Supérieur des Techniques de la Performance"],
    ".ellabts.com": ["Lycée Ella Fitzgerald"],
    ".elorrieta-errekamari.com": ["CIFP Elorrieta-Erreka Mari LHII"],
    ".em-lyon.com": ["Ecole Supérieure de Commerce de Lyon"],
    ".emc-campus.com": ["European Management Center Paris"],
    ".edu.emlyon.com": ["emlyon business school"],
    ".e.enae.com": ["School of International Business, University of Murcia"],
    ".enigma-school.com": ["HIGHER SCHOOL OF COMPUTER SCIENCE IN LILLE"],
    ".ensci.com": [
        "École nationale supérieure de création industrielle (ENSCI - Les Ateliers)"
    ],
    ".ensemblescolaire-niort.com": [
        "ICSSA",
        "Institut Supérieur Saint André",
        "Based at Niort 79 FRANCE",
        "@ensemblescolaire-niort.com",
    ],
    ".ensworth.com": ["Ensworth High School"],
    ".epinfante.com": ["Escola Profissional do Infante"],
    ".epschoolsri.com": ["East Providence Public Schools"],
    ".esat-alumni.com": [
        "\ufeffEscuela Superior de Arte y Tecnología de Valencia"
    ],
    ".esc-amiens.com": [
        "Ecole Supérieure de Commerce Amiens",
        "Business School Amiens",
    ],
    ".esc-cybersecurity.com": ["European School of Cybersecurity"],
    ".escapestudios.com": ["Escape Studios"],
    ".escdijon.com": ["Ecole Supérieure de Commerce de Dijon"],
    ".esiitech-gabon.com": [
        "ECOLE SUPERIEURE D'INGENIERIE ET D'INNOVATION (ESIITECH)"
    ],
    ".espic.com": ["Espic", "Espic"],
    ".esprit-tn.com": [
        "Ecole Superieure Privee d'Ingenierie et de Technologies"
    ],
    ".essat-gabes-elearning.com": [
        "Ecole Supérieure des Sciences Appliquées et de la Technologie Privée de Gabès",
        "Private Higher School of Applied Sciences and Technology of Gabès",
    ],
    ".essat-gabes.com": [
        "Ecole Supérieure des Sciences Appliquées et de la Technologie Privée de Gabès",
        "Private Higher School of Applied Sciences and Technology of Gabès",
    ],
    ".ga.essd40.com": ["Excelsior Springs High School"],
    ".esst-sup.com": [
        "École Supérieure des Sciences et technologie ",
        "Higher School of Science and Technology",
    ],
    ".estiam.com": [
        "ÉSTIAM - École supérieure des technologies de l'information appliquées aux métiers"
    ],
    ".eticalgarve.com": ["Etic Algarve"],
    ".europaskolan.com": ["Europaskolan Strängnäs"],
    ".es05.euroschoolindia.com": ["Euro School India"],
    ".evadformacion.com": [
        "EVAD - Escuela Superior de Videojuegos y Arte Digital",
        "EVAD",
    ],
    ".evolis3d.com": ["Evolis3D", "Evolis3D"],
    ".fac-lisaa.com": ["ESG - Ecole de commerce"],
    ".fakultetpim.com": [
        "Univerzitet za poslovni inženjering i menadžment",
        "University for business engineering and management",
    ],
    ".fallschurchrobotics.com": ["Falls Church High School Robotics"],
    ".fenelon-notredame.com": ["Fenelon Notre-Dame"],
    ".fernando3martos.com": ["I.E.S FERNANDO III MARTOS - JAÉN"],
    ".fgschools.com": ["Ponaganset High School"],
    ".fitstic-edu.com": ["FITSTIC"],
    ".estudiant.fjaverianas.com": ["ETP Xavier"],
    ".flatironschool.com": ["Flatiron School"],
    ".fondespierre.com": ["Fondespierre RH"],
    ".student.fortbendisd.com": ["Quail Valley Middle School"],
    ".schueler.fosbos-mm.com": ["FOSBOS Memmingen", "FOSBOS Memmingen"],
    ".foundationu.com": ["Foundation University"],
    ".foundationuniversity.com": ["Foundation University"],
    ".fpdrioja.com": [
        "Centro integrado público de formación profesional a distancia de La Rioja",
        "https://fpdrioja.es/desarrollo-de-aplicaciones-web-2/",
    ],
    ".fpf-etech.com": [
        "Technological School Desembargador Paulo Feitoza – Etech"
    ],
    ".fpfomento.com": ["Formación Profesional Fomento"],
    ".fpt.com": ["FPT University", "FPT University"],
    ".fpzornotza.com": ["FP Zornotza"],
    ".frhsd.com": ["Freehold High School"],
    ".ftmsglobal.com": ["FTMS Global Academy"],
    ".fullsail.com": ["Full Sail University"],
    ".furzeplatt.com": ["Furze Platt Senior School"],
    ".gardenrayong.com": [
        "Garden International School",
        "188/24 Moo 4 Pala-Ban Chang Road, Tambol Pala, Amphur Ban Chang, Rayong, Thailand 21130",
    ],
    ".student.gatewayhs.com": ["Gateway Regional High School"],
    ".gaursinternationalschool.com": ["Gaurs International School"],
    ".gcsnc.com": ["Guilford County Public Schools"],
    ".gdgoenkasurat.com": [
        "G D Goenka International School ",
        "http://www.gdgoenkasurat.com/",
    ],
    ".generalestudis.com": [
        "General Estudis Online Lleida",
        "https://generalestudis.com/",
    ],
    ".george-heriots.com": ["George Heriot's School"],
    ".georgegreens.com": ["George Green's School"],
    ".etu.gip-cei.com": [
        "Ecole Supérieur de Logistique Industrielle",
        "Higher School of Industrial Logistics",
    ],
    ".gisma-education.com": ["Gisma"],
    ".gisma-student.com": ["Gisma University of Applied Sciences"],
    ".gitjaipur.com": ["Global Institute of Technology, Jaipur"],
    ".gladesmore.com": ["Gladesmore Community School"],
    ".gladesmorestudent.com": ["Gladesmore Community School"],
    ".globalopencampus.com": ["L'OPEN CAMPUS D'ANGERS", "Open Campus"],
    ".goandalus.com": ["Al andalus private schools"],
    ".gocva.com": ["Carrabassett Valley Academy"],
    ".gollisuniversity.com": ["Gollis University"],
    ".gravesendgrammar.com": ["Gravesend Grammar School"],
    ".greenecountyschools.com": [
        "William Monroe High School",
        "William Monroe High School",
    ],
    ".greenvilleisd.com": ["Greenville ISD"],
    ".grenoble-em.com": ["Grenoble Ecole de Management"],
    ".grietcollege.com": [
        "Gokaraju Rangaraju Institute of Engineering and Technology",
        "Gokaraju Rangaraju Institute of Engineering and Technology",
    ],
    ".groupe-esc-troyes.com": ["Groupe ESC Troyes"],
    ".groupe-gema.com": ["IA School"],
    ".groupe-igslyon.com": ["IPI Lyon"],
    ".groupeiam.com": [
        "Institut Africain de Management",
        "African Institute of Management",
    ],
    ".groupeisi.com": [
        "Institut Supérieur d'Informatique (Groupe ISI)",
        "Institut Supérieur d'Informatique (Groupe ISI)",
    ],
    ".grupofleming.com": ["Grupo Fleming"],
    ".gtu-info.com": ["Gujarat technology University"],
    ".gusto-education.com": ["GUSTO University"],
    ".student.h-farm.com": ["H-FARM College"],
    ".student.h-is.com": [
        "H-International School",
        "H-Farm International School",
        ".group",
    ],
    ".h-is.com": ["H-FARM International School"],
    ".halcyonschool.com": ["Halcyon London International School"],
    ".hallamcitycampus.com": ["Hallam City Campus"],
    ".hamidaligirlsintercollege.com": [
        "Hamid Ali Girls Inter College",
        "Hamid Ali Girls Inter College",
    ],
    ".haringtonschool.com": ["Harrington School"],
    ".hartismere.com": ["Hartismere School"],
    ".headstartphuket.com": ["HeadStart International School Phuket"],
    ".hessleacademy.com": ["Hessle High School and Sixth Form College"],
    ".hfamilie.com": ["Instituut Heilige Familie Sint-Niklaas"],
    ".hilcoeschool.com": ["HiLCoE School of Computer Science And Technology"],
    ".hnsoftedu.com": [
        "湖南软件职业技术大学",
        "Hunan Software Vocational and Technical University",
    ],
    ".hnxxc.com": ["潇湘职业学院", "xiaoxiang vocational college"],
    ".holbertonschool.com": ["Holberton School"],
    ".holbertonstudents.com": ["Holberton Students"],
    ".hollandcollege.com": ["Holland College"],
    ".htl-shkoder.com": ['Österreichische Schule "Peter Mahringer"'],
    ".htlinternationalschool.com": ["HTL International School"],
    ".hualangschool.com": [
        "深圳华朗国际学校",
        "shenzhen hualang international school",
    ],
    ".hudsonhs.com": ["Hudson High School of Learning Technologies"],
    ".hw.com": ["Harvard Westlake"],
    ".hwemail.com": ["Harvard Westlake"],
    ".hzcollege.com": [
        "惠州经济职业技术学院",
        "Huizhou Ecomonics And Polytechnic College",
    ],
    ".iae-aix.com": [
        "Institut d'Administration des Entreprises (Aix-en-Provence, France)"
    ],
    ".iae-toulouse.com": [
        "Institut d'Administration des Entreprises (Toulouse, France)"
    ],
    ".iamacolt.com": ["Christian Community School"],
    ".iamburkina.com": ["Institut Africain de Management, Burkina Faso"],
    ".doz.ibadual.com": ["Iba – Internationale Berufsakademie"],
    ".stud.ibadual.com": [
        "iba - Internationale Berufsakademie der F+U Unternehmensgruppe gGmbH",
        "iba - University of Cooperative Education",
    ],
    ".ibnuchaldun.com": ["Universitas Ibn Chaldun Jakarta"],
    ".ici-luzern.com": ["International Culinary Institute (ICI)"],
    ".icn-artem.com": ["ICN Business School ARTEM"],
    ".icn-nancy.com": ["Institut Commercial de Nancy"],
    ".icsmilan.com": [
        "ICS Milan",
        "https://icsmilan.com",
        "IGCSE & DP Computer Science",
    ],
    ".icsw.com": ["Institute of Clinical Social Work"],
    ".idbbxl.com": ["Institut Don Bosco Woluwe-Saint-Pierre"],
    ".ideponline.com": ["IDEP Barcelona"],
    ".alumni.iebschool.com": ["IEBS Business School", "IEBS Business School"],
    ".iemcal.com": ["Institute of Engineering and Management"],
    ".iesanetwork.com": ["IESA multimédia"],
    ".iesblecua.com": ["IES José Manuel Blecua"],
    ".iescampanillas.com": ["Ies Campanillas "],
    ".iescastelar.com": ["IES Castelar (Badajoz)"],
    ".iesciudadjardin.com": [
        "Instituto de educación secundaria Ciudad Jardín (Sevilla)"
    ],
    ".iescomercio.com": ["IES Comercio"],
    ".iesdoctorbalmis.com": [
        'Instituto de Educación Secundaria "Doctor Balmis"'
    ],
    ".iesebre.com": ["Institut de l'Ebre"],
    ".ieselcalamot.com": ["IES El Calamot"],
    ".iesemilidarder.com": ["Institut d'Educació Secundària i FP"],
    ".iesiliberis.com": [
        "Instituto de Educación Secundaria Ilíberis",
        "IES Ilíberis",
        "I.E.S Ilíberis",
    ],
    ".iesleopoldoqueipo.com": ["IES. Leopoldo Queipo"],
    ".iesmarenostrum.com": ["IES Mare Nostrum (Alicante)"],
    ".iesmiguelherrero.com": ["IES Miguel Herrero (Cantabria)"],
    ".iesmutxamel.com": ["IES MUTXAMEL", "Secondary Institute MUTXAMEL"],
    ".iespabloserrano.com": [
        "Instituto de Educación Secundaria Pablo Serrano"
    ],
    ".iessanandres.com": ["IES San Andres"],
    ".iessanisidoro.com": ["IES San Isidoro"],
    ".iessantiagohernandez.com": [
        "Instituto de Educacion Secundaria Santiago Hernandez"
    ],
    ".iessierradesanjorge.com": ["IES Sierra de San Jorge"],
    ".iestacio.com": ["IES l'ESTACIO", "IES l'ESTACIO"],
    ".iesvirgendelcarmen.com": ["IES Virgen del Carmen (Jaén)"],
    ".ifnti.com": [
        "Institut de Formation aux Normes et Technologies de l'informatique"
    ],
    ".ifp-school.com": ["IFP School"],
    ".igensia.com": ["Campus Igensia Toulouse - Ecole en Informatique IPI"],
    ".ipi.igsgroupe.com": [
        "University from Paris ",
        "Institut Poly Informatique",
        "http://www.ipi-ecoles.com/",
    ],
    ".iihtsrt.com": [
        "Indian Institute of Hardware Technology,Surat,Gujarat,India"
    ],
    ".iimtu.com": ["iimtu"],
    ".iimtuniversity.com": ["IIMT University"],
    ".iitmjanakpuri.com": [
        "Institute of Information Technology and Management, Janakpuri"
    ],
    ".ikzubirimanteo.com": ["IES Zubiri-Manteo BHI"],
    ".alumnes.ilerna.com": ["Ilerna lleida"],
    ".alumnos.ilerna.com": ["Ilerna madrid"],
    ".alumnos.ilernaonline.com": ["ILERNA", "ILERNA"],
    ".imerir.com": [
        "Institut Méditerranéen d'Etude et de Recherche en Informatique et Robotique"
    ],
    ".imf.com": ["IMF Business School", "IMF Business School"],
    ".imi-luzern.com": ["International Hotel Management Institute"],
    ".impspolytech.com": ["IMPS Polytechnic College, Jalpaiguri"],
    ".imsnoida.com": ["IMS noida"],
    ".indoreinstitute.com": [
        "Indore Institute of Science and Technology",
        "Indore Institute of Science and Technology",
    ],
    ".indusschoolhyd.com": ["Indus International School Hyderabad"],
    ".indusschoolpune.com": ["Indus International School, Pune"],
    ".infouniron.com": ["Faculdade Interamericana de Porto Velho"],
    ".ingesup.com": ["Ingésup - Ecole supérieure d'ingénierie informatique"],
    ".initcollege.com": ["International IT College of Sweden"],
    ".inseec-edu.com": [
        "Institut des hautes études économiques et commerciales"
    ],
    ".inseec-france.com": ["INSEEC"],
    ".institutotimoteo.com": ["Instituto Timoteo"],
    ".institutsolacroup.com": ["Institut Marie-Thérèse Solacroup"],
    ".intedgroup.com": ["Inted Group"],
    ".doz.internationale-ba.com": [
        "iba - University of Cooperative Education",
        "iba - Internationale Berufsakademie der F+U Unternehmensgruppe gGmbH",
    ],
    ".intisana.com": ["Colegio Intisana"],
    ".ionis-stm.com": ["Ionis School of Technology and Management"],
    ".iou-students.com": ["Islamic Online University"],
    ".ipnetinstitute.com": ["IPNet Institute of Technology"],
    ".ipsksa.com": [
        "International Programs School",
        "International Programs School, Prince Sultan Road, Qurtoba, Al Khobar 34236, Saudi Arabia",
    ],
    ".ipssi-lyon.com": ["École Informatique IP Formation Lyon"],
    ".irup.com": [
        "Irup: Institut régional universitaire polytechnique",
        "Regional Institute University Polytechnique",
    ],
    ".student.isartdigital.com": [
        "Isart Digital Paris",
        "https://www.isart.com/en/",
    ],
    ".isartdigital.com": ["ISART Digital"],
    ".isbatuniversity.com": [
        "isbatuniversity",
        "International School of Business and Tecnology University",
    ],
    ".isbm-school.com": ["International School of Business Management"],
    ".isboman.com": ["Indian School Bousher", "Indian School Bousher"],
    ".iscmosuperiori.com": ["Istituto Sacro Cuore"],
    ".edu.iscomo.com": ["International School of Como"],
    ".iscparis.com": ["iscparis"],
    ".isd284.com": ["Wayzata High School", "Wayzata Schools", ".group"],
    ".islamicug.com": ["Islamic University College"],
    ".it-akademija.com": ["It Akademija"],
    ".itd-hub.com": [
        "Institut des Technologies du Digital",
        "Digital Technology Institute",
    ],
    ".iticparis.com": [
        "Institut des Techniques Informatiques et Commerciales",
        "Institute of Information Technology and Commercial Techniques",
        "ITIC Paris",
    ],
    ".itismeucci.com": ["ITIS Antonio Meucci, Firenze IT"],
    ".itisvinci.com": ["ITIS Leonardo Da Vinci, Carpi (MO)"],
    ".itlearning-settat.com": ["IT Learning Campus Pole dévelopement"],
    ".itsdigitalacademy.com": ["ITS Digital Academy Mario Volpato, Italy"],
    ".ituniversity-mg.com": ["IT University"],
    ".iu-travnik.com": ["International University of Travnik"],
    ".ivgpu.com": [
        "Федеральное государственное бюджетное образовательное учреждение высшего образования «Ивановский государственный политехнический университет»",
        "Federal State Budget Educational Institution of Higher Education «Ivanovo State Polytechnic University»",
    ],
    ".jbdelasalle.com": ["Ensemble scolaire Jean-Baptiste de La Salle"],
    ".jeffstateonline.com": ["Jefferson State Community College"],
    ".johntalabot.com": ["John Talabot Parvulari", "John Talabot"],
    ".joyintlschool.com": [
        "Huai'an Joy International School",
        "淮安市嘉洋国际学校",
    ],
    ".jpcatholic.com": ["John Paul the Great Catholic University"],
    ".jpgzx.com": ["Golden Apple Jin Cheng No.1 Secondary School"],
    ".student.junia.com": ["Junia ISEN Lille"],
    ".junia.com": [
        "Junia Engineering School",
        "Junia ISEN",
        "Junia ISA",
        "Junia HEI",
        ".group",
    ],
    ".jxgmxy.com": ["江西工业贸易职业技术学院"],
    ".karpagam.com": ["Karpagam Institutions"],
    ".kcgcollege.com": [
        "KCG College of Technology",
        "KCG College of Technology",
    ],
    ".kcisg.com": [
        "昆山康桥高级中学",
        "Kunshan KangQiao International School",
    ],
    ".kd-ict.com": ["KD-ICT", "KD-ICT Professional IT School"],
    ".kdu-online.com": ["KDU University College"],
    ".kearneycats.com": ["Kearney High School", "Kearney High School"],
    ".kedgebs.com": ["Kedge Business School"],
    ".kellerisd.com": ["Keller Center For Advanced Learning (KCAL)"],
    ".kesbath.com": ["King Edward's School"],
    ".keshetschool.com": [
        "Keshet Democratic School in Zichron Yaakov, Israel",
        "בית הספר הדמוקרטי קשת בזכרון יעקב",
    ],
    ".keyin.com": ["Keyin College"],
    ".khaitanpublicschool.com": ["Khaitan Public School"],
    ".khawarizmi.com": ["Al Khawarizmi International College"],
    ".khpcc.com": [
        "Харківський комп'ютерний фаховий колеледж",
        "Kharkiv Computer Applied College",
    ],
    ".kingsolomonhigh.com": ["Kantor King Solomon High School"],
    ".kingstirana.com": ["Kings Tirana"],
    ".kodecx.com": ["KODING INSTITUTE OF TECHNOLOGY", "KODECX UNIVERSITY"],
    ".kolieh.com": ["International Centre for Isclamic Science"],
    ".kongucollege.com": [
        "Kongu College of Arts & Science, Karur",
        "Kongu College of Arts & Science, Karur",
    ],
    ".kosinka.com": [
        "Střední škola technická a obchodní Olomouc, Kosinova 4",
        "Technical and Business Secondary School Olomouc, Kosinova 4",
    ],
    ".kristujayanti.com": ["Kristu Jayanti College"],
    ".kukullagaikas.com": ["KUKULLAGA HERRI ESKOLA"],
    ".la-joliverie.com": ["School of La Joliverie"],
    ".labmiddleschool.com": ["NYC Lab Middle School"],
    ".lambdastudents.com": ["Lambda School", "Lambda"],
    ".lamerce.com": ["Institut Mare de Déu de la Mercè"],
    ".lasallecollege.com": ["LaSalle College / Collège LaSalle"],
    ".lasallecollegevancouver.com": ["LaSalle College Vancouver"],
    ".lasallesaintdenis.com": ["Groupe Scolaire - La Salle Saint Denis"],
    ".lawrencesheriffschool.com": ["Lawrence Sheriff School"],
    ".ldcyzy.com": ["娄底楚怡职业学校", "Loudi Chuyi Vocational School"],
    ".ldjsxy.com": ["娄底技师学院", "Loudi Technician College"],
    ".lecfl.com": ["LUBAVITCH EDUCATIONAL CENTER"],
    ".lecole-ldlc.com": ["L'Ecole LDLC"],
    ".lecolededesign.com": ["L'Ecole de Design Nantes Atlantique"],
    ".leightonpark.com": ["Leighton Park School"],
    ".lepidorocco.com": ["Lepido Rocco", "Lepido Rocco"],
    ".letumongolia.com": ["LETU Mongolia"],
    ".lew-port.com": ["Lewiston-Porter High School"],
    ".lfblbv.com": [
        "Lycée Franco-Britannique de Libreville Ecole Internationale"
    ],
    ".liceolapaz.com": ['CPR Liceo "La Paz"'],
    ".liceovirgilioroma.com": ["Liceo Ginnasio Statale «Virgilio»"],
    ".limashawnee.com": ["Shawnee Local School District"],
    ".litsey7.com": ["High Boarding School #7 / Kazan, Russia"],
    ".lome-bs.com": ["Lome Business School", "Business School of Lome"],
    ".lomebs.com": ["Lomé Business School", "Lomé Business School"],
    ".loyalistcollege.com": ["Loyalist College"],
    ".lpssonline.com": ["Lafayette Parish School System"],
    ".lsfed.com": ["Prendergast school"],
    ".lsmu.com": ["Luhansk State Medical University"],
    ".ludus-academie.com": ["Ludus Academie"],
    ".lycee-langevin-wallon.com": ["Lycée Langevin-Wallon"],
    ".lycee-ndduroc.com": [
        "Lycée Notre Dame du Roc",
        "Formation Informatique : https://www.lycee-ndduroc.com/enseignement-superieur/initiale/30-bts-sio.html",
    ],
    ".lycee-saintdenis.com": ["Institut Supérieur Saint-Denis"],
    ".lyceeastier.com": [
        "Lycée Polyvalent Astier",
        "BTS SN Informatique et Réseaux : https://www.btssnir.fr/",
    ],
    ".lyceerobertschuman.com": ["LYCÉE PRIVÉ ET UFA ROBERT SCHUMAN"],
    ".lyceesaintefamille.com": [
        "Lycée Sainte Famille",
        "Sainte Famille High School",
    ],
    ".mac-eg.com": ["Misr American College"],
    ".madeiratorres.com": [
        "Agrupamento de Escolas Madeira Torres",
        "School Cluster of Madeira Torres",
    ],
    ".madisonu.com": ["Madison University (Distance Education)"],
    ".maghullhigh.com": ["Maghull High School"],
    ".mail-esd.com": ["Ecole supérieure du digital"],
    ".makeschool.com": ["Make School"],
    ".maldaparamedicalcollege.com": ["Malda Paramedical College"],
    ".manorhallschool.com": [
        "Manor Hall International School",
        "Manor Hall International School",
    ],
    ".manukaumail.com": ["Manukau Institute of Technology"],
    ".marianopolis.com": ["Marianopolis College"],
    ".marienschule-students.com": ["Marienschule Opladen"],
    ".marienschule.com": ["Marienschule Opladen"],
    ".marxadella.com": ["IES La Marxadella"],
    ".masonohioschools.com": ["William Mason High School"],
    ".mechwart.com": [
        "Debreceni SZC Mechwart András Gépipari és Informatikai Technikum",
        "DSZC Mechwart András Industrial Engineering and Information Technology Technical School",
    ],
    ".mediadesignschool.com": ["Media Design School"],
    ".melies.com": ["Faculdade de Tecnologia Melies"],
    ".melroseschools.com": ["Melrose Public Schools"],
    ".merchanttaylors.com": ["Merchant Taylors' School"],
    ".merrickprep.com": ["Merrick Preparatory School"],
    ".mevoot-eron.com": ["מבואות עירון", "Mevo'ot Eron"],
    ".mgberon.com": [
        'МГ "Др. Петър Берон" Варна',
        'School of mathematics "Dc. Petur Beron" Varna',
    ],
    ".millfieldschool.com": ["Millfield School"],
    ".mintcollege.com": ["MINT College"],
    ".misbbocconi.com": ["MISB Bocconi: Mumbai campus of SDA Bocconi, Milan"],
    ".mitkundapura.com": [
        "mitkundapura engineering college : mitkundapura.com"
    ],
    ".mitrastudents.com": ["Mitra Academy"],
    ".mittymonarch.com": ["Archbishop Mitty High School"],
    ".mjm-design.com": ["MJM Graphic Design"],
    ".mogadishuuniversity.com": ["Mogadishu University"],
    ".moniris.com": ["Ecole IRIS"],
    ".monlau.com": ["Monlau Centro de Estudios"],
    ".montpellier-bs.com": ["Montpellier Buisness School"],
    ".moorelanduniversity.com": ["Mooreland University"],
    ".student.moringaschool.com": ["Moringa School"],
    ".mpcstudent.com": ["Mount Paran Christian School"],
    ".mrjaffesclass.com": ["Patrick Henry High School"],
    ".msijanakpuri.com": ["Maharaja Surajmal Institute"],
    ".msnsixth.com": ["Midsomer Norton Sixth Form"],
    ".mspvl.com": ["MSP Velayutha Nadar Lakshmithaiammal Polytechnic College"],
    ".mtparanschool.com": ["Mount Paran Christian School"],
    ".mutacth.com": [
        "มหาวิทยาลัยเทคโนโลยีมหานคร",
        "Mahanakorn University of Technology",
    ],
    ".edu.my-campus-berlin.com": [
        "DHGS Deutsche Hochschule für Gesundheit & Sport"
    ],
    ".mydigitalschool.com": ["mydigitalschool.com"],
    ".ust-ics.mygbiz.com": [
        "University of Santo Tomas",
        "University of Santo Tomas",
    ],
    ".mygyanvihar.com": ["Suresh Gyan vihar University, Jagatpura Jaipur"],
    ".myiuc.com": [
        "Institut Universitaire de la Côte",
        "Coast University Institute",
        "IUC",
    ],
    ".mypscedu.com": [
        "Paramount School and College",
        "Paramount School and College",
    ],
    ".myuax.com": ["Universidad Alfonso X El Sabio"],
    ".mywhitecliffe.com": ["Whitecliffe College of Arts and Design"],
    ".nahdaschools.com": ["Al Nahda National School"],
    ".nakaesa.com": ["Nakaesamakkiwittaya School"],
    ".student.narayanagroup.com": ["Narayana School"],
    ".ncetmail.com": [
        "Nagarjuna college of engineering and technology",
        "NCET",
    ],
    ".neelamcollege.com": ["Neelam College of Engineering and Technology"],
    ".nehrucolleges.com": ["Nehru Institute of Technology"],
    ".nehruworldschool.com": ["Nehru World School, India"],
    ".neoma-bs.com": ["Neoma Business School"],
    ".newburyportschools.com": ["Newburyport High School", ".group"],
    ".newprinceshribhavani.com": [
        "New Prince Shri Bhavani College of Engineering and Technology"
    ],
    ".nhlstenden.com": ["NHL Stenden University"],
    ".nortonhillschool.com": ["Norton Hill School"],
    ".notleyhigh.com": ["Notley high"],
    ".noviuniversity.com": [
        "Hogeschool NOVI b.v.",
        "University of Applied Science NOVI",
    ],
    ".npshsr.com": [],
    ".npskrm.com": ["NPS Koramangala", "NPS Koramangala"],
    ".nugaaluniversity.com": ["Nugaal University"],
    ".objectif3d.com": [
        "Objectif 3D",
        "Montferrier-sur-Lez",
        "https://www.objectif3d.com/",
    ],
    ".ohel-shem.com": ['תיכון "אהל-שם"', "Ohel shem Ramat gan"],
    ".okaloosaschools.com": ["Davidson Middle School", "FL, US"],
    ".students.olatheschools.com": ["Olathe Public Schools"],
    ".omnesintervenant.com": ["OMNES Education", "INSEEC (old name)"],
    ".1lokutno.onmicrosoft.com": [
        "I Liceum Ogólnokształcące im. gen. J. H. Dąbrowskiego w Kutnie"
    ],
    ".1loszczecinek.onmicrosoft.com": [
        "I Liceum Ogólnokształcące im. Księżnej Elżbiety w Szczecinku",
        "The first General Secondary School named after Duchess Elizabeth in Szczecinek",
    ],
    ".1lowbelchatowie.onmicrosoft.com": [
        "I Liceum Ogólnokształcące im. W. Broniewskiego w Bełchatowie"
    ],
    ".acledaaib.onmicrosoft.com": ["Acleda University of Business"],
    ".aktuacin.onmicrosoft.com": [
        "Sagar Institute of Technology and Management"
    ],
    ".atmemys.onmicrosoft.com": ["ATME COLLEGE OF ENGINEERING MYSORE"],
    ".balticinstitute.onmicrosoft.com": ["Baltic Institute of Technology"],
    ".bappassau.onmicrosoft.com": [
        "Private Berufsakademie für Aus- und Weiterbildung Passau gGmbH",
        "The BAP IT school is an institute where you can enter a 3 year apprenticeship to earn a degree as Software Engineer.",
        "Official website: https://it-schule-passau.de/",
        'URL with the page detailing the long-term (3 year course) "Ausbildung":',
        "https://it-schule-passau.de/hp412/Ausbildung.htm",
        "Student email differs from the official website URL:",
        "Pattern of the email would be: fi_<FirstNameInitial><LastName>@bappassau.onmicrosoft.com",
        "e.g. fi_cfluegel@bappassau.onmicrosoft.com",
        "Kind regards,",
        "Christopher Flügel",
    ],
    ".bbqberlin.onmicrosoft.com": [
        "BBQ – Baumann Bildung und Qualifizierung",
        "BBQ is an institute where you can get a degree, official website URL:",
        "https://www.bbq.de/",
        "URL of a page on the official website where a long-term (>1 year) IT",
        "https://www.bbq.de/umschulung/koeln/fachinformatiker-anwendungsentwicklung/",
        "The student email differs from the official website, so",
        "The domain that we ask you to add to your database is:",
        "walid.alghanem@BBQBerlin.onmicrosoft.com",
        "best regards",
        "Walid Alghanem",
    ],
    ".berufsschulebt1.onmicrosoft.com": [
        "Staatliche Berufsschule I Bayreuth",
        "https://www.bs1-bt.de/",
        "The website of the IT department (usually courses of 3 years) is located at:",
        "https://www.bs1-bt.de/berufsschule/it",
        "Students Emails differ from staff and are hosted via Microsoft, the pattern is as follows:",
        "  firstname.surename@berufsschulebt1.onmicrosoft.com",
    ],
    ".bkalsdorfde.onmicrosoft.com": [
        "Berufskolleg Alsdorf",
        "Vocational College Alsdorf",
    ],
    ".bntuby.onmicrosoft.com": [
        "Белорусский национальный технический университет",
        "Belarusian National Technical University",
    ],
    ".bswiesaude.onmicrosoft.com": [
        "Staatliches Berufliches Schulzentrum Wiesau",
        "State Vocational School Center Wiesau",
    ],
    ".buddhidharma1.onmicrosoft.com": [
        "Universitas Buddhi Dharma",
        "Buddhi Dharma University",
    ],
    ".bztgoldenburgde.onmicrosoft.com": [
        "Bildungszentrum für Technik und gestaltung",
        "BZTG is an institute where you can get a degree, official website URL:",
        "https://www.bztg-oldenburg.de",
        "Alternative URLs that is being used for different services: https://mybztg.de/",
        "URL of a page on the official website where a long-term (>1 year) IT:",
        "https://www.bztg-oldenburg.de/bildungsangebot/berufsfachschulen/informatik/",
        "The student email differs from the official website, because only the teachers get an E-Mail with the official domain. ",
        "The student E-Mails are mainly used to get access to the office package.",
        "Office Page: https://bztg-oldenburg.de/o356-conditions/",
        "Here is a picture of the page where you get your onmicrosoft.com login email: https://ss.zhost.xyz/images/R804.jpg",
        "You have to login to see your email.",
    ],
    ".cdtnue.onmicrosoft.com": [
        "Control Data Training GmbH",
        "Control Data Training GmbH",
    ],
    ".chippewavalley.onmicrosoft.com": ["Chippewa Valley Schools"],
    ".chrobry1lo.onmicrosoft.com": [
        "1 liceum im. Bolesława Chrobrego w Piotrkowie Trybunalskim",
        "Bolesław I the Brave High School in Piotrków Trybunalski",
    ],
    ".ckpsiedlce.onmicrosoft.com": ["Centrum Kształcenia Zawodowego"],
    ".cndiovtua.onmicrosoft.com": [
        "Центральний науково-дослідний інститут озброєння та військової техніки Збройних Сил України",
        "Central Scientific Research Institute of Armament and Military Equipment of Armed Forces of Ukraine",
    ],
    ".cnogsibiu.onmicrosoft.com": ['Colegiul National "Octavian Goga" Sibiu'],
    ".comgymdeg.onmicrosoft.com": [
        "Comenius Gymnasium Deggendorf",
        "Comenius Gymnasium Deggendorf",
    ],
    ".correoipn.onmicrosoft.com": [
        "Instituto Politecnico Nacional",
        "National Polytechnic Institute",
    ],
    ".csorsay.onmicrosoft.com": ["COURS SECONDAIRE D'ORSAY"],
    ".csssnina.onmicrosoft.com": ["Cirkevná spojená škola Snina"],
    ".czerwonyogolniak.onmicrosoft.com": [
        "I Liceum Ogólnokształcące im. Marii Skłodowskiej-Curie w Starogardzie Gdańskim",
        "I Highschool Marii Skłodowskiej Curie in Starogard Gdański",
    ],
    ".dypisp.onmicrosoft.com": ["Dr. D. Y. Patil School of Engineering"],
    ".ebkherne.onmicrosoft.com": [
        "Emschertal Berufskolleg herne",
        "Emschertal vocational college herne",
    ],
    ".eckegym.onmicrosoft.com": ["Gymnasium Eckental"],
    ".elucy.onmicrosoft.com": [
        "European Leadership University",
        "European Leadership University",
    ],
    ".emineornekkoleji.onmicrosoft.com": [
        "Emine Örnek Koleji",
        "Emine Ornek Collage",
    ],
    ".epshl.onmicrosoft.com": ["Emil-Possehl-Schule"],
    ".esimetz.onmicrosoft.com": ["ESI Metz, France"],
    ".esstu.onmicrosoft.com": [
        "Восточно-Сибирский государственный университет технологий и управления",
        "East Siberia State University of Technology and Management",
    ],
    ".fagoceducacional.onmicrosoft.com": ["UniFagoc"],
    ".fesesde.onmicrosoft.com": ["Friedrich-Ebert-Schule"],
    ".firstwald.onmicrosoft.com": [
        "Evangelisches Firstwald Gymnasium Mössingen"
    ],
    ".galatasarayuniv.onmicrosoft.com": [
        "Galatasaray Üniversitesi",
        "Galatasaray University",
        "Galatasaray High School",
    ],
    ".ghsede.onmicrosoft.com": [
        "Gwerbliche und Hauwirtschaftlich-Sozialpflegerische Schulen Emmendingen"
    ],
    ".gymro.onmicrosoft.com": ["Gymnasium Rodenkirchen"],
    ".hansbockl.onmicrosoft.com": ["Hans-Böckler-Berufskolleg, Marl, Germany"],
    ".hhbkde.onmicrosoft.com": ["Heinrich-Hertz-Berufskolleg Düsseldorf"],
    ".hsbks.onmicrosoft.com": ["Hubertus Schwartz Berufskolleg"],
    ".htblaperg.onmicrosoft.com": [
        "Höhere Technische Lehranstalt Perg ( Higher Technical College Perg ) / Austria"
    ],
    ".iisfortunato.onmicrosoft.com": [
        "IIS Giustino Fortunato, Pisticci (MT)",
        "High School in Pisticci, Italy",
        "Official Website: http://www.iisgiustinofortunato.it",
        "Information about IT Department: http://www.iisgiustinofortunato.it/index.php?option=com_content&view=article&id=359&Itemid=1438",
        "We have three years of IT specialization in the 3th, 4th and 5th year with a focus on programming ",
        "http://www.iisgiustinofortunato.it/files/MTIS011001/Quadro_orario_ITT.pdf",
    ],
    ".ismonnet.onmicrosoft.com": ["IIS Jean Monnet"],
    ".itbildungshauseducation.onmicrosoft.com": [
        "Das IT-Bildungshaus, Bremen"
    ],
    ".itiscastelli.onmicrosoft.com": [
        "IIS Castelli, Brescia (former ITIS Castelli)",
        "High School in Brescia, Italy",
        "Official Website: https://www.iiscastelli.edu.it",
        "Information about IT Department: https://www.iiscastelli.edu.it/pager.aspx?Page=dip_info",
        "We have three years of IT specialization in the 3th, 4th and 5th year with a focus on programming ",
        "https://www.slideshare.net/slideshow/embed_code/15570843?wmode=transparent",
    ],
    ".itstalentfactory.onmicrosoft.com": ["ITS Tech Talent Factory"],
    ".itstepuniv.onmicrosoft.com": [
        "INSTITUTO SUPERIOR DE TECNOLOGÍA Y  EDUCACIÓN PROFESIONAL ",
        "STEP ACADEMY",
    ],
    ".kgsu.onmicrosoft.com": [
        "ФГБОУ ВО «Курганский государственный университет»"
    ],
    ".klaraopp.onmicrosoft.com": [
        "Klara-Oppenheimer-Schule Würzburg (student accounts)"
    ],
    ".knitukazan.onmicrosoft.com": [
        "Казанский Национальный Исследовательский Университет",
        "Kazan National Research Technological University",
    ],
    ".koblenzcbs.onmicrosoft.com": ["Carl Benz Schule Koblenz"],
    ".kpiapeps.onmicrosoft.com": [
        "National Technical University (Kiev Politechnical Institute)"
    ],
    ".lbiro.onmicrosoft.com": [
        'Colegiul National de Informatica "Tudor Vianu"',
        'National College of Informatics "Tudor Vianu"',
    ],
    ".liis.onmicrosoft.com": [
        'Liceul Teoretic de Informatica "Grigore Moisil"',
        'High School of Computer Science "Grigore Moisil"',
    ],
    ".lo13wroc.onmicrosoft.com": [
        "Liceum Ogólnokształcące nr XIII im. Aleksandra Fredry"
    ],
    ".lo9wrocpl.onmicrosoft.com": [
        "Liceum ogólnokształcące nr IX im. Juliusza Słowackiego ",
        "Secondary School No. IX named after Juliusz Słowacki",
    ],
    ".lozuromin.onmicrosoft.com": [
        "Liceum Ogólnokształcące im. Marii Dąbrowskiej w Żurominie"
    ],
    ".lyceeclosmaire.onmicrosoft.com": ["Lycée Polyvalent Clos-Maire"],
    ".madiasu.onmicrosoft.com": [
        "Московский автомобильно-дорожный государственный технический университет (МАДИ)"
    ],
    ".marconipontedera.onmicrosoft.com": ["ITI G. Marconi"],
    ".mescoeorg.onmicrosoft.com": [
        "Modern Education Society's College of Engineering,Pune"
    ],
    ".mountunion.onmicrosoft.com": [
        "University of Mount Union",
        "University of Mount Union",
    ],
    ".mylifeunisaac.onmicrosoft.com": ["University of South Africa"],
    ".nguyenkhuyenpy.onmicrosoft.com": [
        "Trường trung học phổ thông Nguyễn Khuyến Tây Ninh",
        "Nguyen Khuyen Tay Ninh High School",
    ],
    ".nusu.onmicrosoft.com": [
        "National University of Singapore",
        "National University of Singapore",
    ],
    ".o365frcuutneduar.onmicrosoft.com": [
        "Universidad Tecnológica Nacional, Facultad Regional Concepción del Uruguay (UTN - FRCU)",
        "National Technological University, Concepción del Uruguay Regional Faculty (UTN - FRCU)",
    ],
    ".onlineg3.onmicrosoft.com": ["G3"],
    ".opolelo3.onmicrosoft.com": [
        "Publiczne Liceum Ogólnokształcące nr III z Oddziałami Dwujęzycznymi im. Marii Skłodowskiej-Curie w Opolu"
    ],
    ".oszimt.onmicrosoft.com": [
        "Oberstufenzentrum Informations- und Medizintechnik",
        "Upper Secondary School Information and Medical Technology",
    ],
    ".ottokuehneschule.onmicrosoft.com": [
        "Pädagogium Otto-Kühne-Schule Godesberg"
    ],
    ".panimalarengg.onmicrosoft.com": ["Panimalar Engineering Collage"],
    ".pfaffenhofenschule.onmicrosoft.com": [
        "Grund und Mittelschule Pfaffenhofen"
    ],
    ".pforta.onmicrosoft.com": [
        "Landesschule Pforta",
        "The Landesschule Pforta is a boarding school located in Germany, with a special concept of furthering talented students in natural sciences.",
        "Official website: https://www.landesschule-pforta.de/en/index.php",
        "Department of Natural Sciences: https://www.landesschule-pforta.de/en/departments.php",
        "We have four years of IT specialization with a focus on programming.",
        "We also have a lot of student led extracurricular activities, which focus on programming.",
        "The email pattern is <name>@pforta.onmicrosoft.com",
        "Best regards",
    ],
    ".pictorius.onmicrosoft.com": ["Pictorius Berufskolleg Coesfeld"],
    ".politecnicamgprogrammersliv.onmicrosoft.com": [
        "Centro Universitário UNA, Brasil"
    ],
    ".sabje.onmicrosoft.com": ["King David Schools"],
    ".schlaun.onmicrosoft.com": [
        "Johann-Conrad-Schlaun-Gymnasium Münster",
        "Johann-Conrad-Schlaun-College Muenster",
    ],
    ".sgxanten.onmicrosoft.com": ["Städtisches Stiftsgymnasium Xanten"],
    ".sjcacblr.onmicrosoft.com": ["St. Joseph's College (Autonomous)"],
    ".sp1wegrow.onmicrosoft.com": [
        "Szkoła Podstawowa Nr 1 im. Jana Dobrogosta Krasińskiego w Węgrowie"
    ],
    ".sp6swidnica.onmicrosoft.com": [
        "Szkoła Podstawowa nr 6 im. Tysiąclecia Państwa Polskiego"
    ],
    ".stasziczsp.onmicrosoft.com": [
        "Zespół Szkół Ponadpodstawowych im. Stanisława Staszica w Białobrzegach"
    ],
    ".steppingstoneschd.onmicrosoft.com": [
        "Stepping Stones Senior Secondary School"
    ],
    ".studentmgppu.onmicrosoft.com": [
        "Московский государственный психолого-педагогический университет (МГППУ)",
        "Moscow city university of psychology and pedagogy (second Live ID e-mail, primary e-mail already exists mgppu.ru)",
    ],
    ".studuniroma3.onmicrosoft.com": ["UniRoma3"],
    ".szkolykielcepl.onmicrosoft.com": ["Prywatne Technikum Awans w Kielcach"],
    ".technikumcyfrowe.onmicrosoft.com": [
        "Technikum Technologii Cyfrowych w Szczecinie",
        "Technical School of Digital Technologies in Szczecin",
    ],
    ".thptyenvieneduvn.onmicrosoft.com": [
        "Trung học phổ thông Yên Viên",
        "Yen Vien High School",
    ],
    ".tlkrakowpl.onmicrosoft.com": [
        "Zespół Szkół Łączności im. Obrońców Poczty Polskiej w Gdańsku w Krakowie"
    ],
    ".tmgdaun.onmicrosoft.com": ["Thomas-Morus-Gymnasium Daun"],
    ".tmsnoida.onmicrosoft.com": [
        "The Millennium School",
        "The Millennium School",
    ],
    ".tthkee.onmicrosoft.com": [
        "Tallinna Tööstushariduskeskus",
        "Tallinn Center of Industrial Education",
    ],
    ".umistrzapaderewskiego.onmicrosoft.com": [
        "Zespol Szkol Ogolnoksztalcacych i Zawodowych imieniem Ignacego Jana Paderewskiego w Ciezkowicach"
    ],
    ".unidebhu.onmicrosoft.com": [
        "Debrecen University of Agricultural Sciences",
        "University of Debrecen ",
    ],
    ".upsanok.onmicrosoft.com": [
        "Uczelnia Państwowa im. Jana Grodka w Sanok",
        "Jan Grodek State University in Sanok",
    ],
    ".urfume.onmicrosoft.com": ["Ural Federal University"],
    ".uvmx.onmicrosoft.com": ["Universidad Veracruzana"],
    ".uzlabina.onmicrosoft.com": ["SPŠE v Úžlabině"],
    ".valeovil.onmicrosoft.com": [
        "Agrupamento de Escolas de Vale de Ovil, Baião"
    ],
    ".venkateshwaraschool.onmicrosoft.com": [
        "Venkateshwara International School"
    ],
    ".vyatsu.onmicrosoft.com": ["Vyatka State University"],
    ".wsiiulodz.onmicrosoft.com": [
        "Wyższa Szkoła Informatyki i Umiejętności w Łodzi"
    ],
    ".zespolszkolmechanicznyche.onmicrosoft.com": [
        "Zespol Szkol Mechanicznych Nr 3"
    ],
    ".zs10zabrze.onmicrosoft.com": [
        "Technikum Nr 7 Zabrze im. prof. Janusza Groszkowskiego w Zabrzu"
    ],
    ".zsebydgoszcz.onmicrosoft.com": [
        "Technikum Elektroniczne nr 7 im. Wojska Polskiego w Bydgoszczy"
    ],
    ".zseii.onmicrosoft.com": [
        "Zespół Szkół Elektronicznych i Informatycznych w Sosnowcu"
    ],
    ".zsezdw.onmicrosoft.com": [
        "Zespół szkół elektronicznych nr 2 im. Stanisława Staszica w Zduńskiej Woli",
        "Electronic School Complex No. 2 named after Stanisław Staszic in Zduńska Wola",
    ],
    ".zsipkzwbielawie.onmicrosoft.com": [
        "Zespół Szkół i Placówek Kształcenia Zawodowego w Bielawie"
    ],
    ".zskocjan.onmicrosoft.com": [
        "Zespół szkół nr 3 imienia Antoniego Kocjana w Olkuszu",
        "Antoni Kocjan School Complex No. 3 in Olkusz",
    ],
    ".zsm01.onmicrosoft.com": ["Zespół Szkół Mechanicznych nr 1 w Bydgoszczy"],
    ".zsmogilno.onmicrosoft.com": [
        "Zespół Szkół W Mogilnie",
        "High School in Mogilno",
    ],
    ".zsp1sieradz.onmicrosoft.com": ["Powiatowy Zespół Szkół nr1 w Sieradzu"],
    ".zspgrojec.onmicrosoft.com": [
        "Zespół Szkół im. Armii Krajowej Obwodu „Głuszec” – Grójec w Grójcu"
    ],
    ".zstlezajskpl.onmicrosoft.com": ["ZST Leżajsk", "ZST Leżajsk"],
    ".zsvltava.onmicrosoft.com": [
        "ZŠ a ZUŠ Bezdrevská 3, České Budějovice",
        "ZŠ Vltava",
    ],
    ".openclassrooms.com": ["OpenClassrooms"],
    ".oradeauniversity.com": [
        "Oradea University",
        "University of Medicine and Pharmacology of Oradea",
    ],
    ".oshmed.com": ["Medical Institute,Osh State University"],
    ".oshsch.com": ["Old Swinford Hospital"],
    ".ostrovskeho.com": ["SOŠ Ostrovského"],
    ".oultoncollege.com": ["Oulton College"],
    ".outwood.com": ["Outwood Grange Academies Trust"],
    ".oxcoll.com": ["Oxford International College"],
    ".p4ed.com": ["Poliedro curso"],
    ".pacificworldschool.com": [
        "Pacific World School",
        "https://www.pacificworldschool.com/",
    ],
    ".paneurouni.com": ["Paneuropean University"],
    ".parvamat.com": [
        "Първа Частна Математическа Гимназия",
        "First Private Mathematic High School",
    ],
    ".pccsk12.com": ["Plymouth-Canton Community Schools"],
    ".stu.pearlacademy.com": ["Pearl Academy, India"],
    ".peelsb.com": ["Peel District School Board"],
    ".pgi-varna.com": ['PGI "Dr. Ivan Bogorov"'],
    ".pgknma.com": [
        "\ufeffПрофесионална гимназия по компютърни науки и математически анализи проф. Минко Балкански Стара Загора"
    ],
    ".pharminnotech.com": [
        "St. Petersburg State Chemical Pharmaceutical Academy",
        "St. Petersburg State Chemical Pharmaceutical Academy",
    ],
    ".phinmaed.com": ["University of Pangasinan"],
    ".pierrerouge.com": ["Saint Joseph Pierre Rouge"],
    ".plaiaundi.com": ["IES Plaiaundi BHI", "Plaiaundi Vocational Institute"],
    ".playgroundsquad.com": ["PlaygroundSquad"],
    ".pmgkn.com": [
        "h.todorov03@pmgkn.com",
        'Maths and Science High School "Prof. Emanuil Ivanov", Kyustendil, Bulgaria',
        'Природоматематическа гимназия "Проф. Емануил Иванов", Кюстендил, България',
    ],
    ".podarinternationalschool.com": ["Podar International School, Mumbai"],
    ".pole3d.com": ["Pole 3D"],
    ".poleformation74.com": ["Pole Formation de la Haute Savoie"],
    ".politecnicomalaga.com": [
        "IES Politécnico Jesús Marín",
        "IES Politecnico Jesus Marin",
    ],
    ".poolegrammar.com": ["Poole Grammar School"],
    ".powayusd.com": ["Poway Unified School District"],
    ".preciousheritageschool.com": [
        "Precious Heritage College",
        "https://preciousheritageschool.com/",
    ],
    ".prettyriveracademy.com": ["Pretty River Academy "],
    ".ms.princepublicschool.com": ["Prince Public School"],
    ".pristineschool.com": ["Pristine Private School"],
    ".ptsdwebapps.com": ["Peters Township Highschool"],
    ".purple-formation.com": ["Purple Campus"],
    ".pwioi.com": ["PW Institute Of Innovation"],
    ".qegsonline.com": ["Queen Elizabeth's Grammar School Blackburn"],
    ".queensmetro.com": [
        "Queens Metropolitan High School",
        "Queens Metropolitan High School",
    ],
    ".qyytzx.com": ["庆云云天中学", "Qingyun Yuntian Middle School"],
    ".raghuenggcollege.com": ["RAGHU ENGINEERING COLLEGE"],
    ".raghuinstech.com": ["Raghu institution of technology"],
    ".ralphthoresby.com": ["Ralph Thoresby School"],
    ".rayatbahra.com": ["Rayat Bahra Institute of Management"],
    ".rcsi-mub.com": ["RCSI-Medical University of Bahrain"],
    ".rcsi.com": ["Royal College of Surgeons in Ireland"],
    ".redclayschools.com": ["Red Clay Consolidated School District"],
    ".rennes-sb.com": ["Renne School of Business"],
    ".rgshw.com": ["Royal Grammar School, High Wycombe"],
    ".alunos.ribadouro.com": ["Externato Ribadouro, Porto"],
    ".richardchalloner.com": ["Richard Challoner School"],
    ".risewpu.com": [
        "WPU RISE Digital Learning Pvt. Ltd. ",
        "MIT World Peace University",
    ],
    ".ritroorkee.com": ["Roorkee Institute of Technology"],
    ".riyadhnajed.com": ["Riyadh Najed Schools"],
    ".rmutsvmail.com": ["Rajamangala University of Technology Srivijaya"],
    ".rnpodarschool.com": ["R N Podar School"],
    ".rondearingutc.com": ["Ron Dearing UTC"],
    ".rondebosch.com": ["Rondebosch Boys' Schools"],
    ".rosaryshs-j.com": ["rosary sister high school"],
    ".rothberg100.com": ["Rothberg High School"],
    ".rubika-edu.com": ["Rubika"],
    ".runnymede-college.com": ["Runnymede College", "Runnymede College"],
    ".saadcollege.com": ["Saad College of Nursing and Allied Health Sciences"],
    ".sacrecoeur22.com": ["Lycée Polyvalent Privé Sacré-Coeur La Salle"],
    ".saedubai.com": ["Sae Institute Dubai"],
    ".safabritishschool.com": ["Safa British School – Dubai"],
    ".a.safamadrid.com": ["Colegio Sagrada Familia de Madrid"],
    ".saint-gab.com": ["Saint Gab' (Vendée)", "Saint Gab'"],
    ".saintadrien.com": ["Lycée Saint-Adrien La Salle"],
    ".sainte-elisabeth.com": [
        "Sainte Elisabeth",
        "https://www.sainte-elisabeth.com/",
        "Proof of School Domain Name in Yellow on top left side of the document : https://i.imgur.com/ljeY6EJ.jpg",
    ],
    ".sainteunans.com": ["saint eunans"],
    ".student.saintkentigern.com": ["Saint Kentigern College"],
    ".saintluc-cambrai.com": [
        "Ensemble Saint Luc Cambrai",
        "Ensemble Saint Luc Cambrai North of France",
    ],
    ".salesianosdosa.com": [
        "Salesianos Domingo Savio Madrid",
        "Salesians Domingo Savio Madrid",
    ],
    ".szkola.salezjanie.com": [
        "Publiczne Salezjańskie Liceum Ogólnokształcące w Krakowie",
        "https://salezjanie.com/",
    ],
    ".sanataneducation.com": ["SANATAN PUBLIC SCHOOL, TOHANA, INDIA"],
    ".santhigiricollege.com": ["SANTHIGIRI COLLEGE, THODUPUZHA "],
    ".saveetha.com": ["Saveetha university"],
    ".savio-lambersart.com": ["Dominique SAVIO Enseignement Catholique "],
    ".sbe5d.com": ["Shenley Brook End School, Milton Keynes"],
    ".sbjacksonville.com": ["Sanford-Brown Institute"],
    ".scetop.com": [
        "四川托普信息技术职业学院",
        "SiChuan Top IT Voctional institute",
    ],
    ".schillerstrasbourg.com": [
        "Schiller International University, Strasbourg"
    ],
    ".sdglobalschool.com": ["sdglobalschool"],
    ".sdsydxx.com": ["\ufeffShandong Post and Telecommunications School"],
    ".sekpacifico.com": [
        "Colegio Sek Pacifico",
        "Colegio Internacional Sek Pacifico",
    ],
    ".sempreceub.com": ["Centro Universitário de Brasília"],
    ".serrahs.com": ["Junipero Serra High School"],
    ".severnschool.com": ["Severn School"],
    ".sfhs.com": ["Saint Francis High School"],
    ".sgbonaire.com": ["Scholengemeenschap Bonaire (SGB) "],
    ".sgsc-students.com": [
        "St. georges school cologne",
        "St. georges school cologne",
    ],
    ".sh-sipopolytechnic.com": ["Shanghai Sipo Polytechnic"],
    ".shannoncollege.com": ["Shannon College of Hotel Management"],
    ".sheldoncollege.com": ["Sheldon College"],
    ".sheldonisd.com": ["C.E. King High School"],
    ".shms.com": ["Swiss Hotel Management School"],
    ".shohzyxy.com": ["上海欧华职业技术学院", "Shanghai Ouhua College"],
    ".shooliniuniversity.com": ["Shoolini University"],
    ".shrikrishnacollege.com": ["Krishna Engineering College"],
    ".signesetformations.com": ["Signes & Formations"],
    ".siligurimodelhighschool.com": ["Siliguri Model Senior Secondary School"],
    ".singaporeschoolcebu.com": ["Singapore School Cebu"],
    ".sio-carriat.com": ["Lycée Carriat", "Lycée Polyvalent J.-M. Carriat"],
    ".sitechhs.com": [
        "Staten Island Technical High School",
        "Website: https://www.siths.org ",
        "Email: sitechhs.com",
    ],
    ".sjcwebmail.com": ["St Josephs College"],
    ".sjvhs.com": ["Saint John Vianney High School"],
    ".skadron.com": ["Skadron College"],
    ".skylineuniversity.com": ["Skyline University College, Sharjah"],
    ".bruinmail.slcc.com": ["Salt Lake Community College"],
    ".smalandsgymnasiet.com": ["Smålandsgymnasiet"],
    ".smartoakprojects.com": ["Zespół Szkół Łączności"],
    ".smcsmail.com": [
        "St. Michael's College School",
        "St. Michael's College School",
    ],
    ".student.smrchs.com": ["St Matthew's Roman Catholic High School"],
    ".somosicev.com": ["iCEV Instituto de Ensino Superior"],
    ".soraschools.com": ["Sora High School"],
    ".southfieldsacademy.com": ["Southfields Academy"],
    ".southoldufsd.com": ["Southold UFSD"],
    ".souunilavras.com": ["Centro Universitário de Lavras", "Unilavras"],
    ".spbgut.com": [
        "The Bonch-Bruevich Saint - Petersburg State University of Telecommunications"
    ],
    ".spencervillebearcats.com": ["Spencerville Local School District"],
    ".springbranchisd.com": ["Spring Branch ISD", ".group"],
    ".spsmma.com": [
        "St. Petersburg StateMechnikov  Medical Academy",
        "St. Petersburg StateMechnikov  Medical Academy",
    ],
    ".spyponders.com": ["Arlington High School"],
    ".srcspatna.com": ["SHRI RAM CENTENNIAL SCHOOL"],
    ".ssipmt.com": [
        "Shri Shankaracharya Institute of Professional Management and Technology"
    ],
    ".sspubhilai.com": [
        "SHRI SHANKARACHARYA TECHNICAL CAMPUS",
        "SHRI SHANKARACHARYA TECHNICAL CAMPUS",
    ],
    ".st-andrews.com": ["St Andrew's International School in The Bahamas"],
    ".st-laurence.com": ["St-Laurence School"],
    ".st-teresas.com": ["St Teresa's Independent school"],
    ".stadjutor.com": ["Lycée Saint-Adjutor"],
    ".stagiaire-humanbooster.com": [
        "HUMAN BOOSTER",
        "https://humanbooster.com/",
    ],
    ".stccampus.com": ["Sattahip Commercial Technological College"],
    ".academie.ste-therese.com": ["Académie Ste-Thérèse"],
    ".stenden.com": ["Stenden University"],
    ".stephenperse.com": ["stephen perse foundation"],
    ".stithian.com": ["St Stithians College", "St Stithians College"],
    ".stjodijon.com": [
        "Enseignement Supérieur Saint Joseph Dijon - ESJO Dijon",
        "Website: https://www.stjodijon.com/enseignement-superieur/presentation-5/",
    ],
    ".stjomaristes.com": ["Saint Joseph les Maristes"],
    ".stnicolau.com": ["Sant Nicolau"],
    ".stockholm-fu.com": ["Free University Stockholm"],
    ".stonarschool.com": [
        "Stonar School",
        "Wiltshire, SN12 8NT, United Kingdom",
    ],
    ".stowevalley.com": ["Stowe Valley Multi Academy Trust"],
    ".stpetersca.com": [
        "St Peters Catholic School",
        "St Peters Catholic School",
    ],
    ".stpetershyd.com": ["St Peter's Engineering College"],
    ".stratfordschools.com": ["Stratford Schools"],
    ".stretfordgrammar.com": ["Stretford Grammar School"],
    ".stswithuns.com": ["St Swithun's"],
    ".stu-esgf.com": ["ESG Finance"],
    ".stucom.com": ["El Centre d’Estudis Stucom"],
    ".studi.com": ["Studi, the French online school"],
    ".studygroup.com": ["Study Group"],
    ".stwillibrord.com": [
        "St. Willibrord High School and Juinor College of Science and Commerce",
        "Mumbai, Maharashtra, India.",
    ],
    ".stxtigers.com": ["St. Xavier High School "],
    ".sugunapips.com": ["Suguna PIP School"],
    ".suh-edu.com": ["Salahddin University (Kurdistan Region)"],
    ".summerfields.com": ["Summer Fields School", "summerfields.com"],
    ".summit-academy.com": ["Summit Academy"],
    ".supcareer.com": [
        "Sup Career",
        "École de commerce du groupe INSEEC à Paris, France",
    ],
    ".supdepub.com": ["Sup de Pub"],
    ".supdeweb-paris.com": ["Supdeweb : L'école des métiers du digital"],
    ".supdeweb-strasbourg.com": [
        "Supdeweb : L'école des métiers du web et du multimedia"
    ],
    ".supinfo.com": [
        "SUPINFO International University - École Supérieure d'Informatique de Paris (ESI)"
    ],
    ".suptgniort.com": ["suptg niort"],
    ".svalero.com": ["Fundación San Valero"],
    ".svamail.com": ["Silicon Valley Academy email domain"],
    ".swa-jkt.com": ["Sinarmas World Academy"],
    ".swargaranischool.com": ["swargarani school"],
    ".swbgs.com": ["Sir William Borlase's Grammar School"],
    ".taawish.com": ["Taawish College of Education"],
    ".taftcharter.com": ["Taft Charter High School"],
    ".tajamar365.com": ["Formacion Tajamar"],
    ".tanokullari.com": [
        "Özel Tan Okulları, Bursa",
        "Tan Private Schools, Bursa",
    ],
    ".teccart.com": ["Teccart Institute"],
    ".technischools.com": [
        "Niepubliczne Technikum Programistyczne Techni Schools"
    ],
    ".technoindiaeducation.com": [
        "Techno India University",
        "Techno India University",
    ],
    ".tera-campus.com": ["Tera Campus"],
    ".faculty.thecoreschool.com": ["The Core School"],
    ".professional.thecoreschool.com": ["The Core School"],
    ".student.thecoreschool.com": [
        "The Core Entertainment Science School in Madrid"
    ],
    ".thedeltahighschool.com": ["Delta High School"],
    ".thefarnboroughacademy.com": ["The Farnborough Academy "],
    ".thegameassembly.com": ["The Game Assembly"],
    ".theglobeformacion.com": ["Centro de enseñanza The Globe"],
    ".theharveeschool.com": ["The Harvee School"],
    ".thesrisaicollege.com": ["Sri Sai College"],
    ".thevallians.com": [
        "The Vallians",
        "The Vallians Digital University, The Valley DBS",
    ],
    ".student.threepoints.com": [
        "Three Points The School for Digital Business"
    ],
    ".tichonet.com": ["תיכונט ע''ש אלתרמן", "tichonet"],
    ".tiftschools.com": ["Tift County High School"],
    ".tjbhzy.com": ["Tianjin Bohai Vocational Technical College"],
    ".tkrcet.com": [
        "TKR College of Engineering and Technology",
        "TKR College of Engineering and Technology",
    ],
    ".totharpadgimnazium.com": [
        "Tóth Árpád Gimnázium",
        "Tóth Árpád Secondary School",
    ],
    ".trios.com": ["triOS College"],
    ".trioscollege.com": ["triOS College"],
    ".triosstudent.com": ["triOS College"],
    ".truemax.com": ["TRUEMAX academy"],
    ".twynhamschool.com": ["Twynham School"],
    ".u-tad.com": [
        "U-tad - Centro Universitario de Tecnología y Arte Digital"
    ],
    ".2024.ucac-icam.com": ["UCAC-ICAM"],
    ".2026.ucac-icam.com": ["Ucac-Icam"],
    ".ucac-icam.com": ["Institut Ucac-Icam"],
    ".ucreativa.com": ["Universidad Creativa", "Creative University"],
    ".udlondres.com": ["UNIVERSIDAD DE LONDRES", "UNIVERSITY OF LONDON"],
    ".uft-plovdiv.com": ["University of Food Technology"],
    ".alumnos.ui1.com": ["Universidad Isabel I"],
    ".students.paca.uk.com": [
        "Portslade Aldridge Community Academy. http://www.paca.uk.com/ email: @students.paca.uk.com"
    ],
    ".turton.uk.com": ["Turton School"],
    ".uktc-bg.com": [
        "Национална професионална гимназия по компютърни  технологии и системи"
    ],
    ".ukuepa.com": ["KUEPA DE MÉXICO,S.A DE C.V."],
    ".ulc-icam.com": [
        "Faculté d'ingénierie ULC-Icam",
        "Université Loyola du Congo",
        "Institut Catholique d'Arts et Métiers",
    ],
    ".ult-tunisie.com": ["Tunisia Private University"],
    ".umi-pk.com": ["University of Munawwar-ul-Islam"],
    ".uni-prizren.com": ["Universiteti i Prizrenit"],
    ".uniactiva.com": ["Universidad Abierta Interactiva"],
    ".students.unicoischools.com": ["Unicoi County High School"],
    ".unidompedro.com": ["Centro Universitario Dom Pedro II"],
    ".uniedpa.com": [
        "Universidad Interamericana de Educacion a Distancia de Panama"
    ],
    ".unigoias.com": [
        "UNIGOIÁS - Centro Universitário de Goiás",
        "UNIGOIÁS - University Center of Goiás",
    ],
    ".students.uninettunouniversity.com": [
        "Universita Uninettuno ",
        "Uninettuno University",
    ],
    ".studenti.uninsubria.com": ["Università degli studi dell'Insubria"],
    ".uninter.com": ["Centro Universitário Internacional UNINTER"],
    ".uniriosead.com": ["Centro Universitário do Rio São Francisco, UNIRIOS"],
    ".univ-barackobama.com": ["University of Barack Obama"],
    ".univ-catho-sjd.com": ["Institut universitaire Saint Jerome de Douala"],
    ".univ-douala.com": ["Université de Douala"],
    ".universae360.com": ["UNIVERSAE Higher Vocational Training Institute"],
    ".professional.universidadviu.com": [
        "Universidad Internacional de Valencia",
        "Valencian Internacional Univesity",
    ],
    ".professor.universidadviu.com": [
        "Universidad Internacional de Valencia",
        "Valencian Internacional Univesity",
    ],
    ".student.universidadviu.com": [
        "Universidad Internacional de Valencia",
        "Valencian International University",
    ],
    ".universitatunipro.com": ["UNIPRO, Universitat Digital Europea"],
    ".universitetiaab.com": ["Kolegji AAB", "AAB College"],
    ".university-365.com": ["University 365"],
    ".universityschools.com": ["University Schools", "University Schools"],
    ".unswalumni.com": ["University of New South Wales"],
    ".up-esi.com": ["UP-ESI"],
    ".upatoday.com": ["University Preparatory Academy"],
    ".uu-sy.com": ["Ittihad Private University"],
    ".student.uva.com": ["University of Amsterdam"],
    ".uw.com": ["University of Washington"],
    ".vanarts.com": ["Vancouver Institute of Media Arts (VanArts)"],
    ".vaucanson38.com": ["Lycée Polyvalent Vaucanson"],
    ".vbschools.com": ["Bayside High School"],
    ".vcertk.com": ["vaish college of engineering, Rohtak"],
    ".vegaschool.com": ["Vega School"],
    ".velhightech.com": [
        "Vel Tech High Tech Dr. Rangarajan Dr. Sakunthala Engineering college"
    ],
    ".vfs.com": ["Vancouver Film School"],
    ".vidyavalley.com": ["Vidya Valley School, Pune, India"],
    ".virolai.com": ["Escola Virolai"],
    ".vivekanandgroup.com": ["Vivekanand Group of Institutions"],
    ".edu.vlerick.com": ["Vlerick Business School"],
    ".voxelschool.com": ["Voxel School", "Voxel School"],
    ".vpi-school.com": [
        "مدرسة رواد النصر العالمية",
        "Victory Pioneers International School",
    ],
    ".vpslao.com": ["Vientiane Pattana School International"],
    ".vsavm.com": ["Vitebsk State Academy of Veterinary Medicine"],
    ".vtcsy.com": ["沈阳职业技术学院", "shenyang polytechnic college"],
    ".vtsd.com": ["Vernon Township School District"],
    ".wairaka.com": ["Unitec Institute of Technology"],
    ".waleshigh.com": ["Wales High School"],
    ".wallingfordschool.com": ["Wallingford School"],
    ".wayneschools.com": ["Wayne Township Public Schools"],
    ".student.wb-hochschule.com": ["Wilhelm Büchner Hochschule"],
    ".wbbroncos.com": ["Western Brown High School"],
    ".wcs-g.com": ["Westmount Charter School"],
    ".wcsch.com": ["Westminster City School"],
    ".wells-cathedral-school.com": ["Wells Cathedral School"],
    ".wells-school.com": ["Wells International School", "โรงเรียนนานาชาติเวลล์ส"],
    ".wernethschool.com": ["Werneth High School"],
    ".westcoastuniversity-edu.com": ["West Coast University (WCU)"],
    ".mail.whicu.com": ["武汉商贸职业学院"],
    ".wildcodeschool.com": ["Wild Code School"],
    ".williamandreed.com": ["William and Reed Academy"],
    ".williambrookes.com": ["William Brookes School"],
    ".students.williscollege.com": [
        "Willis College, Business, Technology and Healthcare",
        "https://williscollege.com/",
    ],
    ".williscollege.com": [
        "Willis College, Business, Technology and Healthcare",
        "https://williscollege.com/",
    ],
    ".williston.com": ["Williston Northampton School"],
    ".wilmslowhigh.com": ["Wilmslow High School"],
    ".wirralgrammarboys.com": ["Wirral Grammar School for Boys"],
    ".wis-ecoles.com": ["Web International School"],
    ".wissalacademy.com": ["WISSAL SYSTEMS ACADEMY", "academey"],
    ".woonsocketschools.com": [
        "Woonsocket Area Career and Technical Center",
        "Woonsocket High School",
        "https://woonsocketschools.com/schools/wactc",
        ".group",
    ],
    ".wpsstudent.com": [
        "Domain for students at Winchester High School pull request.",
        "website: http://www.winchesterps.org/",
        "email domain: @wpsstudent.com",
    ],
    ".wrekincollege.com": ["Wrekin College", "https://wrekinoldhall.com/"],
    ".xabiainternationalcollege.com": ["Xabia International College"],
    ".xujc.com": [
        "Xiamen University Jiageng College",
        "Xiamen University Tan Kah Kee College",
    ],
    ".y-nov.com": [
        "Y-nov | Lim'art - Ingésup - Infosup | Carrefour des formations aux métiers du numérique."
    ],
    ".ycswgz.com": ["盐城生物工程高等职业技术学校"],
    ".yhischina.com": [
        "烟台华圣外籍人员子女学校",
        "Yantai huasheng international school",
    ],
    ".ynov.com": [
        "Y-nov | Lim'art - Ingésup - Infosup | Carrefour des formations aux métiers du numérique."
    ],
    ".yoobeecolleges.com": ["Yoobee College of Creative Innovation"],
    ".zealeducation.com": [
        "Zeal College of Engineering and Research",
        ".group",
    ],
    ".zgym45.com": ["Запорізька гімназія №45", "Zaporizhzhya gymnasium 45"],
    ".zhbit.com": ["Beijing Institute of Technology, Zhuhai"],
    ".ziv-school.com": ['מקיף ע"ש זיו', "Makkif Ziv and Marks"],
    ".zubirimanteo.com": ["IES Zubiri-Manteo BHI"],
    ".universita.corsica": ["Università di Corsica Pasquale Paoli"],
    ".esuaca.ac.cr": ["Universidad Autónoma de Centro América"],
    ".fundepos.ac.cr": ["Universidad Fundepos Alma Mater"],
    ".itcr.ac.cr": ["Instituto Tecnológico de Costa Rica"],
    ".uaca.ac.cr": ["Universidad Autónoma de Centro América"],
    ".uam.ac.cr": ["Universidad Americana"],
    ".uca.ac.cr": ["Universidad de Cartago Florencio del Castillo"],
    ".ucatolica.ac.cr": ["Universidad Católica Anselmo Llorente"],
    ".ucem.ac.cr": ["Universidad Centroamericana de Ciencias Empresariales"],
    ".ucenfotec.ac.cr": ["Universidad Cenfotec"],
    ".uci.ac.cr": ["Universidad para la Cooperación Internacional"],
    ".uhispano.ac.cr": ["Universidad Hispanoamericana"],
    ".uhispanoamericana.ac.cr": ["Universidad Hispanoamericana"],
    ".uia.ac.cr": ["Universidad Internacional de las Américas"],
    ".ulacit.ac.cr": ["Universidad Latinoamericana de Ciencia y Tecnología"],
    ".ulasalle.ac.cr": ["Universidad de La Salle"],
    ".ulatina.ac.cr": ["Universidad Latina de Costa Rica"],
    ".ulead.ac.cr": ["Lead University"],
    ".ulicori.ac.cr": ["Universidad Libre de Costa Rica"],
    ".una.ac.cr": ["Universidad Nacional"],
    ".unam.ac.cr": ["Universidad Autonoma Monterrey"],
    ".uned.ac.cr": ["Universidad Estatal a Distancia"],
    ".usam.ac.cr": ["Universidad San Marcos"],
    ".usanmarcos.ac.cr": ["Universidad San Marcos"],
    ".usj.ac.cr": ["Universidad de San José"],
    ".utn.ac.cr": ["Universidad Técnica Nacional"],
    ".utur.ac.cr": ["Universidad del Turismo"],
    ".uveritas.ac.cr": ["Universidad Veritas"],
    ".cuc.cr": ["Colegio Universitario de Cartago"],
    ".ulacit.ed.cr": ["Universidad Latinoamericana de Ciencia y Tecnología"],
    ".estudiantec.cr": ["Costa Rica Institute of Technology"],
    ".est.mep.go.cr": [
        "COTEPECOS (Colegio Técnico Profesional de Educación Comercial y Servicios)",
        "Professional Technical College of Business Education and Services",
    ],
    ".ina.cr": [
        "Instituto Nacional de Aprendizaje",
        "Instituto Nacional de Aprendizaje",
    ],
    ".estudiantes.tec.cr": [
        "Tecnológico de Costa Rica",
        "Costa Rica Technology Institute",
    ],
    ".ucr.cr": ["Universidad de Costa Riza Sede de Guanacaste"],
    ".una.cr": ["Universidad Nacional de Costa Rica"],
    ".uned.cr": ["Universidad Estatal a Distancia"],
    ".co.cu": ["Universidad de Granma"],
    ".cujae.edu.cu": [
        "Instituto Superior Politécnico José Antonio Echeverría"
    ],
    ".ismm.edu.cu": [
        "Instituto Superior Minero Metalúrgico Dr. Antonio Núñez Jiménez"
    ],
    ".reduc.edu.cu": ["Universidad de Camagüey"],
    ".ucf.edu.cu": ["Universidad de Cienfuegos"],
    ".uclv.edu.cu": ["Universidad Central de Las Villas"],
    ".uho.edu.cu": ["Universidad de Holguín"],
    ".uo.edu.cu": ["Universidad de Oriente"],
    ".upr.edu.cu": ["Universidad de Pinar del Río"],
    ".rimed.cu": ["Universidad Pedagógica José Martí, Camagüey"],
    ".uh.cu": ["Universidad de La Habana"],
    ".unica.cu": ["Universidad de Ciego de Avila"],
    ".iscee.edu.cv": [
        "Instituto Superior de Ciências Económicas e Empresariais",
        "http://iscee.edu.cv/",
    ],
    ".um.edu.cv": ["Universidade de Mindelo", "University of Mindelo"],
    ".unicv.edu.cv": ["Universidade Cabo Verde"],
    ".us.edu.cv": ["Universidade de Santiago", "University of Santiago"],
    ".uta.cv": [
        "Instituto de Engenharia e Ciências do Mar",
        "Institute of Engineering and Marine Sciences",
    ],
    ".frateraureliosbo.cw": ["Frater Aurelio SBO"],
    ".uoc.cw": ["University of Curaçao"],
    ".aan.ac.cy": ["American Academy Nicosia"],
    ".ac.ac.cy": ["Americanos College"],
    ".academy.ac.cy": ["American Academy Larnaca"],
    ".americanacademy.ac.cy": ["American Academy School, Limassol"],
    ".ciim.ac.cy": ["Cyprus International Institute of Management (CIIM)"],
    ".cim.ac.cy": ["Cyprus Business School"],
    ".ctleuro.ac.cy": ["The CTL Eurocollege"],
    ".cut.ac.cy": ["Cyprus University of Technology"],
    ".cycollege.ac.cy": ["Cyprus College"],
    ".euc.ac.cy": ["European University of Cyprus"],
    ".stud.fit.ac.cy": ["Frederick University, Nicosia"],
    ".frederick.ac.cy": ["Frederick University"],
    ".live.intercollege.ac.cy": ["Intercollege", "Intercollege"],
    ".nup.ac.cy": ["Neapolis University Pafos"],
    ".ouc.ac.cy": ["Open University of Cyprus"],
    ".ucy.ac.cy": ["University of Cyprus"],
    ".unic.ac.cy": ["University of Nicosia"],
    ".uol.ac.cy": ["University of Limassol"],
    ".isl.cy": ["The Island Private School Of Limassol"],
    ".bryngwyn.cymru": ["Bryngwyn Comprehensive School"],
    ".1kspa-ltm.cz": ["Soukromá střední\xad odborná škola (1. KŠPA)"],
    ".2zsjh.cz": ["Základní škola Jindřichův Hradec II, Janderova 160"],
    ".4zsmb.cz": [
        "4 ZŠ T.G.Masaryka a MŠ Mladá Boleslav",
        "4 ZŠ T.G.Masaryka and MŠ Mladá Boleslav",
    ],
    ".agstepanska.cz": ["Akademické gymnázium Štěpánská"],
    ".ambis.cz": [
        "Vysoká škola regionálního rozvoje a Bankovní institut - AMBIS, a.s."
    ],
    ".amu.cz": ["Academy of Performing Arts"],
    ".bigy-cb.cz": [
        "Biskupské gymnázium J. N. Neumanna a Církevní základní škola"
    ],
    ".bigy.cz": ["Biskupske gymnazium Brno"],
    ".bivs.cz": ["The College of Banking", "Bankovní institut vysoká škola"],
    ".but.cz": ["Brno University of Technology"],
    ".jh-inst.cas.cz": [
        "Ústav fyzikální chemie J. Heyrovského Akademie Věd ČR",
        "J. Heyrovský Institute of Physical Chemistry of the Czech Academy of Sciences",
    ],
    ".math.cas.cz": [
        " Institute of Mathematics of the Czech Academy of Sciences"
    ],
    ".cerge-ei.cz": [
        "Center for Economic Research and Graduate Education - Economics Institute"
    ],
    ".ceskolipska.cz": ["Gymnázium, Praha 9, Českolipská 373"],
    ".cichnovabrno.cz": [
        "High School of informatics, postal services and finance Brno, funded organization"
    ],
    ".copsu.cz": ["VOŠ, SŠ, COP Sezimovo Ústí"],
    ".coptkm.cz": [
        "Střední škola - Centrum odborné přípravy technické Kroměříž"
    ],
    ".creativehill.cz": [
        "STŘEDNÍ ŠKOLA FILMOVÁ, MULTIMEDIÁLNÍ A POČÍTAČOVÝCH TECHNOLOGIÍ, s.r.o."
    ],
    ".cuni.cz": ["Charles University Prague"],
    ".cvut.cz": ["Czech Technical University of Prague"],
    ".czu.cz": ["Czech University of Agriculture Prague"],
    ".delta-skola.cz": [
        "DELTA - Střední škola informatiky a ekonomie",
        "DELTA - High School of Informatics and Economics",
    ],
    ".delta-studenti.cz": [
        "DELTA - Střední škola informatiky a ekonomie",
        "DELTA - High School of Informatics and Economics",
    ],
    ".duhovkagymnazium.cz": ["GYMNÁZIUM DUHOVKA"],
    ".educanet.cz": [
        "EDUCAnet - Gymnázium, střední odborná škola a základní škola Praha, s.r.o."
    ],
    ".educapardubice.cz": [" EDUCA Pardubice – Střední odborná škola"],
    ".educhem.cz": [
        "Střední Škola Educhem a.s.",
        "Official Web: https://educhem.cz",
        "Long-term courses website page: https://educhem.cz/uchazec-o-studium/nabidka-oboru-vzdelavani/informacni-technologie/",
        "Contact: https://educhem.cz/o-skole/uredni-deska/ ",
        "Address: Okružní 128 435 13 Meziboří u Litvínova",
        "Domain: educhem.cz",
    ],
    ".edukomplex.cz": ["European Polytechnic Institute"],
    ".ekodom.cz": ["VOŠ, OA a SZŠ Domažlice"],
    ".evropska33.cz": ["VOŠ, SOŠP a Gymnázium Evropská 33"],
    ".famu.cz": ["Academy of Performing Arts, Film and TV Fakulty"],
    ".frengp.cz": [
        "Gymnázium a Střední průmyslová škola elektrotechniky a informatiky, Frenštát pod Radhoštěm, příspěvková organizace"
    ],
    ".fzu.cz": [
        "Fyzikální ústav AV ČR",
        "Institute of Physics of the Czech Academy of Sciences",
    ],
    ".g8mb.cz": ["GYMNÁZIUM, MLADÁ BOLESLAV, PALACKÉHO 191/1"],
    ".gbl.cz": ["Josef Svatopluk Machar's high school"],
    ".gchd.cz": ["Gymnazium Christiana Dopplera"],
    ".geukaplice.cz": ["SOŠ a SOU Kaplice"],
    ".gfp.cz": [
        "Gymnazium F. Palackeho v Neratovicich",
        "Grammar School of Frantisek Palacky in Neratovice",
    ],
    ".ggg.cz": ["Gymnázium, Praha 8, Ústavní 400"],
    ".ghb.cz": ["\ufeffGymnázium Havlíčkův Brod"],
    ".ghrabuvka.cz": [
        "Gymnázium, Ostrava-Hrabůvka, příspěvková organizace",
        "Gymnazium, Ostrava-Hrabuvka, prispevkova organizace",
    ],
    ".gjak.cz": ["Gymnázium J. A. Komenského a Jazyková škola Uherský Brod"],
    ".gjb-spgs.cz": [
        "Gymnázium Jana Blahoslava a Střední pedagogická škola, Přerov",
        "Jan Blahoslav Grammar School and Secondary Pedagogical School, Přerov",
    ],
    ".gjj.cz": ["Gymnázium Josefa Jungmanna Litoměřice"],
    ".gjk.cz": ["Gymnazium Jana Keplera"],
    ".student.gjp.cz": ["Gymnázium Jiřího z Poděbrad"],
    ".student.gjvj.cz": ["Gymnázium Jana Valeriána Jirsíka"],
    ".gjvj.cz": ["Gymnázium Jana Valeriána Jirsíka"],
    ".gkolin.cz": [
        "Gymnázium, Kolín III, Žižkova 162",
        "Grammar school in Kolín, the Czech Rep.",
    ],
    ".glnb.cz": ["Gymnazium Lipnik nad Becvou"],
    ".gml.cz": ["Gymnázium Matyáše Lercha"],
    ".goa-orlova.cz": ["Gymnázium a Obchodní akademie Orlová"],
    ".gozhorice.cz": ["Zemědělská akademie a Gymnázium Hořice"],
    ".gpjp.cz": ["Gymnázium prof. Jana Patočky", "GPJP"],
    ".zak.gvid.cz": ["Gymanzium Brno Videnska"],
    ".gyarab.cz": ["Gymnázium Arabská"],
    ".gybon.cz": ["Božena Němcová Grammar School"],
    ".gym-tisnov.cz": ["GYMNÁZIUM TIŠNOV", "Grammar School, Tišnov"],
    ".gymberoun.cz": [
        "Gymnázium Joachima Barranda Beroun",
        "Joachim Barrand Beroun Grammar School",
    ],
    ".gymhu.cz": ["Gymnazium dr. A. Hrdlicky, Humpolec"],
    ".gymi.cz": [
        "Gymnázium Mimoň, Gymnázium, Mimoň, Letná 263, příspěvková organizace"
    ],
    ".gymjh.cz": [
        "Gymnázium Jaroslava Heyrovského, Prague",
        "https://www.gymjh.cz/",
    ],
    ".gymkc.cz": ["Gymnázium Karla Čapka v Dobříši"],
    ".gymkyjov.cz": [
        "Klvaňovo gymnázium a střední zdravotnická škola Kyjov, příspěvková organizace"
    ],
    ".gymnasiumkladno.cz": ["Gymnasium Kladno"],
    ".gympb.cz": [
        "Gymnázium, Příbram, Legionářů 402",
        "Grammar School Příbram",
    ],
    ".gymspit.cz": ["Gymnázium, Praha 9, Špitálská 700"],
    ".gymstr.cz": ["Gymnázium, Strakonice, Máchova 174"],
    ".gymzn.cz": ["Gymnázium Dr. Karla Polesného"],
    ".gymzr.cz": ["Gymnazium Zdar nad Sazavou"],
    ".gyohavl.cz": [
        "Gymnázium Olgy Havlové, Ostrava-Poruba",
        "Olga Havlova Grammar School, Ostrava-Poruba",
    ],
    ".gypce.cz": [
        "Gymnázium, Pardubice, Dašická 1083",
        "Gymnasium, Pardubice, Dašická 1083",
    ],
    ".infis.cz": [
        "Střední škola informatiky a finančních služeb, Plzeň, Klatovská 200G",
        "Secondary School of Informatics and Financial Services, Plzeň, Klatovská 200G",
    ],
    ".infovsem.cz": [
        "University of economics and management Prague",
        "Vysoká škola ekonomie a managementu",
    ],
    ".isp.cz": ["International School of Prague", "ISP"],
    ".iss-cheb.cz": ["ISŠ Cheb – Integrovaná střední škola Cheb, p. o."],
    ".itgymnazium.cz": ["1. IT Gymnázium, s.r.o."],
    ".jaroska.cz": [
        "Gymnázium Brno, třída Kapitána Jaroše, příspěvková organizace"
    ],
    ".jcu.cz": ["University of South Bohemia"],
    ".jirovcovka.cz": ["Gymnázium, České Budějovice, Jirovcova 8"],
    ".kavalirka.cz": ["Gymnázium, Praha 5, Nad Kavalírkou 1"],
    ".kyberna.cz": ["High School and College of Applied Cybernetic"],
    ".labyrinthschool.cz": [
        "LABYRINTH – gymnázium a základní škola, s.r.o.",
        "LABYRINTH – Grammar school and primary school, s.r.o.",
    ],
    ".matfyz.cz": [
        "Matematicko-fyzikální fakulta Univerzity Karlovy v Praze",
        "Faculty of Mathematics and Physics of the Charles University in Prague",
    ],
    ".mendelu.cz": ["Mendel University in Brno"],
    ".mensagymnazium.cz": ["Mensa gymnázium, o.p.s."],
    ".meruzalka.cz": ["Meruzalka-Montessori MŠ a ZŠ v Jihlavě"],
    ".mg-akademie.cz": ["\ufeffSOŠ Manažerská Akademie"],
    ".mikulasske.cz": ["Gymnázium, Plzeň, Mikulášské nám. 23"],
    ".mkgym.cz": ["Gymnázium Moravský Krumlov, příspěvková organizace"],
    ".muni.cz": ["Masaryk University"],
    ".mup.cz": [
        "Metropolitní univerzita Praha",
        "Metropolitan University Prague",
    ],
    ".nosch.cz": ["Střední odborná škola NET OFFICE Orlová"],
    ".novyporg.cz": ["Nový Porg Základní Škola a Gymnázium"],
    ".oa-opava.cz": [
        "Obchodní akademie a Střední odborná škola logistická, Opava, příspěvková organizace"
    ],
    ".oaopava.cz": [
        "Obchodní akademie a Střední odborná škola logistická, Opava, příspěvková organizace"
    ],
    ".oauh.cz": ["Obchodní Akademie Uherské Hradiště"],
    ".oavm.cz": ["Obchodní akademie a VOŠ Valašské Meziříčí"],
    ".odbskmb.cz": [
        "STŘEDNÍ ODBORNÁ ŠKOLA A STŘEDNÍ ODBORNÉ UČILIŠTĚ, MLADÁ BOLESLAV, JIČÍNSKÁ 762"
    ],
    ".omska.cz": ["Gymnázium Omská"],
    ".orangefactory.cz": [
        "Soukroma VOS umeni a reklamy s.r.o. Orange Factory"
    ],
    ".orbiszlin.cz": [
        "ORBIS, MATEŘSKÁ ŠKOLA, ZÁKLADNÍ ŠKOLA A STŘEDNÍ ŠKOLA, S.R.O.",
        "ORBIS, KINDERGARTEN, PRIMARY SCHOOL AND SECONDARY SCHOOL, S.R.O.",
    ],
    ".ossp.cz": [
        "Odborná střední škola podnikání a mediální tvorby Kolín s.r.o. "
    ],
    ".osu.cz": ["University of Ostrava"],
    ".pbis.cz": ["Prague British International School"],
    ".polac.cz": ["Police Academy of Czech Republic"],
    ".porg.cz": ["PORG – gymnázium a základní škola, o. p. s. "],
    ".praguecollege.cz": ["Prague College"],
    ".prumkadc.cz": [
        "Vyšší odborná škola a Střední průmyslová škola strojní, stavební a dopravní, Děčín, příspěvková organizace"
    ],
    ".pslib.cz": [
        "Střední průmyslová škola strojní a elektrotechnická a Vyšší odborná škola Liberec"
    ],
    ".pspbystrice.cz": [
        "Základní škola a mateřská škola Stanisława Hadyny s polským jazykem vyučovacím Bystřice 366, okr. Frýdek-Místek, příspěvková organizace",
        "Stanisław Hadyna Elementary School and Kindergarten with Polish language of instruction Bystřice 366, okr. Frýdek-Místek, contributory organization",
    ],
    ".purkynka.cz": [
        "Střední průmyslová škola Brno, Purkyňova, příspěvková organizace"
    ],
    ".savs.cz": ["ŠKODA AUTO Vysoká škola", "ŠKODA AUTO University"],
    ".schs.cz": ["Svobodná chebská škola"],
    ".sgagy.cz": ["Sportovní gymnázium Kladno"],
    ".skolaac.cz": [
        "Střední škola André Citroëna Boskovice, příspěvková organizace"
    ],
    ".skolagaia.cz": [
        "Mateřská škola a základní škola GAIA",
        "GAIA Kindergarten and Elementary School",
    ],
    ".skolajecna.cz": [
        "Vyšší odborná škola zdravotnická SŘMR",
        "Higher vocational school of healthcare SŘMR",
    ],
    ".skolakrizik.cz": [
        "Vyšší odborná škola a střední průmyslová škola elektrotechnická Františka Křižíka"
    ],
    ".slu.cz": ["Silesian University"],
    ".sos-jh.cz": ["SOŠ a SOU Jindřichův Hradec"],
    ".sosklobouky.cz": ["Městská střední odborná škola Klobouky u Brna"],
    ".sostp.cz": [
        "Hotelová škola, Obchodní akademie a Střední průmyslová škola Teplice"
    ],
    ".student.sostrinec.cz": [
        "Střední odborná škola Třineckých železáren",
        "Secondary Technical School TŽ",
    ],
    ".sosvel.cz": [
        "Střední odborná škola strojní a elektrotechnická Velešín",
        "Secondary Vocational School of Mechanical and Electrical Engineering Velešín",
    ],
    ".sps-cl.cz": ["Střední průmyslová škola Česká Lípa"],
    ".sps-karvina.cz": [
        "Střední průmyslová škola, Karviná, příspěvková organizace"
    ],
    ".sps-pi.cz": ["SPŠ a VOŠ Písek"],
    ".sps-prosek.cz": ["Střední průmyslová škola na Proseku"],
    ".sps-tabor.cz": ["SPŠ strojní a stavební, Tábor"],
    ".sps-tachov.cz": [
        "Střední průmyslová škola, Tachov, Světce 1",
        "High School industrial school, Tachov, Světce 1",
    ],
    ".spscv.cz": ["SPS a VOS Chomutov"],
    ".spse.cz": ["SPŠE a VOŠ Pardubice"],
    ".spseiostrava.cz": [
        "Upper Secondary Technical School of Electrical Engineering and Computer Science"
    ],
    ".spsejecna.cz": ["SPŠE Ječná"],
    ".spselit.cz": [
        "Střední průmyslová škola elektrotechniky a informačních technologií"
    ],
    ".spseol.cz": [
        "Vyšší odborná škola a Střední průmyslová škola elektrotehcnická Olomouc"
    ],
    ".spseplzen.cz": ["VOŠ a SPŠE Plzeň"],
    ".spshranice.cz": ["Střední průmyslová škola Hranice"],
    ".spsjc.cz": ["VOŠ a SPŠ, Jičín"],
    ".spsmb.cz": ["Střední průmyslová škola Mladá Boleslav"],
    ".spsoafm.cz": [
        "Střední průmyslová škola a obchodní akademie, Frýdek-Místek",
        "Secondary High School - SPSOAFM",
    ],
    ".spsostrov.cz": [
        "Střední průmyslová škola Ostrov, příspěvková organizace"
    ],
    ".spspzlin.cz": [
        "\ufeffStřední průmyslová škola polytechnická – COP Zlín"
    ],
    ".spsrakovnik.cz": [
        "Střední průmyslová škola Emila Kolbena Rakovník, příspěvková organizace"
    ],
    ".spssol.cz": ["Střední průmyslová škola strojnická Olomouc"],
    ".spsstavbrno.cz": ["Střední průmyslová škola stavební Brno"],
    ".spstrutnov.cz": ["Střední průmyslová škola Trutnov Školní 101"],
    ".spsul.cz": [
        "Střední průmyslová škola, Ústí nad Labem, Resslova 5, příspěvková organizace"
    ],
    ".spszr.cz": ["VOŠ a SPŠ Žďár nad Sázavou"],
    ".ssakhk.cz": ["High School and College of Applied Cybernetic"],
    ".ssemi.cz": ["Střední škola elektrotechniky, multimédií a informatiky"],
    ".ssinfotech.cz": ["Stredni skola informacnich technologii, s.r.o."],
    ".sspbrno.cz": [
        "High School of Electrical Engineering and Information Technology"
    ],
    ".ssphzuh.cz": [
        "Střední škola průmyslová, hotelová, zdravotnická a Vyšší odborná škola Uherské Hradiště",
        "Secondary Technical, Hotel, Nursing and Higher vocational school Uherské Hradiště",
    ],
    ".ssps.cz": ["Smíchovská střední průmyslová škola"],
    ".sspu-opava.cz": ["Střední škola průmyslová a umělecká Opava"],
    ".sssenp.cz": [
        "Střední škola strojírenská a elektrotechnická Nová Paka",
        "Secondary School of Mechanical and Electrical Engineering Nová Paka",
    ],
    ".sssvt.cz": ["Soukromá střední škola výpočetní techniky"],
    ".sstas-karvina.cz": [
        "Střední Škola Techniky a Služeb Karviná",
        "High School of Technology and Services Karviná",
    ],
    ".stavskola.cz": [
        "Střední průmyslová škola stavební akademika Stanislava Bechyně Havlíčkův Brod",
        "High school for construction od  akademic Stanislava Bechyně in Havlíčkův Brod",
    ],
    ".sting.cz": ["Vysoká škola Sting"],
    ".stredniskola.cz": ["Střední škola informatiky a právních studií"],
    ".studentstc.cz": ["Student Trainee Center, Czech Republic"],
    ".gy.svitavy.cz": [
        "Gymnázium, obchodní akademie a jazyková škola Svitavy",
        "Gymnasium, Business Academy and Language School Svitavy",
    ],
    ".tul.cz": ["Technical University of Liberec"],
    ".ufe.cz": [
        "Institute of Photonics and Electronics, Czech Academy of Sciences"
    ],
    ".uhk.cz": ["University of Hradec Králové"],
    ".ujep.cz": ["University of Jan Evangelista Purkyne"],
    ".unicorncollege.cz": ["Unicorn College"],
    ".unob.cz": ["University of Defence"],
    ".unva.cz": ["University of Northern Virginia, Prague Campus"],
    ".unyp.cz": ["University of New York in Prague"],
    ".upce.cz": ["University of Pardubice"],
    ".upol.cz": ["Palacky University"],
    ".utb.cz": ["Tomas Bata University in Zlin"],
    ".uzlabina.cz": ["SPŠE v Úžlabině"],
    ".vassboskovice.cz": [
        "Vyšší odborná škola ekonomická a zdravotnická a Střední škola Boskovice"
    ],
    ".vfu.cz": ["University of Veterinary and Pharmaceutical Science"],
    ".vitkovickastrendni.cz": ["VÍTKOVICKÁ STŘEDNÍ PRŮMYSLOVÁ ŠKOLA"],
    ".vosp.cz": ["College of Media and Journalism"],
    ".vsb.cz": ["Technical University of Mining and Metallurgy Ostrava"],
    ".vscht.cz": ["Prague Institute of Chemical Technology"],
    ".vsci.cz": ["Cevro Institut College"],
    ".vse.cz": ["University of Economics Prague"],
    ".vsfs.cz": ["The University of Finance and Administration"],
    ".vslg.cz": [
        "Vysoká škola logistiky",
        "The College of Logistics (VŠLG), Prague",
    ],
    ".vslib.cz": ["Technical University of Liberec"],
    ".vsp.cz": ["University of Education Hradec Kralove"],
    ".vspj.cz": ["College of Polytechnics Jihlava"],
    ".vspp.cz": ["University of Education business and law"],
    ".vsps-su.cz": ["VOŠ a SPŠ Šumperk"],
    ".vstecb.cz": [
        "Vysoká škola technická a ekonomická v Českých Budějovicích"
    ],
    ".vut.cz": ["Brno University of Technology"],
    ".vutbr.cz": ["Brno University of Technology"],
    ".wigym.cz": [
        "Wichterlovo gymnázium, Ostrava - Poruba",
        "Wichterle Grammar School, Ostrava - Poruba",
    ],
    ".zaalejka.cz": ["ZŠ Za Alejí"],
    ".zcu.cz": ["University of West Bohemia"],
    ".zemsbn.cz": [
        "Vyšší odborná škola a Střední zemědělská škola Benešov",
        "Agricultural College and Agricultural Secondary School Benešov",
    ],
    ".zsgvitkov.cz": ["Základní škola a Gymnázium Vítkov"],
    ".zshanusovice.cz": ["Elementary School in Hanušovice"],
    ".zsjak.cz": ["Základní škola J. A. Komenského"],
    ".zsjunacka.cz": ["Základní škola Ostrava-Stará Bělá"],
    ".zskomenskeho.cz": [
        "Základní škola, Kroměříž, Komenského náměstí 440, příspěvková organizace"
    ],
    ".zskv.cz": ["Základní škola Chodov", "Secondary school Chodov"],
    ".zsnachodovci.cz": [" ZŠ Na Chodovci"],
    ".zspodskalkou.cz": ["ZŠ Pod Skalkou"],
    ".zssvat.cz": [
        "Základní škola Svatoplukova 7, Šternberk, příspěvková organizace"
    ],
    ".zstsobra.cz": ["Základní škola Tomáše Šobra a Mateřská škola Písek"],
    ".student.42berlin.de": ["42 Berlin"],
    ".student.42heilbronn.de": ["42 Heilbronn gGmbH", "42 Heilbronn"],
    ".student.42wolfsburg.de": ["42wolfsburg", "42wolfsburg"],
    ".schueler.6072-fuerth.de": [
        "Martin-Segitz-Schule – Staatliche Berufsschule III Fürth"
    ],
    ".Birklehof.de": ["Schule Birklehof e.V. Hinterzarten"],
    ".aagcux.de": ["Amandus-Abendroth-Gymnasium Cuxhaven"],
    ".abendgymnasium-muenster.de": ["Abendgymnasium Münster"],
    ".extern.abk-stuttgart.de": [
        "Staatliche Akademie der Bildenden Künste Stuttgart"
    ],
    ".stud.abk-stuttgart.de": [
        "Staatliche Akademie der Bildenden Künste Stuttgart"
    ],
    ".abs-it-kiel.de": [
        "ABS-IT UG (haftungsbeschränkt)",
        "Geschäftsführer Paul Klein M.A.",
        "Werftstraße 193",
        "24143 Kiel",
        "Email: info@abs-it-kiel.de",
        "Domain: https://www.abs-it-kiel.de",
    ],
    ".adolfinum.de": ["Gymnasium Adolfinum Moers"],
    ".aeg-boeblingen.de": ["Albert-Einstein-Gymnasium Böblingen"],
    ".aeg-nb.de": ["Albert-Einstein-Gymnasium Neubrandenburg"],
    ".aegmail.de": ["Albert-Einstein-Gymnasium Duisburg-Rumeln"],
    ".aibgym.de": ["Gymnasium Bad Aibling"],
    ".students.ajc-bk.de": ["Adam - Josef - Cüppers - Berufskolleg Ratingen"],
    ".akad.de": [
        "AKAD Hochschulen für Berufstätige, Fachhochschule Leipzig",
        "Hochschule für Berufstätige Rendsburg",
    ],
    ".albbw.de": ["Annedore-Leber-Berufsbildungswerk Berlin"],
    ".sus.alfred-wegener-schule.de": ["Alfred Wegener Schule"],
    ".aloberlin.de": [
        "Annedore-Leber-Berufsbildungswerk",
        "Annedoore-Leber Vocational School",
    ],
    ".alstergymnasium.de": ["Alster Gymnasium"],
    ".gmg.amberg.de": ["Gregor-Mendel-Gymnasium Amberg"],
    ".ammersee-gymnasium.de": ["Ammersee-Gymnasium"],
    ".amseegym.de": ["Ammersee-Gymnasium"],
    ".anna-schmidt-schule.de": ["Anna Schmidt Schule"],
    ".anno-gymnasium.de": ["Städtisches Anno-Gymnasium Siegburg"],
    ".schueler.ars-mr.de": ["Adolf-Reichwein-Schule Marburg"],
    ".ars-mr.de": ["Adolf Reichwein Schule"],
    ".asfh-berlin.de": [
        "Alice-Salomon-Fachhochschule für Sozialarbeit und Sozialpädagogik Berlin"
    ],
    ".asg-ehst.de": ["Albert-Schweitzer Gymnasium Eisenhüttenstadt"],
    ".asg-huerth.de": ["Albert-Schweitzer-Gymnasium Hürth"],
    ".ass-vs.de": ["Albert-Schweitzer-Schule"],
    ".asw-berufsakademie.de": ["ASW – Berufsakademie Saarland e.V."],
    ".athenetz.de": ["Gymnasium Athenaeum Stade"],
    ".atiw.de": ["ATIW Berufskolleg"],
    ".augustana.de": ["Augustana Hochschule Neuendettelsau"],
    ".avg-wesel.de": ["Andreas-Vesalius-Gymnasium"],
    ".avs-itzehoe1.de": ["Auguste-Viktoria-Schule Itzehoe, Hs. 1"],
    ".b-tu.de": ["Brandenburg University of Technology Cottbus–Senftenberg"],
    ".b3-fuerth.de": [
        "Martin-Segitz-Schule / Staatliche Berufsschule III Fürth",
        "Martin-Segitz-Schule / State vocational school III Fürth",
    ],
    ".ba-bautzen.de": [
        "Berufsakademie Sachsen Staatliche Studienakademie Bautzen"
    ],
    ".rz.ba-dresden.de": ["Staatliche Studienakademie Dresden"],
    ".ba-dresden.de": [
        "Berufsakademie Sachsen Staatliche Studienakademie Dresden"
    ],
    ".ba-eisenach.de": ["Berufsakademie Eisenach"],
    ".ba-fulda.de": [
        "Private Berufsakademie Fulda University of Cooperative Education ",
        "http://www.ba-fulda.de",
    ],
    ".ba-glauchau.de": ["Staatliche Studienakademie Glauchau"],
    ".ba-leipzig.de": ["Berufsakademie Leipzig"],
    ".ba-riesa.de": [
        "Berufsakademie Sachsen Staatliche Studienakademie Riesa"
    ],
    ".ba-rm.de": ["Berufsakademie Rhein Main"],
    ".ba-sachsen.de": [
        "Berufsakademie Sachsen Staatliche Studienakademie Leipzig"
    ],
    ".sibi.badhonnef.de": ["Siebengebrigsgymnasium"],
    ".barnim-gym.de": ["Barnimgymnasium Berlin-Lichtenberg"],
    ".bbbk.de": ["Bertolt-Brecht-Berufskolleg"],
    ".bbq.de": ["BBQ - Baumann Bildung und Qualifizierung"],
    ".bbs-buchholz.de": [
        "BBS Buchholz",
        "Berufsbildende Schulen Buchholz in der Nordheide",
        "www.bbs-buchholz.de",
        "www.bbs-buchholz.de/internet/bildungsangebote/fachrichtungen/fachrichtungen.php#Informationsverarbeitung",
    ],
    ".bbs-buxtehude.de": ["Berufsbildende Schulen Buxtehude"],
    ".bbs-einbeck.de": ["Berufsbildende Schulen Einbeck"],
    ".bbs-holzminden.de": [
        "Georg-von-Langen-Schule",
        "Georg-von-Langen School",
    ],
    ".bbs-lingen-wirtschaft.de": [
        "BBS Wirtschaft Lingen",
        "BBS Lingen economy",
    ],
    ".bbs-me.de": ["BBS-ME – Otto-Brenner-Schule "],
    ".bbs-meppen.de": ["Berufsbildende Schulen Meppen"],
    ".bbs-montabaur.de": ["BBS Montabaur"],
    ".bbs-nienburg.de": [
        "Berufsbildende Schulen des Landkreises Nienburg/Weser"
    ],
    ".bbs-ohz.de": ["Berufsbildende Schulen Osterholz-Scharmbeck"],
    ".bbs-row.de": ["BBS Rotenburg"],
    ".bbs-schueler.de": ["Berufsbildende Schulen Walsrode"],
    ".bbs-stadthagen.de": [
        "Berufsbildende Schule Stadthagen",
        "vocational schools Stadthagen",
    ],
    ".bbs-verden.de": ["BBS Verden"],
    ".bbs-westerburg.de": ["BBS Westerburg", "HBFI Westerburg"],
    ".bbs-wittlich.de": ["Berufsbildende Schule Wittlich"],
    ".bbs-ww.de": ["BBS Westerburg", "HBFI Westerburg"],
    ".bbs1-gifhorn.de": ["BBS1 Gifhorn", "Berufsbildene Schule 1 Gifhorn"],
    ".bbs1-kl.de": ["Berufsbildenden Schulen I Kaiserslautern"],
    ".bbs1-lg.de": ["Berufsbildenden Schulen I Lüneburg"],
    ".bbs1-lueneburg.de": ["BBS I Lüneburg"],
    ".unterricht.bbs1-mainz.de": ["BBS 1 Mainz"],
    ".bbs1emd.de": ["Berufsbildende Schulen I Emden"],
    ".bbs2-mainz.de": ["Sophie Scholl Schule Mainz"],
    ".bbs2-northeim.de": ["BBS 2 Northeim"],
    ".bbs2.de": [
        "Berufsbildende Schule 2 Delmenhorst (BBS 2 Delmenhorst)",
        "Kerschensteiner School Delmenhorst",
    ],
    ".bbs2leer.de": ["BBS 2 Leer"],
    ".bbs2wob.de": ["Berufsbildende Schulen 2 Wolfsburg"],
    ".bbsandernach.de": ["BBS Andernach August-Horch-Schule"],
    ".bbssoltau.de": ["Berufsbildende Schulen Soltau"],
    ".students.bbssth.de": [
        "Berufsbildende Schule Stadthagen",
        "vocational schools Stadthagen",
    ],
    ".bbssth.de": [
        "Berufsbildende Schule Stadthagen",
        "vocational schools Stadthagen",
    ],
    ".bbst-clp.de": ["Berufsbildende Schule Technik Cloppenburg"],
    ".bbstghs.de": ["\ufeffBerufliches Gymnasium Technik Bad Kreuznach"],
    ".bbstghs365.de": ["\ufeffBerufliches Gymnasium Technik Bad Kreuznach"],
    ".bbw-fi.de": ["SFZ Förderzentrum gGmbH (Berufsbildungswerk Chemnitz)"],
    ".bbw-rki-berlin.de": [
        "Rotkreuz-Institut Berufsbildungswerk",
        "Homepage:https://www.rkibbw.de/",
        "IT-Course example: https://www.rkibbw.de/angebote/berufsausbildung/fachinformatiker-anwendungsentwicklung.html",
    ],
    ".bbwa-abensberg.de": [
        "BBW Abensberg",
        "Abensberg vocational training center (loose translation)",
    ],
    ".sus.bbz-rd-eck.de": ["BBZ Berufsbildungszentrum Rendsburg-Eckernförde"],
    ".bbzsm.de": ["Berufsbildungszentrum Schmalkalden"],
    ".bccn-berlin.de": [
        "BERNSTEIN CENTER FOR COMPUTATIONAL NEUROSCIENCE, BERLIN"
    ],
    ".bcw-gruppe-net.de": ["bcw-gruppe-net"],
    ".berlin-international.de": [
        "Berlin International University of Applied Sciences"
    ],
    ".berlin.de": ["Fachhochschule für Verwaltung und Rechtspflege Berlin"],
    ".sus.bertha-online.de": ["Bertha-von-Suttner Schule "],
    ".berufsakademie-oldenburg.de": ["Berufsakademie Oldenburg"],
    ".berufsakademie-sh.de": ["Berufsakademie Schleswig-Holstein"],
    ".schueler.berufskolleg.de": [
        "Berufskolleg Hilden",
        "Berufskolleg Hilden des Kreises Mettmann",
    ],
    ".berufskolleg-beckum.de": [
        "Berufskolleg Beckum des Kreises Warendorf Europaschule"
    ],
    ".students.berufskolleg-borken.de": [
        "Berufskolleg Borken",
        "Borken Vocational College",
    ],
    ".berufskolleg-borken.de": ["Berufskolleg Borken", "Berufskolleg Borken"],
    ".berufskolleg-geilenkirchen.de": [
        "Berufskolleg Ernaehrung, Sozialwesen, Technik des Kreises Heinsberg in Geilenkirchen"
    ],
    ".berufskolleg-kleve.de": ["Berufskolleg des Kreises Kleve in Kleve"],
    ".berufskolleg-meschede.de": ["Berufskolleg Meschede"],
    ".berufskolleg-rheine.de": ["Berufskolleg Rheine des Kreises Steinfurt"],
    ".berufskolleg-technik.de": [
        "Berufskolleg Technik des Kreises Siegen-Wittgenstein"
    ],
    ".berufskolleg-werne.de": ["Freiherr-vom-Stein Berufskolleg Werne"],
    ".berufskolleg.de": [
        "Berufskolleg Hilden des Kreises Mettmann",
        "Berufskolleg Hilden",
    ],
    ".berufsschule-dachau.de": [
        "Staatliche Berufsschule Dachau",
        "Nikolaus-Lehner-Schule",
    ],
    ".berufsschule-fs.de": ["Berufsschule Freising"],
    ".best-sabel.de": ["BEST-Sabel Designschule Berlin Germany"],
    ".bethel.de": ["Kirchliche Hochschule Bethel"],
    ".beuth-hochschule.de": ["Beuth Hochschule für Technik Berlin"],
    ".teiln.bfw-dortmund.de": [
        "Berufsförderungswerk Dortmund",
        "vocational training organisation Dortmund (roughly translated)",
    ],
    ".bfw-hamburg.de": ["Berufsförderungswerk Hamburg", "Bfw Hamburg"],
    ".bfw-hamm.de": [
        "Berufsförderungswerk Hamm GmbH",
        "Berufsförderungswerk Hamm",
        "BFW Hamm",
    ],
    ".bfw-koblenz.de": ["CJD Berufsförderungswerk Koblenz Gemeinnützige GmbH"],
    ".bfw-koeln.de": ["Berufsförderungswerk Köln"],
    ".bfw-leipzig.de": [
        "Berufsförderungswerk Leipzig gemeinnützige GmbH",
        "Berufsförderungswerk Leipzig",
        "BFW Leipzig",
    ],
    ".bfw-oberhausen.de": ["Berufsförderungswerk Oberhausen, Primary Domain"],
    ".m365.bfwbb-lernen.de": [
        "Berufsförderungswerk Berlin Brandenburg Standort Mühlenbeck"
    ],
    ".bfwob.de": ["Berufsförderungswerk Oberhausen"],
    ".bgbentheim.de": ["Burg-Gymnasium Bad Bentheim"],
    ".stud.bhh.de": ["Berufliche Hochschule Hamburg (BHH)"],
    ".bht-berlin.de": ["Berliner Hochschule für Technik"],
    ".bib.de": ["Fachhochschule für die Wirtschaft"],
    ".biioe.de": ["Biionisches Institut fur okologische Energieforschung"],
    ".gym-muentzer.bildung-lsa.de": [
        'GIEBICHENSTEIN-GYMNASIUM "THOMAS MÜNTZER" HALLE'
    ],
    ".gym-siemens.bildung-lsa.de": ["Werner-von-Siemens Gymnasium Magdeburg"],
    ".bildung-unna.de": ["Hellweg Berufskolleg Unna"],
    ".bimm-institute.de": ["BIMM University Berlin"],
    ".bits-iserlohn.de": [
        "BiTS - Business and Information Technology School gGmbH"
    ],
    ".bk-berliner-platz.de": ["Berufskolleg Berliner Platz"],
    ".bk-deutz.de": ["Berufskolleg Deutzer Freiheit "],
    ".bk-h.de": ["Berufskolleg Hattingen"],
    ".bk-hennef.de": [
        "Carl-Reuther-Berufskolleg des Rhein-Sieg-Kreises in Hennef"
    ],
    ".365.bk-lk.de": ["Berufskolleg Lübbecke"],
    ".bk-opladen.de": ["Berufskolleg Opladen"],
    ".bk-technik-dueren.de": [
        "Berufskolleg für Technik Düren",
        "https://www.bkt-dueren.de/",
    ],
    ".bk-technik-moers.de": ["Berufskolleg für Technik Moers"],
    ".bk-tm.de": ["Berufskolleg Platz der Republik fur Technik und Medien"],
    ".bkgeldern.de": ["Berufskolleg Geldern des Kreises Kleve"],
    ".bkgut.de": [
        "Berufskolleg für Gestaltung und Technik Aachen",
        "Vocational college for design and engineering, Aachen",
        "Teacher accounts",
    ],
    ".bkhaspel.de": ["Berufskolleg Am Haspel"],
    ".bksuedstadt.de": ["Berufskolleg Südstadt"],
    ".schueler.bkt-luedenscheid.de": [
        "Berufskolleg für Technik des Märkischen Kreises in Lüdenscheid"
    ],
    ".bkt-luedenscheid.de": [
        "Berufskolleg für Technik des Märkischen Kreises in Lüdenscheid"
    ],
    ".student.bkukr.de": ["Berufskolleg Krefeld Uerdingen"],
    ".goethegym.blk.de": ["Goethegymnasium Weißenfels"],
    ".hhek.bonn.de": ["Heinrich Hertz Europakolleg"],
    ".bracke-igs.de": ["Wilhelm Bracke Gesamtschule"],
    ".brand-university.de": [
        "Brand University of Applied Sciences, Hamburg, Germany"
    ],
    ".schule.bremen.de": ["Bremer Schulzentrum"],
    ".bs-an.de": ["Staatliche Berufsshule I Ansbach"],
    ".bs-elmshorn.de": [
        "Berufliche Schule des Kreises Pinneberg in Elmshorn, Europaschule",
        "http://www.bs-elmshorn.de",
    ],
    ".bs-erlangen.de": ["Staatliche Berufsschule Erlangen"],
    ".schueler.bs-ffb.de": ["Staatliche Berufsschule Fürstenfeldbruck"],
    ".bs-gelnhausen.de": [
        "Berufliche Schulen des Main-Kinzig-Kreises in Gelnhausen (Teacher accounts)"
    ],
    ".bs-gn.de": [
        "Berufliche Schulen des Main-Kinzig-Kreises in Gelnhausen (Student accounts)"
    ],
    ".bs-hassfurt.de": [
        "Heinrich-Thein-Schule",
        "Staatliches Berufliches Schulzentrum Haßfurt",
    ],
    ".bs-intra.de": ["Staatliches Berufliches Schulzentrum Roth"],
    ".bs-korbach.de": [
        "Berufliche Schulen des Landkreises Waldeck-Frankenberg in Korbach und Bad Arolsen AöR"
    ],
    ".bs-mil-obb.de": ["Berufsschule Miltenberg Obernburg"],
    ".bs-riedlingen.de": ["Berufliche Schule Riedlingen"],
    ".bs-schramberg.de": ["Berufliche Schulen Schramberg"],
    ".bs-wangen.de": ["Berufliches Schulzentrum Wangen"],
    ".bs1-bt.de": [
        "Staatliche Berufsschule I Bayreuth",
        "Link to IT-course (3 years):",
        "  https://www.bs1-bt.de/berufsschule/it",
        "Staff Email:",
        "  firstname.surname@bs1-bt.de",
        "Students Emails differ from staff and are hosted via Microsoft, tha pattern is as follows:",
        "  firstname.surename@berufsschulebt1.onmicrosoft.com",
    ],
    ".bs1-kempten.de": ["Staatliche Berufsschule I Kempten"],
    ".bs1-landshut.de": [
        "Staatliche Berufsschule 1 Landshut mit Berufsfachschule für Informatik",
        "Public Vocational School 1 Landshut with Vocational School for Informatics",
    ],
    ".bs19hh.de": ["Berufliche Schule Farmsen 19, Hamburg"],
    ".bs1in.de": ["Staatliche Berufsschule I Ingolstadt"],
    ".bs1traunstein.de": ["Staatliche Berufsschule 1 Traunstein"],
    ".bs2pa.de": ["Staatliche Berufsschule 2 Passau"],
    ".bs7-augsburg.de": ["Berufsschule 7 ", "Career School 7 "],
    ".bso-hef.de": ["Berufliche Schulen Bad Hersfeld"],
    ".lernende.bspaf.de": ["Berufsschule Pfaffenhofen"],
    ".bsutaunus.de": ["Berufliche Schulen Untertaunus"],
    ".student.bsz-bietigheim.de": ["BSZ Bietigheim-Bissingen"],
    ".bsz-eoplauen.de": ["Berufliches Schulzentrum e.o.plauen"],
    ".s.bsz-kulmbach.de": [
        "Adalbert-Raps-Schule - Berufliches Schulzentrum Kulmbach"
    ],
    ".bsz-vogtland.de": [
        "Berufliches Schulzentrum Vogtland",
        "Vogtland Vocational School Center for business and IT",
    ],
    ".bsz-waldkirch.de": ["Berufliches Schulzentrum Waldkirch"],
    ".bsz-wiesau.de": [
        "Staatliches Berufliches Schulzentrum Wiesau",
        "State Vocational School Center Wiesau",
    ],
    ".bszh.de": ["Staatliches Berufsschulzentrum Hermsdorf"],
    ".bszn-da.de": ["Berufsschulzentrum Nord Darmstadt"],
    ".bsznl.de": ["Staatliches Berufliches Schulzentrum Nürnberger Land"],
    ".bt-office.de": ["Berufskolleg für Technik des Kreis Borken"],
    ".buhmann-hannover.de": [
        "Dr. Buhmann Schule & Akademie Hannover",
        "Dr. Buhmann School & Academy Hanover",
    ],
    ".buhmann.de": [
        "Dr. Buhmann Schule & Akademie Hannover",
        "Dr. Buhmann School & Academy Hanover",
    ],
    ".burg-halle.de": ["Burg Giebichenstein Kunsthochschule Halle"],
    ".burgaugymnasium.de": ["Burgaugymnasium Düren"],
    ".burggymnasium-altena.de": ["Burggymnasium Altena"],
    ".businessschool-berlin.de": ["BSP Business & Law School Berlin"],
    ".zsl.kv.bwl.de": [
        "Zentrum für Schulqualität und Lehrerbildung (Kultusverwaltung Land BW)"
    ],
    ".bws-hofheim.de": ["Brühlwiesenschule Hofheim"],
    ".schueler.bwv-ac.de": [
        "Berufskolleg für Wirtschaft und Verwaltung der StädteRegion Aachen"
    ],
    ".bwv-ahaus.de": ["Berufskolleg Wirtschaft und Verwaltung Ahaus"],
    ".bztg-oldenburg.de": [
        "Bildungszentrum für Technik und Gestaltung Oldenburg"
    ],
    ".caeci-ol.de": ["Gymnasium Cäcilienschule Oldenburg"],
    ".carl-miele-berufskolleg.de": ["Carl-Miele-Berufskolleg für Technik"],
    ".carl-orff-gym.de": ["Carl-Orff-Gymnasium Unterschleißheim"],
    ".cased.de": ["Center for Advanced Security Research Darmstadt"],
    ".cato-achim.de": ["Cato Bontjes van Beek-Gymnasium"],
    ".cbk1.de": ["Cuno-Berufskolleg I"],
    ".cbs-edu.de": ["Cologne Business School"],
    ".cbs-heidelberg.de": ["Carl-Bosch-Schule Heidelberg"],
    ".cbw-onlineschulung.de": ["CBW - College Berufliche Weiterbildung GmbH"],
    ".cdt-nue.de": [
        "Control Data Training GmbH",
        "Control Data Training GmbH",
    ],
    ".cdtm.de": ["Center for Digital Technology and Management"],
    ".ceg-erlangen.de": ["Christian-Ernst-Gymnasium"],
    ".charite.de": ["\ufeffCharité - Universitätsmedizin Berlin"],
    ".chf.de": ["Institut Dr. Flad"],
    ".cit-leipzig.de": ["CiT Leipzig"],
    ".cjd-bs.de": ["CJD Jugenddorf-Christophorusschule Braunschweig"],
    ".cjd-elz.de": ["CJD Christophorusschule Elze - Gymnasium"],
    ".cmb-gt.de": ["Carl-Miele-Berufskolleg für Technik"],
    ".cmb-portal.de": ["Carl-Miele-Berufskolleg des Kreises Gütersloh"],
    ".cs-bodensee.de": [
        "Christliche Schule im Hegau",
        "Christian School in the Hegau",
    ],
    ".csbme.de": ["Carl-Severing-Berufskolleg für Metall- und Elektrotechnik"],
    ".dacs-bund.de": ["Hochschule des Bundes für öffentliche Verwaltung"],
    ".dalberg-gymnasium.de": ["Karl-Theodor-v.-Dalberg-Gymnasium"],
    ".das-mgh-hamm.de": ["Name: Märkisches Gymnasium Hamm / MGH Hamm"],
    ".db-gym.de": ["Dietrich-Bonhoeffer-Gymnasium Ahlhorn"],
    ".dbb-detmold.de": [
        "Dietrich-Bonhoeffer-Berufskolleg des Kreises Lippe in Detmold (dbb)"
    ],
    ".dbb-lippe.de": [
        "Dietrich-Bonhoeffer-Berufskolleg des Kreises Lippe in Detmold (dbb)"
    ],
    ".dbg-ratingen.de": ["Dietrich-Bonhoeffer-Gymnasium Ratingen"],
    ".student.dbuas.de": [
        "Digital Business University of Applied Sciences",
        "Digital Business University of Applied Sciences",
    ],
    ".dbuas.de": ["Digital Business University of Applied Sciences"],
    ".design-akademie-berlin.de": [
        "design akademie berlin / SRH Hochschule für Kommunikation und Design"
    ],
    ".deutschehochschule.de": [
        "Deutsche Hochschule für angewandte Wissenschaften (DHAW)",
        "German University of Applied Sciences",
    ],
    ".dgk-keh.de": ["Donau Gymnasium Kelheim"],
    ".dh-karlsruhe.de": ["DHBW-Karlsruhe"],
    ".cas.dhbw.de": [
        "Center for Advanced Studies Duale Hochschule Baden Württemberg"
    ],
    ".heilbronn.dhbw.de": ["DHBW Heilbronn"],
    ".lehre.mosbach.dhbw.de": [
        "\ufeffDuale Hochschule Baden-Württemberg, Mosbach"
    ],
    ".mosbach.dhbw.de": ["Duale Hochschule Baden-Württemberg Mosbach"],
    ".dhbw-heidenheim.de": ["Duale Hochschule Baden-Württemberg, Heidenheim"],
    ".student.dhbw-karlsruhe.de": [
        "Duale Hochschule Baden-Württemberg Karlsruhe"
    ],
    ".dhbw-karlsruhe.de": ["Duale Hochschule Baden-Württemberg Karlsruhe"],
    ".dhbw-loerrach.de": ["Duale Hochschule Baden-Württemberg Lörrach"],
    ".dhbw-mannheim.de": ["Duale Hochschule Baden-Württemberg, Mannheim"],
    ".dhbw-mosbach.de": ["Duale Hochschule Baden-Württemberg, Mosbach"],
    ".stud.dhbw-ravensburg.de": [
        "Duale Hochschule Baden-Württemberg Ravensburg"
    ],
    ".dhbw-ravensburg.de": ["Duale Hochschule Baden-Württemberg Ravensburg"],
    ".lehre.dhbw-stuttgart.de": [
        "DHBW Stuttgart",
        "Cooperative State University Stuttgart",
    ],
    ".dhbw-stuttgart.de": ["Duale Hochschule Baden-Württemberg Stuttgart"],
    ".dhbw-vs.de": ["Baden-Wuerttemberg Cooperative State University"],
    ".dhfpg-bsa.de": [
        "Deutsche Hochschule für Prävention und Gesundheitsmanagement"
    ],
    ".dhfpg.de": [
        "Deutsche Hochschule für Prävention und Gesundheitsmanagement"
    ],
    ".stud.eisenach.dhge.de": [
        "Duale Hochschule Gera Eisenach",
        "Gera Eisenach Cooperative State University",
        "Homepage: https://www.dhge.de/DHGE.html",
    ],
    ".stud.gera.dhge.de": [
        "Duale Hochschule Gera Eisenach",
        "Gera Eisenach Cooperative State University",
        "Homepage: https://www.dhge.de/DHGE.html",
    ],
    ".dhge.de": [
        "Duale Hochschule Gera Eisenach",
        "Gera Eisenach Cooperative State University",
    ],
    ".dhsh.de": ["Berufsakademie Schleswig-Holstein"],
    ".edu.dhsn.de": ["Duale Hochschule Sachsen", "Berufsakademie Sachsen"],
    ".dhv-speyer.de": [
        "Deutsche Hochschule für Verwaltungswissenschaften Speyer"
    ],
    ".diesterweg-gymnasium.de": ["Diesterweg Gymnasium"],
    ".diploma.de": [
        "DIPLOMA-Fachhochschule Ölsnitz/Vogtland",
        "Fachhochschule Nordhessen",
    ],
    ".dkfz-heidelberg.de": ["DKFZ Heidelberg"],
    ".domgymnasium-verden.de": ["Domgymnasium Verden"],
    ".donau-gymnasium.de": ["Donau-Gymnasium in Kelheim"],
    ".doz-provadis-hochschule.de": [
        "Provadis School of International Management & Technology AG"
    ],
    ".drais-schule.de": ["Drais-Gemeinschaftsschule"],
    ".drsneuwied.de": ["David-Roentgen-Schule Neuwied"],
    ".drsschueler.de": ["David-Roentgen-Schule Neuwied"],
    ".drv-bund.de": [
        "Federal University of Applied Administrative Sciences > Department Social Security"
    ],
    ".dshs-koeln.de": ["Deutsche Sporthochschule Köln"],
    ".schule.duesseldorf.de": ["Schloß-Gymnasium Düsseldorf"],
    ".dv-schulen.de": [
        "Städtische Berufsfachschule für IT-Berufe",
        "Städtische Berufsfachschule für Büroberufe",
        "Städtische Berufsfachschule für Kaufmännische Assistenten",
        "Städtische Fachschule für Datenverarbeitung",
        "Städtische Wirtschafsschule Außenstelle Grombühl",
        ".group",
    ],
    ".dzne.de": [
        "Deutsches Zentrum für Neurodegenerative Erkrankungen, (DZNE)",
        "German Center for Neurodegenerative Diseases",
    ],
    ".e-b-z.de": [
        "Europäisches Bildungszentrum der Wohnungs- und Immobilienwirtschaft (EBZ)- gemeinnützige Stiftung"
    ],
    ".eah-jena.de": ["Ernst-Abbe-Hochschule Jena"],
    ".eba-muenchen.de": ["Europäische Betriebswirtschafts-Akademie"],
    ".campus.ebc-hochschule.de": ["EBC Hochschule"],
    ".ebs-iserv.de": ["ELSA-BRÄNDSTRÖM-SCHULE"],
    ".ebs.de": ["European Business School Schloß Reichartshausen"],
    ".ecla.de": ["European College of Liberal Arts"],
    ".mmbbs.eduplaza.de": ["multi media BBS"],
    ".edv-schulen-wiesau.de": [
        "Staatliche EDV-Schulen Wiesau",
        "Berufliches Schulzentrum Wiesau",
    ],
    ".edvschule-plattling.de": ["EDV-Schulen des Landkreises Deggendrof"],
    ".edvw.de": ["EDV-Schule Wiesau"],
    ".schueler.effner.de": [
        "Josef-Effner-Gymnasium",
        "Josef-Effner-Highschool",
    ],
    ".efh-bochum.de": [
        "Evangelische Fachhochschule Rheinland-Westfalen-Lippe"
    ],
    ".efh-darmstadt.de": ["Evangelische Fachhochschule Darmstadt"],
    ".efh-freiburg.de": [
        "Evangelische Fachhochschule Freiburg, Hochschule für Soziale Arbeit, Diakonie und Religionspädagogik"
    ],
    ".efh-hannover.de": ["Evangelische Fachhochschule Hannover"],
    ".efh-reutlingen-ludwigsburg.de": [
        "Evangelische Fachhochschule Reutlingen-Ludwigsburg, Hochschule für Soziale Arbeit, Religionspädagogik und Diakonie"
    ],
    ".efhlu.de": [
        "Evangelische Fachhochschule Ludwigshafen Hochschule für Sozial- und Gesundheitswesen"
    ],
    ".egb-koeln.de": ["Erich-Gutenberg Berufskolleg "],
    ".eggk.de": ["Evangelisches Gymnasium zum Grauen Kloster"],
    ".ehs-dresden.de": [
        "Evangelische Hochschule für Soziale Arbeit Dresden (FH)"
    ],
    ".eichendorff-gymnasium.de": ["Eichendorff Gymnasium Ettlingen"],
    ".imap.elektronikschule.de": ["Elektronikschule Tettnang"],
    ".elektronikschule.de": ["Elektronikschule Tettnang"],
    ".element-i-schule.de": [
        "Freie element-i Gemeinschaftsschule im Bildungshaus Karlsruhe"
    ],
    ".embl.de": [
        "European Molecular Biology Laboratory",
        "EMBL, Heidelberg",
        "URL: https://www.embl.de/",
        "Courses: https://www.embl.de/training/index.php",
    ],
    ".emg-haar.de": ["Emg Haar"],
    ".ems-mainz.de": ["European Management School"],
    ".erasgym.de": ["Erasmus Gymnasium"],
    ".erasmus-kittler-schule.de": ["Erasmus-Kittler-Schule, Darmstadt"],
    ".ernestinum-rinteln.de": ["Gymnasium Ernestinum Rinteln"],
    ".ers-hameln.de": ["Eugen-Reintjes-Schule Hameln"],
    ".schueler.ers-hm.de": ["Eugen-Reintjes-Schule Hameln"],
    ".ess-erfurt.de": [
        "Edith Stein Schule Erfurt",
        "Edith Stein School Erfurt",
    ],
    ".ess-liborius.de": ["Liborius Gymnasium Dessau"],
    ".esz-radebeul.de": ["Evangelisches Schulzentrum Radebeul"],
    ".eufh-mail.de": ["Europäische Fachhochschule"],
    ".eufh.de": ["Europäische Fachhochschule"],
    ".stud.euro-fh.de": [
        "Europäische Fernhochschule Hamburg GmbH",
        "University of Applied Sciences",
    ],
    ".europa-uni.de": [" "],
    ".euv-frankfurt-o.de": ["Europa-Universität Viadrina Frankfurt (Oder)"],
    ".evb-gymnasium.de": [
        "Städtisches Engelbert-von-Berg-Gymnasium",
        "Engelbert-von-Berg-Gymnasium",
        "EvB-Gymnasium",
    ],
    ".evfh-berlin.de": [
        "Evangelische Fachhochschule Berlin, Fachhochschule für Sozialarbeit und Sozialpädagogik"
    ],
    ".evfh-nuernberg.de": ["Evangelische Fachhochschule Nürnberg"],
    ".stud.evhn.de": [
        "Evangelische Hochschule Nürnberg",
        "Lutheran University of Applied Sciences",
    ],
    ".fau.de": ["Friedrich-Alexander-Universität Erlangen-Nürnberg"],
    ".schule.fcbg.de": ["Freie Christliche Bekenntnisschule Gummersbach"],
    ".schueler.fcg-duesseldorf.de": [
        "Freies Christliches Gymnasium",
        "Free Christian High School",
    ],
    ".febb.de": ["FEBB (Freie Evangelische Bekenntnis Schule Bremen)"],
    ".feg-sandhausen.de": ["Friedrich-Ebert-Gymnasium Sandhausen"],
    ".feintechnikschule.de": [
        "Staatliche Feintechnikschule mit Technischem Gymnasium Schwenningen"
    ],
    ".ferdinand-braun-schule.de": ["Ferdinand-Braun-Schule"],
    ".ferdinand-steinbeis-institut.de": [
        "Ferdinand Steinbeis Institute, Stuttgart ",
        "Steinbeis University, Berlin ",
        "Bildungscampus, Heilbronn ",
    ],
    ".fern-fh.de": ["Fern-Fachhochschule Hamburg"],
    ".fernuni-hagen.de": ["Fernuniversität Gesamthochschule Hagen"],
    ".fes-es.de": ["Friedrich-Ebert Schule Esslingen"],
    ".fes-wiesbaden.de": [
        "Friedrich-Ebert-Schule Wiesbaden",
        "Friedrich-Ebert-School Wiesbaden",
    ],
    ".fes365-pfungstadt.de": [
        "Friedrich-Ebert-Schule, Pfungstadt",
        "http://www.fes-pfungstadt.de",
    ],
    ".fg-kassel.de": ["Friedrichsgymnasium Kassel"],
    ".fgs-bln.de": ["Friedenauer Gemeinschaftsschule"],
    ".fh-Kempten.de": [
        "Fachhochschule Kempten, Hochschule für Technik und Wirtschaft"
    ],
    ".alumni.fh-aachen.de": ["Fachhochschule Aachen"],
    ".fh-aachen.de": ["Fachhochschule Aachen"],
    ".fh-aalen.de": ["Internationale Fachhochschule Aalen"],
    ".fh-aschaffenburg.de": ["Fachhochschule Aschaffenburg"],
    ".fh-augsburg.de": ["Fachhochschule Augsburg"],
    ".fh-bad-honnef.de": ["Internationale Fachhochschule Bad Honnef"],
    ".fh-biberach.de": [
        "Fachhochschule Biberach, Hochschule für Bauwesen und Wirtschaft"
    ],
    ".fh-bingen.de": ["Fachhochschule Bingen"],
    ".fh-bochum.de": ["Fachhochschule Bochum"],
    ".fh-bonn-rhein-sieg.de": ["Fachhochschule Bonn-Rhein-Sieg"],
    ".fh-brandenburg.de": ["Technische Hochschule Brandenburg"],
    ".fh-deggendorf.de": [
        "Fachhochschule Deggendorf/Deggendorf Institute of Technology",
        "Domain:th-deg.de",
        "Email: ..@stud.th-deg.de",
        "Email: ..@th-deg.de",
    ],
    ".fh-dortmund.de": ["Fachhochschule Dortmund"],
    ".fh-duesseldorf.de": ["Hochschule Düsseldorf"],
    ".fh-erfurt.de": ["Fachhochschule Erfurt"],
    ".fh-flensburg.de": [
        "Hochschule Flensburg",
        "The old domain of Fachhochschule Flensburg, renamed to Hochschule Flensburg.",
        "The domain ist still in use for student email accounts.",
    ],
    ".fh-frankfurt.de": ["Fachhochschule Frankfurt am Main"],
    ".fh-fresenius.de": ["Europa Fachhochschule Fresenius"],
    ".fh-furtwangen.de": [
        "Fachhochschule Furtwangen, Hochschule für Technik und Wirtschaft"
    ],
    ".fh-gelsenkirchen.de": ["Fachhochschule Gelsenkirchen"],
    ".fh-giessen.de": ["Fachhochschule Gießen-Friedberg"],
    ".fh-hamburg.de": ["Fachhochschule Hamburg"],
    ".fh-hannover.de": ["Fachhochschule Hannover"],
    ".fh-heidelberg.de": ["Fachhochschule Heidelberg"],
    ".fh-heilbronn.de": [
        "Fachhochschule Heilbronn, Hochschule für Technik und Wirtschaft"
    ],
    ".fh-hildesheim.de": [
        "Fachhochschule Hildesheim/Holzminden/Göttingen, Hochschule für angewandte Wissenschaft und Kunst"
    ],
    ".fh-hof.de": ["Fachhochschule Hof"],
    ".fh-ingolstadt.de": ["Fachhochschule Ingolstadt"],
    ".fh-isny.de": [
        "Fachhochschule und Berufskollegs NTA, Prof.Dr. Grübler gemein. GmbH"
    ],
    ".fh-jena.de": ["Fachhochschule Jena"],
    ".fh-karlsruhe.de": ["Fachhochschule Karlsruhe, Hochschule für Technik"],
    ".fh-kiel.de": ["Fachhochschule Kiel"],
    ".fh-kl.de": ["Fachhochschule Kaiserslautern"],
    ".fh-koblenz.de": ["Fachhochschule Koblenz"],
    ".fh-koeln.de": ["Technische Hochschule Köln"],
    ".fh-konstanz.de": [
        "Fachhochschule Konstanz, Hochschule für Technik, Wirtschaft und Gestaltung"
    ],
    ".fh-landshut.de": [
        "Fachhochschule Landshut, Hochschule für Wirtschaft - Sozialwesen - Technik"
    ],
    ".fh-lausitz.de": ["Fachhochschule Lausitz"],
    ".fh-lippe.de": ["Fachhochschule Lippe"],
    ".fh-ludwigshafen.de": [
        "Fachhochschule Ludwigshafen, Hochschule für Wirtschaft"
    ],
    ".fh-luebeck.de": ["Fachhochschule Lübeck"],
    ".fh-mainz.de": ["Fachhochschule Mainz"],
    ".fh-mannheim.de": [
        "Fachhochschule Mannheim, Hochschule für Technik und Gestaltung"
    ],
    ".fh-merseburg.de": ["Fachhochschule Merseburg"],
    ".fh-muenchen.de": ["Fachhochschule München"],
    ".fh-muenster.de": ["FH Muenster"],
    ".fh-neu-ulm.de": ["Fachhochschule Neu-Ulm"],
    ".fh-niederrhein.de": ["Fachhochschule Niederrhein"],
    ".fh-nordhausen.de": ["Fachhochschule Nordhausen"],
    ".fh-nuernberg.de": ["Georg-Simon-Ohm-Fachhochschule Nürnberg"],
    ".fh-nuertingen.de": [
        "Fachhochschule Nürtingen, Hochschule für Wirtschaft, Landwirtschaft und Landespflege"
    ],
    ".fh-offenburg.de": [
        "Fachhochschule Offenburg, Hochschule für Technik und Wirtschaft"
    ],
    ".fh-oow.de": ["Fachhochschule Oldenburg/Ostfriesland/Wilhelmshaven"],
    ".fh-osnabrueck.de": ["Fachhochschule Osnabrück"],
    ".fh-ottersberg.de": ["Freie Kunst-Studienstätte Ottersberg"],
    ".fh-potsdam.de": ["Fachhochschule Potsdam"],
    ".fh-regensburg.de": ["Fachhochschule Regensburg"],
    ".fh-reutlingen.de": [
        "Fachhochschule Reutlingen, Hochschule für Technik und Wirtschaft"
    ],
    ".fh-rosenheim.de": [
        "Fachhochschule Rosenheim, Hochschule für Technik und Wirtschaft"
    ],
    ".fh-rottenburg.de": [
        "Fachhochschule Rottenburg, Hochschule für Forstwirtschaft"
    ],
    ".fh-sm.de": ["Fachhochschule Schmalkalden"],
    ".fh-stralsund.de": ["Fachhochschule Stralsund"],
    ".fh-swf.de": ["Fachhochschule Südwestfalen"],
    ".fh-telekom-leipzig.de": ["Deutsche Telekom Fachhochschule Leipzig"],
    ".fh-trier.de": [
        "Fachhochschule Trier, Hochschule für Technik, Wirtschaft und Gestaltung"
    ],
    ".fh-ulm.de": ["Fachhochschule Ulm, Hochschule für Technik"],
    ".fh-wedel.de": ["Fachhochschule Wedel"],
    ".fh-weihenstephan.de": ["Fachhochschule Weihenstephan"],
    ".fh-weingarten.de": ["Fachhochschule Ravensburg-Weingarten"],
    ".fh-westkueste.de": [
        "Fachhochschule Westküste, Hochschule für Wirtschaft und Technik"
    ],
    ".fh-wiesbaden.de": ["Fachhochschule Wiesbaden"],
    ".fh-wolfenbuettel.de": ["Fachhochschule Braunschweig/Wolfenbüttel"],
    ".fh-worms.de": ["Fachhochschule Worms"],
    ".fh-wuerzburg.de": [
        "Hochschule für angewandte Wissenschaften Würzburg-Schweinfurt"
    ],
    ".fh-zwickau.de": ["Westsächsische Hochschule Zwickau"],
    ".edu.fham.de": [
        "Hochschule für angewandtes Management - Ismaning/München",
        "University of Applied Management - Ismaning/Munich",
    ],
    ".fham.de": [
        "Hochschule für angewandtes Management - Ismaning/München",
        "University of Applied Management - Ismaning/Munich",
    ],
    ".edu.fhdw.de": [
        "Fachhochschule der Wirtschaft Nordrhein-Westfalen gGmbH",
        "Fachhochschule der Wirtschaft",
        "FHDW",
        "FHDW NRW",
    ],
    ".fhdw.de": ["Fachhochschule der Wirtschaft"],
    ".fhkt.de": ["Staatlich anerkannte Fachhochschule für Kunsttherapie"],
    ".fhm-mittelstand.de": ["Fachhochschule des Mittelstandes (FHM)"],
    ".fhnon.de": ["Fachhochschule Nordostniedersachsen"],
    ".fhoebb.de": ["Fachhochschule für das öffentliche Bibliothekswesen Bonn"],
    ".fhs-mannheim.de": [
        "Fachhochschule Mannheim, Hochschule für Sozialwesen"
    ],
    ".fhs-moritzburg.de": [
        "Evangelische Fachhochschule für Religionspädagogik, und Gemeindediakonie Moritzburg"
    ],
    ".fht-stuttgart.de": ["Fachhochschule Stuttgart, Hochschule für Technik"],
    ".fhtw-berlin.de": ["Fachhochschule für Technik und Wirtschaft Berlin"],
    ".fhw-berlin.de": ["Fachhochschule für Wirtschaft Berlin"],
    ".fhws.de": [
        "Hochschule für angewandte Wissenschaften Würzburg-Schweinfurt"
    ],
    ".fhwt.de": [
        "Private Fachhochschule für Wirtschaft und Technik Vechta/Diepholz"
    ],
    ".fhwue.de": [
        "Hochschule für angewandte Wissenschaften Würzburg-Schweinfurt"
    ],
    ".fichtenberg-oberschule.de": ["Fichtenberg-Oberschule"],
    ".filderbenden.de": ["Gymnasium in den Filder Benden"],
    ".filmakademie.de": ["Filmakademie Baden-Württemberg"],
    ".filmuniversitaet.de": ["Filmuniversität Babelsberg-Potsdam"],
    ".firstwald.de": ["Evangelisches Firstwald Gymnasium Mössingen"],
    ".fjm-siegen.de": ["Fürst-Johann-Moritz Gymnasium", "FJM"],
    ".fkggoettingen.de": [
        "Felix Klein Gymnasium Göttingen",
        "Felix Klein Gymnasium Göttingen (Germany)",
    ],
    ".flachsland-hamburg.de": ["Flachsland Zukunftsschulen"],
    ".fli.de": ["Friedrich-Loeffler-Institut"],
    ".fls-da.de": ["Friedrich-List Schule Darmstadt"],
    ".fls-wiesbaden.de": ["Friedrich-List-Schule Wiesbaden"],
    ".fmg-brk.de": ["Franz-Miltenberger-Gymnasium"],
    ".fmsg-speyer.de": ["Friedrich-Magnus-Schwerd Gymnasium Speyer"],
    ".folkwang-uni.de": [
        "Folkwang Universtität der Künste",
        "Folkwang University of the arts",
    ],
    ".fom-net.de": ["Fachhochschule für Oekonomie und Management (FOM)"],
    ".fom.de": ["Fachhochschule für Oekonomie und Management (FOM)"],
    ".stud.fos-karlsfeld.de": ["Fachoberschule Karlsfeld"],
    ".fos-karlsfeld.de": ["Fos Karlsfeld"],
    ".fos2-n.de": ["Staatliche Fachoberschule II"],
    ".fosbos-neumarkt.de": [
        "Maximilian Kolbe (Fachober- & Berufsober-) Schule Neumarkt"
    ],
    ".stud.fosbos-ush.de": ["Berufliche Oberschule Unterschleißheim "],
    ".fra-uas.de": ["Frankfurt University of Applied Sciences"],
    ".franz-oberthuer-schule.de": ["Franz Oberthür Schule"],
    ".franziskusgymnasium-it.de": [
        "Franziskusgymnasium Lingen (Ems)",
        "High School Franziskusgymnasium Lingen",
    ],
    ".freie-georgenschule.de": ["Freie Georgenschule"],
    ".freie-schule-anne-sophie.de": ["Freie Schule Anne-Sophie"],
    ".friedrich-ebert-gymnasium.de": ["Friedrich Ebert Gymnasium"],
    ".fs-students.de": ["Frankfurt School of Finance & Management"],
    ".fs.de": ["Frankfurt School of Finance and Management"],
    ".ftsvs.de": [
        "Staatliche Feintechnikschule mit Technischem Gymnasium Schwenningen"
    ],
    ".fu-berlin.de": ["Freie Universität Berlin"],
    ".fvs-sus.de": ["FvS Minden - Freiherr-vom-Stein-Berufskolleg Minden"],
    ".fz-juelich.de": ["Juelich Forschungzentrum"],
    ".fzi.de": [
        "Forschungszentrum Informatik",
        "FZI Research Center for Information Technology",
    ],
    ".g18.de": ["Staatliche Gewerbeschule G18 - Technical College G18"],
    ".games-academy.de": ["Games Academy"],
    ".gaussschule-bs.de": ["Gaußschule - Gymnasium am Löwenwall"],
    ".gbg-kaarst.de": ["Georg-Büchner-Gymnasium Kaarst"],
    ".gbg-remscheid.de": [
        "Gertrud-Bäumer-Gymnasium",
        "Gertrud-Bäumer-Gymnasium",
    ],
    ".gbgrs.de": ["Gertrud-Bäumer-Gymnasium", "Gertrud-Bäumer-Gymnasium"],
    ".sus.gbs-grafschaft.de": ["GBS Grafschaft Bentheim"],
    ".gbs-sha.de": ["Gewerbliche Schule Schwäbisch Hall"],
    ".gbsleipzig.de": [
        "GBS Fachschule für Technik und Wirtschaft",
        "GBS Professional School of Technology and Business Administration",
    ],
    ".gd-serv.de": ["Gymnasium Damme"],
    ".gds2.de": [
        "\ufeffGottlieb-Daimler-Schule 2",
        "Technisches Schulzentrum Sindelfingen",
        "mit Abteilung Akademie für Datenverarbeitung",
    ],
    ".ge-meiersheide.de": ["Gesamtschule Hennef Meiersheide"],
    ".ge-walsum.de": ["Gesamtschule Walsum"],
    ".geestnetz.de": ["Geestlandschule"],
    ".gemont.de": ["Gebrüder-Montgolfier-Gymnasium Berlin"],
    ".genoapps.de": ["Genokolleg Münster"],
    ".genoveva.de": ["Genoveva gymnasium"],
    ".genth-schule.de": ["Kooperative Gesamtschule des Main-Kinzig-Kreises"],
    ".geomar.de": ["GEOMAR Helmholtz-Zentrum für Ozeanforschung Kiel"],
    ".geporta.de": ["Gesamtschule Porta Westfalica"],
    ".german-uds.de": [
        "German University of Digital Science",
        "German University of Digital Science",
    ],
    ".gesa-rhede.de": ["Gesamtschule Rhede", "Rhede comprehensive school"],
    ".gesa-soest.de": ["Hannah-Arendt-Gesamtschule Soest"],
    ".cloud.gesamtschule-barmen.de": ["Gesamtschule Barmen"],
    ".gesamtschule-fischbach.de": ["Gesamtschule Fischbach"],
    ".gesamtschule-hardt.de": ["gesamtschule-hardt.de"],
    ".gesamtschule-stolberg.de": [
        "Staedtische Gesamtschule Stolberg",
        "https://gesamtschule-stolberg.de",
        "https://gesamtschule-stolberg.de/wp-content/uploads/2018/09/Schulprogramm017-09-19.pdf",
    ],
    ".geskn.de": ["Gesamtschule Kürten", "Kürten Comprehensive School"],
    ".gewerbeschule-vs.de": ["Gewerbeschule villingen Schwenningen"],
    ".gg-lin.de": [
        "Gymnasium Georgianum Lingen",
        "Georgianum High School Lingen",
    ],
    ".gghi.de": ["Goethegymnasium Hildesheim"],
    ".ggs-duisburg.de": ["Green Gesamtschule"],
    ".ghse.de": [
        "Gewerbliche und Hauswirtschaftlich-Sozialpflegerische Schulen Emmendingen"
    ],
    ".student.giu-berlin.de": [
        "German International University of Applied Sciences",
        "German International University of Applied Sciences",
    ],
    ".student.giu-uni.de": [
        "German International University of Applied Sciences"
    ],
    ".glh.de": ["Gymnasium Lüneburger Heide"],
    ".gms-da.de": ["Georg Mueller Schule Darmstadt"],
    ".goegy.de": [
        "Goethe-Gymnasium Regensburg",
        "Goethe-Gymnasium Regensburg",
    ],
    ".os-scultetus.goerlitz.de": ["Scultetus-Oberschule Goerlitz"],
    ".office.goetheschule-essen.de": ["Goetheschule Essen"],
    ".goetheschule-ldk.de": ["Goetheschule Wetzlar"],
    ".schueler.goldberg-gymnasium.de": ["Goldberg-Gymnasium Sindelfingen"],
    ".gottfried-kinkel-realschule.de": [
        "Gottfried Kinkel Realschule",
        "Gottfried Kinkel Realschule",
    ],
    ".grimmels.de": [
        "Name: Grimmelshausen Gymnasium Gelnhausen",
        "Website: http://grimmels.de/wordpress/",
        "Computer science course: http://grimmels.de/wordpress/qualifikationsphase/ (Proof that is it offered as intensive course: On the site jump to: E > Kursangebot des GGG > Leistungsfächerangebot > ",
        "\tAufgabenfeld III > Informatik )",
        "Email proof: http://grimmels.de/wordpress/kontakte/",
    ],
    ".gs-bk.de": ["Gewerbliche Schule Backnang"],
    ".student.gs-ldk.de": ["Gewerblichen Schulen Dillenburg"],
    ".gs-wn.de": ["Gewerbliche Schule Waibligen"],
    ".schueler.gs-wt.de": ["Gewerbliche Schulen Waldshut"],
    ".gs-wt.de": ["Gewerbliche Schulen Waldshut"],
    ".schueler.gsg-waldkirch.de": ["Geschwister Scholl Gymnasium Waldkirch"],
    ".gso-koeln.de": ["Georg-Simon-Ohm-Berufskolleg Köln"],
    ".gsp-ploen.de": ["Gymnasium Schloss Plön"],
    ".student.gsso.de": ["Grafenbergschule Schorndorf"],
    ".gsso.de": ["Grafenbergschule Schorndorf"],
    ".gsz-bl.de": [
        "Philipp-Matthäus-Hahn-Schule – Gewerbliches Schulzentrum Balingen"
    ],
    ".gsz-zak.de": [
        "Philipp-Matthäus-Hahn-Schule – Gewerbliches Schulzentrum Balingen"
    ],
    ".gustav-heinemann-oberschule.de": ["Gustav-Heinemann-Oberschule"],
    ".msedu.gutenberg-gym.de": ["Gutenbergschule Wiesbaden"],
    ".gwdg.de": [
        "Georg-August-Universtät Göttingen",
        "Georg-August-University Goettingen",
    ],
    ".mail.gws-loerrach.de": ["Gewerbliche Schule Lörrach"],
    ".gy-steinheim.de": ["Städtisches Gymnasium Steinheim"],
    ".gyfa-hh.de": ["Gymnasium Farmsen"],
    ".gym-kothen.de": ["Gymnasium Am Kothen"],
    ".gym-lachendorf.de": ["Immanuel-Kant-Gymnasium Lachendorf"],
    ".gym-meiendorf.de": [
        "Name: Gymnasium Meiendorf",
        "Website: https://www.gymei.de/",
        "E-Mail Proof: https://www.gymei.de/impressum/",
    ],
    ".gym-mellendorf.de": ["Gymnasium Mellendorf"],
    ".gym-papenburg.de": ["Gymnasium Papenburg"],
    ".mail.gym-sarstedt.de": [
        "Gymnasium Sarstedt",
        "Homepage: http://gymnasiumsarstedt.de/",
        "http://gymnasiumsarstedt.de/?s=informatik&submit=Suchen",
        "http://gymnasiumsarstedt.de/informatik/",
    ],
    ".gym-schiff.de": [
        "Gymnasium Schifferstadt im Paul-von-Denis-Schulzentrum"
    ],
    ".gym-stolz.de": ["Gymnasium Stolzenau"],
    ".stud.gymb.de": ["Gymnasium Miesbach"],
    ".gymbla.de": ["Gymnasium Blankenese"],
    ".gymbruck.de": ["Gymnasium Bruckmuehl"],
    ".gymbu.de": ["Gymnasium Burgdorf"],
    ".gymbuckhorn.de": ["Gymnasium Buckhorn"],
    ".gymburlo.de": ["Gymnasium Mariengarden", "Mariengarden high school"],
    ".gymger.de": ["Gymnasium Geretsried"],
    ".gymhaan.de": ["Städtisches Gymnasium Haan"],
    ".gymhum.de": ["Gymnasium Hummelsbüttel"],
    ".gymlgh.de": ["Gymnasium Langenhagen"],
    ".gymlil.de": ["Gymnasium Lilienthal"],
    ".gymn-benedictinum.de": ["Gymnasium der Benediktiner, Meschede"],
    ".gymnasium-babelsberg.de": ["Bertha von Suttner Gymnasium Babelsberg"],
    ".gymnasium-essen-werden.de": ["Gymnasium Essen-Werden"],
    ".gymnasium-frechen.de": ["Gymnasium Frechen"],
    ".gymnasium-gag.de": ["Graf-Anton-Günther-Schule"],
    ".gymnasium-heiligenhaus.de": ["Immanuel-Kant-Gymnasium Heiligenhaus"],
    ".gymnasium-himmelsthuer.de": ["Gymnasium Himmelsthür"],
    ".gymnasium-hohenschwangau.de": [
        "Staatliches Gymnasium mit Internat Hohenschwangau"
    ],
    ".gymnasium-mariengarden.de": ["Gymnasium Mariengarden"],
    ".gymnasium-marienstatt.de": ["Privates Gymnasium Marienstatt"],
    ".gymnasium-schmallenberg.de": ["Gymnasium Schmallenberg"],
    ".gymneureut.de": ["Gymnasium Neureut"],
    ".gymolching.de": ["Gymnasium Olching"],
    ".gymsas.de": ["Sankt-Ansgar-Schule Hamburg"],
    ".gymteg.de": ["Gymnasium Tegernsee"],
    ".gywa.de": ["Gymnasium Waldstraße, Germany", "https://gywa.de/"],
    ".gywem.de": ["Gymnasium Wesermünde"],
    ".h-ab.de": ["Hochschule Aschaffenburg"],
    ".h-brs.de": ["Bonn-Rhein-Sieg University of Applied Sciences"],
    ".h-da.de": ["Hochschule Darmstadt University of Applied Sciences"],
    ".h-ka.de": ["Karlsruhe University of Applied Sciences"],
    ".stud.h2.de": [
        "Hochschule Magdeburg-Stendal",
        "Magdeburg-Stendal University of Applied Sciences",
    ],
    ".bsb.hamburg.de": [
        "Name: Immanuel Kant Gymnasium",
        "Website: https://immanuel-kant-gymnasium.de",
        "It-Course ( On Site 13) : http://download.immanuel-kant-gymnasium.de/WPU-Brosch%C3%BCre%202015%20Jg%209.pdf",
        "E-Mail Proof: https://immanuel-kant-gymnasium.de/index.php/impressum-footer",
    ],
    ".fifa.hamburg.de": ["Stadtteilschule Fischbek-Falkenberg"],
    ".hibb.hamburg.de": [
        "Berufliche Schule ITECH Elbinsel Wilhelmsburg (BS14) ",
        "Vocational school ITECH Elbinsel Wilhelmsburg (BS14)",
    ],
    ".hlg.hamburg.de": ["Helene-Lange-Gymnasium"],
    ".jbg.hamburg.de": ["Johannes-Brahms-Gymnasium"],
    ".johannes-brahms-gymnasium.hamburg.de": [
        "Johannes-Brahms-Gymnasium, Hamburg"
    ],
    ".hamburger-fh.de": ["Hamburger Fern-Hochschule (HFH)"],
    ".hans-baldung-gymnasium.de": ["Hans-Baldung-Gymnasium"],
    ".edu.hansenberg.de": [
        "Internatsschule Schloss Hansenberg",
        "Boarding School Schloss Hansenberg",
    ],
    ".hanseuni.de": ["Private Hanseuniversität"],
    ".haw-hamburg.de": ["Hamburg University of Applied Sciences"],
    ".haw-ingolstadt.de": ["Ingolstadt University of Applied Sciences"],
    ".haw-landshut.de": ["Landshut University of Applied Sciences"],
    ".hawk-hhg.de": [
        "HAWK Hochschule für angewandte Wissenschaft und Kunst Hildesheim Holzminden Göttingen"
    ],
    ".hawk.de": ["HAWK Hochschule für angewandte Wissenschaft und Kunst"],
    ".hbbk-office.de": [
        "Hans-Böckler-Berufskolleg, Münster",
        "(hbbk-muenster.de)",
    ],
    ".hbg-troisdorf.de": ["Heinrich-Böll-Gymnasium"],
    ".hbk-bs.de": ["Hochschule für Bildende Künste Braunschweig"],
    ".hbksaar.de": ["Hochschule der Bildenden Künste Saar"],
    ".hcu-hamburg.de": ["Hafencity Universität Hamburg"],
    ".hdbw-hochschule.de": [
        "Hochschule der Bayerischen Wirtschaft für angewandte Wissenschaften (HDBW) gGmbH",
        "University of the Bavarian Economy for Applied Sciences (HDBW)",
    ],
    ".hdm-stuttgart.de": ["Fachhochschule Stuttgart, Hochschule der Medien"],
    ".hds-le.de": ["Heinrich-Drake-Schule Lemgo"],
    ".health-and-medical-university.de": ["Health and Medical University"],
    ".hebk.de": ["Hermann-Emanuel-Berufskolleg"],
    ".hector-seminar.de": [
        "Hector Seminar Heidelberg, Karlsruhe, Mannheim, Pforzheim"
    ],
    ".heinrich-kleyer-schule.de": [
        "Heinrich-Kleyer-Schule",
        "Heinrich Kleyer School",
    ],
    ".heinrich-mann-schule.de": [
        "Heinrich-Mann-Schule Dietzenbach",
        "https://www.hms-dtzb.de/",
    ],
    ".heinrichheinedo.de": ["Heinrich-Heine-Gymnasium Dortmund"],
    ".mut.heliosschule.de": ["Heliosschule"],
    ".helmholtz-gymnasium.de": ["Helmholtz-Gymnasium Essen"],
    ".helmholtz-muenchen.de": ["Helmholtz Zentrum München"],
    ".helmholtz-munich.de": ["helmholtz-munich", "helmholtz-munich"],
    ".helmholtzschule.de": ["Hermann-von-Helmholtz Gymnasium Potsdam"],
    ".hfb.de": [
        "Hochschule für Bankwirtschaft (HfB), Private Fachhochschule der Bankakademie"
    ],
    ".hfbk-hamburg.de": ["Hochschule für bildende Künste Hamburg"],
    ".hff-muc.de": [
        "Hochschule für Fernsehen und Film München",
        "University of Television and Film Munich",
    ],
    ".hfg-gmuend.de": [
        "Fachhochschule Schwäbisch Gmünd, Hochschule für Gestaltung"
    ],
    ".hfk-bremen.de": ["Hochschule für Künste Bremen"],
    ".hfm-detmold.de": [
        "Hochschule für Musik Detmold",
        "University for Music Detmold",
    ],
    ".hfm-karlsruhe.de": ["University of Music Karlsruhe"],
    ".hfmt-hamburg.de": [
        "Hochschule für Musik und Theater Hamburg",
        "Music and Theater College in Hamburg",
    ],
    ".hfmt-koeln.de": ["Hochschule für Musik und Tanz Köln"],
    ".aiv.hfoed.de": [
        "Hochschule für den öffentlichen Dienst in Bayern (Allgemeine Innere Verwaltung)"
    ],
    ".aub.hfoed.de": [
        "Hochschule für den öffentlichen Dienst in Bayern (Archiv- und Bibliothekswesen)"
    ],
    ".hfph.de": ["Hochschule für Philosophie, Muenchen"],
    ".hfpol-bw.de": ["Hochschule für Polizei Baden-Württemberg"],
    ".hfpv-hessen.de": [
        "Hessian University of Applied Sciences for Police and Public Administration",
        "Hessische Hochschule für Polizei und Verwaltung",
    ],
    ".hft-leipzig.de": [
        "Deutsche Telekom University of Applied Sciences Leipzig"
    ],
    ".hft-stuttgart.de": ["Stuttgart University of Applied Sciences"],
    ".hfwu.de": ["Hochschule für Wirtschaft und Umwelt Nürtingen-Geislingen"],
    ".hg-gf.de": ["Humboldt-Gymnasium Gifhorn"],
    ".hg-gladbeck.de": ["Heisenberg Gymnasium"],
    ".hgb-leipzig.de": ["Academy of Visual Arts Leipzig"],
    ".hgbp.de": ["Humboldt Gymnasium Bad Pyrmont"],
    ".hgo-ol.de": ["Herbartgymnasium Oldenburg"],
    ".hgs-singen.de": ["Hohentwiel Gewerbeschule Singen"],
    ".hgw-iserv.de": ["Hölty-Gymnasium Wunstorf"],
    ".hhek.de": ["Heinrich Hertz Europakolleg"],
    ".hhg-kl.de": ["Staatliches Heinrich-Heine-Gymnasium Kaiserslautern"],
    ".hhgym.de": ["Heinrich-Hertz-Gymnasium Berlin"],
    ".hhl.de": ["Handelshochschule Leipzig"],
    ".hhu.de": ["Heinrich Heine University Düsseldorf"],
    ".hit-thueringen.de": [
        "HIT | Akademische Personalentwicklung an Hochschulen in Thüringen",
        "hit-thueringen.de",
    ],
    ".hkdm.de": ["Hochschule für Kunst, Design und populäre Musik Freiburg"],
    ".hlg-do-edu.de": ["Helene Lange Gymnasium Dortmund"],
    ".hms-dtzb.de": [
        "Heinrich-Mann-Schule Dietzenbach",
        "https://www.hms-dtzb.de/",
    ],
    ".hmt-leipzig.de": [
        "Hochschule für Musik und Theater Leipzig",
        "University of Music and Theatre Leipzig",
    ],
    ".stud.hmtm-hannover.de": [
        "Hochschule für Musik, Theater und Medien Hannover",
        "Hanover University of Music, Drama and Media",
    ],
    ".stud.hn.de": ["Hochschule Niederrhein"],
    ".hn.de": ["Hochschule Niederrhein"],
    ".hnbk.de": ["Heinz-Nixdorf-Berufskolleg Essen"],
    ".hnee.de": ["Eberswalde University for Sustainable Development"],
    ".student.hnu.de": ["Hochschule Neu Ulm University of applied sciences"],
    ".hnu.de": ["Hochschule Neu Ulm University of applied sciences"],
    ".hochschule-bc.de": [
        "Hochschule Biberach ",
        "Hochschule Biberach (Biberach University of Applied Sciences)",
    ],
    ".hochschule-heidelberg.de": ["SRH Hochschule Heidelberg"],
    ".hochschule-regensburg.de": ["Hochschule Regensburg"],
    ".hochschule-rhein-waal.de": ["Hochschule Rhein-Waal"],
    ".hochschule-stralsund.de": ["Fachhochschule Stralsund"],
    ".hochschule-trier.de": ["Trier University of Applied Sciences"],
    ".hochtaunusschule.de": ["Hochtaunusschule Oberursel"],
    ".hoenne-berufskolleg.de": ["Hoenne-Berufskolleg"],
    ".hoev-rlp.de": ["Hochschule für öffentliche Verwaltung Rheinland-Pfalz"],
    ".hof-university.de": ["Hochschule für Angewandte Wissenschaften Hof"],
    ".hpi.de": ["Hasso Plattner Institute"],
    ".hrsaaf.de": ["Schule Altes Amt Friedeburg"],
    ".hs-aalen.de": ["Hochschule Aalen"],
    ".hs-albsig.de": ["Hochschule Albstadt-Sigmaringen"],
    ".hs-anhalt.de": [
        "Hochschule Anhalt (FH), Hochschule für angewandte Wissenschaften"
    ],
    ".hs-ansbach.de": ["Ansbach University of Applied Sciences"],
    ".hs-augsburg.de": [
        "Technische Hochschule Augsburg",
        "Augsburg University of Applied Sciences",
    ],
    ".hs-bochum.de": ["Hochschule Bochum"],
    ".hs-bremen.de": ["Hochschule Bremen"],
    ".hs-bremerhaven.de": ["Hochschule Bremerhaven"],
    ".hs-coburg.de": ["Hochschule Coburg"],
    ".study.hs-duesseldorf.de": ["Hochschule Düsseldorf"],
    ".hs-duesseldorf.de": ["Hochschule Düsseldorf"],
    ".hs-emden-leer.de": ["Hochschule Emden / Leer"],
    ".hs-esslingen.de": ["Hochschule Esslingen"],
    ".hs-flensburg.de": ["Hochschule Flensburg"],
    ".hs-fresenius.de": ["Hochschule Fresenius"],
    ".hs-fulda.de": ["Hochschule Fulda"],
    ".hs-furtwangen.de": ["Furtwangen University of Applied Sciences"],
    ".hs-gesundheit.de": ["Hochschule für Gesundheit"],
    ".hs-gm.de": ["Hochschule Geisenheim University"],
    ".hs-hannover.de": ["Hochschule Hannover"],
    ".hs-harz.de": [
        "Hochschule Harz, Hochschule für angewandte Wissenschaften (FH)"
    ],
    ".hs-heilbronn.de": ["Hochschule Heilbronn (FH)"],
    ".hs-kempten.de": [
        "Hochschule für angewandte Wissenschaften Kempten",
        "University of Applied Sciences Kempten",
    ],
    ".hs-kl.de": [
        "Hochschule Kaiserslautern",
        "University of Applied Sciences",
    ],
    ".hs-koblenz.de": ["Hochschule Koblenz"],
    ".hs-lausitz.de": ["Hochschule Lausitz"],
    ".hs-lu.de": ["Hochschule Ludwigshafen am Rhein"],
    ".hs-magdeburg.de": ["Hochschule Magdeburg-Stendal (FH)"],
    ".hs-mainz.de": ["Hochschule Mainz - University of Applied Sciences"],
    ".hs-mannheim.de": ["Mannheim University of Applied Sciences"],
    ".stud.hs-merseburg.de": ["University of Applied Sciences Merseburg"],
    ".hs-merseburg.de": ["University of Applied Sciences Merseburg"],
    ".hs-mittweida.de": ["University of Applied Sciences Mittweida"],
    ".hs-nb.de": ["Hochschule Neubrandenburg"],
    ".student.hs-neu-ulm.de": [
        "Hochschule Neu Ulm University of applied sciences"
    ],
    ".hs-neu-ulm.de": ["Hochschule Neu Ulm University of applied sciences"],
    ".hs-niederrhein.de": ["Hochschule Niederrhein"],
    ".hs-nordhausen.de": ["Hochschule Nordhausen"],
    ".hs-offenburg.de": ["Offenburg University of Applied Sciences"],
    ".hs-osnabrueck.de": ["University Of Osnabrück"],
    ".hs-owl.de": ["Hochschule Ostwestfalen-Lippe"],
    ".hs-pforzheim.de": [
        "Hochschule Pforzheim für Gestaltung, Technik und Wirtschaft"
    ],
    ".hs-rm.de": ["Rheinmain University of Applied Sciences"],
    ".hs-ruhrwest.de": ["Hochschule Ruhr West"],
    ".hs-sm.de": ["Hochschule Schmalkalden"],
    ".hs-ulm.de": ["University of Applied Sciences Ulm"],
    ".hs-weingarten.de": [
        "University of Applied Sciences Ravensburg-Weingarten"
    ],
    ".hs-wismar.de": [
        "Hochschule Wismar, Fachhochschule für Technik, Wirtschaft und Gestaltung"
    ],
    ".hs-worms.de": ["Hochschule Worms University of Applied Sciences"],
    ".hs-zigr.de": ["Hochschule Zittau/Görlitz (FH)"],
    ".hs21.de": ["Hochschule 21/Buxtehude (FH)"],
    ".hsba.de": [
        "HSBA Hamburg School of Business Administration (old accounts)"
    ],
    ".hsbi.de": ["Hochschule Bielefeld"],
    ".hshl.de": ["Hochschule Hamm-Lippstadt"],
    ".hss-wi.de": ["Hubert-Sternberg-Schule Wiesloch"],
    ".hss-wiesloch.de": ["Hubert-Sternberg-Schule Wiesloch"],
    ".hssfds.de": ["Heinrich-Schickhardt-Schule"],
    ".hsu-hh.de": [
        "Helmut-Schmidt-Universität - Universität der Bundeswehr Hamburg",
        "Helmut-Schmidt-University Hamburg (Germany)",
    ],
    ".hsw-hameln.de": ["Hochschule Weserbergland"],
    ".hsw-stud.de": ["Hochschule Weserbergland"],
    ".hswt.de": ["Weihenstephan-Triesdorf University of Applied Sciences"],
    ".hszg.de": ["Hochschule Zittau/Görlitz (FH)"],
    ".htw-aalen.de": ["hs-aalen.txt"],
    ".htw-berlin.de": ["University of Applied Sciences, Berlin"],
    ".htw-dresden.de": ["Hochschule für Technik und Wirtschaft Dresden (FH)"],
    ".htw-saarland.de": [
        "Hochschule für Technik und Wirtschaft des Saarlandes"
    ],
    ".htwg-konstanz.de": [
        "Hochschule Konstanz University of Applied Sciences"
    ],
    ".htwk-leipzig.de": [
        "Hochschule für Technik, Wirtschaft und Kultur Leipzig (FH)"
    ],
    ".htwm.de": ["Hochschule Mittweida (FH)"],
    ".htwsaar.de": ["Hochschule für Technik und Wirtschaft des Saarlandes"],
    ".hu-berlin.de": ["Humboldt Universität Berlin"],
    ".hwg-lu.de": ["Hochschule für Wirtschaft und Gesellschaft Ludwigshafen"],
    ".hwos.de": ["Hildegard-Wegscheider-Gymnasium"],
    ".hwp-hamburg.de": [
        "HWP - Hamburger Universität für Wirtschaft und Politik"
    ],
    ".hwr-berlin.de": [
        "HWR Berlin - Hochschule für Wirtschaft und Recht Berlin (Berlin School of Economics and Law)"
    ],
    ".stud.hwtk.de": ["Hochschule für Wirtschaft, Technik und Kultur"],
    ".hzdr.de": ["Helmholtz-Zentrum Dresden-Rossendorf"],
    ".i-u.de": ["International University in Germany"],
    ".students.ial.de": [
        "Institut für Angewandte Logistik GmbH",
        "Institute of Applied Logistics GmbH",
    ],
    ".ib-hochschule.de": ["IB Hochschule Berlin", "IB University Berlin"],
    ".ibs-ol.de": [
        "IBS IT & Business School Oldenburg e. V.",
        "Berufsakademie für IT & Wirtschaft Oldenburg",
    ],
    ".ids-mannheim.de": ["Leibniz-Institut für Deutsche Sprache"],
    ".student.if-koeln.de": ["COLOGNE INTERNATIONAL SCHOOL"],
    ".igs-del.de": ["IGS Delmenhorst"],
    ".igs-goettingen.de": [
        "Georg-Christoph-Lichtenberg-Gesamtschule Göttingen-Geismar"
    ],
    ".igs-kastellaun.de": ["Integrierte Gesamtschule Kastellaun"],
    ".igs-kreyenbrueck.de": ["Integrierte Gesamtschule Kreyenbrück"],
    ".igs-os.de": ["Integrierte Gesamtschule Osnabrück"],
    ".igs-ost.de": ["Gesamtschule Gießen Ost"],
    ".igs-sassenburg.de": [
        "IGS Sassenburg",
        "Integriertegesamtschule Sassenburg",
    ],
    ".igs-seevetal.de": ["IGS Seevetal"],
    ".igs-wedemark.de": ["IGS Wedemark"],
    ".igs-winsen.de": ["IGS Winsen Roydorf"],
    ".igs-wunstorf.de": ["IGS Wunstorf"],
    ".igsquerum.de": ["IGS Querum"],
    ".igssolms-ldk.de": ["Integrierte Gesamtschule Solms"],
    ".ihi-zittau.de": ["Internationales Hochschulinstitut Zittau"],
    ".imtek.de": [
        "Institut für Mikrosystemtechnik - IMTEK Albert-Ludwigs-Universität Freiburg"
    ],
    ".inntal-gymnasium.de": [
        "Inntal-Gymnasium, Raubling",
        "Inntal High School, Raubling",
    ],
    ".io-warnemuende.de": [
        "Leibniz Insitut für Ostseeforschung Warnemünde (IOW)",
        "Leibniz Institute for Baltic Sea Research Warnemünde (IOW)",
    ],
    ".ipu.de": ["International Psychoanalytic University"],
    ".isdedu.de": ["International School of Düsseldorf"],
    ".iserv-gis.de": ["Gymnasium im Schloss Wolfenbüttel"],
    ".iserv-herderschule-giessen.de": ["Herderschule Gießen"],
    ".iserv-schiller-schule.de": ["Schiller-Schule Bochum"],
    ".iserv-schillerschule.de": ["Schillerschule Hannover"],
    ".iserv-trg-oha.de": ["Tilman-Riemenschneider-Gymnasium Osterode am Harz"],
    ".iserv-willms.de": ["Gymnasium an der Willmsstraße"],
    ".iservigs-embsen.de": ["IGS Embsen"],
    ".dozent.ism.de": ["International School of Management (ISM) Germany "],
    ".student.ism.de": ["International School of Management"],
    ".ism-dortmund.de": ["International School of Management ISM Dortmund"],
    ".isnm.de": ["International School of New Media, University of Lübeck"],
    ".isr-school.de": ["International School on the Rhine"],
    ".itbspa.de": ["Karl-Peter-Obermaier Schule Passau"],
    ".itc-dortmund.de": ["IT-Center Dortmund"],
    ".itc-studenten.de": ["IT-Center Dortmund"],
    ".itech-bs14.de": [
        "Berufliche Schule ITECH Elbinsel Wilhelmsburg (BS14)",
        "Vocational school ITECH Elbinsel Wilhelmsburg (BS14)",
    ],
    ".its-stuttgart.de": ["it.schule Stuttgart"],
    ".iu-akademie.de": ["IU Internationale Hochschule GmbH"],
    ".iubh-dualesstudium.de": ["IUBH Internationale Hochschule GmbH"],
    ".iubh-fernstudium.de": ["Internationale Hochschule Bad Honnef · Bonn"],
    ".iubh.de": [
        "International University of Applied Sciences Bad Honnef - Bonn"
    ],
    ".jacobs-university.de": ["Jacobs University Bremen"],
    ".jade-hs.de": ["Jade Hochschule Wilhelms/Oldenburg/Elsfleth"],
    ".jakob-brucker-gymnasium.de": ["Jakob-Brucker-Gymnasium, Kaufbeuren"],
    ".angergymnasium.jena.de": ["Staatliches Angergymnasium Jena"],
    ".cz-gymnasium.jena.de": ["Carl Zeiss Gymnasium Jena"],
    ".stud.jfg-augsburg.de": ["Jakob-Fugger-Gymnasium"],
    ".jhgcloud.de": ["JosephHaydenGymnasium"],
    ".jkg-ibb.de": ["Johannes-Kepler-Gymnasium Ibbenbüren"],
    ".jkgc.de": ["Johannes-Kepler-Gymnasium Chemnitz"],
    ".johannes-althusius-gymnasium.de": ["johannes althusius gymnasium"],
    ".johanneum-lg.de": ["Johanneum Lüneburg"],
    ".joseph-koenig-gymnasium.de": ["Joseph-Koenig-Gymnasium Haltern am See"],
    ".jprs.de": [
        "Johann-Philipp-Reis-Schule Friedberg (Hessen), Berufliches Gymnasium"
    ],
    ".jsg-karlstadt.de": ["Johann-Schöner-Gymnasium Karlstadt"],
    ".jules-verne-campus.de": ["Jules Verne Campus"],
    ".julianum.de": ["Gymnasium Julianum"],
    ".julius-wegeler-schule.de": ["Julius-Wegeler-Schule Koblenz"],
    ".jws-rv.de": ["Josef-Wilhelm-Schule Ravensburg"],
    ".kag-erding.de": ["Korbinian-Aigner-Gymnasium Erding"],
    ".kapellen-ms.de": ["Kapellen-Mittelschule Augsburg"],
    ".karlkuebelschule.de": ["Karl Kübel Schule"],
    ".karlshochschule.de": ["Karlshochschule International University"],
    ".hhs.karlsruhe.de": ["Heinrich-Hertz-Schule Karlsruhe"],
    ".mgg.karlsruhe.de": [
        "Markgrafen-Gymnasium Karlsruhe",
        "Markgrafen High School Karlsruhe",
    ],
    ".kath-fh-nord.de": ["Katholische Fachhochschule Norddeutschland"],
    ".katharineum.de": ["Katharineum zu Lübeck"],
    ".kbbz-dillingen.de": [
        "Kaufmänisches Berufsbildungszentrum Dillingen",
        "KBBZ Dillingen",
    ],
    ".student.kbm-du.de": [
        "Kaufmännisches Berufskolleg Duisburg-Mitte",
        "Kaufmännisches Berufskolleg Duisburg-Mitte",
    ],
    ".kbs-nordhorn.de": [
        "Kaufmännische Berufsbildende Schulen Nordhorn (KBS)"
    ],
    ".kerschensteinerschule.de": ["Kerschensteinerschule.de"],
    ".kfb-berlin.de": ["Katholische Fachhochschule Berlin (KFB)"],
    ".kfh-Freiburg.de": [
        "Katholische Fachhochschule Freiburg, Hochschule für Sozialwesen, Religionspädagogik und Pflege"
    ],
    ".kfh-mainz.de": ["Katholische Fachhochschule Mainz"],
    ".kfhnw.de": ["Katholische Fachhochschule Nordrhein-Westfalen"],
    ".kgw-duisburg.de": ["Kopernikus Gymnasium Walsum"],
    ".kh-berlin.de": [
        "Kunsthochschule Berlin-Weissensee, Hochschule für Gestaltung "
    ],
    ".khgmettmann.de": ["Konrad-Heresbach-Gymnasium Mettmann"],
    ".khm.de": ["Academy of Media Arts, Cologne"],
    ".khsa.de": ["Katholische Hochschule für Soziale Arbeit Saarbrücken"],
    ".kinzig-schule.de": [
        "Berufliches Schulzentrum des Main-Kinzig-Kreises in Schlüchtern"
    ],
    ".kisd.de": ["KISD - Köln International School of Design"],
    ".kitz-heidelberg.de": [
        "Hopp Children's Cancer Center Heidelberg (KiTZ)",
        "Heidelberg University Hospital and the German Cancer Research Center (DKFZ)",
    ],
    ".kks-kiel.de": ["Käthe-Kollwitz Gymnasium Kiel"],
    ".klara-oppenheimer-schule.de": ["Klara-Oppenheimer-Schule Würzburg"],
    ".kmg-fn.de": ["Karl-Maybach-Gymnasium Friedrichshafen"],
    ".kmgfn.de": ["Karl-Maybach-Gymnasium Friedrichshafen"],
    ".knabenrealschule-neumarkt.de": ["Staatliche Knabenrealschule"],
    ".kolleg-illertissen.de": ["Kolleg der Schulbrüder Illertissen"],
    ".kolleg-st-sebastian.de": ["Kolleg St. Sebastian, Stegen"],
    ".konrad-zuse-schule.de": ["Konrad-Zuse-Schule"],
    ".krbor.de": ["Berufskollegs des Kreises Borken"],
    ".mail.kreuzgymnasium.de": ["Evangelisches Kreuzgymnasium Dresden"],
    ".ks-ldk.de": ["Kaufmännische Schulen Dillenburg"],
    ".edu.ksan.de": ["Medienzentrum Kassel", ".group"],
    ".ksfh.de": ["Katholische Stiftungsfachhochschule München"],
    ".kst-vechta.de": ["Kolleg St. Thomas"],
    ".ku-eichstaett.de": ["Katholische Universität Eichstätt"],
    ".ku.de": ["Katholische Universität Eichstätt"],
    ".kunstakademie-duesseldorf.de": ["Kunstakademie Düsseldorf."],
    ".kvg-mettingen.de": ["Kardinal von Galen Gymnasium Mettingen"],
    ".kvgg.de": ["Kardinal-von-Galen-Gymnasium Kevelaer"],
    ".kvgschulen.de": ["Kardinal von Galen Gymnasium Mettingen"],
    ".kwr-hannover.de": ["Kaiser- Wilhelm und Ratsgymnasium Hannover"],
    ".schule.landsh.de": ["Gymnasium Sylt"],
    ".law-school.de": ["Bucerius Law School gGmbH"],
    ".lazi-akademie.de": [
        "Lazi Akademie is an Academy for Media Design in Esslingen, Germany",
        "Homepage: https://www.lazi-akademie.de/",
        "3 years education:",
        "https://www.lazi-akademie.de/ausbildung/grafik-kommunikationsdesign/",
        "https://www.lazi-akademie.de/master-of-arts/",
        "Domain for repository: lazi-akademie.de",
    ],
    ".lebk247.de": ["Ludwig-Erhard-Berufskolleg Muenster"],
    ".leibniz-fh.de": ["Leibniz Fachhochschule"],
    ".leibniz-gymnasium-essen.de": ["Leibniz-Gymnasium Essen"],
    ".leo-statz-berufskolleg.de": [
        "Leo-Statz-Berufskolleg",
        "we'll use webstorm in this course of study: ",
        "https://www.leo-statz-berufskolleg.de/bildungsangebot/kfm-assistentin-fuer-informationsverarbeitung",
    ],
    ".leogos.de": ["Leononore Goldschmidt Schule"],
    ".afra.lernsax.de": ["Sächsisches Landesgymnasium Sankt Afra zu Meißen"],
    ".ars-bsz.lernsax.de": [
        "Arwed-Rossbach-Schule, Berufliches Schulzentrum der Stadt Leipzig"
    ],
    ".bsz1.lernsax.de": [
        "Beruflichen Schulzentrums 1 der Stadt Leipzig Wirtschaft und Verwaltung"
    ],
    ".bszetdd.lernsax.de": [
        "Berufliches Schulzentrum für Elektrotechnik, Dresden",
        "Vocational high school for electrical engineering, Dresden",
    ],
    ".bsztw-riesa.lernsax.de": [
        "Berufliches Schulzentrum für Technik und Wirtschaft Riesa"
    ],
    ".ewvt.lernsax.de": [
        "School: Ehrenfried-Walther-von-Tschirnhaus-Gymnasium Dresden",
        "E-Mail-Suffix: ewvt.lernsax.de",
        "Proof that this school use this mail provider:",
        'On the page lernsax.de is on the left side a botton with the text "LernSax Kennenlernen" it means get to know lernsax. You have to click this button.',
        'On this new page is on the left side a botton with the text "Karte der LernSax-Nutzer" it shows you a map of the lernsax users. ',
        "On this map you have to click this circle (https://prnt.sc/1ak5py1).",
        "You can also check the official Website (https://ewvt.de) and the part explaining Lernsax (https://ewvt.de/index.php/kontakt-und-service/lernsax2).",
        'Click the "Impressium" (inprint) botton to check if the school website is ewvt.de',
    ],
    ".gsg-loebau.lernsax.de": ["Geschwister-Scholl-Gymnasium Löbau"],
    ".guts.lernsax.de": [
        "Gutenbergschule, Berufliches Schulzentrum der Stadt Leipzig"
    ],
    ".gymkn.lernsax.de": ["Gymnasium Markneukirchen"],
    ".jkgc.lernsax.de": ["Johannes-Kepler-Gymnasium Chemnitz"],
    ".manos-dresden.lernsax.de": ["Martin-Andersen-Nexö-Gymnasium Dresden"],
    ".whg-rie.lernsax.de": [
        "School: Werner-Heisenberg-Gymnasium Riesa",
        "E-Mail-Suffix: whg-rie.lernsax.de",
        "Proof that this school use this mail provider:",
        'On the page lernsax.de is on the left side a botton with the text "LernSax Kennenlernen" it means get to know lernsax. You have to click this button.',
        'On this new page is on the left side a botton with the text "Karte der LernSax-Nutzer" it shows you a map of the lernsax users. ',
        "On this map you have to click this circle (http://prntscr.com/ltmjc4). There are now some links one of this is the link of the school (Werner-Heisenberg-Gymnasium Riesa).",
        '"whg-rie" is the short form of "Werner-Heisenberg-Gymnasium Riesa". The school website uses this short form too because the school website is whg-rie.de.',
        'Click the "Impressium" (inprint) botton to check if the school website is whg-rie.de',
    ],
    ".lernsax.de": [
        "School: Schülerrechenzentrum Dresden",
        "E-Mail-Suffix: srz.lernsax.de",
        "Proof that this school use this mail provider:",
        'On the page lernsax.de is on the left side a botton with the text "LernSax Kennenlernen" it means get to know lernsax. You have to click this button.',
        'On this new page is on the left side a botton with the text "Karte der LernSax-Nutzer" it shows you a map of the lernsax users. ',
        "On this map you have to click this circle (https://prnt.sc/1ak5py1).",
        'Click the "Impressium" (inprint) botton to check if the school website is ewvt.de',
    ],
    ".leuphana.de": ["Leuphana Universität Lüneburg"],
    ".lg-bs.de": ["Lessinggymnasium Braunschweig"],
    ".schueler.lg-ks.de": ["Lichtenberg-Gymnasium Kassel"],
    ".schueler.lg-nu.de": ["Lessing-Gymnasium Neu-Ulm"],
    ".lgbk.de": ["Lessing Gymnasium | Berufskolleg"],
    ".lgs-di.de": ["Landrat-Gruber-Schule"],
    ".liebigschule-giessen.de": ["Liebigschule Giessen"],
    ".ligcux.de": ["Lichtenberg-Gymnasium Cuxhaven"],
    ".lindengymnasium.de": ["Staedtisches Lindengymnasium Gummersbach"],
    ".lio-darmstadt.de": [
        "Justus-Liebig-Schule Darmstadt",
        "Justus-Liebig school Darmstadt, Germany",
    ],
    ".list-gymnasium.de": [
        "Friedrich List Gymnasium Reutlingen",
        "Friedrich List High School Reutlingen",
    ],
    ".lls-bad.de": ["Louis-Lepoix-Schule"],
    ".lmgrhl.de": ["Lise-Meitner-Gesamtschule"],
    ".lmu.de": ["Ludwig Maximilian University of Munich"],
    ".gd.by.lo-net2.de": ["Schmuttertal-Gymnasium Diedorf"],
    ".bbs-hol.ni.lo-net2.de": [
        "Georg-von-Langen-Schule - Berufsbildende Schulen Holzminden"
    ],
    ".bbs-whv.ni.lo-net2.de": ["Berufsbildene Schule Wilhelmshaven"],
    ".fvsg-ob.nw.lo-net2.de": ["Freiherr-vom-Stein Gymnasium Oberhausen"],
    ".gyko.nw.lo-net2.de": ["Gymnasium Korschenbroich"],
    ".lhbk.nw.lo-net2.de": ["Lebenshilfe Berufskolleg Huerth"],
    ".mcgduesseldorf.nw.lo-net2.de": ["Marie-Curie Gymnasium Düsseldorf"],
    ".tbs1.nw.lo-net2.de": ["Technische Berufliche Schule 1 - Bochum"],
    ".lornsenschule.sh.lo-net2.de": ["Lornsenschule Schleswig"],
    ".log-web.de": ["Lichtenberg-Oberstufen-Gymnasium Bruchköbel"],
    ".bkbe.logineo.de": ["Berufskolleg Barmen Europaschule"],
    ".lore-lorentz-schule.de": ["Lore Lorentz Schule"],
    ".louis-leitz-schule.de": ["Louis Leitz Schule"],
    ".louisenlund.de": ["Stiftung Louisenlund", "Louisenlund Foundation"],
    ".lsbkmi.de": ["Leo-Sympher-Berufskolleg"],
    ".lsh-marquartstein.de": ["Gymnasium Landschulheim Marquartstein"],
    ".ludwig-geissler-schule.de": ["Ludwig-Geißler-Schule"],
    ".lwl-bz-soest.de": ["LWL Berufskolleg Soest"],
    ".lwl-vvs.de": ["Von-Vinke-Schule Soest"],
    ".stud.macromedia.de": [
        "Macromedia University Munich (stud.macromedia.de)"
    ],
    ".maedchenrealschule-neumarkt.de": ["Staatliche Mädchenrealschule"],
    ".mailwb-online-campus.de": [
        "Wilhelm Büchner Hochschule",
        "Wilhelm Büchner University",
    ],
    ".marienschule-bielefeld.de": ["Marienschule Bielefeld"],
    ".markdorf-robotics.de": [
        "Gymnasium im Bildungszentrum Markdorf - Roboter AG"
    ],
    ".schueler.max-eyth-schule.de": [
        "Max-Eyth-Schule Berufliche Schule Kassel"
    ],
    ".max-planck-ge.de": ["Max-Planck-Gymnasium Gelsenkirchen-Buer"],
    ".max-weber-schule.de": ["Max-Weber-Schule Freiburg im Breisgau"],
    ".maxe-del.de": ["Max-Planck-Gymnasium, Delmenhorst", "mpg Delmenhorst"],
    ".maxplanckschools.de": ["Max Planck School of Cognition"],
    ".mbg-germering.de": ["Max-Born-Gymnasium Germering"],
    ".mbs-altona.de": ["Max-Brauer-Schule"],
    ".mcg-berlin.de": ["Marie Curie Gymnasium"],
    ".mcggehrden.de": ["Matthias Claudius Gymnasium Gehrden"],
    ".mdc-berlin.de": [
        "Max-Delbrück-Centrum für Molekulare Medizin Graduate School"
    ],
    ".mdg-hamburg.de": ["Marion Dönhoff Gymnasium"],
    ".media-uni.de": ["Media University of Applied Sciences"],
    ".mediadesign.de": ["Mediadesign Hochschule"],
    ".student.medicalschool-hamburg.de": ["Medical School Hamburg"],
    ".mein-gaussge.de": [
        "Carl-Friedrich-Gauß-Gymnasium Gelsenkirchen, Germany",
        "gaussge.de (school domain / homepage)",
        "mein-gaussge.de (the school's learning platform, used for email)",
    ],
    ".mein-karrieretutor.de": ["Karrieretutor"],
    ".mercator-berufskolleg.de": [],
    ".merz-akademie.de": [
        "Merz Akademie, Hochschule für Gestaltung Stuttgart"
    ],
    ".mes-portal.de": ["Max Eyth Schule Schiffdorf"],
    ".mesk.de": ["Max-Eyth-Schule Kirchheim"],
    ".mfh-iserlohn.de": ["Märkische Fachhochschule Iserlohn"],
    ".mh-freiburg.de": ["Hochschule für Musik Freiburg"],
    ".mh-hannover.de": ["Medizinische Hochschule Hannover"],
    ".mh-trossingen.de": ["Staatliche Hochschule für Musik"],
    ".mhmk.de": ["Hochschule Macromedia University of Applied Sciences"],
    ".mhn.de": ["Hochschule für Politik (HFP)"],
    ".mint-kolleg.de": ["MINT-Kolleg Baden-Württemberg"],
    ".mis-munich.de": ["Munich International School"],
    ".mk-bs.de": [
        "Martino-Katharineum Gymnasium",
        "Martino-Katharineum high school",
    ],
    ".mlg-bad.de": ["Markgraf-Ludwig-Gymnasium Baden-Baden"],
    ".mls-marburg.de": ["Martin-Luther Schule Marburg"],
    ".mm-bbs.de": ["multi media BBS Hannover"],
    ".stud.mobile-university.de": [
        "SRH Fernhochschule ",
        "The Mobile University",
    ],
    ".monte-koeln.de": ["Montessori Gymnasium Köln"],
    ".ae.mpg.de": ["Max-Planck Institute for Empirical Aesthetics"],
    ".biochem.mpg.de": ["Max Planck Institute for Biochemistry"],
    ".brain.mpg.de": ["Max Planck Institute for Brain Research"],
    ".cbs.mpg.de": [
        "International Max Planck Research School on Neuroscience of Communication"
    ],
    ".coll.mpg.de": [
        "Max-Planck-Institut zur Erforschung von Gemeinschaftsgütern",
        "Max-Planck-Institute for research on collective goods",
    ],
    ".ds.mpg.de": ["Max Planck Institute for Dynamics and Self-Organization"],
    ".eva.mpg.de": [
        "Max-Planck-Institut für evolutionäre Anthropologie",
        "Max Planck Institute for Evolutionary Anthropology",
    ],
    ".fhi-berlin.mpg.de": [
        "Fritz-Haber-Institut Max-Planck-Gesellschaft",
        "Fritz-Haber-Institut Max-Planck-Society",
    ],
    ".fkf.mpg.de": ["Max-Planck-Institute for Solid State Research"],
    ".ip.mpg.de": [
        "Max-Planck-Institut für Innovation und Wettbewerb",
        "Max Planck Institute for Innovation and Competition",
    ],
    ".ipp.mpg.de": [
        "Max-Planck-Institut für Plasmaphysik",
        "Max Planck Institute for Plasma Physics",
    ],
    ".is.mpg.de": [
        "Max Planck Institute for Intelligent Systems, Stuttgart, Germany"
    ],
    ".molgen.mpg.de": ["Max Planck Institute for Molecular Genetics"],
    ".mpe.mpg.de": ["Max-Planck Institute for Extraterrestrial Physics"],
    ".mpi-inf.mpg.de": ["Max Planck Institute for Informatics"],
    ".mpia-hd.mpg.de": [
        "International Max Planck Research School for Astronomy and Cosmic Physics at the University of Heidelberg"
    ],
    ".mpimet.mpg.de": [
        "Max-Planck-Institut für Meteorologie",
        "Max Planck Institute for Meteorology",
    ],
    ".mpip-mainz.mpg.de": [
        "Max Planck Institute for Polymer Research, mainz, Germany",
        "http://www.mpip-mainz.mpg.de",
    ],
    ".mpiwg-berlin.mpg.de": [
        "Max Planck Institute for the History of Science"
    ],
    ".mpl.mpg.de": [
        "Max-Planck-Institut für die Physik des Lichts",
        "Max Planck Institute for the Science of Light",
    ],
    ".mpp.mpg.de": [
        "Max Planck Institut für Physik",
        "Max Planck Institute for Physics",
    ],
    ".mpsd.mpg.de": [
        "Max Planck Institut für Struktur und Dynamik der Materie",
        "Max Planck Institute for the Structure and Dynamics of Matter",
    ],
    ".mpzpm.mpg.de": ["Max Planck Institut"],
    ".pks.mpg.de": ["Max Planck Institute for the Physics of Complex Systems"],
    ".psych.mpg.de": [
        "Max-Planck-Institut für Psychiatrie",
        "Max Planck Institute of Psychiatry",
    ],
    ".tue.mpg.de": [
        "Max Planck Institute for Intelligent Systems, Tuebingen, Germany"
    ],
    ".mpg-bb.de": ["Max-Planck-Gymnasium Böblingen"],
    ".mpg-ka.de": ["Max-Planck-Gymnasium Karlsruhe"],
    ".mpg-trier.de": ["Max-Planck-Gymnasium Trier"],
    ".schueler.mpg-umstadt.de": ["Max-Planck-Gymnasium Groß-Umstadt"],
    ".mpi-cbg.de": [
        "Max Planck Institute of Molecular Cell Biology and Genetics"
    ],
    ".mpia.de": [
        "International Max Planck Research School for Astronomy and Cosmic Physics at the University of Heidelberg"
    ],
    ".annette.ms.de": ["Annette-von-Droste-Hülshoff-Gymnasium Münster"],
    ".kant.ms.de": ["Immanuel Kant Gymnasium Hiltrup"],
    ".pascal.ms.de": ["Pascalgymnasium Münster", "Pascal College Muenster"],
    ".schiller.ms.de": ["Schillergymnasium Münster"],
    ".stein.ms.de": ["Freiherr-vom-Stein Gymnasium Muenster"],
    ".ms-muc.de": [
        "Meisterschulen am Ostbahnhof, München",
        "Master Schools at Ostbahnhof, Munich, Germany",
    ],
    ".mseu.de": ["Marienschule Euskirchen"],
    ".mtgmuenchen.de": ["Staatliches Maria-Theresia-Gymnasium München"],
    ".mu-luebeck.de": ["Medizinische Universität Lübeck"],
    ".mtg.musin.de": ["Maria-Theresia-Gymnasium München"],
    ".bs-info.muenchen.musin.de": [
        "Städtische Berufsschule für Informationstechnik"
    ],
    ".fosbos-technik.muenchen.musin.de": [
        "Staatliche Fachoberschule und Berufsoberschule München - Ausbildungsrichtungen: Technik / Agrarwirtschaft, Bio- und Umwelttechnologie"
    ],
    ".gg.muenchen.musin.de": ["Gisela-Gymnasium München-Schwabing"],
    ".gmm.muenchen.musin.de": ["Gymnasium München Moosach"],
    ".hhg.muenchen.musin.de": ["Städtisches Heinrich Heine Gymnasium München"],
    ".kkg.muenchen.musin.de": ["Käthe-Kollwitz-Gymnasium"],
    ".lfg.muenchen.musin.de": ["Städtisches Lion-Feuchtwanger-Gymnasium"],
    ".lpg.muenchen.musin.de": ["Luitpold-Gymnasium München"],
    ".mpg.muenchen.musin.de": [
        "Max-Planck-Gymnasium-München",
        "Max-Planck-Gymnasium-Munich",
    ],
    ".mtg.muenchen.musin.de": ["Maria-Theresia-Gymnasium München"],
    ".thg.muenchen.musin.de": ["Theresien-Gymnasium München"],
    ".ts.muenchen.musin.de": ["Technikerschule München"],
    ".willi-graf-gymnasium.muenchen.musin.de": [
        "Städtisches Willi-Graf-Gymnasium München"
    ],
    ".wsg.muenchen.musin.de": [
        "Städtisches Werner-von-Siemens-Gymnasium München"
    ],
    ".wsg.musin.de": ["Städtisches Werner-von-Siemens-Gymnasium München"],
    ".muthesius.de": [
        "Muthesius-Hochschule, Fachhochschule für Kunst und Gestaltung"
    ],
    ".mvl-gym.de": ["Maria von Linden Gymnasium"],
    ".mwn.de": ["Hochschule für Philosophie München"],
    ".mws-mainz.de": ["Maria Ward-Schule Mainz"],
    ".mycorvey.de": ["Gymnasium Corveystraße", "high school Corveystraße"],
    ".myhsba.de": ["HSBA Hamburg School of Business Administration"],
    ".myhss.de": ["Hubert-Sternberg-Schule Wiesloch"],
    ".myrobotron.de": [
        "Robotron Bildungs- und Beratungszentrum",
        "Official Website: https://www.robotron-online.de/",
        "IT-Related two year course: https://www.robotron-online.de/umschulungen/it-umschulungen/umschulung-fachinformatiker-anwendungsentwicklung",
        "Proof that domain belongs to the organization: https://www.robotron-online.de/impressum",
        "last section:",
        '"Hinweis zu myrobotron.de',
        'Die Domain myrobotron.de wird ausschließlich zu Schulungszwecken verwendet. Jegliche E-Mail-Kommunikation über diese Domain trägt keinen rechtsverbindlichen Charakter. Rechtlich verbindliche Mitteilungen erfolgen ausschließlich über die offiziellen Kommunikationskanäle."',
    ],
    ".mytum.de": ["Technical University of Munich"],
    ".naturkundemuseum-bw.de": ["Staatliches Museum für Naturkunde Stuttgart"],
    ".neg-velbert.de": ["Nikolaus-Ehlen-Gymnasium"],
    ".neponet.de": ["Gymnasium Nepomucenum Coesfeld"],
    ".neue-schule-magdeburg.de": ["Neue Schule Magdeburg"],
    ".neuefische.de": ["neuefische - School and Pool for Digital Talent"],
    ".noether-gymnasium.de": ["Emmy-Noether-Gymnasium"],
    ".nordakademie.de": [
        "Nordakademie, Staatlich anerkannte private Fachhochschule mit dualen Studiengängen"
    ],
    ".nordic-campus.de": ["Berufsbildungswerk Nordic Campus bremen"],
    ".hspv.nrw.de": [
        "Hochschule für Polizei und öffentliche Verwaltung NRW",
        "University of Applied Sciences for Police and Public Administration in North Rhine-Westphalia",
    ],
    ".nta-isny.de": [
        "Naturwissenschaftlich technische Akademie Isny - Fachhochschule & Berufskollegs Prof. Dr. Grübler GmbH",
        "Scientific and technical academy Isny - University of Applied Science and Vocational Colleges, Prof. Dr. Gruebler ltd.",
    ],
    ".b8.nuernberg.de": ["Berufliche Schule 8 Nürnberg"],
    ".dg.nuernberg.de": ["Nuernberg Schule"],
    ".rdf.nuernberg.de": ["Rudolf-Diesel-Fachschule"],
    ".schulen.nuernberg.de": ["Nuernberg Schule"],
    ".obs-ganderkesee.de": ["Oberschule Ganderkesee"],
    ".obs-hilter.de": ["Oberschule Hilter"],
    ".obs-weener.de": ["Oberschule Weener"],
    ".obs1celle.de": ["Oberschule Celle 1"],
    ".obsbs.de": [
        "Otto-Bennemann-Schule, Berufsbildende Schulen Wirtschaft und Verwaltung"
    ],
    ".oegym.de": ["Ökumenisches Gymnasium zu Bremen"],
    ".ohg-bensberg.de": ["Otto-Hahn-Gymnasium Bergisch Gladbach - Bensberg"],
    ".ohg-boeblingen.de": ["Otto-Hahn-Gymnasium Böblingen"],
    ".ohg-sb.de": ["Otto-Hahn-Gymnasium Saarbrücken"],
    ".ohggf.de": ["Otto-Hahn-Gymnasium"],
    ".ohmoor.de": ["Gymnasium Ohmoor"],
    ".ohs-bensberg.de": ["Otto-Hahn-Gymnasium Bergisch Gladbach - Bensberg"],
    ".onbtineuss.de": [
        "Berufskolleg für Technik und Informatik Neuss",
        "BTI Neuss",
    ],
    ".osrw.de": ["Oberschule Rauschwalde Görlitz"],
    ".ostendorfer.de": ["Ostendorfer Gymnasium"],
    ".ostfalia.de": ["Ostfalia Hochschule für angewandte Wissenschaften"],
    ".osz-biv.de": ["EWF Europäische Wirtschaftsfachschule Berlin"],
    ".osz-teltow.de": ["Oberstufenzentrum Technik Teltow", "OSZ Teltow"],
    ".oszimt.de": ["Oberstufenzentrum Informations- und Medizintechnik"],
    ".schueler.osztiem.de": ["OSZ TIEM"],
    ".oth-aw.de": ["Ostbayerische Technische Hochschule Amberg-Weiden"],
    ".oth-regensburg.de": ["Ostbayerische Technische Hochschule Regensburg"],
    ".otto-nagel-gymnasium.de": ["Otto-Nagel-Gymnasium"],
    ".ottohahngymnasium.de": ["Otto-Hahn-Gymnasium", "Otto-Hahn-High-School"],
    ".ovgu.de": ["Otto von Guericke University of Magdeburg"],
    ".ovm-kassel.de": ["Oskar-von-Miller-Schule", "Oskar-von-Miller-School"],
    ".paderborn.de": ["Theologische Fakultät Paderborn"],
    ".pdr-kelkheim.de": ["Privatgymnasium Dr. Richter"],
    ".pertha.de": ["Pertha Universität", "Pertha University"],
    ".pfh.de": ["Private Hochschule Göttingen"],
    ".pgs-portal.de": ["Paul-Gerhardt Schule Dassel"],
    ".ph-erfurt.de": ["Pädagogische Hochschule Erfurt/Mühlhausen"],
    ".ph-freiburg.de": ["Pädagogische Hochschule Freiburg"],
    ".ph-gmuend.de": ["Pädagogische Hochschule Schwäbisch Gmünd"],
    ".ph-heidelberg.de": ["Pädagogische Hochschule Heidelberg"],
    ".ph-karlsruhe.de": ["Pädagogische Hochschule Karlsruhe"],
    ".ph-ludwigsburg.de": ["Pädagogische Hochschule Ludwigsburg"],
    ".ph-weingarten.de": ["Pädagogische Hochschule Weingarten"],
    ".philtheol-augustin.de": [
        "Philosophisch-Theologische Hochschule SVD Sankt Augustin"
    ],
    ".phwt.de": ["Private Hochschule fur Wirtschaft und Technick"],
    ".pmhs.de": ["Philipp-Matthäus-Hahn-Schule Nürtingen"],
    ".popakademie.de": ["Popakademie Baden-Württemberg"],
    ".ppc-schule.de": ["Peter-Paul-Cahensly Schule"],
    ".privatfh-da.de": ["Private FernFachhochschule Darmstadt"],
    ".privatgymnasium-weinheim.de": ["Privatgymnasium Weinheim"],
    ".pth-bb.de": [
        "Philosophisch-Theologische Hochschule der Salesianer Don Boscos"
    ],
    ".pth-muenster.de": ["Philosophisch-Theologische Hochschule Münster"],
    ".pthv.de": [
        "Philosophisch-Theologische Hochschule Vallendar der Gesellschaft des Katholischen Apostolates (Pallottiner)"
    ],
    ".rak.de": [
        "RHEINISCHE AKADEMI KÖLN ",
        "https://www.rak.de",
        "https://www.rak.de/die-rak/service-fuer-schueler-und-studierende/",
    ],
    ".ratsgymnasium-pe.de": ["Ratsgymnasium Peine"],
    ".ratsgympeine.de": ["Ratsgymnasium Peine"],
    ".rauheshaus.de": [
        "Evangelische Fachhochschule für Sozialpädagogik der Diakonenanstalt des Rauhen Hauses Hamburg"
    ],
    ".rbbk-do.de": ["Robert-Bosch-Berusfkolleg"],
    ".rbbk-dortmund.de": ["Robert-Bosch-Berufskolleg"],
    ".rbs-ulm.de": ["Robert-Bosch-Schule Ulm"],
    ".rdg-online.de": ["Rudolf Diesel Gymnasium Augsburg"],
    ".reuchlin-gymnasium.de": ["Reuchlin-Gymnasium Pforzheim"],
    ".reutlingen-university.de": ["Reutlingen University"],
    ".schule.rfgs.de": ["Richard Fehrenbach Gewerbeschule"],
    ".rfgs.de": ["Richard Fehrenbach Gewerbeschule"],
    ".rfh-campus.de": ["Rheinische Fachhochschule Koeln"],
    ".rfh-koeln.de": ["Rheinische Fachhochschule Köln"],
    ".ext.rh-koeln.de": ["Rheinische Hochschule Köln"],
    ".rhein-gymnasium-sinzig.de": ["Rhein-Gymnasium Sinzig"],
    ".rheinahrcampus.de": ["Hochschule Koblenz Rhein-Ahr-Campus"],
    ".rhs-bs.de": ["Ricarda-Huch-Schule Braunschweig"],
    ".riemenschneider-gymnasium.de": ["Riemenschneider Gymnasium Würzburg"],
    ".rks-linz.de": ["Robert-Koch-Schule"],
    ".pl.rlp.de": [
        "Pädagogisches Landesinstitut Rheinland-Pfalz",
        "Pedagogical Institute of the State of Rhineland-Palatinate",
    ],
    ".rptu.de": [
        "Rheinland-Pfälzische Technische Universität Kaiserslautern-Landau",
        "University of Kaiserslautern-Landau",
    ],
    ".schueler.rs-feucht.de": ["Realschule Feucht"],
    ".rs-ilsede.de": ["Realschule Groß Ilsede"],
    ".rs-leimen.de": ["Otto-Graf Realschule"],
    ".rs-unterpfaffenhofen.de": ["Staatliche Realschule Unterpfaffenhofen"],
    ".rsh-duesseldorf.de": [
        "Robert Schumann Hochschule Düsseldorf",
        "Robert Schumann University of Music and Media",
    ],
    ".rsnibelungen.de": ["Nibelungen-Realschule"],
    ".rsplus-nierstein.de": [
        "Carl-Zuckmayer-Realschule Plus und Fachoberschule Nierstein"
    ],
    ".rsplus-st-thomas.de": ["St. Thomas Realschule plus"],
    ".rss-witten.de": [
        "Rudolf-Steiner-Schule Witten",
        "Rudolf-Steiner-School Witten",
    ],
    ".rsu-germering.de": ["Staatliche Realschule Unterpfaffenhofen"],
    ".edu.rub.de": ["Ruhr-Universität Bochum"],
    ".rub.de": ["Ruhr-Universität Bochum"],
    ".ruhr-gymnasium.de": ["Ruhr-Gymnasium Witten"],
    ".edu.ruhr-uni-bochum.de": ["Ruhr-Universität Bochum"],
    ".ruhr-uni-bochum.de": ["Ruhr-Universität Bochum"],
    ".rvwbk.de": ["Richard-von-Weizsäcker-Berufskolleg"],
    ".stud.rwg-waren.de": ["Richard Wossidlo Gymnasium"],
    ".rwth-aachen.de": ["Rheinisch Westfälische Technische Hochschule Aachen"],
    ".rwu.de": [
        "RWU Hochschule Ravensburg-Weingarten University of Applied Sciences"
    ],
    ".sadds.de": ["Schule an der Donauschleife"],
    ".saglh.de": ["Sant Antonius Gymnasium", "Sant Antonius Gymnasium"],
    ".sartre-gymnasium.de": ["Sartre-Gymnasium Berlin"],
    ".sbs-herzogenaurach.de": [
        "SBS Herzogenaurach-Höchstadt ",
        "www.sbs-herzogenaurach.de",
    ],
    ".sbsz-jena.de": [
        "Staatliches Berufsbildendes Schulzentrum Jena-Göschwitz",
        "State vocational school center Jena-Göschwitz",
        "SBSZ Jena-Göschwitz",
        "https://www.sbsz-jena.de/",
    ],
    ".schiller-gymnasium-bautzen.de": [
        "Schiller-Gymnasium Bautzen",
        "Schiller-Gymnasium Bautzen",
    ],
    ".schiller-og.de": ["Schiller Gymnasium Offenburg"],
    ".schueler-bkgut.de": [
        "Berufskolleg für Gestaltung und Technik Aachen",
        "Vocational college for design and engineering, Aachen",
        "Student accounts",
    ],
    ".schueler-bsd.de": [
        "Staatliche Berufsschule Dachau",
        "Nikolaus-Lehner-Schule",
    ],
    ".gjo.schulbistum.de": ["Gymnasium Johanneum", '"Die Loburg"'],
    ".gsma.schulbistum.de": [
        "St. Michael Gymnasium Ahlen",
        "Website: http://www.gymnasium-sankt-michael.de/",
        "Proof of long-term IT course: http://www.gymnasium-sankt-michael.de/unterricht/informatik/index.html",
    ],
    ".schuldorf.de": ["Schuldorf Bergstraße, Seeheim-Jugenheim"],
    ".mgl.lb.bw.schule.de": ["Mörike-Gymnasium Ludwigsburg"],
    ".dbg.rt.bw.schule.de": ["Dietrich-Bonhoeffer-Gymnasium"],
    ".vbs.ul.bw.schule.de": ["Valckenburgschule Ulm"],
    ".rbb.do.nw.schule.de": [
        "http://do.nw.schule.de/rbb/",
        "http://do.nw.schule.de/rbb/itberufe.html",
    ],
    ".bs-tnk1.c.sn.schule.de": [
        "Berufliches Schulzentrum für Technik 1 - Industrieschule Chemnitz"
    ],
    ".siemens.md.st.schule.de": ["Werner-von-Siemens-Gymnasium Magdeburg"],
    ".ghsem.em.schule-bw.de": [
        "Gewerbliche und Hauswirtschaftlich-Sozialpflegerische Schulen Emmendingen"
    ],
    ".hoelderlin.hd.schule-bw.de": ["Hölderlin Gymnasium Heidelberg"],
    ".schule-cgl.de": [
        "Copernicus Gymnasium Löningen",
        "Copernicus High School Loeningen",
    ],
    ".schule-franzburg.de": ["Regionale Schule mit Grundschule Franzburg"],
    ".schule-ge-velbert.de": ["Gesamtschule Velbert-Mitte"],
    ".bertha.schule-ob.de": ["Bertha-von-Suttner-Gymnasium Oberhausen"],
    ".schule-schloss-salem.de": ["Schule Schloss Salem"],
    ".schule-sh.de": ["Schleswig-Holstein Schools, Germany"],
    ".166364.schulen-bn.de": ["Friedrich-Ebert-Gymnasium Bonn"],
    ".166376.schulen-bn.de": ["Helmholtz-Gymnasium"],
    ".schulen-fulda.de": ["Ferdinand-Braun-Schule Fulda"],
    ".bk-btg.schulen-gelsenkirchen.de": [
        "Berufskolleg für Technik und Gestaltung Gelsenkirchen"
    ],
    ".schulen-hannover.de": ["schulen-hannover.de"],
    ".gemsal.schulen-itzehoe.de": [
        "Gemeinschaftsschule am Lehmwohld Itzehoe",
        "Community School at Lehmwohld Itzehoe",
    ],
    ".whg.schulen-lev.de": ["Werner-Heisenberg-Gymnasium Leverkusen"],
    ".ass.schulen-offenbach.de": ["Albert Schweitzer Schule"],
    ".schullogin.de": ["Vitzthum Gymnasium Dresden"],
    ".schulverbund.de": ["Isar-Gymnasium München"],
    ".schulzentrum-am-sund.de": ["Schulzentrum am Sund"],
    ".schweinfurt.de": ["Dr.-Georg-Schäfer-Schule"],
    ".sdi-muenchen.de": ["Sprachen und Dolmetscher Institut München"],
    ".selk.de": ["Lutherische Theologische Hochschule Oberursel"],
    ".sembska.de": ["Seminar Berufliche Schulen Karlsruhe "],
    ".semper-schueler.de": ["Semper Fachoberschule Dresden"],
    ".semper-schulen.de": ["Semper Schulen"],
    ".semperschulen.de": ["Semper Schulen"],
    ".sgh-holzgerlingen.de": [
        "Schönbuch Gymnasium Holzgerlingen",
        "Pls. add this school in Germany: https://www.schoenbuch-gymnasium.de/sgh/",
        "The short domain the students get IDs for is sgh-holzgerlingen.de",
    ],
    ".sgy-dt.de": ["Stadtgymnasium Detmold"],
    ".shg-hi.de": ["Scharnhorstgymnasium Hildesheim"],
    ".siegtal-gymnasium.de": ["Siegtal-Gymnasium Eitorf"],
    ".siewerth-akademie.de": ["Gustav-Siewerth-Akademie"],
    ".sis-fellbach.de": ["Swiss International School"],
    ".siu-heidelberg.de": ["Schiller International University, Heidelberg"],
    ".bkt.siwiwissen.de": [
        "Berufskolleg Technik des Kreises Siegen-Wittgenstein"
    ],
    ".bwv.siwiwissen.de": [
        "Berufskolleg Wirtschaft und Verwaltung des Kreises Siegen-Wittgenstein"
    ],
    ".sk-wadersloh.de": ["Sekundarschule Wadersloh"],
    ".smns-bw.de": ["Staatliches Museum für Naturkunde Stuttgart"],
    ".sp-gs.de": [
        "Sally Perel Gesamtschule",
        "Sally Perel Comprehensive School",
    ],
    ".sportschule-potsdam.de": ["Sportschule Potsdam"],
    ".spranger-hamm.de": ["Eduard Spranger Berufskolleg Hamm www.esb-hamm.de"],
    ".bfw.srh.de": [
        "SRH Berufliche Rehabilitation GmbH. Berufsförderungswerk Heidelberg"
    ],
    ".srh-berlin.de": ["SRH University of Applied Sciences"],
    ".stud.srh-campus-berlin.de": ["Design Akademie Berlin"],
    ".stud.srh-university.de": [
        "SRH Hochschule Berlin",
        "SRH Berlin University of Applied Sciences",
    ],
    ".srh.de": ["SRH Berufliche Rehabilitation GmbH"],
    ".srhk.de": ["Berlin School of Design and Communication"],
    ".staedelschule.de": [
        "Hochschule für bildende Künste Frankfurt, Städelschule"
    ],
    ".student.steinbeis-hochschule.de": [
        "Steinbeis Hochschule",
        "Steinbeis University",
    ],
    ".student.steinbeis-sibe.de": [
        "Steinbeis School of International Business and Entrepreneurship (SIBE) GmbH"
    ],
    ".stiftkeppel.de": ["Gymnasium Stift Keppel"],
    ".stiftsgymnasium.de": ["Stiftsgymnasium Sindelfingen"],
    ".stresemanngymnasium.de": ["Gustav Stresemann Gymnasium"],
    ".sts-bahrenfeld.de": [
        "Esther Bejerano Schule ",
        "Stadtteilschule Bahrenfeld",
    ],
    ".sts-old.de": ["Stadtteilschule Oldenfelde"],
    ".stud-provadis-hochschule.de": [
        "Provadis School of International Management and Technology AG, 65926 Frankfurt am Main"
    ],
    ".students-hnbk.de": ["Heinz-Nixdorf Berufskolleg"],
    ".stw.de": ["Steinbeis-Hochschule-Berlin"],
    ".sus-am-bktm.de": [
        "Berufskolleg Platz der Republik für Technik und Medien"
    ],
    ".sus-bbswhs.de": ["Berufliches Gymnasium Wildeshausen"],
    ".syntax-institut.de": ["Syntax Institut"],
    ".edu.sz-deg.de": ["Robert-Koch-Gymnasium Deggendorf"],
    ".sz-haltern.de": [
        "Joseph-König-Gymnasium Haltern am See",
        "Alexander-Lebenstein-Realschule Haltern am See",
        "at Schulzentrum Haltern am See",
    ],
    ".sz-uetze.de": ["Gymnasium unter den Eichen Uetze"],
    ".szh-ahrensburg.de": ["Gemeinschafts Schule am Heimgarten"],
    ".tagore-gymnasium.de": ["Tagore-Gymnasium"],
    ".tbk-solingen.de": ["Technisches Berufskolleg Solingen"],
    ".tbs1.de": ["Technische Berufliche Schule 1 - Bochum"],
    ".technik-emden.de": ["Hochschule Emden-Leer"],
    ".technikerschule-berlin.de": ["Staatliche Technikerschule Berlin"],
    ".tek-up.de": ["TEK-UP University", "TEK-UP University"],
    ".tel-ran.de": ["Tel-Ran.de"],
    ".tfh-berlin.de": ["Technische Fachhochschule Berlin"],
    ".tfh-bochum.de": [
        "Technische Fachhochschule Georg Agricola für Rohstoff, Energie und, Umwelt zu Bochum"
    ],
    ".tfh-wildau.de": ["Technische Fachhochschule Wildau"],
    ".th-ab.de": [
        "Technische Hochschule Aschaffenburg",
        "University of applied sciences Aschaffenburg",
    ],
    ".th-bingen.de": [
        "Technische Hochschule Bingen University of Applied Sciences"
    ],
    ".th-brandenburg.de": ["Technische Hochschule Brandenburg"],
    ".th-deg.de": ["Technische Hochschule Deggendorf"],
    ".th-koeln.de": ["Fachhochschule Köln", "Technische Hochschule Köln"],
    ".th-luebeck.de": ["TH Lübeck"],
    ".th-nuernberg.de": ["Technische Hochschule Nürnberg Georg Simon Ohm"],
    ".th-owl.de": [
        "Technische Hochschule Ostwestfalen-Lippe",
        "OWL University of Applied Sciences",
    ],
    ".stud.th-rosenheim.de": [
        "Technische Hochschule Rosenheim",
        "Rosenheim Technical University of Applied Sciences",
    ],
    ".th-rosenheim.de": [
        "Technische Hochschule Rosenheim",
        "Technical University Of Applied Sciences Rosenheim",
    ],
    ".th-wildau.de": ["Wildau Technical University of Applied Sciences"],
    ".tha.de": [
        "Technische Hochschule Augsburg",
        "Augsburg University of Applied Sciences",
    ],
    ".theresianum-mainz.de": ["Gymnasium Theresianum Mainz"],
    ".thga.de": [
        "Technische Hochschule Georg Agricola",
        "University of Applied Sciences Georg Agricola",
    ],
    ".thh-friedensau.de": ["Theologische Hochschule Friedensau"],
    ".thi.de": ["Technische Hochschule Ingolstadt"],
    ".thk-optec.de": [
        "Institute of Optical Technologies at Cologne University of Applied Sciences, Germany"
    ],
    ".thm.de": ["University of Applied Sciences Giessen-Friedberg"],
    ".ths-berlin.de": ["Theodor-Haubach-Schule"],
    ".thu.de": [
        "Technische Hochschule Ulm",
        "Ulm University of Applied Science ",
    ],
    ".thws.de": ["Technische Hochschule Würzburg-Schweinfurt"],
    ".tiho-hannover.de": ["Tierärztliche Hochschule Hannover"],
    ".tms-badoldesloe.de": ["TMS Bad Oldesloe"],
    ".ts-aalen.de": ["Technische Schule Aalen"],
    ".tu-berlin.de": ["Technische Universität Berlin"],
    ".tu-braunschweig.de": [
        "Technische Universität Carolo-Wilhelmina zu Braunschweig"
    ],
    ".tu-bs.de": ["Technische Universität Carolo-Wilhelmina zu Braunschweig"],
    ".tu-chemnitz.de": ["Technische Universität Chemnitz-Zwickau"],
    ".tu-clausthal.de": ["Technische Universität Clausthal"],
    ".tu-cottbus.de": ["Brandenburgische Technische Universität Cottbus"],
    ".tu-darmstadt.de": ["Technische Universität Darmstadt"],
    ".tu-dortmund.de": [
        "Technische Universität Dortmund",
        "TU Dortmund University",
    ],
    ".tu-dresden.de": ["Technische Universität Dresden"],
    ".tu-freiberg.de": ["Technische Universität Bergakademie Freiberg"],
    ".tu-harburg.de": ["Technische Universität Hamburg-Harburg"],
    ".tu-ilmenau.de": ["Technische Universität Ilmenau"],
    ".tu-muenchen.de": ["Technical University of Munich"],
    ".tuhh.de": ["Technische Universität Hamburg-Harburg"],
    ".tum.de": ["Technical University of Munich"],
    ".udk-berlin.de": ["Universität der Künste Berlin"],
    ".ue-germany.de": [
        "University of Applied Sciences Europe (Campus Hamburg)",
        "University of Applied Sciences Europe (Campus Hamburg)",
    ],
    ".ukbonn.de": ["Universitätsklinikum Bonn", "University Hospital Bonn"],
    ".ulricianum-aurich.de": ["Gymnasium Ulricianum Aurich"],
    ".umwelt-campus.de": ["Hochschule Trier, Umwelt-Campus Birkenfeld"],
    ".uni-a.de": ["Universität Augsburg", "Augsburg University"],
    ".uni-augsburg.de": ["Universität Augsburg"],
    ".uni-bamberg.de": ["Otto-Friedrich Universität Bamberg"],
    ".uni-bayreuth.de": ["Universität Bayreuth"],
    ".uni-bielefeld.de": ["Universität Bielefeld"],
    ".uni-bonn.de": [
        "Rheinische Friedrich-Wilhelms Universität Bonn",
        "University of Bonn",
    ],
    ".uni-bremen.de": ["Universität Bremen"],
    ".uni-dortmund.de": ["Universität Dortmund"],
    ".uni-due.de": ["University Duisburg-Essen"],
    ".uni-duesseldorf.de": ["Heinrich-Heine Universität Düsseldorf"],
    ".uni-duisburg-essen.de": ["Universität Duisburg-Essen"],
    ".uni-erfurt.de": [
        "Philosophisch-Theologisches Studium Erfurt, Staatlich anerkannte Wissenschaftliche Hochschule",
        "Universität Erfurt",
    ],
    ".uni-erlangen.de": ["Friedrich-Alexander Universität Erlangen-Nürnberg"],
    ".uni-flensburg.de": ["Universität Flensburg"],
    ".uni-frankfurt.de": [
        "Johann Wolfgang Goethe Universität Frankfurt am Main",
        "Philosophisch-Theologische Hochschule Sankt Georgen",
    ],
    ".uni-freiburg.de": ["Albert-Ludwigs-Universität Freiburg"],
    ".uni-giessen.de": ["Justus Liebig Universität Gießen"],
    ".stud.uni-goettingen.de": ["Georg-August-Universität Göttingen"],
    ".uni-goettingen.de": ["Georg-August Universität Göttingen"],
    ".uni-greifswald.de": ["Ernst-Moritz-Arndt Universität Greifswald"],
    ".uni-halle.de": [
        "Martin-Luther-Universität Halle-Wittenberg",
        "Martin Luther University Halle-Wittenberg",
    ],
    ".uni-hamburg.de": ["Universität Hamburg"],
    ".uni-hannover.de": ["Universität Hannover"],
    ".uni-heidelberg.de": [
        "Hochschule für Jüdische Studien Heidelberg",
        "Ruprecht-Karls-Universität Heidelberg",
    ],
    ".uni-hildesheim.de": ["Universität Hildesheim"],
    ".uni-hohenheim.de": ["Universität Hohenheim"],
    ".uni-jena.de": ["Friedrich-Schiller Universität Jena"],
    ".uni-karlsruhe.de": [
        "Universität Fridericana Karlsruhe (Technische Hochschule)"
    ],
    ".uni-kassel.de": ["Universität Kassel"],
    ".uni-kiel.de": ["Christian-Albrechts-Universität Kiel"],
    ".uni-kl.de": ["Universität Kaiserslautern"],
    ".uni-koblenz-landau.de": ["Universität Koblenz-Landau"],
    ".uni-koblenz.de": ["University of Koblenz and Landau"],
    ".uni-koeln.de": ["Universität Köln"],
    ".uni-konstanz.de": ["Universität Konstanz"],
    ".uni-landau.de": ["Universität Koblenz-Landau"],
    ".uni-leipzig.de": ["Universität Leipzig"],
    ".uni-luebeck.de": ["University of Lübeck"],
    ".uni-lueneburg.de": ["Universität Lüneburg"],
    ".uni-magdeburg.de": ["Otto-von-Guericke Universität Magdeburg"],
    ".uni-mainz.de": ["Johannes-Gutenberg Universität Mainz"],
    ".students.uni-mannheim.de": ["Universität Mannheim"],
    ".uni-mannheim.de": ["Universität Mannheim"],
    ".uni-marburg.de": ["Philipps-Universität Marburg"],
    ".uni-muenchen.de": ["Ludwig-Maximilians-Universität München"],
    ".uni-muenster.de": ["Westfälische Wilhelms-Universität Münster"],
    ".uni-oldenburg.de": ["Carl von Ossietzky Universität Oldenburg"],
    ".uni-osnabrueck.de": ["Universität Osnabrück"],
    ".uni-paderborn.de": ["Universität Paderborn"],
    ".uni-passau.de": ["Universität Passau"],
    ".uni-potsdam.de": ["Universität Potsdam"],
    ".uni-regensburg.de": ["Universität Regensburg"],
    ".uni-rostock.de": ["Universität Rostock"],
    ".uni-saarland.de": ["Universität des Saarlandes"],
    ".uni-siegen.de": ["Universität Siegen"],
    ".uni-stuttgart.de": ["Universität Stuttgart"],
    ".uni-trier.de": ["Theologische Fakultät Trier", "Universität Trier"],
    ".uni-tuebingen.de": ["Eberhard-Karls-Universität Tübingen"],
    ".uni-ulm.de": ["Universität Ulm"],
    ".uni-vechta.de": ["Hochschule Vechta"],
    ".uni-weimar.de": ["Bauhaus-Universität Weimar"],
    ".uni-wh.de": ["Private Universität Witten/Herdecke"],
    ".uni-wuerzburg.de": [
        "Bayerische Julius-Maximilians-Universität Würzburg"
    ],
    ".uni-wuppertal.de": [
        "Bergische Universität Gesamthochschule Wuppertal",
        "Kirchliche Hochschule Wuppertal",
    ],
    ".unibw-hamburg.de": ["Universität der Bundeswehr Hamburg"],
    ".unibw-muenchen.de": ["Universität der Bundeswehr München"],
    ".unibw.de": ["Universität der Bundeswehr München", "www.unibw.de"],
    ".uniklinik-freiburg.de": [
        "University Medical Center University of Freiburg"
    ],
    ".uol.de": [
        "Carl von Ossietzky Universität Oldenburg",
        "https://uol.de/en",
        "https://uol.de/en/course-of-study/computing-science-subject-bachelor-133",
        "https://uol.de/en/it-services/services/user-account-at-the-university/user-account-for-university-members",
    ],
    ".uos.de": ["University of Osnabrueck"],
    ".upb.de": ["University of Paderborn"],
    ".ursulinenschule.de": ["Ursulinenschule Fritzlar"],
    ".utn.de": ["Technische Universität Nürnberg"],
    ".valckenburgschule.de": ["Valckenburgschule Ulm"],
    ".vbs-lauterbach.de": ["Vogelsbergschule Lauterbach"],
    ".grosse-schule.versus-wf.de": ["Gymnasium Große Schule Wolfenbüttel"],
    ".victoria-hochschule.de": [
        "Victoria | Internationale Hochschule",
        "Victoria | International University of Applied Sciences",
    ],
    ".vit-bund.de": [
        "Federal University of Applied Administrative Sciences > Departmental Branch of Financial Administration > degree course: administrative information systems"
    ],
    ".w-hs.de": ["Westfalia University of Applied Sciences"],
    ".schule.wa-nord.de": ["Wirtschaftsakademie Nord gGmbH"],
    ".wak-sh.de": ["Wirtschaftsakademie Schleswig-Holstein"],
    ".waldorf-augsburg.de": ["Freie Waldorfschule Augsburg"],
    ".wara.de": ["Walther-Rathenau Gewerbeschule Freiburg"],
    ".webmail.wavelearn.de": ["sgd-OnlineCampus"],
    ".wb-fernstudium.de": [
        "Wilhelm Büchner Hochschule",
        "Wilhelm Büchner Hochschule",
    ],
    ".wbgym.de": ["Weinberg Gymnasium Kleinmachnow"],
    ".wbs-schulen.de": ["WBS TRAINING Schulen"],
    ".wbsedu.de": ["WBS TRAINING AG"],
    ".wbstraining.de": [
        "wbs training AG in Berlin,Germany",
        "Domain: https://www.wbstraining.de",
    ],
    ".weg-schwabach.de": ["Wolfram-von-Eschenbach-Gymnasium Schwabach"],
    ".weiterbildung-reutlingen-university.de": [
        "Hochschule Reutlingen",
        "Reutlingen University",
    ],
    ".wgg-neumarkt.de": ["Willibald-Gluck-Gymnasium"],
    ".wgmail.de": ["Wolkenberg-Gymnasium Michendorf"],
    ".whg-duew.de": ["Werner-Heisenberg-Gymnasium Bad Dürkheim"],
    ".whg-lu.de": ["Wilhelm-von-Humboldt-Gymnasium"],
    ".whu-koblenz.de": [
        "Wissenschaftliche Hochschule für Unternehmensführung, Otto-Beisheim Hochschule"
    ],
    ".wilhelm-busch-gymnasium.de": ["Wilhelm Busch Gymnasium Stadthagen"],
    ".wrs-lueneburg.de": ["Wilhelm Raabe Schule"],
    ".wss-stuttgart.de": [
        "Werner Siemens Schule Stuttgart",
        "Werner Siemens Technical School Stuttgart",
    ],
    ".bsg.wtkedu.de": ["Berufliche Schulen am Gradierwerk", "BSG Bad Nauheim"],
    ".wuemmeschule.de": ["Wümmeschule Ottersberg"],
    ".wvo-dbg.de": ["Wilhelm von Oranien Schule"],
    ".wvs-ffm.de": ["Werner-von-Siemens-Schule"],
    ".wvsi.de": [" Werner-von-Siemens-Schule"],
    ".wvss-hildesheim.de": ["Werner-von-Siemens-Schule Hildesheim"],
    ".wvss-wetzlar.de": ["Werner-von-Siemens-Schule Wetzlar"],
    ".wvss2-hildesheim.de": ["Werner-von-Siemens-Schule Hildesheim"],
    ".wwgsk.de": [
        " Wirtschaftswissenschaftliches Gymnasium und Saarland-Kolleg"
    ],
    ".gisny.wwschool.de": ["Gymnasium Isny"],
    ".gnr.wwschool.de": ["Gymnasium Nepomucenum Rietberg"],
    ".wwu.de": ["University of Münster"],
    ".student.xu-university.de": ["xu-university", "xu-university"],
    ".zgk-konstanz.de": ["Zeppelin-Gewerbeschule Konstanz"],
    ".zgs-konstanz.de": ["Zeppelin Gewerbeschule Konstanz"],
    ".zsl-rss.de": [
        "Zentrum für Schulqualität und Lehrerbildung Baden-Württemberg, Regionalstelle Stuttgart"
    ],
    ".zu.de": ["Zeppelin University"],
    ".epitech.digital": [
        "Epitech Digital - L’ÉCOLE DE LA TRANSFORMATION DIGITALE"
    ],
    ".edu.dj": ["Université de Djibouti"],
    ".katrinebjergskolen.aarhus.dk": ["Katrinebjergskolen"],
    ".edu.aarhustech.dk": ["Aarhus Tech"],
    ".aarhustech.dk": ["Aarhus Tech"],
    ".aatg.dk": ["Aalborg Tekniske Gymnasium"],
    ".aau.dk": ["Aalborg University"],
    ".ah.dk": ["Aalborg Business College"],
    ".akademiaarhus.dk": ["Business Academy Aarhus"],
    ".askovefterskole.dk": ["Askov efterskole game design"],
    ".aspit.dk": ["AspIT, Denmark"],
    ".ats.dk": ["Aarhus Technical College"],
    ".au.dk": ["Aarhus University"],
    ".auc.dk": ["Aalborg University"],
    ".bierstedskole.dk": ["Biersted Skole", "Biersted School"],
    ".brock.dk": ["Niels Brock"],
    ".edu.campusvejle.dk": ["Campus Vejle, Denmark"],
    ".cbs.dk": ["Copenhagen Business School"],
    ".ciid.dk": ["Copenhagen Institute of Interaction Design (CIID)"],
    ".cphbusiness.dk": ["Copenhagen Business Academy"],
    ".db.dk": ["Royal School of Library and Information Science"],
    ".ddea.dk": ["Danish Business Academy"],
    ".detfri.dk": ["Det frie Gymnasium"],
    ".diku.dk": ["University of Copenhagen"],
    ".dkdm.dk": ["Royal Danish Academy of Music"],
    ".dlh.dk": ["Royal Danish School of Educational Sciences"],
    ".mail.dmjx.dk": [
        "Danmarks Medie- og Journalisthøjskole / Danish School of Media and Journalism"
    ],
    ".dmjx.dk": ["Danish School of Media and Journalism"],
    ".dpu.dk": ["Danish University of Education"],
    ".dtu.dk": ["Technical University of Denmark"],
    ".eaaa.dk": ["Erhvervs Akademi Aarhus", "Business Academy Aarhus"],
    ".eadania.dk": ["Dania Academy of Higher Education"],
    ".eal.dk": ["Erhvervsakademiet Lillebælt"],
    ".eamv.dk": ["Erhvervsakademi MidtVest"],
    ".easj.dk": ["ErhvervsAkademi Sjælland"],
    ".easv.dk": ["Business Academy SouthWest"],
    ".easv365.dk": ["Business Academy SouthWest"],
    ".eg-gym.dk": ["Espergærde Gymnasium og HF"],
    ".ek.dk": ["Erhvervsakademi København", "Business Academy Copenhagen"],
    ".elevcampus.dk": ["EUC Syd - Teknisk Gymnasium Sønderjylland"],
    ".elevportal.dk": ["elevportal.dk"],
    ".euclive.dk": [
        "EUC Nord HTX Frederikshavn",
        "EUC North HTX Frederikshavn",
    ],
    ".eucnordvest.dk": ["EUC Nordvest"],
    ".unv.eucsj.dk": ["EUC SJÆLLAND"],
    ".eucsyd.dk": ["EUC SYD"],
    ".gefion-gym.dk": ["Gefion Gymnasium"],
    ".ghg.dk": ["Gammel Hellerup Gymnasium"],
    ".hansenberg.dk": ["Hansenberg"],
    ".herningsholm.dk": ["Herningsholm Erhvervsskole"],
    ".hha.dk": ["Aarhus School of Business"],
    ".hhs.dk": ["Southern Denmark Business School"],
    ".iba.dk": [
        "IBA Erhvervsakademi Kolding",
        "IBA International Business Academy",
    ],
    ".iha.dk": ["Engineering College of Aarhus"],
    ".ihk-edu.dk": ["Engineering College of Copenhagen"],
    ".ihk.dk": ["Engineering College of Copenhagen"],
    ".ind-it.dk": ["Individualisterne"],
    ".individualisterne.dk": ["Individualisterne"],
    ".ipc.dk": ["International People's College"],
    ".itu.dk": ["IT University of Copenhagen"],
    ".edu.kadk.dk": [
        "Det Kongelige Akademi ",
        "Royal Danish Academy, School of Visual Design",
        "Formerly KADK ",
        "The Royal Danish Academy of Fine Arts' Schools of Architecture, Design and Conservation",
        "@edu.kadk.dk",
    ],
    ".karch.dk": ["Royal Danish Academy of Fine Arts, School of Architecture"],
    ".kea.dk": ["Copenhagen School of Design and Technology"],
    ".kglakademi.dk": ["Det Kongelige Akademi", "Royal Danish Academy"],
    ".kp.dk": ["Københavns Professionshøjskole"],
    ".ku.dk": ["Copenhagen University"],
    ".kunstakademiet.dk": [
        "Royal Danish Academy of Fine Arts, School of Visual Art"
    ],
    ".kvl.dk": ["Royal Veterinary and Agricultural University"],
    ".learnmark.dk": ["Learnmark Horsens"],
    ".marselisborg-gym.dk": ["Marselisborg Gymnasium"],
    ".mediacollege.dk": ["Media College Aalborg"],
    ".mercantec.dk": ["Mercantec"],
    ".mitvuc.dk": ["VUC Syd"],
    ".edu.munkensdam.dk": ["Munkensdam Gymnasium"],
    ".musik-kons.dk": ["Royal Academy of Music"],
    ".nagadm.dk": ["Nærum Gymnasium", "Naerum High School"],
    ".g.nagym.dk": ["Nærum Gymnasium", "Naerum High School"],
    ".nbi.dk": ["Niels Bohr Institute"],
    ".edu.nextkbh.dk": [
        "Next Uddannelse København",
        "Next Education Copenhagen",
    ],
    ".nextkbh.dk": ["NEXT Uddannelse København", "NEXT Education Copenhagen"],
    ".edu.nyborg-gym.dk": ["Nyborg Gymnasium"],
    ".ofe.dk": ["Osted fri og efterskole"],
    ".ou.dk": ["Odense University"],
    ".pha.dk": ["Professionshøjskolen Absalon"],
    ".phmetropol.dk": ["Professionshøjskolen Metropol"],
    ".regionh.dk": ["Bispebjerg University Hospital"],
    ".rgnet.rg.dk": ["Rødovre Gymnasium", "Rødovre Highschool"],
    ".rhs.dk": ["Roskilde Business College"],
    ".roskilde-gym.dk": ["Roskilde Gymnasium"],
    ".roskildegymnasium.dk": ["Roskilde Gymnasium"],
    ".rts-365.dk": ["Roskilde Tekniske Skole", "Roskilde Technical School"],
    ".ruc.dk": ["Roskilde University"],
    ".rybners.dk": ["Rybners"],
    ".scu.dk": [
        "Skanderborg-Odder Center for Uddannelse",
        "Skanderborg-Odder Center for Education",
    ],
    ".sde.dk": [
        "Business School of Southern Denmark (Website, english version: http://www.sde.dk/sde/site.aspx?p=1136)"
    ],
    ".sdu.dk": ["University of Southern Denmark"],
    ".edu.simac.dk": ["Svendborg International Maritime Academy"],
    ".skals-efterskole.dk": ["Skals Efterskole"],
    ".skivecollege.dk": ["Skive College"],
    ".slagelse-gym.dk": ["Slagelse Gymnasium"],
    ".stenhus-gym.dk": ["Stenhus Gymnasium "],
    ".studiebyenesbjerg.dk": ["Erhvervs Akademi Sydvest"],
    ".svendborg-gym.dk": ["Svendborg Gymnasium", "Svendborg Gymnasium"],
    ".svhfvuc.dk": ["Skive Viborg Hf & VUC"],
    ".svkskole.dk": [
        "Svendborg Kommunes Skoler ",
        "Svendborg Municipality Schools",
    ],
    ".sydfynsfrifagskole.dk": ["Sydfyns Fri Fagskole"],
    ".tcaa.dk": ["Tech College Aalborg"],
    ".tec.dk": ["TEC - Technical Education Copenhagen"],
    ".techcollege.dk": ["Tech College Aalborg"],
    ".teologi.dk": ["Lutheran School Of Theology In Aarhus"],
    ".tietgen.dk": ["Tietgen Business College"],
    ".elev.tradium.dk": ["Tradium (Students)"],
    ".ucl.dk": ["UCL Erhvervsakademi og Professionshøjskole"],
    ".ucn.dk": ["University College of Northern Denmark"],
    ".ucsyd.dk": ["UC SYD Kolding"],
    ".uoie.dk": ["University of Ismay Elwood"],
    ".skole.vejle.dk": ["Thyregod skole"],
    ".via.dk": ["VIA University College"],
    ".viauc.dk": ["VIA University College"],
    ".videndjurs.dk": [
        'Videndjus Gymnasier, Videndjurs Erhvervsuddannelser (English website "http://www.videndjurs.dk/Default.aspx?ID=3992")'
    ],
    ".vordingborgskolen.dk": ["Vordingborg Fri Fagskole"],
    ".zbc.dk": ["ZBC - Zealand Business College"],
    ".zealand.dk": [
        "Zealand - Sjællands Erhvervsakademi",
        "Zealand - Academy of Technologies and Business",
    ],
    ".centroeducativoinvironda.edu.do": [
        "Centro Educativo Invironda",
        "Centro Educativo Invironda",
    ],
    ".genesis.edu.do": [
        "Colegio Cristiano Genesis",
        "Genesis Christian School",
    ],
    ".icda.edu.do": [
        "Universidad Dominico-Americana",
        "Universidad Dominico-Americana",
    ],
    ".intec.edu.do": [
        "Instituto Tecnológico De Santo Domingo",
        "Technological Institute of Santo Domingo",
    ],
    ".ipl.edu.do": [
        "Instituto Especializado de Estudios Superiores Loyola",
        "Instituto Especializado de Estudios Superiores Loyola",
    ],
    ".oym.edu.do": ["Universidad dominicana O&M"],
    ".oymas.edu.do": ["universidad Dominicana O&M"],
    ".uafam.edu.do": [
        "Universidad Agroforestal Fernando A.Meriño",
        "Universidad Agroforestal Fernando A.Meriño",
    ],
    ".uapa.edu.do": [
        "Universidad Abierta Para Adultos",
        "Universidad Abierta Para Adultos",
    ],
    ".uasd.edu.do": [
        "Universidad Autónoma de Santo Domingo",
        "Universidad Autónoma de Santo Domingo",
    ],
    ".ucateba.edu.do": [
        "Universidad Católica Tecnológica de Barahona",
        "Catholic Technological University of Barahona",
    ],
    ".ucateci.edu.do": [
        "Universidad Católica Tecnológica del Cibao",
        "Universidad Católica Tecnológica del Cibao",
    ],
    ".ucne.edu.do": [
        "Universidad Católica Nordestana",
        "Universidad Católica Nordestana",
    ],
    ".ucsd.edu.do": [
        "Universidad Católica de Santo Domingo",
        "Universidad Católica de Santo Domingo",
    ],
    ".udoym.edu.do": [
        "Universidad Dominicana O&amp;M",
        "Universidad Dominicana O&amp;M",
    ],
    ".unad.edu.do": [
        "Universidad Adventista Dominicana",
        "Universidad Adventista Dominicana",
    ],
    ".unefa.edu.do": [
        "Universidad Experimental Felix Adam",
        "Universidad Experimental Felix Adam",
    ],
    ".unicaribe.edu.do": ["Universidad del Caribe", "Universidad del Caribe"],
    ".unicda.edu.do": [
        "Universidad Domínico Americano",
        "Universidad Domínico Americano",
    ],
    ".uniremhos.edu.do": [
        "Universidad Eugenio Maria de Hostos",
        "Universidad Eugenio Maria de Hostos",
    ],
    ".unphu.edu.do": [
        "Universidad Nacional Pedro Henríquez Ureña",
        "Universidad Nacional Pedro Henríquez Ureña",
    ],
    ".uod.edu.do": [
        "Universidad Odontológica Dominicana",
        "Universidad Odontológica Dominicana",
    ],
    ".ute.edu.do": [
        "Universidad de la Tercera Edad",
        "Universidad de la Tercera Edad",
    ],
    ".utesur.edu.do": [
        "Universidad Tecnológica del Sur",
        "Universidad Tecnológica del Sur",
    ],
    ".cdta.dz": [
        "Center for Development of Advenced Technologies",
        "Centre de développement des technologies avancées",
    ],
    ".centre-univ-mila.dz": [
        "Centre Universitaire Abdelhafid Boussouf Mila",
        "Abdelhafid Boussouf University Center in Mila",
    ],
    ".cu-elbayadh.dz": [
        "University Center Nour Bachir El-Bayadh",
        "Centre Universitaire Nour Bachir El-Bayadh",
        "المركز الجامعي نور البشير البيض",
    ],
    ".cuniv-naama.dz": [
        "salhi ahmed university center naama  algeria",
        "salhi ahmed university center naama  algeria",
    ],
    ".enp.edu.dz": [
        "Polytechnic School of Algiers",
        "Ecole Nationale Polytechnique, Alger",
    ],
    ".umc.edu.dz": ["Université Mentouri Constantine"],
    ".enp-oran.dz": ["Ecole Nationale Polytechnique d'Oran Maurice Audin"],
    ".ens-kouba.dz": [
        "ENS El-Bachir El-Ibrahimi - Kouba ",
        "El-Bachir El-Ibrahimi ENS - Kouba",
    ],
    ".enset-skikda.dz": ["ENSET SKIKDA"],
    ".ensh.dz": [
        "ENSH - Ecole Nationale Supérieure d'Hydraulique de Blida",
        "ENSH - National School of Hydraulics of Blida",
    ],
    ".enst.dz": ["Ecole Nationale Superieure de Technologie"],
    ".ensti-annaba.dz": [
        "École Nationale Supérieure de Technologie et d'Ingénierie d'Annaba, Algérie"
    ],
    ".ensttic.dz": ["ENSTTIC"],
    ".epst-oran.dz": ["Ecole Préparatoire en Sciences et Techniques"],
    ".esas-eloued.dz": ["Higher School of Saharan Agriculture – El oued"],
    ".esgee-oran.dz": [
        "École Supérieure en Génie Électrique et Énergétique d'Oran (ESGEE-Oran)",
        "Higher School of Electrical and Energy Engineering of Oran",
    ],
    ".esi-sba.dz": [
        "Ecole Nationale Supérieure D'Informatique de Sidi Belabbess"
    ],
    ".esi.dz": ["l'Ecole Nationale Supérieure D'Informatique"],
    ".essa-tlemcen.dz": [
        "Ecole Supérieure en Sciences Appliquées de Tlemcen",
        "School of Applied Sciences Tlemcen",
    ],
    ".estin.dz": [
        "École supérieure en Sciences et Technologies de l'Informatique et du Numérique",
        "Higher School of Digital and Computer Sciences and Technologies",
        "المدرسة العليا في علوم و تكنولوجيات الإعلام الآلي و الرقمنة",
    ],
    ".hns-re2sd.dz": [
        "Ecole Nationale Supérieure des Energies Renouvelables, de l'Environnement et du Développement Durable",
        "Higher National School of Renewable Energy, Environment & Sustainable Development",
    ],
    ".inttic.dz": [
        "Institut National Télécommunications et en Technologies de l'Information et de la Communications",
        "National Institute of telecommunications and ICT",
    ],
    ".ito.dz": [
        "Institut National des Télécommunications et des TIC",
        "National Institute of Telecommunications and ICT",
    ],
    ".lagh-univ.dz": ["Université Amar Telidji"],
    ".umbb.dz": ["Université M'hamed Bouguerra de Boumerdes"],
    ".ummto.dz": ["Université Mouloud Mammeri de Tizi Ouzou"],
    ".univ-alger.dz": ["Université d'Alger"],
    ".univ-alger3.dz": ["Université d'Alger 3"],
    ".univ-annaba.dz": ["Université Badji Mokhtar"],
    ".univ-batna2.dz": [
        "University of Batna 2, Mostefa Ben Boulaïd",
        "Université Batna 2, Mostefa Ben Boulaïd",
    ],
    ".univ-bba.dz": ["Université Bordj Bou Arreridj"],
    ".univ-bechar.dz": [
        "Université TAHRI Mohammed Bechar",
        "TAHRI Mohammed University of Bechar",
    ],
    ".univ-bejaia.dz": ["Université de Béjaia"],
    ".univ-biskra.dz": [
        "Université Mohamed Khider Biskra",
        "Mohamed Khider University of Biskra",
    ],
    ".univ-blida.dz": ["Université de Blida"],
    ".univ-bouira.dz": ["Akli Mohand Oulhadj Bouira university"],
    ".univ-boumerdes.dz": ["Université M'hamed Bouguerra de Boumerdes"],
    ".univ-chlef.dz": ["Université de Chlef"],
    ".univ-constantine2.dz": ["Université Abdelhamid Mehri Constantine 2"],
    ".univ-constantine3.dz": [
        "université constantine3 salah boubnider",
        "university constantine3 salah boubnider",
    ],
    ".univ-dbkm.dz": ["Djilali Bounaama University of Khemis Miliana"],
    ".edu.univ-djelfa.dz": ["جامعة زيان عاشور الجلفة"],
    ".mail.univ-djelfa.dz": [
        "Ziane Achour University of Djelfa",
        "Ziane Achour University of Djelfa",
    ],
    ".univ-djelfa.dz": ["Ziane Achour University of Djelfa"],
    ".univ-eloued.dz": ["جامعة الوادي", "University Of El Oued"],
    ".univ-eltarf.dz": [
        "Université Chadli Benjedid El tarf",
        "Chadli Benjedid El Tarf University",
    ],
    ".univ-guelma.dz": [
        "université 8 Mai 1945 Guelma",
        "University of 8 May 1945 Guelma",
    ],
    ".univ-jijel.dz": ["Centre Universitaire de Jijel"],
    ".univ-khenchela.dz": [
        "Université de Khenchela",
        "University of Khenchela",
    ],
    ".univ-mascara.dz": [
        "Université de Mascara - Mustapha Stambouli",
        "University of Mascara",
    ],
    ".univ-medea.dz": ["Yahia Fares University"],
    ".univ-mosta.dz": ["Université de Mostaganem"],
    ".univ-msila.dz": ["Université de M'sila"],
    ".univ-oeb.dz": ["Centre Universitaire d'Oum El Bouaghi"],
    ".univ-oran.dz": ["Université d'Oran Es-Senia"],
    ".univ-oran1.dz": ["Université d'Oran 1 Ahmed Ben Bella"],
    ".univ-oran2.dz": [
        "Université d'Oran 2 Mohamed Ben Ahmed",
        "University of Oran 2 Mohamed Ben Ahmed",
    ],
    ".univ-ouargla.dz": ["University of Ouargla"],
    ".univ-saida.dz": ["Université de Saida"],
    ".univ-sba.dz": ["Université de Sidi-Bel-Abbès (Djillali Liabès)"],
    ".univ-setif.dz": ["Université de Sétif"],
    ".univ-skikda.dz": [
        "universite 20 Aout 1955 Skikda",
        "20 August 1955 Skikda University",
    ],
    ".univ-tebessa.dz": ["Centre Universitaire de Tebessa"],
    ".univ-tiaret.dz": ["Centre Universitaire de Tiaret"],
    ".univ-tlemcen.dz": ["Université Abou Bekr Belkaid, Tlemcen"],
    ".univ-usto.dz": ["Université des Sciences et de la Technologie d'Oran"],
    ".usthb.dz": [
        "Université des Sciences et de la Technologie Houari Boumediène"
    ],
    ".aitec.edu.ec": [
        "Instituto Superior Tecnológico Almirante Illingworth",
        "Instituto Superior Tecnológico Almirante Illingworth",
    ],
    ".casagrande.edu.ec": ["Universidad Casa Grande"],
    ".condamine.edu.ec": [
        "Lycée la Condamine Quito",
        "La Condamine High School Quito",
    ],
    ".cordillera.edu.ec": [
        "Instituto Tecnologico Universitario Cordillera",
        "University Technological Institute Cordillera",
    ],
    ".cruzrojainstituto.edu.ec": [
        "Instituto Tecnológico Superior Cruz Roja Ecuatoriana",
        "Technological Institute Ecuadorian Red Cross",
    ],
    ".delfos.edu.ec": [
        "Unidad Educativa Bilingüe Delfos",
        "Delfos Bilingual Educational Unit",
    ],
    ".deming.edu.ec": [
        "Instituto Tecnológico Corporativo Edwards Deming",
        "Edwards Deming Corporate Institute of Technology",
    ],
    ".domingocomin.edu.ec": [
        "Unidad Educativa Salesiana Fiscomisional Domingo Comin"
    ],
    ".est.ecotec.edu.ec": ["ECOTEC"],
    ".eston.ecotec.edu.ec": ["ECOTEC"],
    ".epn.edu.ec": ["Escuela Politécnica Nacional"],
    ".espam.edu.ec": [
        "Escuela Superior Politécnica Agropecuaria de Manabí Manuel Félix López ",
        "Higher Polytechnic Agricultural School of Manabí Manuel Félix López",
    ],
    ".espe.edu.ec": ["Escuela Politécnica del Ejercito"],
    ".espol.edu.ec": ["Escuela superior politecnica del litoral", "ESPOL"],
    ".euroamericano.edu.ec": ["Tecnológico Universitario EuroAmericano"],
    ".iaen.edu.ec": ["Instituto de Altos Estudios Nacionales"],
    ".est.ikiam.edu.ec": ["Universidad Regional Amazónica Ikiam"],
    ".incine.edu.ec": ["Incine Universitario"],
    ".insteclrg.edu.ec": ["Luis Rogerio Gonzalez"],
    ".internacional.edu.ec": ["Universidad Internacional del Ecuador"],
    ".istcarloscisneros.edu.ec": [
        "Instituto Superior Tecnológico Carlos Cisneros"
    ],
    ".ister.edu.ec": ["Tecnológico Universitario Rumiñahui"],
    ".istg.edu.ec": ["Instituto Superior Tecnológico Guayaquil"],
    ".istvidanueva.edu.ec": [
        "Tecnológico Universitario Vida Nueva",
        "New Life Technological University",
    ],
    ".istvr.edu.ec": ["Instituto Superior Tecnológico Vicente Rocafuerte"],
    ".istx.edu.ec": ["Instituto Superior Tecnológico Cotopaxi"],
    ".itb.edu.ec": [
        "Instituto Tecnológico Bolivariano",
        "Domain: @itb.edu.ec",
    ],
    ".itecsur.edu.ec": [
        "ITECSUR - Instituto Superior Universitario Compu Sur"
    ],
    ".iti.edu.ec": ["Tecnológico Internacional Universitario"],
    ".itq.edu.ec": [
        "Instituto Tecnologico Superior Quito",
        "Instituto Quito-ITQ",
    ],
    ".itslibertad.edu.ec": ["Instituto superior tecnológico libertad"],
    ".itsqmet.edu.ec": [
        "Instituto Tecnologico Universitario Quito Metropolitano",
        "Quito Metropolitan University Institute of Technology",
    ],
    ".est.itstena.edu.ec": [
        "INSTITUTO SUPERIOR TECNOLOGICO TENA",
        "TENA HIGHER TECHNOLOGICAL INSTITUTE",
    ],
    ".lametro.edu.ec": ['Instituto Metropolitano de Diseño, "La Metro"'],
    ".paradox.edu.ec": [
        "Paradox - Instituto Tecnológico de Imagen y Sonido",
        "Paradox - Technological Institute of Image and Sound",
    ],
    ".puce.edu.ec": ["Pontificia Universidad Católica del Ecuador"],
    ".pucesd.edu.ec": [
        "Pontificia Universidad Católica del Ecuador sede Santo Domingo"
    ],
    ".pucese.edu.ec": [
        "Pontificia Universidad Católica del Ecuador Sede Esmeraldas"
    ],
    ".pucesi.edu.ec": [
        "Pontificia Universidad Católica del Ecuador Sede Ibarra"
    ],
    ".pucesm.edu.ec": [
        "Pontificia Universidad Catolica Del Ecuador Sede Manabi"
    ],
    ".sanjuanpablo.edu.ec": ["San Juan Pablo Segundo"],
    ".sudamericano.edu.ec": [
        "Instituto Superior Tecnológico Particular Sudamericano"
    ],
    ".tecazuay.edu.ec": [
        "Instituto Superior Tecnológico del Azuay",
        "Higher Technological Institute of Azuay",
    ],
    ".tecnologicoargos.edu.ec": [
        "Tecnológico Universitario Argos",
        "Argos University Technological",
    ],
    ".tecnologicoismac.edu.ec": ["Instituto Tecnológico UNiversitario ISMAC"],
    ".tecnologicoliceocristiano.edu.ec": [
        "Tecnológico Liceo Cristiano de Guayaquil",
        "Tecnológico Liceo Cristiano de Guayaquil",
    ],
    ".tecnologicoloja.edu.ec": ["Instituto Superior Tecnologico Loja"],
    ".tecsu.edu.ec": ["Tecnológico Sudamericano"],
    ".tes.edu.ec": ["Tecnológico Universitario Espíritu Santo"],
    ".tsachila.edu.ec": ["INSTITUTO SUPERIOR TECNOLÓGICO TSA´CHILA"],
    ".uagraria.edu.ec": ["Universidad Agraria del Ecuador"],
    ".uasb.edu.ec": ["Universidad Andina Simón Bolívar"],
    ".uazuay.edu.ec": ["Universidad del Azuay"],
    ".ube.edu.ec": ["Universidad Bolivariana del Ecuador"],
    ".ucacue.edu.ec": ["UNIVERSIDAD CATOLICA DE CUENCA"],
    ".ucsg.edu.ec": ["Universidad Católica de Santiago de Guayaquil"],
    ".ucuenca.edu.ec": ["Universidad de Cuenca", "University of Cuenca"],
    ".udla.edu.ec": ["Universidad de Las Américas"],
    ".uea.edu.ec": ["Universidad Estatal Amazónica"],
    ".ueb.edu.ec": ["\ufeffUNIVERSIDAD ESTATAL DE BOLÍVAR"],
    ".uees.edu.ec": ["Universidad de Especialidades del Espíritu Santo"],
    ".uefsorteresavalse.edu.ec": [
        "Unidad Educativa Fiscomisional Sor Teresa Valse"
    ],
    ".uegfm.edu.ec": ["Unidad Educativa Gladys Flores Macias"],
    ".estudiantes.uhemisferios.edu.ec": [
        "Universidad de los Hemisferios",
        "University of the Hemispheres",
    ],
    ".uide.edu.ec": ["Universidad Internacional del Ecuador"],
    ".uisek.edu.ec": [
        "Universidad Internacional SEK Ecuador",
        "SEK Ecuador International University",
    ],
    ".uisrael.edu.ec": ["Universidad Israel"],
    ".uleam.edu.ec": ["Universidad Laica Eloy Alfaro de Manabi"],
    ".ulvr.edu.ec": [
        "Universidad Laica Vicente Rocafuerte",
        "Laica Vicente Rocafuerte University",
    ],
    ".unae.edu.ec": [
        "Universidad Nacional de Educación",
        "National Univeristy of Education",
    ],
    ".unemi.edu.ec": [
        "Universidad Estatal De Milagro UNEMI",
        "Milagro State University ",
    ],
    ".unesum.edu.ec": ["Universidad Estatal del Sur de Manabi"],
    ".uniandes.edu.ec": ["Universidad Regional Autònoma de Los Andes"],
    ".unibe.edu.ec": [" Universidad Iberoamericana del Ecuador"],
    ".unitecdiscovery.edu.ec": ["UNITEC DISCOVERY", "UNITEC DISCOVERY"],
    ".unl.edu.ec": ["Universidad Nacional de Loja"],
    ".uotavalo.edu.ec": ["Universidad de Otavalo", "Otavalo University"],
    ".upacifico.edu.ec": ["Universidad del Pacifico"],
    ".upec.edu.ec": [
        "Universidad Politécnica Estatal Del Carchi",
        "Carchi State Polytechnic University",
        "Web: https://upec.edu.ec/",
        "Career of IT: https://upec.edu.ec/subsitios/computacion/",
    ],
    ".ups.edu.ec": ["Universidad Politécnica Salesiana"],
    ".usfq.edu.ec": ["Universidad San Francisco de Quito"],
    ".usm.edu.ec": ["Universidad Santa María Campus Guayaquil"],
    ".uta.edu.ec": ["Universidad Técnica de Ambato"],
    ".utb.edu.ec": ["Universidad Técnica de Babahoyo"],
    ".utc.edu.ec": ["Universidad Técnica de Cotopaxi"],
    ".ute.edu.ec": ["Universidad Tecnológica Equinoccial"],
    ".uteg.edu.ec": [
        "Universidad Tecnológica Empresarial de Guayaquil",
        "Guayaquil University of Technology and Business (UTEG)",
    ],
    ".utelvt.edu.ec": ["Universidad Técnica de Esmeraldas Luis Vargas Torres"],
    ".uteq.edu.ec": ["Universidad Técnica Estatal de Quevedo"],
    ".utm.edu.ec": ["Universidad Técnica de Manabí"],
    ".utn.edu.ec": ["Universidad Técnica del Norte"],
    ".yachaytech.edu.ec": [
        "Universidad Yachay Tech",
        "Yachay Tech University",
    ],
    ".yavirac.edu.ec": ["Instituto Tecnológico Superior Yavirac"],
    ".udlanet.ec": ["Universidad de Las Americas - UDLA Quito"],
    ".4cd.edu": ["Contra Costa Community College District"],
    ".Asher.edu": ["Asher College"],
    ".Student.DallasCollege.edu": ["Dallas College"],
    ".hawkmail.HACC.edu": ["Harrisburg Area Community College", "HACC"],
    ".Nicholls.edu": [
        "Nicholls State University",
        "Nicholls State University",
    ],
    ".Roberts.edu": ["Roberts Wesleyan University"],
    ".WalshCollege.edu": [
        "Walsh College,",
        "3838 Livernois Rd., Troy, MI 48083",
        "1-800-WALSH-01",
    ],
    ".Watumull.edu": [
        "Watumull Institute of Electronics Engineering and Computer Technology",
        "affiliated to Mumbai University and is approved by AICTE",
    ],
    ".aacc.edu": ["Anne Arundel Community College"],
    ".stu.aami.edu": ["American Academy McAllister Institute"],
    ".aamu.edu": ["Alabama Agricultural and Mechanical University"],
    ".aast.edu": ["Arab Academy for Science &amp; Technology"],
    ".aauj.edu": ["Arab American University - Jenin"],
    ".ab.edu": ["Alderson Broaddus College"],
    ".students.abtech.edu": ["AB-Tech"],
    ".academy.edu": [
        "International Academy of  Merchandising and Design Tampa"
    ],
    ".academyart.edu": ["Academy of Art College"],
    ".acg.edu": [
        "The American College of Greece",
        "American College of Greece",
        "DEREE",
        "ALBA",
        "DEREE - The American College of Greece",
        "ALBA - The American College of Greece",
        "Alba Graduate Business School",
        "ACG",
        "Αμερικανικό Κολλέγιο Ελλάδος",
        "Αμερικανικό Κολλέγιο Ελλάδας",
    ],
    ".acp.edu": ["Albany College of Pharmacy"],
    ".act.edu": ["American College of Thessaloniki"],
    ".acu.edu": ["Abilene Christian University"],
    ".adams.edu": ["Adams State University"],
    ".adelphi.edu": ["Adelphi University"],
    ".adler.edu": ["Adler School of Professional Psychology"],
    ".adrian.edu": ["Adrian College"],
    ".aeu.edu": [
        "America Evangelical University",
        "aeu.edu",
        "https://aeu.edu/?aca&dp_id=27&lang=en",
    ],
    ".afacademy.af.edu": ["United States Air Force Academy"],
    ".af.edu": ["Air Force Institute of Technology"],
    ".afit.edu": ["Air Force Institute of Technology"],
    ".africau.edu": ["Africa University"],
    ".agnesscott.edu": ["Agnes Scott"],
    ".ahgaff.edu": ["Alahgaff University"],
    ".aic.edu": ["American International College"],
    ".aicag.edu": ["American Indian College of the Assemblies of God"],
    ".aie.edu": ["Academy of Interactive Entertainment"],
    ".aii.edu": [
        "The Art Institutes International San Francisco",
        "The Art Institutes International Portland",
    ],
    ".aiias.edu": ["Adventist International Institute of Advanced Studies"],
    ".aiims.edu": ["All India Institutes of Medical Sciences"],
    ".aiu.edu": ["Atlantic International University"],
    ".aiub.edu": ["American International University-Bangladesh"],
    ".aiuniv.edu": [
        "American InterContinental University - London",
        "American InterContinental University - Georgia",
        "American InterContinental University - Ft. Lauderdale",
        "American InterContinental University - Atlanta",
    ],
    ".aju.edu": ["Andrew Jackson University"],
    ".akbible.edu": ["Alaska Bible College"],
    ".aku.edu": ["Aga Khan University"],
    ".student.alamo.edu": ["Alamo Colleges District", ".group"],
    ".alamo.edu": ["Alamo Colleges District", ".group"],
    ".alaska.edu": [
        "University of Alaska - Anchorage",
        "University of Alaska - Southeast",
        "University of Alaska (System)",
    ],
    ".alaskapacific.edu": ["Alaska Pacific University"],
    ".alasu.edu": ["Alabama State University"],
    ".albany.edu": ["State University of New York at Albany"],
    ".albanylaw.edu": ["Albany Law School"],
    ".my.albemarle.edu": ["College of The Albemarle", "COA"],
    ".albertus.edu": ["Albertus Magnus College"],
    ".albion.edu": ["Albion College"],
    ".albizu.edu": ["Carlos Albizu University"],
    ".albright.edu": ["Albright College"],
    ".alc.edu": ["Alice Lloyd College"],
    ".alcorn.edu": ["Alcorn State University"],
    ".alfaisal.edu": ["Alfaisal University"],
    ".alfred.edu": ["Alfred University"],
    ".alfredadler.edu": ["Alfred Adler Graduate School"],
    ".alfredstate.edu": [],
    ".allegany.edu": ["Allegany College of Maryland"],
    ".allegheny.edu": ["Allegheny College"],
    ".alma.edu": ["Alma College"],
    ".alquds.edu": ["Al-Quds University - The Arab University in Jerusalem"],
    ".alvernia.edu": ["Alvernia College"],
    ".alverno.edu": ["Alverno College"],
    ".ambassador.edu": ["Ambassador University"],
    ".amc.edu": ["Albany Medical Center"],
    ".american.edu": ["American University"],
    ".amherst.edu": ["Amherst College"],
    ".amity.edu": ["Amity university"],
    ".amnh.edu": [
        "American Museum of Natural History - Richard Gilder Graduate School"
    ],
    ".cb.amrita.edu": ["Amrita Vishwa Vidyapeetham, Coimbatore"],
    ".amrita.edu": ["Amrita Vishwa Vidyapeetham"],
    ".students.an.edu": ["American National University"],
    ".anderson.edu": ["Anderson University"],
    ".andersonuniversity.edu": ["Anderson University"],
    ".andover.edu": ["Phillips Academy Andover"],
    ".andrews.edu": ["Andrews University"],
    ".angelina.edu": ["Angelina College"],
    ".angelo.edu": ["Angelo State University"],
    ".annauniv.edu": ["Anna University, Chennai, India"],
    ".anokaramsey.edu": ["Anoka Ramsey Community College "],
    ".anselm.edu": ["St. Anselm College"],
    ".antioch.edu": ["Antioch University"],
    ".antiochla.edu": ["Antioch University Los Angeles"],
    ".antiochne.edu": ["Antioch New England Graduate School"],
    ".antiochsb.edu": ["Antioch University Santa Barbara"],
    ".antiochsea.edu": ["Antioch University Seattle"],
    ".learn.apeejay.edu": ["Apeejay School", ".group"],
    ".apeejay.edu": ["Apeejay School", ".group"],
    ".apiu.edu": ["Asia-pacific International University "],
    ".appstate.edu": ["Appalachian State University"],
    ".apsu.edu": ["Austin Peay State University"],
    ".apu.edu": ["Azusa Pacific University"],
    ".apus.edu": ["American Military University"],
    ".aquinas.edu": ["Aquinas College"],
    ".arapahoe.edu": ["Arapahoe Community College"],
    ".arbor.edu": ["Spring Arbor College"],
    ".arcadia.edu": ["Arcadia University"],
    ".argosy.edu": ["Argosy University"],
    ".arizona.edu": ["University of Arizona"],
    ".armstrong.edu": ["Armstrong Atlantic State University"],
    ".art.edu": ["Academy of Art University (San Francisco, CA)"],
    ".artacademy.edu": ["Art Academy of Cincinnati"],
    ".artcenter.edu": ["Art Center College of Design"],
    ".artic.edu": ["The School of the Art Institute of Chicago"],
    ".artinstitutes.edu": [
        "The Illinois Institute of Art-Chicago",
        "Art Institute of Charlotte",
    ],
    ".asbury.edu": ["Asbury College"],
    ".ashland.edu": ["Ashland University"],
    ".assumption.edu": ["Assumption College"],
    ".astate.edu": ["Arkansas State University"],
    ".asu.edu": [
        "Arizona State University",
        "Arizona State University, Polytechnic Campus",
        "Arizona State University, West Campus",
    ],
    ".asub.edu": ["Arkansas State University, Beebe"],
    ".asumh.edu": ["Arkansas State University, Mountain Home"],
    ".asun.edu": ["Arkansas State University, Newport"],
    ".asurams.edu": ["Albany State University"],
    ".ateneo.edu": ["Ateneo de Manila University"],
    ".athabasca.edu": ["Athabasca University"],
    ".athens.edu": ["Athens State College"],
    ".athenstech.edu": ["Athens Technical College"],
    ".atlantatech.edu": ["Atlanta Technical College"],
    ".buccaneer.atlantic.edu": ["Atlantic Cape Community College"],
    ".atlantic.edu": [
        "Atlantic Cape Community College",
        "Atlantic Cape Community College",
    ],
    ".atlanticuniv.edu": ["Atlantic University"],
    ".atlantisuniversity.edu": ["Atlantis University"],
    ".atu.edu": ["Arkansas Tech University"],
    ".au.edu": ["Assumption University, Thailand"],
    ".mail.aub.edu": ["American University of Beirut"],
    ".aubg.edu": [
        "AUBG (American University In Bulgaria)",
        "American University In Bulgaria",
    ],
    ".auburn.edu": ["Auburn University"],
    ".aucegypt.edu": ["American University in Cairo"],
    ".aucmed.edu": [
        "American University of the Caribbean, Sint Maarten",
        "American University of the Caribbean, School of Medicine",
    ],
    ".aud.edu": ["American University in Dubai"],
    ".augie.edu": ["Augustana College"],
    ".augsburg.edu": ["Augsburg College"],
    ".augusta.edu": ["Augusta University - https://www.augusta.edu/"],
    ".augustana.edu": ["Augustana College"],
    ".aul.edu": ["The American University in London"],
    ".aum.edu": ["Auburn University at Montgomery"],
    ".aup.edu": ["The American University of Paris"],
    ".aurora.edu": ["Aurora University"],
    ".aus.edu": ["American University of Sharjah"],
    ".aust.edu": ["Ahsanullah University of Science &amp; Technology"],
    ".g.austincc.edu": ["Austin Community College", "ACC"],
    ".austincc.edu": ["Austin Community College"],
    ".aut.edu": ["American University College of Technology"],
    ".students.avc.edu": ["Antelope Valley College"],
    ".avc.edu": ["Antelope Valley College"],
    ".avemaria.edu": ["Ave Maria University"],
    ".averett.edu": ["Averett College"],
    ".avila.edu": ["Avila College"],
    ".b-sc.edu": ["Barber-Scotia College"],
    ".babson.edu": ["Babson College"],
    ".bac.edu": ["Belmont Abbey College"],
    ".baker.edu": [
        "Baker College of Auburn Hills",
        "Baker College of Cadillac",
        "Baker College of Flint",
        "Baker College of Mount Clemens",
        "Baker College of Muskegon",
        "Baker College of Owosso",
        "Baker College of Port Huron",
    ],
    ".bakersfieldcollege.edu": ["Bakersfield College"],
    ".bakeru.edu": ["Baker University"],
    ".barclaycollege.edu": ["Barclay College"],
    ".bard.edu": [
        "Bard College",
        "Bard Graduate Center for Studies in the Decorative Arts",
    ],
    ".barnard.edu": ["Barnard College"],
    ".barry.edu": ["Barry University"],
    ".barton.edu": ["Barton College"],
    ".bastyr.edu": ["Bastyr University"],
    ".bates.edu": ["Bates College"],
    ".bath.edu": [
        "University of Bath",
        "official url: http://www.bath.ac.uk/",
        "long-term IT related course: http://www.bath.ac.uk/courses/undergraduate-2018/computer-science/",
        "recognition of of domain: http://www.bath.ac.uk/alumni/services/bathmail/index.html",
    ],
    ".bau.edu": ["Bay Atlantic University"],
    ".baylor.edu": ["Baylor University"],
    ".bc.edu": ["Boston College"],
    ".bc3.edu": ["Butler County Community College "],
    ".bcm.edu": ["Baylor College of Medicine"],
    ".beaufortccc.edu": ["Beaufort County Community College"],
    ".belhaven.edu": ["Belhaven College"],
    ".bellarmine.edu": ["Bellarmine College"],
    ".bellevue.edu": ["Bellevue University"],
    ".bellevuecollege.edu": ["Bellevue College"],
    ".belmont.edu": ["Belmont University"],
    ".belmontcollege.edu": ["Belmont College"],
    ".beloit.edu": ["Beloit College"],
    ".bemidjistate.edu": ["Bemidji State University"],
    ".ben.edu": ["Benedictine University", "Illinois Benedictine University"],
    ".benedict.edu": ["Benedict College"],
    ".benedictine.edu": ["Benedictine College"],
    ".bennett.edu": ["Bennett College"],
    ".bennington.edu": ["Bennington College"],
    ".bentley.edu": ["Bentley College"],
    ".berea.edu": ["Berea College"],
    ".berean.edu": ["Berean University of the Assemblies of God"],
    ".bergen.edu": ["Bergen Community College", "@me.bergen.edu"],
    ".berkeley.edu": ["University of California, Berkeley"],
    ".mymail.berkeleycollege.edu": ["Berkeley College"],
    ".berklee.edu": ["Berklee College of Music"],
    ".berkshirecc.edu": ["Berkshire Community College"],
    ".berry.edu": ["Berry College"],
    ".bethany.edu": ["Bethany College California"],
    ".bethanylb.edu": ["Bethany College Kansas"],
    ".bethel.edu": ["Bethel College St. Paul"],
    ".bethelks.edu": ["Bethel College Newton"],
    ".betheluniversity.edu": ["Bethel University"],
    ".bethlehem.edu": ["Bethlehem University"],
    ".bgsu.edu": [
        "Bowling Green State University",
        "Bowling Green State University, Firelands",
    ],
    ".bhc.edu": ["Black Hawk College"],
    ".bhcc.edu": ["Bunker Hill Community College"],
    ".bhsu.edu": ["Black Hills State University"],
    ".bhu.edu": ["Baltimore Hebrew University"],
    ".bible.edu": ["Washington Bible College"],
    ".bietdvg.edu": [
        "Bapuji Institute of Engineering and Technology",
        "Bapuji Institute of Engineering and Technology",
    ],
    ".binghamton.edu": [
        "Binghamton University",
        "Binghamton University State University of New York",
    ],
    ".binus.edu": ["Bina Nusantara", "Bina Nusantara"],
    ".biola.edu": ["Biola University"],
    ".bircham.edu": ["Bircham International University"],
    ".birzeit.edu": ["Birzeit University"],
    ".bju.edu": ["Bob Jones University"],
    ".blackburn.edu": ["Blackburn College"],
    ".bloomfield.edu": ["Bloomfield College"],
    ".bloomu.edu": ["Bloomsburg University of Pennsylvania"],
    ".my.bluecc.edu": ["Blue Mountain Community College"],
    ".bluefield.edu": ["Bluefield College"],
    ".bluefieldstate.edu": ["Bluefield State College"],
    ".bluffton.edu": ["Bluffton College"],
    ".bmc.edu": ["Blue Mountain College"],
    ".bmcc.edu": ["Bay Mills Community College"],
    ".boisebible.edu": ["Boise Bible College"],
    ".boisestate.edu": ["Boise State University"],
    ".bonaventure.edu": ["St. Bonaventure University"],
    ".boricuacollege.edu": ["Boricua College"],
    ".bowdoin.edu": ["Bowdoin College"],
    ".bowiestate.edu": ["Bowie State University"],
    ".bpc.edu": ["Brewton-Parker College"],
    ".bpcc.edu": ["Bossier Parish Community College"],
    ".bpkihs.edu": ["B.P.Koirala Institute of Health Sciences"],
    ".bradley.edu": ["Bradley University"],
    ".brandeis.edu": ["Brandeis University"],
    ".brandman.edu": ["Brandman University"],
    ".brcc.edu": ["Blue Ridge Community College"],
    ".brcn.edu": ["Blessing-Rieman College of Nursing"],
    ".brenau.edu": ["Brenau University"],
    ".brescia.edu": ["Brescia University"],
    ".brevard.edu": ["Brevard College"],
    ".bridgeport.edu": ["University of Bridgeport"],
    ".bridgevalley.edu": ["BridgeValley Community and Technical College"],
    ".bridgew.edu": ["Bridgewater State College"],
    ".bridgewater.edu": ["Bridgewater College"],
    ".bristolcc.edu": ["Bristol Community College"],
    ".brockport.edu": ["State University of New York College at Brockport"],
    ".brookdalecc.edu": ["Brookdale Community College"],
    ".brooklaw.edu": ["Brooklyn Law School"],
    ".brooks.edu": ["Brooks Institute of Photography"],
    ".broward.edu": ["Broward College"],
    ".brown.edu": ["Brown University"],
    ".brunswickcc.edu": ["Brunswick Community College"],
    ".bryan.edu": ["Bryan College"],
    ".bryant.edu": ["Bryant University"],
    ".bryantstratton.edu": ["Bryant and Stratton College"],
    ".brynmawr.edu": ["Bryn Mawr College"],
    ".bsc.edu": ["Birmingham-Southern College"],
    ".bsu.edu": ["Ball State University"],
    ".bths.edu": [
        "Brooklyn Technical Highschool",
        "https://www.bths.edu/ourpages/auto/2014/2/22/57015226/Software%20Engineeering%20Major%202019-2020.pdf",
    ],
    ".bucknell.edu": ["Bucknell University"],
    ".bucks.edu": ["Bucks County Community College"],
    ".buffalo.edu": [
        "State University of New York at Buffalo",
        "State University of New York School of Engineering and Applied Sciences",
    ],
    ".buffalostate.edu": ["Buffalo State University"],
    ".bush.edu": ["The Bush School "],
    ".butler.edu": ["Butler University"],
    ".butlercc.edu": ["Butler Community College"],
    ".butte.edu": ["Butte College"],
    ".bvu.edu": ["Buena Vista University"],
    ".bw.edu": ["Baldwin Wallace University"],
    ".studentbody.byu.edu": ["Brigham Young University"],
    ".byu.edu": ["Brigham Young University"],
    ".byuh.edu": ["Brigham Young University Hawaii"],
    ".byui.edu": ["Brigham Young University"],
    ".byupathway.edu": ["BYU-Pathway Worldwide"],
    ".cabrillo.edu": ["Cabrillo College"],
    ".cabrini.edu": ["Cabrini College"],
    ".cahsu.edu": [
        "Central America Health Sciences University (Belize Medical College)"
    ],
    ".cairn.edu": ["Cairn University"],
    ".calarts.edu": ["California Institute of the Arts"],
    ".calbaptist.edu": ["California Baptist College"],
    ".calcoast.edu": ["California Coast University"],
    ".caldwell.edu": ["Caldwell College"],
    ".callutheran.edu": ["California Lutheran University"],
    ".calpoly.edu": [
        "California Polytechnic State University - San Luis Obispo"
    ],
    ".calstatela.edu": ["California State University, Los Angeles"],
    ".caltech.edu": ["California Institute of Technology"],
    ".stu.calums.edu": ["California university of management science"],
    ".calvary.edu": ["Calvary Bible College"],
    ".calvin.edu": ["Calvin College"],
    ".cambridge.edu": ["Cambridge College"],
    ".go.cambridgecollege.edu": ["Cambridge College", "Cambridge College"],
    ".students.camdencc.edu": ["Camden County College"],
    ".cameron.edu": ["Cameron University"],
    ".campbell.edu": ["Campbell University"],
    ".campbellsville.edu": ["Campbellsville University"],
    ".canisius.edu": ["Canisius College"],
    ".canton.edu": ["State University of New York at Canton"],
    ".canyons.edu": ["College of the Canyons"],
    ".capecod.edu": ["Cape Cod Community College"],
    ".capella.edu": ["Capella University"],
    ".capellauniversity.edu": ["Capella University"],
    ".capital.edu": ["Capital University", "Capital University Law School"],
    ".capitol-college.edu": ["Capitol College"],
    ".captechu.edu": [
        "Capitol Technology University",
        "11301 Springfield Rd",
        "Laurel, MD 20708",
    ],
    ".caribbean.edu": ["Caribbean University"],
    ".carleton.edu": ["Carleton College"],
    ".carlow.edu": ["Carlow College"],
    ".carolinau.edu": ["Carolina University"],
    ".carroll.edu": ["Carroll College Helena"],
    ".carrollcc.edu": ["Carroll Community College"],
    ".carrollu.edu": ["Carroll University"],
    ".carthage.edu": ["Carthage College"],
    ".cascadia.edu": ["Cascadia College"],
    ".case.edu": [
        "Case Western Reserve University",
        "Case Western Reserve University",
    ],
    ".mycc.caspercollege.edu": ["Casper College"],
    ".catawba.edu": ["Catawba College"],
    ".cau.edu": ["Clark Atlanta University"],
    ".cayuga-cc.edu": ["Cayuga Community College"],
    ".cbc.edu": ["Central Baptist College"],
    ".cbcag.edu": ["Central Bible College"],
    ".cbu.edu": ["Christian Brothers University"],
    ".cc-sd.edu": ["California College San Diego"],
    ".cc.edu": ["Carroll College Waukesha"],
    ".ccac.edu": [
        "College name: Community College of Allegheny County",
        "College home page: https://ccac.edu",
        "Software development program: https://ccac.edu/Software_Development_AS.aspx",
        "Email domain: https://www.ccac.edu/ITS__Academic_Email_for_Students_and_Faculty.aspx",
    ],
    ".ccad.edu": ["Columbus College of Art and Design"],
    ".ccbcmd.edu": ["Community College of Baltimore County"],
    ".ccc.edu": ["City Colleges of Chicago"],
    ".cccb.edu": ["Central Christian College of the Bible"],
    ".cccd.edu": ["Coastline College"],
    ".student.cccs.edu": [
        "Colorado Community College System",
        "Front Range Community College",
        "  .group",
    ],
    ".cccs.edu": [
        "Colorado Community College System",
        "Arapahoe Community College",
        ".group",
    ],
    ".student.ccga.edu": ["College of Coastal Georgia"],
    ".ccis.edu": ["Columbia College of Missouri"],
    ".student.ccm.edu": ["County College of Morris"],
    ".ccm.edu": ["County College Of Morris"],
    ".ccp.edu": ["Community College of Philadelphia", "www.ccp.edu"],
    ".ccri.edu": ["Community College of Rhode Island"],
    ".ccsdetroit.edu": ["College for Creative Studies", "ccsdetroit"],
    ".ccsf.edu": ["City College of San Francisco"],
    ".ccsj.edu": ["Calumet College of St. Joseph"],
    ".students.ccsnh.edu": [
        "Community College System of New Hampshire",
        "Great Bay Community College",
        ".group",
    ],
    ".ccsu.edu": ["Central Connecticut State University"],
    ".cctech.edu": ["Central Carolina Technical College"],
    ".ccu.edu": ["Colorado Christian University"],
    ".cdrewu.edu": ["Charles R. Drew University of Medicine and Science"],
    ".cecil.edu": ["Cecil College", "Cecil College"],
    ".ceconline.edu": ["College of Engineering Chengannur"],
    ".cedarcrest.edu": ["Cedar Crest College"],
    ".cedarville.edu": ["Cedarville College"],
    ".ceibs.edu": [
        "中欧国际工商学院",
        "China Europe International Business School",
    ],
    ".centenary.edu": ["Centenary College of Louisiana"],
    ".central.edu": ["Central College"],
    ".centralaz.edu": ["Central Arizona College"],
    ".student.centralgatech.edu": ["Central Georgia Technical College"],
    ".centralmethodist.edu": ["central methodist university"],
    ".centralpenn.edu": ["Central Penn College"],
    ".centralstate.edu": ["Central State University"],
    ".centre.edu": ["Centre College"],
    ".century.edu": ["Century community college"],
    ".cerritos.edu": ["Cerritos College"],
    ".cerrocoso.edu": ["Cerro Coso Community District"],
    ".ceu.edu": ["Central European University", "Central European University"],
    ".patriots.cf.edu": [
        "College of Central Florida",
        "College of Central Florida",
    ],
    ".mail.cfcc.edu": ["Cape Fear Community College"],
    ".cfcc.edu": ["Cape Fear Community College"],
    ".cga.edu": ["United States Coast Guard Academy"],
    ".cgc.edu": ["Chandler Gilbert Community College"],
    ".cgu.edu": ["Claremont Graduate University"],
    ".panther.chaffey.edu": ["Chaffey college"],
    ".chaffey.edu": ["Chaffey College"],
    ".chaminade.edu": ["Chaminade University of Honolulu"],
    ".champlain.edu": ["Champlain College"],
    ".chapman.edu": ["Chapman University"],
    ".charlotte.edu": ["University of North Carolina at Charlotte"],
    ".charteroak.edu": ["Charter Oak State College"],
    ".chatham.edu": ["Chatham College"],
    ".chattahoocheetech.edu": ["Chattahoochee Technical College"],
    ".chattanoogastate.edu": ["Chattanooga State Community College"],
    ".chc.edu": ["Chestnut Hill College"],
    ".cheyney.edu": ["Cheyney University of Pennsylvania"],
    ".chicagobooth.edu": ["Univsersity of Chicago Booth School of Business"],
    ".chiropractic.edu": ["National College of Chiropractic"],
    ".chonnam.edu": ["Chonnam National University"],
    ".chop.edu": ["The Children's Hospital of Philadelphia"],
    ".chowan.edu": ["Chowan College"],
    ".christendom.edu": ["Christendom College"],
    ".cia.edu": ["Cleveland Institute of Art"],
    ".alumnos.cide.edu": [
        "Centro de Investigacion y Docencia Económicas, A.C."
    ],
    ".ciis.edu": ["California Institute of Integral Studies"],
    ".cim.edu": ["Cleveland Institute of Music"],
    ".cincinnatistate.edu": [
        "Name: Cincinnati State Technical and Community College",
        "Address: 3520 Central Parkway, Cincinnati, OH 45223",
        "Website: www.cincinnatistate.edu",
    ],
    ".student.cinec.edu": [
        "Colombo International Nautical and Engineering College"
    ],
    ".student.citadel.edu": [
        "The Citadel, Military College of South Carolina"
    ],
    ".citadel.edu": [
        "The Citadel, The Military College of South Carolina",
        "The Citadel",
        "Citadel",
    ],
    ".cityu.edu": ["City University"],
    ".cityuniversity.edu": ["City University of Seattle"],
    ".ciu.edu": ["Columbia International University"],
    ".claflin.edu": ["Claflin University"],
    ".clarion.edu": ["Clarion University"],
    ".clarke.edu": ["Clarke College"],
    ".clarkson.edu": ["Clarkson University"],
    ".clarksoncollege.edu": ["Clarkson College"],
    ".clarkstate.edu": ["Сlark State College"],
    ".clarku.edu": ["Clark University"],
    ".clayton.edu": ["Clayton College &amp; State University"],
    ".clcillinois.edu": ["College of Lake County"],
    ".clearwater.edu": ["Clearwater Christian College"],
    ".cleary.edu": ["Cleary College"],
    ".clemson.edu": ["Clemson University"],
    ".clevelandcc.edu": ["Cleveland Community College"],
    ".cloud.edu": ["Cloud County Community College"],
    ".clovis.edu": ["Clovis Community College"],
    ".clu.edu": [
        "Universidad de Puerto Rico",
        "Universidad de Puerto Rico, Humacao",
    ],
    ".cmc.edu": ["Central Methodist College"],
    ".cmconnect.cmcc.edu": ["Central Maine Community College"],
    ".cmich.edu": ["Central Michigan University"],
    ".cmsv.edu": ["College of Mount St. Vincent"],
    ".cmu.edu": ["Carnegie Mellon University"],
    ".cn.edu": ["Carson-Newman College"],
    ".cnm.edu": ["Central New Mexico Community College"],
    ".cnr.edu": ["College of New Rochelle"],
    ".cnu.edu": ["Christopher Newport University"],
    ".coa.edu": ["College of the Atlantic"],
    ".coastal.edu": ["Coastal Carolina University"],
    ".coastalpines.edu": ["Coastal Pines Technical College"],
    ".coastline.edu": ["Coastline College"],
    ".cobleskill.edu": [
        "State University of New York College of Agriculture and Technology at Cobleskill"
    ],
    ".cocc.edu": ["Central Oregon Community College"],
    ".students.coconino.edu": ["Coconino Community College"],
    ".cod.edu": ["College of DuPage"],
    ".coe.edu": ["Coe College"],
    ".cofc.edu": [
        "College of Charleston",
        "University of Charleston South Carolina",
    ],
    ".coffeyville.edu": ["Coffeyville Community College"],
    ".cofo.edu": ["College of the Ozarks"],
    ".cogswell.edu": ["Cogswell Polytechnical College"],
    ".coker.edu": ["Coker College"],
    ".colby-sawyer.edu": ["Colby-Sawyer College"],
    ".colby.edu": ["Colby College"],
    ".coleman.edu": ["Coleman College"],
    ".colgate.edu": ["Colgate University"],
    ".collegeamerica.edu": [
        "CollegeAmerica, Phoenix",
        "CollegeAmerica, Denver",
    ],
    ".collegeofidaho.edu": ["College of Idaho"],
    ".collegeofthedesert.edu": ["College of the Desert"],
    ".colorado.edu": ["Colorado Boulder"],
    ".coloradocollege.edu": ["Colorado College"],
    ".mavs.coloradomesa.edu": ["Colorado Mesa University"],
    ".coloradomesa.edu": ["Colorado Mesa University"],
    ".colostate.edu": ["Colorado State University"],
    ".colum.edu": ["Columbia College Chicago"],
    ".columbia.edu": [
        "Barnard College - Columbia University",
        "Columbia University",
        "Teachers College, Columbia University",
    ],
    ".students.columbiabasin.edu": ["Columbia Basin College"],
    ".columbiacollege.edu": ["Columbia College Hollywood"],
    ".columbiasouthern.edu": ["Columbia Southern University"],
    ".columbiastate.edu": ["Columbia State Commuinty College"],
    ".columbus.edu": ["Columbus University"],
    ".students.columbusstate.edu": ["Columbus State University"],
    ".columbusstate.edu": ["Columbus State University"],
    ".student.columbustech.edu": [
        "Columbus Technical College",
        "Columbus Technical College",
    ],
    ".comillas.edu": ["Universidad Pontificia Comillas"],
    ".commonwealthu.edu": ["Commonwealth University of Pennsylvania"],
    ".concord.edu": ["Concord College"],
    ".concordia-ny.edu": ["Concordia College, Bronxville"],
    ".concordia.edu": ["Concordia University, Austin"],
    ".conncoll.edu": ["Connecticut College"],
    ".cookman.edu": ["Bethune-Cookman College"],
    ".cooper.edu": ["The Cooper Union for the Advancement of Science and Art"],
    ".coppin.edu": ["Coppin State College"],
    ".cord.edu": ["Concordia College, Moorhead"],
    ".cornell.edu": [
        "Cornell University",
        "Weill Medical College of Cornell University",
    ],
    ".cornellcollege.edu": ["cornell college"],
    ".corning-cc.edu": ["Corning Community College"],
    ".cornish.edu": ["Cornish College of the Arts"],
    ".cortland.edu": ["State University of New York College at Cortland"],
    ".cos.edu": ["College of the Sequoias"],
    ".cosc.edu": ["Charter Oak State College"],
    ".covenant.edu": ["Covenant College"],
    ".cpp.edu": ["California State Polytechnic University - Pomona"],
    ".cps.edu": ["Lane Tech College Prep", "Lane Tech College Prep"],
    ".cranbrook.edu": ["Cranbrook Schools"],
    ".cranbrookart.edu": ["Cranbrook Academy of Art"],
    ".creighton.edu": ["Creighton University"],
    ".crown.edu": ["Crown College"],
    ".csbsju.edu": ["College of St. Benedict and St. John's University"],
    ".csc.edu": ["Chadron State College"],
    ".cscc.edu": ["Columbus State Community College"],
    ".csi.edu": ["College of Southern Idaho"],
    ".csinow.edu": ["Computer Systems Institute"],
    ".csj.edu": ["College of St. Joseph"],
    ".csld.edu": ["Conway School of Landscape Design"],
    ".csm.edu": ["College of St. Mary"],
    ".csmc.edu": ["Cedars-Sinai Medical Center"],
    ".mymail.csmd.edu": ["College of Southern Maryland"],
    ".csn.edu": [
        "College of Southern Nevada",
        "The College of Southern Nevada",
        "CSN",
    ],
    ".csp.edu": ["Concordia College, St. Paul"],
    ".cspp.edu": [
        "California School of Professional Psychology - Berkley/Alameda",
        "California School of Professional Psychology - Fresno",
        "California School of Professional Psychology - Los Angels",
        "California School of Professional Psychology - San Diego",
    ],
    ".css.edu": [
        "College of St. Scholastica",
        "The College of St. Scholastica",
    ],
    ".cstu.edu": ["California Science And Technology University", "CSTU"],
    ".csu.edu": ["Chicago State University"],
    ".csub.edu": ["California State University, Bakersfield"],
    ".csubak.edu": ["California State University, Bakersfield"],
    ".csuci.edu": ["California State University, Channel Islands"],
    ".csudh.edu": ["California State University, Dominguez Hills"],
    ".csueastbay.edu": ["California State University East Bay"],
    ".csufresno.edu": ["California State University, Fresno"],
    ".csuglobal.edu": ["Colorado State University Global Campus"],
    ".csuhayward.edu": ["California State University, Hayward"],
    ".csulb.edu": ["California State University, Long Beach"],
    ".csum.edu": ["California Maritime Academy"],
    ".csumb.edu": ["California State University Monterey Bay"],
    ".csuniv.edu": ["Charleston Southern University"],
    ".csuohio.edu": ["Cleveland State University"],
    ".csus.edu": ["California State University, Sacramento"],
    ".csusb.edu": ["California State University, San Bernadino"],
    ".csusm.edu": ["California State University, San Marcos"],
    ".csustan.edu": ["California State University, Stanislaus"],
    ".pierce.ctc.edu": [
        "Pierce College",
        "Pierce College, Washington",
        "Pierce College, Puyallup, Washington",
    ],
    ".ctsem.edu": ["Continental Theological Seminary"],
    ".ctstate.edu": ["Gateway Community College"],
    ".ctu.edu": ["Catholic Theological Union"],
    ".student.ctuonline.edu": ["Colorado Technical University"],
    ".ctuonline.edu": ["Colorado Technical University"],
    ".cu-portland.edu": ["Concordia University, Portland"],
    ".cua.edu": [
        "The Catholic University of America",
        "https://www.catholic.edu/index.html",
        "https://engineering.catholic.edu/academics/minor-programs/computer-science/index.html",
    ],
    ".cuaa.edu": ["Concordia University Ann Arbor"],
    ".cuanschutz.edu": ["University of Colorado Anschutz Medical Campus"],
    ".cuea.edu": ["Catholic University of Eastern Africa"],
    ".cuesta.edu": ["San Luis Obispo Cuesta College"],
    ".cui.edu": ["Concordia University, Irvine"],
    ".cuk.edu": ["THE CYBER UNIVERSITY OF KOREA"],
    ".culver.edu": ["Culver-Stockton College"],
    ".cumberland.edu": ["Cumberland University"],
    ".cune.edu": ["Concordia College, Seward"],
    ".cunef.edu": ["CUNEF University"],
    ".cunisanjuan.edu": [
        "Colegio Universitario de San Juan",
        "San Juan University College",
    ],
    ".cuny.edu": [
        "City University of New York, Bernard M. Baruch College",
        "City University of New York, Brooklyn College",
        "City University of New York, City College",
        "City University of New York, College of Staten Island",
        "City University of New York (CUNY) System",
        "City University of New York, Graduate School and University Center",
        "City University of New York, Hunter College",
        "City University of New York, John Jay College of Criminal Justice",
        "City University of New York, Lehman College",
        "City University of New York, Medgar Evers College",
        "City University of New York Medical School / Sophie Davis School of Biomedical Education",
        "City University of New York, New York City Technical College",
        "City University of New York, School of Law at Queens College",
        "City University of New York, York College",
    ],
    ".curtis.edu": ["The Curtis Institute of Music"],
    ".md.cusm.edu": ["California University of Science and Medicine"],
    ".cuw.edu": ["Concordia University, Mequon"],
    ".piratemail.cv.edu": ["Chattahoochee Valley Community College"],
    ".students.cvcc.edu": ["Catawba Valley Community College"],
    ".cvtc.edu": ["Chippewa Valley Technical College"],
    ".cw.edu": ["The College of Westchester"],
    ".cwi.edu": ["College of Western Idaho"],
    ".cwsl.edu": ["California Western School of Law"],
    ".cwu.edu": ["Central Washington University"],
    ".cypresscollege.edu": ["Cypress Community College, California"],
    ".daemen.edu": ["Daemen College"],
    ".dallas.edu": ["Dallas Christian College"],
    ".darton.edu": ["Darton College"],
    ".davenport.edu": [
        "Davenport College of Business, Grand Rapids",
        "Davenport College of Business, Kalamazoo",
        "Davenport College of Business, Lansing",
        "Detroit College of Business - Flint",
        "Detroit College of Business - Warren",
    ],
    ".davidson.edu": ["Davidson College"],
    ".davistech.edu": [
        "Davis Technical College",
        "Davis Technical College (Formerly DATC)",
    ],
    ".dayanandasagar.edu": ["Dayananda Sagar University"],
    ".dbq.edu": ["University of Dubuque"],
    ".dbu.edu": ["Dallas Baptist University"],
    ".dbumn.edu": ["Duluth Business University"],
    ".dc.edu": ["Dominican College"],
    ".dcb.edu": ["Detroit College of Business"],
    ".dcc.edu": ["Delgado Community College, New Orleans"],
    ".dccc.edu": ["Delaware County Community College"],
    ".dcccd.edu": ["Dallas County Community College District"],
    ".dcita.edu": ["Defense Cyber Investigations Training Academy"],
    ".deanza.edu": ["De Anza College"],
    ".deepsprings.edu": ["Deep Springs College"],
    ".defiance.edu": ["The Defiance College"],
    ".denison.edu": ["Denison University"],
    ".depaul.edu": ["DePaul University"],
    ".depauw.edu": ["DePauw University"],
    ".desales.edu": ["DeSales University"],
    ".desu.edu": ["Delaware State University"],
    ".devry.edu": [
        "DeVry Institute of Technology, Pomona",
        "DeVry Institute of Technology, Decatur",
        "DeVry Institute of Technology, Chicago",
        "DeVry Institute of Technology, DuPage",
        "DeVry Institute of Technology, Kansas City",
        "DeVry Institute of Technology, Irving",
    ],
    ".dgu.edu": ["Dongguk University"],
    ".dickinson.edu": ["Dickinson College"],
    ".dickinsonstate.edu": ["Dickinson State University"],
    ".digipen.edu": ["DigiPen Institute of Technology"],
    ".disd.edu": ["Design Institute of San Diego"],
    ".diu.edu": ["Darul Ihsan University"],
    ".dixie.edu": ["Dixie College"],
    ".dliflc.edu": ["Defense Language Institute"],
    ".dmacc.edu": ["Des Moines Area Community College"],
    ".dmcg.edu": ["Dubai Medical College for Girls"],
    ".doane.edu": ["Doane College"],
    ".dom.edu": ["Dominican University"],
    ".dominican.edu": ["Dominican College of San Rafael"],
    ".dongguk.edu": ["Dongguk University"],
    ".dordt.edu": ["Dordt College"],
    ".dowling.edu": ["Dowling College"],
    ".downstate.edu": [
        "State University of New York Downstate Medical Center"
    ],
    ".dpc.edu": ["Dubai Pharmacy College"],
    ".drake.edu": ["Drake University"],
    ".drbu.edu": ["Dharma Realm Buddhist University"],
    ".drew.edu": ["Drew University"],
    ".drexel.edu": ["Drexel University"],
    ".dri.edu": ["Desert Research Institute"],
    ".drury.edu": ["Drury College"],
    ".dsdt.edu": ["Detroit School Of Technology"],
    ".dspt.edu": ["Dominican School of Philosophy and Theology"],
    ".dsu.edu": ["Dakota State University"],
    ".du.edu": ["University of Denver"],
    ".duep.edu": ["Alfred Nobel University of Economics and Law "],
    ".duke.edu": ["Duke University"],
    ".dunwoody.edu": ["Dunwoody College of Technology"],
    ".dupage.edu": ["College of DuPage"],
    ".duq.edu": ["Duquesne University"],
    ".connect.durhamtech.edu": [
        "Durham Technical Community College",
        "1637 East Lawson Street, Durham, NC 27703",
        "www.durhamtech.edu",
    ],
    ".dvc.edu": ["Diablo Valley College"],
    ".dwu.edu": ["Dakota Wesleyan University"],
    ".dyc.edu": ["D'Youville College"],
    ".dypatil.edu": ["DY Patil University"],
    ".monsters.eac.edu": ["Eastern Arizona College"],
    ".earlham.edu": ["Earlham College"],
    ".eastern.edu": ["Eastern College"],
    ".my.easternct.edu": ["Eastern Connecticut State University"],
    ".easternflorida.edu": ["Eastern Florida State College"],
    ".lions.eastms.edu": ["East Mississippi Community College"],
    ".eastwest.edu": ["East-West University"],
    ".ebs.edu": ["\ufeffEBS UNIVERSITÄT"],
    ".ecc.edu": ["SUNY Erie"],
    ".eccu.edu": ["EC-Council University", "EC-Council University"],
    ".eckerd.edu": ["Eckerd College"],
    ".ecok.edu": ["East Central University"],
    ".ecollege.edu": ["Ecclesia College", "Ecclesia College"],
    ".ecpi.edu": ["ECPI University"],
    ".ecsu.edu": ["Elizabeth City State University"],
    ".ecu.edu": ["East Carolina University"],
    ".edmail.edcc.edu": ["Edmonds Community College"],
    ".edgewood.edu": ["Edgewood College"],
    ".edhec.edu": ["EDHEC Business School"],
    ".edinboro.edu": ["Edinboro University of Pennsylvania"],
    ".edisonohio.edu": [
        "Edison State Community College",
        "Edison Community College",
    ],
    ".edmonds.edu": ["Edmonds College"],
    ".egs.edu": ["European Graduate School, Media &amp; Communications"],
    ".ehc.edu": ["Emory &amp; Henry College"],
    ".live.eicc.edu": ["Eastern Iowa Community Colleges"],
    ".einsteinmed.edu": ["Albert Einstein College of Medicine"],
    ".eitc.edu": ["Eastern Idaho Technical College"],
    ".eiu.edu": ["Eastern Illinois University"],
    ".eku.edu": ["Eastern Kentucky University"],
    ".elcamino.edu": ["El Camino College"],
    ".elgin.edu": ["Elgin Community College"],
    ".elmhurst.edu": ["Elmhurst College"],
    ".elmira.edu": ["Elmira College"],
    ".elon.edu": ["Elon College"],
    ".embryriddle.edu": ["Embry-Riddle Aeronautical University"],
    ".emcc.edu": ["Eastern Maine Community College"],
    ".emerson.edu": ["Emerson College", "emerson.edu"],
    ".emich.edu": ["Eastern Michigan University"],
    ".emiratesacademy.edu": ["The Emirates Academy of Hotel Managment"],
    ".emmaus.edu": ["Emmaus Bible College"],
    ".emory.edu": ["Emory University"],
    ".emporia.edu": ["Emporia State University"],
    ".emu.edu": ["Eastern Mennonite University"],
    ".mail.endicott.edu": ["Endicott College"],
    ".endicott.edu": ["Endicott College"],
    ".enmu.edu": ["Eastern New Mexico University"],
    ".ensign.edu": ["Ensign College"],
    ".eou.edu": ["Eastern Oregon University"],
    ".epcc.edu": ["El Paso Community College"],
    ".erau.edu": ["Embry Riddle Aeronautical University, Prescott"],
    ".erskine.edu": ["Erskine College"],
    ".esade.edu": ["ESADE", "https://www.esade.edu/"],
    ".esc.edu": ["State University of New York Empire State College"],
    ".escc.edu": ["Enterprise State Community College"],
    ".staff.escoffier.edu": ["Auguste Escoffier School of Culinary Arts"],
    ".esf.edu": [
        "State University of New York College of Environmental Science and Forestry"
    ],
    ".esic.edu": ["Escuela Superior de Gestion Comercial y Marketing (ESIC)"],
    ".esih.edu": ["École Supérieure d'Infotronique d'Haïti (ESIH)"],
    ".email.essex.edu": ["Essex County College"],
    ".esu.edu": ["East Stroudsburg State University"],
    ".etbu.edu": ["East Texas Baptist University"],
    ".etf.edu": ["Evangelische Theologische Faculteit, Leuven"],
    ".etown.edu": ["Elizabethtown College"],
    ".etsu.edu": ["East Tennessee State University"],
    ".eureka.edu": ["Eureka College"],
    ".euruni.edu": [
        "European University",
        "European University, Athens Campus",
    ],
    ".evangel.edu": ["Evangel University"],
    ".evansville.edu": ["University of Evansville"],
    ".evc.edu": ["Evergreen Valley College"],
    ".everettcc.edu": ["Everett Community College"],
    ".evergreen.edu": ["Evergreen State College"],
    ".evms.edu": ["Eastern Virginia Medical School"],
    ".ewc.edu": ["Edward Waters College"],
    ".ewu.edu": ["Eastern Washington University"],
    ".ewubd.edu": ["East West University", "East-West University, Mohakhali"],
    ".fae.edu": [
        "FAE Business School - Faculdade de Administração e Economia"
    ],
    ".fairfield.edu": ["Fairfield University"],
    ".fairmontstate.edu": ["Fairmont State University"],
    ".famu.edu": ["Florida Agricultural and Mechanical University"],
    ".fandm.edu": ["Franklin and Marshall College"],
    ".farmingdale.edu": [
        "State University of New York College of Technology at Farmingdale"
    ],
    ".fau.edu": ["Florida Atlantic University"],
    ".faulkner.edu": ["Faulkner University"],
    ".fauser.edu": ["Istituto Tecnico Tecnologico Fauser"],
    ".fccc.edu": ["Temple University"],
    ".fcps.edu": ["Fairfax County Schools"],
    ".fdltcc.edu": ["Fond Du Lac Tribal And Community College"],
    ".student.fdtc.edu": ["Florence Darlington Technical College"],
    ".fdu.edu": [
        "Fairleigh Dickinson University, Florham-Madison Campus",
        "Fairleigh Dickinson University, Teaneck-Hackensack Campus",
    ],
    ".stu.feitian.edu": ["Fei Tian College Middletown"],
    ".felician.edu": ["Felician College"],
    ".ferris.edu": ["Ferris State University"],
    ".ferrum.edu": ["Ferrum College"],
    ".fgcu.edu": ["Florida Gulf Coast University"],
    ".fhda.edu": ["Foothill-De Anza Community College District"],
    ".fhsu.edu": ["Fort Hays State University"],
    ".fhu.edu": ["Freed-Hardeman University"],
    ".fielding.edu": ["Fielding Institute"],
    ".findlay.edu": ["University of Findlay"],
    ".fingerlakes.edu": ["Finger Lakes Community College"],
    ".finlandia.edu": ["Finlandia University"],
    ".fis.edu": ["Frankfurt International School"],
    ".fisk.edu": ["Fisk University"],
    ".fit.edu": ["Florida Institute of Technology"],
    ".fitchburgstate.edu": ["Fitchburg State University"],
    ".fiu.edu": ["Florida International University"],
    ".fje.edu": ["Fundació Jesuïtes Educació", "Jesuits Education"],
    ".flagler.edu": ["Flagler College"],
    ".flcc.edu": ["Finger Lakes Community College"],
    ".floridapoly.edu": ["Florida Polytechnic University"],
    ".flsouthern.edu": ["Florida Southern College"],
    ".fmarion.edu": ["Francis Marion University"],
    ".fmc.edu": ["Florida Memorial College"],
    ".fms.edu": ["Faculty of Management Studies, University of Delhi"],
    ".fmu.edu": [
        "Florida Metropolitan University, Fort Lauderdale College",
        "Florida Metropolitan University, Tampa College",
        "Florida Metropolitan University, Tampa College Brandon",
        "Florida Metropolitan University, Tampa College Lakeland",
    ],
    ".stu.fnu.edu": ["Florida National University"],
    ".fontbonne.edu": ["Fontbonne College"],
    ".fontys.edu": ["Fontys University of Applied Sciences"],
    ".foothill.edu": ["Foothill College"],
    ".fordham.edu": ["Fordham University"],
    ".forsythtech.edu": ["Forsyth Technical Community College"],
    ".fortlewis.edu": ["Fort Lewis College"],
    ".fortscott.edu": ["Fort Scott Community College (FSCC)"],
    ".student.framingham.edu": ["Framingham State University"],
    ".framingham.edu": ["Framingham State University"],
    ".francis.edu": ["Saint Francis University"],
    ".franciscan.edu": ["Franciscan University of Steubenville"],
    ".student.francistuttle.edu": ["Francis Tuttle Technology Center"],
    ".franklin.edu": ["Franklin University"],
    ".frederick.frederick.edu": ["Frederick Community College"],
    ".myfcc.frederick.edu": ["Frederick Community College"],
    ".fredonia.edu": ["State University of New York College at Fredonia"],
    ".fresno.edu": ["Fresno Pacific University"],
    ".fresnocitycollege.edu": ["Fresno City College"],
    ".friends.edu": ["Friends University"],
    ".frontrange.edu": ["Front Range Community College"],
    ".frostburg.edu": ["Frostburg State University"],
    ".fscj.edu": ["Florida State College at Jacksonville"],
    ".fst.edu": ["Franciscan School of Theology"],
    ".fsu.edu": ["Florida State University"],
    ".bucs.fsw.edu": ["Florida Southwestern State College"],
    ".fsw.edu": [],
    ".fullcoll.edu": ["Fullerton College"],
    ".fullerton.edu": ["California State University, Fullerton"],
    ".fullsail.edu": ["Full Sail University"],
    ".furman.edu": ["Furman University"],
    ".fvi.edu": ["FVI School of Nursing and Technology"],
    ".fvtc.edu": ["Fox Valley Technical College"],
    ".campus.fxua.edu": ["Fairfax University of America"],
    ".gac.edu": ["Gustavus Adolphus College"],
    ".mti.gadjahmada.edu": [
        "UNIVERSITAS GADJAH MADA",
        "GADJAH MADA UNIVERSITY",
    ],
    ".gadsdenstate.edu": ["Gadsden State Community College"],
    ".galgotiacollege.edu": [
        "Galgotias College of Engineering and Technology"
    ],
    ".galileo.edu": ["Universidad Galileo"],
    ".gallaudet.edu": ["Gallaudet University"],
    ".gannon.edu": ["Gannon University"],
    ".gardner-webb.edu": ["Gardner Webb University"],
    ".garrettcollege.edu": ["Garrett College", "Garrett Community College"],
    ".gatech.edu": ["Georgia Institute of Technology"],
    ".gavilan.edu": ["Gavilan College"],
    ".gbc.edu": ["Goldey-Beacom College"],
    ".gbcnv.edu": ["Great Basin College"],
    ".gbcol.edu": ["Grace Bible College"],
    ".gbs.edu": ["God's Bible School and College"],
    ".gcc.edu": ["Grove City College"],
    ".gcccd.edu": ["Grossmont College"],
    ".gcsu.edu": ["Georgia College &amp; State University"],
    ".gcu.edu": ["Grand Canyon University"],
    ".geisinger.edu": [
        "Geisinger College of Health Sciences",
        "Scranton, PA, United States of America",
    ],
    ".genesee.edu": ["Genesee Community College"],
    ".geneseo.edu": ["State University of New York College at Geneseo"],
    ".geneva.edu": ["Geneva College"],
    ".georgefox.edu": ["George Fox University"],
    ".georgetown.edu": ["Georgetown University"],
    ".georgetowncollege.edu": ["Georgetown College"],
    ".georgian.edu": ["Georgian Court College"],
    ".georgiasouthern.edu": ["Georgia Southern University"],
    ".germanna.edu": ["Germanna Community College"],
    ".gettysburg.edu": ["Gettysburg College"],
    ".gfcmsu.edu": ["Great Falls College Montana State University"],
    ".ggc.edu": ["Georgia Gwinnett College"],
    ".ggu.edu": ["Golden Gate University"],
    ".my.ghc.edu": ["Gray's Harbor College", "Gray's Harbor College"],
    ".gia.edu": ["Gemological Institute of America"],
    ".giet.edu": [
        "Gandhi Institute Of Engineering and Technology",
        "Gandhi Institute Of Engineering and Technology",
    ],
    ".students.git.edu": ["KLS Gogte Institute of Technology"],
    ".gitam.edu": [
        "Gitam Deemed To Be university, Visakhapatnam, Andhra Pradesh, India.",
        "Official webpage: www.gitam.edu",
        "Proof that it offers a CS course: http://vspgit.gitam.edu/cse/about-department",
    ],
    ".glcc.edu": ["Great Lakes Christian College"],
    ".glendale.edu": ["Glendale Community College"],
    ".glendalelaw.edu": ["Glendale University College of Law"],
    ".glion.edu": ["Glion Institute of Higher Education"],
    ".gmc.edu": ["Gwynedd-Mercy College"],
    ".gmercyu.edu": ["Gwynedd Mercy University"],
    ".gmu.edu": ["George Mason University"],
    ".gnomon.edu": ["Gnomon - School of VFX & animation for film and games"],
    ".gntc.edu": ["Georgia Northwestern Technical College"],
    ".goddard.edu": ["Goddard College"],
    ".students.gogebic.edu": ["Gogebic Community College"],
    ".gonzaga.edu": ["Gonzaga University"],
    ".gordon.edu": ["Gordon College"],
    ".gordonstate.edu": ["Gordon State College"],
    ".goshen.edu": ["Goshen College"],
    ".goucher.edu": ["Goucher College"],
    ".govst.edu": ["Governors State University"],
    ".student.gptc.edu": ["Georgia Piedmont Technical College"],
    ".grace.edu": ["Grace College"],
    ".graceland.edu": ["Graceland College"],
    ".graceu.edu": ["Grace University"],
    ".gram.edu": ["Grambling State University"],
    ".grand-canyon.edu": ["Grand Canyon University"],
    ".grandview.edu": ["Grand View University"],
    ".grantham.edu": ["Grantham University"],
    ".gratzcollege.edu": ["Gratz College"],
    ".grcc.edu": ["Grand Rapids Community College"],
    ".greenmtn.edu": ["Green Mountain College"],
    ".student.greenriver.edu": ["Green River College"],
    ".greenriver.edu": ["Green River College"],
    ".greenville.edu": ["Greenville College"],
    ".grinnell.edu": ["Grinnell College"],
    ".gsu.edu": ["Georgia State University"],
    ".gsw.edu": ["Georgia Southwestern University"],
    ".gtcc.edu": [
        "Guilford Technical Community College",
        "Guilford Technical Community College",
    ],
    ".gtu.edu": ["Graduate Theological Union"],
    ".guamcc.edu": ["Guam Community College"],
    ".guilford.edu": ["Guilford College"],
    ".gustavus.edu": ["Gustavus Adolphus Colelge"],
    ".gvc.edu": ["Grand View College"],
    ".my.gvltec.edu": [
        "Greenville Technical College",
        "Greenville Technical College",
    ],
    ".gvsu.edu": ["Grand Valley State University"],
    ".student.gwinnetttech.edu": ["Gwinnett Technical College"],
    ".gwinnetttech.edu": ["GWINNETT TECHNICAL COLLEGE"],
    ".gwu.edu": ["George Washington University"],
    ".hamilton.edu": ["Hamilton College"],
    ".hamline.edu": ["Hamline University"],
    ".hampshire.edu": ["Hampshire College"],
    ".hamptonu.edu": ["Hampton University"],
    ".handong.edu": ["Handong Global University"],
    ".hanover.edu": ["Hanover College"],
    ".hansung.edu": ["한성대학교"],
    ".harcum.edu": ["Harcum College"],
    ".harding.edu": ["Harding University"],
    ".harford.edu": ["Harford Community College"],
    ".harpercollege.edu": ["Harper College"],
    ".harrisburgu.edu": ["Harrisburg University"],
    ".hartford.edu": ["Hartford College for Women", "University of Hartford"],
    ".student.hartnell.edu": ["Hartnell College"],
    ".hartwick.edu": ["Hartwick College"],
    ".harvard.edu": ["Harvard University"],
    ".hastings.edu": ["Hastings College"],
    ".hauniv.edu": ["Hellenic American University"],
    ".haverford.edu": ["Haverford College"],
    ".hawaii.edu": [
        "University of Hawaii - Hilo",
        "University of Hawaii - Manoa",
        "University Of Hawaii - System",
        "University of Hawaii - West Oahu",
    ],
    ".hawkeyecollege.edu": ["Hawkeye College"],
    ".hbs.edu": ["Harvard Business School"],
    ".hbu.edu": ["Houston Baptist University"],
    ".student.hbuhsd.edu": ["Marina high school"],
    ".hcc-nd.edu": ["Holy Cross College"],
    ".live.hccc.edu": [
        "Hudson County Community College",
        "Hudson County Community College",
    ],
    ".student.hccs.edu": ["Houston Community College"],
    ".hccs.edu": ["Houston Community College"],
    ".my.heartland.edu": ["Heartland Community College"],
    ".heartland.edu": ["Heartland Community College"],
    ".hebron.edu": ["Hebron University"],
    ".hec.edu": ["HEC Paris", "HEC"],
    ".heidelberg.edu": ["Heidelberg College"],
    ".hendrix.edu": ["Hendrix College"],
    ".hennepintech.edu": ["Hennepin Technical College"],
    ".heritage.edu": ["Heritage College"],
    ".heritageit.edu": ["Heritage Institute of Technology"],
    ".herzing.edu": ["Herzing University", "Herzing University"],
    ".hawkmail.hfcc.edu": ["Henry Ford College"],
    ".hgc.edu": ["Hartford Graduate Center (Rensselaer at Hartford)"],
    ".hgtc.edu": ["Horry Georgtown Technical college"],
    ".highland.edu": ["Highland Community College"],
    ".highlands.edu": ["Georgia Highlands College"],
    ".highpoint.edu": ["High Point University"],
    ".hightech.edu": ["Ecole Supérieure d'Informatique et de Management"],
    ".hilbert.edu": ["Hilbert College"],
    ".student.hillcollege.edu": ["Hill College"],
    ".hillsdale.edu": ["Hillsdale College"],
    ".hiram.edu": ["Hiram College"],
    ".hiu.edu": ["Hope International University"],
    ".hkapa.edu": ["Hong Kong Academy for Performing Arts "],
    ".hksyu.edu": [
        "Hong Kong Shue Yan University",
        "Hong Kong Shue Yan University",
    ],
    ".hlg.edu": ["Hannibal-Lagrange College"],
    ".hm.edu": ["Hochschule Munchen", "University of applied science Munich"],
    ".hmc.edu": ["Harvey Mudd College"],
    ".hodges.edu": ["Hodges University"],
    ".hofstra.edu": ["Hofstra University"],
    ".hollins.edu": ["Hollins University"],
    ".holycross.edu": ["College of the Holy Cross"],
    ".holyfamily.edu": ["Holy Family University"],
    ".hood.edu": ["Hood College"],
    ".hope.edu": ["Hope College"],
    ".students.hopkins.edu": ["Hopkins School"],
    ".hopkins.edu": ["Hopkins School"],
    ".hoseo.edu": ["호서대학교", "HOSEO UNIVERSITY"],
    ".houghton.edu": ["Houghton College"],
    ".howard.edu": ["Howard University"],
    ".howardcc.edu": ["Howard Community College"],
    ".hpu.edu": ["Hawaii Pacific University"],
    ".hputx.edu": ["Howard Payne University"],
    ".hsbc.edu": ["Hobe Sound Bible College"],
    ".hsc.edu": ["Hampden-Sydney College"],
    ".hscbklyn.edu": ["State University of New York Downstate Medical Center"],
    ".hscsyr.edu": [
        "State University of New York Health Sience Centre Syracuse"
    ],
    ".hsu.edu": ["Henderson State Univerisity"],
    ".hsutx.edu": ["Hardin-Simmons University"],
    ".htc.edu": ["Huston-Tillotson College"],
    ".htu.edu": ["Huston-Tillotson University"],
    ".hult.edu": ["Hult International Business School"],
    ".humboldt.edu": ["Humboldt State University"],
    ".humphreys.edu": ["Humphreys College"],
    ".husson.edu": ["Husson College"],
    ".hvcc.edu": ["Hudson Valley Community College"],
    ".hws.edu": ["Hobart and William Smith Colleges"],
    ".iastate.edu": ["Iowa State University of Science and Technology"],
    ".ibero.edu": ["Ibero Institute"],
    ".ic.edu": ["Illinois College"],
    ".iccms.edu": ["Itawamba Community College", "https://www.iccms.edu/"],
    ".ici.edu": ["ICI University"],
    ".ico.edu": ["Illinois College of Optometry"],
    ".ie.edu": ["IE University"],
    ".alumni.ied.edu": ["IED Istituto Europeo di Design S.p.A."],
    ".ied.edu": ["IED - Istituto Europeo di Design"],
    ".iese.edu": ["IESE Business School"],
    ".iift.edu": ["IIFT Kolkata"],
    ".iilm.edu": ["IILM University, Greater Noida"],
    ".iit.edu": ["Illinois Institute of Technology"],
    ".illinois.edu": ["University of Illinois at Urbana-Champaign"],
    ".illinoistech.edu": ["Illinois Institute of Technology"],
    ".ilstu.edu": [
        "Illinois State University",
        "Mennonite College of Nursing",
    ],
    ".immaculata.edu": ["Immaculata University"],
    ".imperial.edu": ["Imperial Valley College"],
    ".imsa.edu": ["Illinois Mathematics and Science Academy"],
    ".imtu.edu": ["International Medical &amp; Technological University"],
    ".incae.edu": ["INCAE Business School", "INCAE Business School"],
    ".indiana.edu": [
        "Indiana University - East",
        "Indiana University - Northwest",
        "Indiana University - Southeast",
        "Indiana University (System)",
    ],
    ".indianatech.edu": ["Indiana Institute of Technology"],
    ".stu.indianhills.edu": ["Indian Hills Community College"],
    ".indianhills.edu": ["Indian Hills Community College"],
    ".indstate.edu": ["Indiana State University"],
    ".indwes.edu": ["Indiana Wesleyan University"],
    ".inha.edu": ["INHA University"],
    ".insead.edu": ["INSEAD"],
    ".intelliteccollege.edu": ["IntelliTec College - Grand Junction"],
    ".inter.edu": [
        "Universidad Interamericana de Puerto Rico",
        "Universidad Interamericana de Puerto Rico, Bayamón",
        "Universidad Interamericana de Puerto Rico, San Germán",
    ],
    ".interbayamon.edu": [
        "Universidad Interamericana de Puerto Rico",
        "Interamerican University of Puerto Rico",
    ],
    ".intercol.edu": ["Intercollege"],
    ".interfajardo.edu": [
        "Universidad Interamericana de Puerto Rico - Fajardo",
        "University Interamerican University of Puerto Rico - Fajardo",
    ],
    ".iona.edu": ["Iona College"],
    ".tritons.iowacentral.edu": [
        "Name: Iowa Central Community College",
        "Address: One Triton Circle, Fort Dodge, IA 50501",
        "ZIP Code: 50501",
        "Website: www.iowacentral.edu",
        "username@tritons.iowacentral.edu",
    ],
    ".mail.irsc.edu": ["Indian River State College"],
    ".isb.edu": ["indian school of business", "indian school of business"],
    ".isi.edu": [
        "Information Sciences Institute, University of Southern California"
    ],
    ".isothermal.edu": ["Isothermal Community College"],
    ".isu.edu": ["Idaho State University"],
    ".ithaca.edu": ["Ithaca College"],
    ".itt.edu": ["Institute of Textile Technology"],
    ".itu.edu": ["International Technology Institute"],
    ".iu.edu": [
        "Indiana University - Bloomington",
        "Indiana University - Columbus",
        "Indiana University - East",
        "Indiana University - Indianapolis",
        "Indiana University - Kokomo",
        "Indiana University - Northwest",
        "Indiana University - Southeast",
        "Indiana University - South Bend",
        "Indiana University (System)",
    ],
    ".iub.edu": ["Indiana University at Bloomington"],
    ".iubat.edu": [
        "International University of Business Agriculture and Technology"
    ],
    ".iufs.edu": [
        "International University of Fundamental Studies, St. Petersburg",
        "International University of Fundamental Studies, St. Petersburg",
    ],
    ".iuk.edu": ["Indiana University at Kokomo"],
    ".iup.edu": ["Indiana University of Pennsylvania"],
    ".iupui.edu": [
        "Indiana University-Purdue University at Columbus",
        "Indiana University-Purdue University at Indianapolis",
    ],
    ".ius.edu": ["Indiana University Southeast"],
    ".iusb.edu": ["Indiana University at South Bend"],
    ".iut-dhaka.edu": ["Islamic University of Technology"],
    ".iutoic-dhaka.edu": ["Islamic University of Technology"],
    ".ivc.edu": ["Irvine Valley College"],
    ".ivcc.edu": ["Illinois Valley Community College"],
    ".ivy.edu": ["Ivy College"],
    ".ivytech.edu": ["Ivy Tech Community College"],
    ".iwu.edu": ["Illinois Wesleyan University"],
    ".jacksonville.edu": ["Jacksonville University"],
    ".jalc.edu": ["John A. Logan Community College"],
    ".jarvis.edu": ["Jarvis Christian College"],
    ".jbc.edu": ["Johnson Bible College"],
    ".jbu.edu": ["John Brown University"],
    ".jc.edu": ["Jamestown College"],
    ".jccc.edu": ["Johnson County Community College"],
    ".jcsu.edu": ["Johnson C. Smith University"],
    ".jcu.edu": ["John Carroll University"],
    ".jeffco.edu": ["Jefferson College"],
    ".jefferson.edu": ["Thomas Jefferson University"],
    ".jeffersonstate.edu": ["Jefferson State Community College"],
    ".jessup.edu": ["Jessup University"],
    ".jewell.edu": ["William Jewell College"],
    ".jfku.edu": ["John F. Kennedy University"],
    ".jh.edu": ["Johns Hopkins University", "The Johns Hopkins University"],
    ".jhu.edu": ["Johns Hopkins University", "The Johns Hopkins University"],
    ".jinnah.edu": ["Mohammad Ali Jinnah University, Karachi"],
    ".jjc.edu": ["Joliet Junior College, JJC"],
    ".jmls.edu": ["John Marshall Law School"],
    ".jmu.edu": ["James Madison University"],
    ".johncabot.edu": ["John Cabot University"],
    ".johnsonu.edu": ["Johnson University"],
    ".johnwesley.edu": ["John Wesley College"],
    ".jones.edu": ["Jones College"],
    ".my.jru.edu": ["José Rizal University"],
    ".jsu.edu": ["Jacksonville State University"],
    ".jsums.edu": ["Jackson State University"],
    ".ju.edu": ["Jacksonville University"],
    ".juc.edu": ["Jerusalem University College"],
    ".judson.edu": ["Judson College Marion"],
    ".student.judsonu.edu": ["Judson University"],
    ".juilliard.edu": ["The Juilliard School"],
    ".juniata.edu": ["Juniata College"],
    ".juniv.edu": ["Jahangirnagar University"],
    ".jwu.edu": [
        "Johnson &amp; Wales University",
        "Johnson &amp; Wales University, Charleston",
    ],
    ".kansascity.edu": ["Kansas City University"],
    ".kaplan.edu": ["Kaplan University"],
    ".kcad.edu": ["Kendall College of Art and Design"],
    ".kcai.edu": ["Kansas City Art Institute"],
    ".kcc.edu": ["Kentucky Christian College"],
    ".m1.kcg.edu": [
        "京都情報大学院大学",
        "The Kyoto College of Graduate Studies for Informatics",
    ],
    ".m2.kcg.edu": [
        "京都情報大学院大学",
        "The Kyoto College of Graduate Studies for Informatics",
    ],
    ".kckcc.edu": ["Kansas City Kansas Community College"],
    ".kctcs.edu": [
        "Ashland Community & Technical College",
        "Big Sandy Community and Technical College",
        "Bluegrass Community & Technical College",
        "Elizabethtown Community & Technical College",
        "Gateway Community & Technical College",
        "Hazard Community & Technical College",
        "Henderson Community College",
        "Hopkinsville Community College",
        "Jefferson Community & Technical College",
        "Madisonville Community College",
        "Maysville Community & Technical College",
        "Owensboro Community & Technical College",
        "Somerset Community College",
        "Southcentral Kentucky Community and Technical College",
        "Southeast Kentucky Community & Technical College",
        "West Kentucky Community & Technical College",
        ".group\x00",
    ],
    ".kean.edu": ["Kean University of New Jersey"],
    ".keene.edu": ["Keene State College"],
    ".student.keiseruniversity.edu": ["Keiser University"],
    ".keiseruniversity.edu": ["Keiser University", "Keiser University"],
    ".keller.edu": ["Keller Graduate School of Management"],
    ".kellogg.edu": ["Kellogg Community College"],
    ".kendall.edu": ["Kendall College"],
    ".students.kennesaw.edu": ["Kennesaw State University"],
    ".kennesaw.edu": ["Kennesaw State University"],
    ".kent.edu": [
        "Kent State University - Stark",
        "Kent State University",
        "Kent State University - Ashtabula",
        "Kent State University - East Liverpool",
        "Kent State University - Salem",
        "Kent State University - Trumbull",
        "Kent State University - Tuscarawas",
    ],
    ".kenyon.edu": ["Kenyon College"],
    ".kettering.edu": ["Kettering University (GMI)"],
    ".keuka.edu": ["Keuka College"],
    ".kgi.edu": ["Keck Graduate Institute"],
    ".khai.edu": ["National Aerospace University Kharkov Aviation Institute"],
    ".kiet.edu": ["KIET Group of Institutions"],
    ".king.edu": ["King College"],
    ".kings.edu": ["King's College"],
    ".kirkwood.edu": ["Kirkwood Community College"],
    ".kish.edu": ["Kishwaukee College"],
    ".kit.edu": ["Karlsruhe Institute of Technology"],
    ".klnce.edu": ["KLN College of Engineering"],
    ".knox.edu": ["Knox College"],
    ".knoxvillecollege.edu": ["Knoxville College"],
    ".kongu.edu": ["Kongu Engineering College, Perundurai"],
    ".korea.edu": ["korea university"],
    ".ksbe.edu": ["Kamehameha Schools Bishop Estate"],
    ".ksu.edu": ["Kansas State University"],
    ".ktu.edu": ["Kaunas University of Technology"],
    ".ku.edu": ["University of Kansas"],
    ".kumc.edu": ["University of Kansas Medical Center"],
    ".kutztown.edu": ["Kutztown University of Pennsylvania"],
    ".kvcc.edu": ["Kalamazoo Valley Community College"],
    ".kwc.edu": ["Kentucky Wesleyan College"],
    ".kwu.edu": ["Kansas Wesleyan University"],
    ".kysu.edu": ["Kentucky State University"],
    ".kzoo.edu": ["Kalamazoo College"],
    ".lacc.edu": ["Los Angeles College of Chiropractic"],
    ".laccd.edu": ["Los Angeles Community College District"],
    ".lacitycollege.edu": ["Los Angeles City College"],
    ".lacollege.edu": ["Louisiana College"],
    ".lafayette.edu": ["Lafayette College"],
    ".lakeerie.edu": ["Lake Erie College"],
    ".lakeforest.edu": ["Lake Forest College"],
    ".lakeland.edu": ["Lakeland College"],
    ".mail.lakelandcc.edu": ["Lakeland Community College"],
    ".lakelandcollege.edu": ["Lake Land College"],
    ".lakeviewcol.edu": ["Lakeview College of Nursing"],
    ".lamar.edu": ["Lamar University", "Lamar University - Port Arthur"],
    ".lander.edu": ["Lander University"],
    ".landmark.edu": ["Landmark College"],
    ".lanecc.edu": ["Lane Community College"],
    ".lanecollege.edu": ["Lane College"],
    ".lapu.edu": ["Los Angeles Pacific University"],
    ".laroche.edu": ["La Roche College"],
    ".lasalle.edu": ["La Salle University"],
    ".lasell.edu": ["Lasell College"],
    ".lasierra.edu": ["La Sierra University"],
    ".laspositascollege.edu": ["Las Positas Community College"],
    ".latech.edu": ["Louisiana Tech University"],
    ".lattc.edu": ["Los Angeles Trade Technical College"],
    ".lau.edu": ["Lebanese American University"],
    ".laverne.edu": ["The University of La Verne", "La Verne Univeristy"],
    ".lawrence.edu": ["Lawrence University"],
    ".lbc.edu": ["Lancaster Bible College"],
    ".lbcc.edu": ["Long Beach City College"],
    ".mail.lcc.edu": [
        "Lansing Community College",
        "600 N. Grand Avenue, Lansing, MI 48933",
        "www.lcc.edu",
        "Username@mail.lcc.edu",
    ],
    ".lcc.edu": ["Lansing Community College"],
    ".lccc.edu": ["Lehigh Carbon Community College"],
    ".lcchs.edu": ["Lima Central Catholic High School"],
    ".lclark.edu": ["Lewis and Clark College"],
    ".lcsc.edu": ["Lewis-Clark State College"],
    ".lcu.edu": ["Lubbock Christian University"],
    ".mylc.lee.edu": ["Lee College"],
    ".leeu.edu": ["Lee University", "Lee University"],
    ".leeuniversity.edu": ["Lee University"],
    ".lehigh.edu": ["Lehigh Univervsity"],
    ".lemoyne.edu": ["Le Moyne College"],
    ".lancers.lenoircc.edu": ["Lenoir Community College"],
    ".lesroches.edu": ["Les Roches International School of Hotel Management"],
    ".letu.edu": ["Letourneau University"],
    ".lewisu.edu": ["Lewis University"],
    ".lfc.edu": ["Lake Forest College"],
    ".lfgsm.edu": ["Lake Forest Graduate School of Management"],
    ".lhup.edu": ["Lock Haven University of Pennsylvania"],
    ".life.edu": ["Life University"],
    ".lifewest.edu": ["Life Chiropractic College West"],
    ".limcollege.edu": ["Laboratory Institute of Merchandising"],
    ".limestone.edu": ["Limestone College"],
    ".lincoln.edu": ["Lincoln University Pennsylvania"],
    ".lincolnu.edu": ["Lincoln University Missouri"],
    ".lincolnuca.edu": ["Lincoln University San Francisco"],
    ".lincolnucasf.edu": ["Lincoln University San Francisco"],
    ".lindenwood.edu": ["Lindenwood University"],
    ".lindsey.edu": ["Lindsey Wilson College"],
    ".linfield.edu": ["Linfield College"],
    ".mail.linnbenton.edu": ["Linn-Benton Community College"],
    ".lipscomb.edu": ["Lipscomb University"],
    ".my.liu.edu": ["Long Island University", "Long Island University"],
    ".liunet.edu": [
        "Long Island University",
        "Long Island University, C.W. Post Campus",
        "Long Island University, Southampton College",
    ],
    ".livingstone.edu": ["Livingstone College"],
    ".llcc.edu": ["Lincoln Land Community College"],
    ".llu.edu": ["Loma Linda University"],
    ".lmc.edu": ["Lees-McRae College"],
    ".lmu.edu": ["Loyola Marymount University"],
    ".lmunet.edu": ["Lincoln Memorial University"],
    ".logan.edu": ["Logan College of Chiropractic"],
    ".london.edu": ["London Business School"],
    ".loras.edu": ["Loras College"],
    ".lorma.edu": ["Lorma Colleges"],
    ".louisiana.edu": ["University of Louisiana at Lafayette"],
    ".louisville.edu": ["University of Louisville"],
    ".lourdes.edu": ["Lourdes College"],
    ".lowercolumbia.edu": ["Lower Columbia College"],
    ".loyno.edu": ["Loyola University New Orleans"],
    ".loyola.edu": ["Loyola College in Maryland"],
    ".loyolacollege.edu": ["Loyola College"],
    ".student.lssc.edu": ["Lake Sumter State College"],
    ".lssu.edu": ["Lake Superior State University"],
    ".lsu.edu": [
        "Louisiana State University and Agricultural and Mechanical College"
    ],
    ".lsua.edu": ["Louisiana State University Alexandria"],
    ".lsuhs.edu": ["LSU Health Shreveport"],
    ".lsus.edu": ["Louisiana State University in Shreveport"],
    ".ltu.edu": ["Lawrence Technological University"],
    ".luc.edu": ["Loyola University of Chicago"],
    ".lumcon.edu": ["Louisiana Universities Marine Consortium"],
    ".lunet.edu": ["Langston University"],
    ".luther.edu": ["Luther College"],
    ".luzerne.edu": ["Luzerne County Community College"],
    ".lvc.edu": ["Lebanon Valley College"],
    ".lwtech.edu": ["Lake Washington Institute of Technology"],
    ".lycoming.edu": ["Lycoming College"],
    ".lynchburg.edu": ["Lynchburg College"],
    ".lynn.edu": ["Lynn University"],
    ".lyon.edu": ["Lyon College"],
    ".westfield.ma.edu": ["Westfield State University"],
    ".mac.edu": ["MacMurray College"],
    ".macalester.edu": ["Macalester College"],
    ".macalstr.edu": ["Macalester College"],
    ".mail.macc.edu": [
        "Name: Moberly Area Community College",
        "Address: 101 College Avenue, Moberly, MO 65270",
        "Website: www.macc.edu",
    ],
    ".mackenzie.edu": ["Mackenzie Presbyterian University"],
    ".macomb.edu": ["Macomb Community College"],
    ".mahidol.edu": ["มหาวิทยาลัยมหิดล", "Mahidol University"],
    ".maine.edu": ["University of Maine at Augusta"],
    ".mainemaritime.edu": ["Maine Maritime Academy"],
    ".malone.edu": ["Malone College"],
    ".manchester.edu": ["Manchester College"],
    ".mancol.edu": ["Manhattan College"],
    ".online.mandl.edu": ["Mandl School"],
    ".manhattan.edu": ["Manhattan University"],
    ".manipal.edu": ["Manipal Academy of Higher Education"],
    ".mansfield.edu": ["Mansfield University of Pennsylvania"],
    ".marian.edu": ["Marian College"],
    ".marietta.edu": ["Marietta College"],
    ".marin.edu": ["College of Marin"],
    ".marist.edu": ["Marist College"],
    ".maritime.edu": ["Massachusetts Maritime Academy"],
    ".marlboro.edu": ["Marlboro College"],
    ".marquette.edu": ["Marquette University"],
    ".marshall.edu": ["Marshall University"],
    ".martin.edu": ["Martin University"],
    ".martincc.edu": ["Martin Community College"],
    ".marygrove.edu": ["Marygrove College"],
    ".marylhurst.edu": ["Marylhurst University"],
    ".marymount.edu": ["Marymount University"],
    ".live.maryville.edu": ["Maryville University"],
    ".maryville.edu": ["Maryville University"],
    ".maryvillecollege.edu": ["Maryville College"],
    ".marywood.edu": ["Marywood University"],
    ".necc.mass.edu": ["Northern Essex Community College"],
    ".mass.edu": ["Massachusetts Department of Higher Education"],
    ".massart.edu": ["Massachusetts College of Art and Design"],
    ".massasoit.edu": [
        "Massasoit Community College",
        "Massasoit Community College",
    ],
    ".massbay.edu": ["Massachusetts Bay Community College"],
    ".masters.edu": ["The Master's College"],
    ".maufl.edu": ["Millennia Atlantic University"],
    ".mayo.edu": ["Mayo Graduate School", "Mayo Medical School"],
    ".mc.edu": ["Mississippi College"],
    ".mc3.edu": ["Montgomery County Community College"],
    ".mca.edu": ["Memphis College of Art"],
    ".mcad.edu": ["Minneapolis College of Art and Design"],
    ".mcc.edu": ["Charles Stewart Mott Community College"],
    ".mccd.edu": ["Merced College"],
    ".mcckc.edu": ["Metropolitan Community College, Kansas City, Missouri"],
    ".mccks.edu": ["Manhattan Christian College"],
    ".mccn.edu": ["Mount Carmel College of Nursing"],
    ".mccneb.edu": ["Metropolitan Community College"],
    ".mccollege.edu": ["Midwestern Career College"],
    ".mcdaniel.edu": ["McDaniel College"],
    ".students.mchenry.edu": ["McHenry County College"],
    ".mci.edu": ["MCI-Management Center Innsbruck"],
    ".mckendree.edu": ["McKendree College"],
    ".mcm.edu": ["McMurry University"],
    ".mcneese.edu": ["McNeese State University"],
    ".mcpherson.edu": ["McPherson College"],
    ".mcphs.edu": [
        "Massachusetts College of Pharmacy and Health Sciences University"
    ],
    ".mcphu.edu": ["Medical College of Pennsylvania and Hahnemann University"],
    ".mcw.edu": ["Medical College of Wisconsin"],
    ".mdanderson.edu": ["University of Texas - MDAnderson Cancer Center"],
    ".mdc.edu": ["Miami Dade College"],
    ".meca.edu": ["Maine College of Art"],
    ".medaille.edu": ["Medaille College"],
    ".memphis.edu": ["University of Memphis"],
    ".menlo.edu": ["Menlo College"],
    ".mercer.edu": [
        "Mercer University",
        "Mercer University, Cecil B. Day Campus",
    ],
    ".mercy.edu": ["Mercy University"],
    ".mercyhurst.edu": ["Mercyhurst College"],
    ".meredith.edu": ["Meredith College"],
    ".meridiancc.edu": ["Meridian Community College"],
    ".merrimack.edu": ["Merrimack College"],
    ".mesacc.edu": ["Mesa Community College", "Mesa Community College"],
    ".mesalands.edu": ["Mesalands Community College"],
    ".messiah.edu": ["Messiah College"],
    ".methodist.edu": ["Methodist College"],
    ".methodistcollege.edu": [
        "Nebraska Methodist College of Nursing and Allied Health"
    ],
    ".metrostate.edu": ["Metropolitan State University"],
    ".mga.edu": ["Middle Georgia State University"],
    ".mhcc.edu": ["Mt. Hood Community College"],
    ".miad.edu": ["Milwaukee Institute of Art and Design"],
    ".miami.edu": ["University of Miami"],
    ".miamioh.edu": ["Miami University (OH)"],
    ".mica.edu": ["The Maryland Institute, College of Art"],
    ".middlebury.edu": ["Middlebury College"],
    ".middlesex.edu": ["Middlesex Community College"],
    ".my.middlesexcc.edu": ["middlesex college", "middlesex college"],
    ".middlesexcc.edu": ["Middlesex County College"],
    ".middlesexcollege.edu": ["Middlesex College"],
    ".mail.midland.edu": ["Midland College"],
    ".midlandstech.edu": ["Midlands Technical School "],
    ".midmich.edu": [
        "Mid Michigan College",
        "Harrison Campus:",
        "Address: 1375 South Clare Avenue, Harrison, MI 48625",
        "Website: www.midmich.edu",
    ],
    ".midway.edu": ["Midway College"],
    ".midwestern.edu": ["Midwestern University"],
    ".miis.edu": ["Monterey Institute of International Studies"],
    ".miles.edu": ["Miles College"],
    ".millersville.edu": ["Millersville University of Pennsylvania"],
    ".milligan.edu": ["Milligan College"],
    ".millikin.edu": ["Millikin University"],
    ".mills.edu": ["Mills College"],
    ".millsaps.edu": ["Millsaps College"],
    ".milton.edu": ["Milton Academy"],
    ".uni.minerva.edu": ["Minerva University"],
    ".minerva.edu": ["Minerva university", "Minerva university"],
    ".mines.edu": ["Colorado School of Mines"],
    ".minneapolis.edu": ["Minneapolis Community and Technical College"],
    ".minnstate.edu": [
        "North Hennepin Community College",
        "North Hennepin Community College",
    ],
    ".miracosta.edu": ["MiraCosta College"],
    ".misericordia.edu": [
        "Misericordia University",
        "Misericordia University",
    ],
    ".mispp.edu": ["Michigan School of Professional Psychology"],
    ".missioncollege.edu": ["Mission College"],
    ".missouri.edu": ["University of Missouri - Columbia"],
    ".live.missouristate.edu": ["Missouri State University"],
    ".missouristate.edu": ["Missouri State University"],
    ".missouriwestern.edu": ["Missouri Western State University"],
    ".mit.edu": ["Massachusetts Institute of Technology"],
    ".students.mitchellcc.edu": ["Mitchell Community College"],
    ".mitchellhamline.edu": ["Mitchell Hamline School of Law"],
    ".miu.edu": [
        "Maharishi International University",
        "1000 N 4th St, Fairfield, IA 52557, U.S.A.",
    ],
    ".mlc-wels.edu": ["Martin Luther College"],
    ".mlc.edu": ["Midland Lutheran College"],
    ".mmc.edu": ["Meharry Medical College"],
    ".mmm.edu": ["Marymount Manhattan College"],
    ".mnsfld.edu": ["Mansfield University of Pennsylvania"],
    ".mnstate.edu": ["Minnesota State University Moorhead"],
    ".mnsu.edu": ["Minnesota State University, Mankato"],
    ".mnu.edu": ["Mid-America Nazarene University"],
    ".mobap.edu": ["Missouri Baptist College"],
    ".molloy.edu": ["Molloy College"],
    ".monaco.edu": ["International University of Monaco"],
    ".monash.edu": ["Monash University"],
    ".mondragon.edu": ["Mondragon University"],
    ".monmouth.edu": ["Monmouth University"],
    ".monmouthcollege.edu": ["Monmouth College"],
    ".students.westiron.monroe.edu": ["West Irondequoit High School"],
    ".monroeu.edu": ["Monroe University", "Monroe University"],
    ".montana.edu": ["Montana State University"],
    ".montcalm.edu": ["Montcalm Community College"],
    ".montclair.edu": ["Montclair State University"],
    ".montevallo.edu": ["University of Montevallo"],
    ".montgomery.edu": ["Montgomery Community College"],
    ".montgomerycollege.edu": ["Montgomery College"],
    ".montreat.edu": ["Montreat College"],
    ".moody.edu": ["Moody Bible Institute"],
    ".moore.edu": ["Moore College of Art and Design"],
    ".student.morainepark.edu": ["Moraine Park Technical College"],
    ".morainevalley.edu": ["Moraine Valley Community College"],
    ".moravian.edu": ["Moravian College"],
    ".morehead-st.edu": ["Morehead State University"],
    ".moreheadstate.edu": ["Morehead State University"],
    ".morehouse.edu": ["Morehouse College"],
    ".moreland.edu": ["Moreland University"],
    ".morgan.edu": ["Morgan State University"],
    ".morrisbrown.edu": ["Morris Brown College"],
    ".morrisville.edu": ["SUNY Morrisville"],
    ".mountainstate.edu": ["Mountain State University"],
    ".mountmarty.edu": ["Mount Marty University"],
    ".mountunion.edu": ["Mount Union College"],
    ".mpc.edu": ["Monterey Peninsula College"],
    ".mpm.edu": ["Milwaukee Public Museum", "Milwaukee Public Museum"],
    ".msj.edu": ["College of Mount St. Joseph"],
    ".msm.edu": ["Morehouse School of Medicine"],
    ".msmary.edu": ["Mount St. Mary's College Maryland"],
    ".msmc.edu": ["Mount St. Mary College"],
    ".msmnyc.edu": ["Manhattan School of Music"],
    ".msoe.edu": ["Milwaukee School of Engineering"],
    ".msrit.edu": ["M S Ramiah institute of technology"],
    ".mssm.edu": ["Mount Sinai School of Medicine"],
    ".msstate.edu": ["Mississippi State University"],
    ".mssu.edu": ["Missouri Southern State University"],
    ".mst.edu": ["Missouri University of Science and Technology"],
    ".mstc.edu": [
        "Mid-State Technical College",
        "https://www.mstc.edu/programs/IT-Software-Developer",
    ],
    ".msu.edu": ["Michigan State University"],
    ".msubillings.edu": ["Montana State University - Billings"],
    ".msudenver.edu": ["Metropolitan State University Denver"],
    ".msun.edu": ["Montana State University - Northern"],
    ".msutexas.edu": ["Midwestern State University,Wichita Falls,Texas"],
    ".mtaloy.edu": ["Mount Aloysius College"],
    ".mtc.edu": ["Marion technical college"],
    ".stu.mtec.edu": ["Mountainland Technical College"],
    ".mtec.edu": ["Mountainland Technical College"],
    ".mtech.edu": ["Montana Tech"],
    ".mtholyoke.edu": ["Mount Holyoke College"],
    ".mtmary.edu": ["Mount Mary College"],
    ".mtmc.edu": ["Mount Marty College"],
    ".mtsac.edu": ["Mt. San Antonio College"],
    ".mtsu.edu": ["Middle Tennessee State University"],
    ".mtu.edu": ["Michigan Technological University"],
    ".mu.edu": ["Marquette University"],
    ".muhlenberg.edu": ["Muhlenberg College"],
    ".multnomah.edu": ["Multnomah Bible College"],
    ".mum.edu": ["Maharishi University of Management"],
    ".muohio.edu": [
        "Miami University of Ohio",
        "Miami University of Ohio - Hamilton",
        "Miami University of Ohio - Middletown",
    ],
    ".murraystate.edu": ["Murray State University"],
    ".musc.edu": ["Medical University of South Carolina"],
    ".muskingum.edu": ["Muskingum College"],
    ".muw.edu": ["Mississippi University for Women"],
    ".mvc.edu": ["Moreno Valley College"],
    ".student.mvcc.edu": ["mohawk valley community college"],
    ".mville.edu": ["Manhattanville College"],
    ".mail.mvnu.edu": ["Mount Vernon Nazarene University"],
    ".mvnu.edu": ["Mount Vernon Nazarene University"],
    ".mvsu.edu": ["Mississippi Valley State University"],
    ".mwcc.edu": ["Mount Wachusett Community College"],
    ".mwsu.edu": ["Midwestern State University"],
    ".mybrcc.edu": ["Baton Rouge Community College"],
    ".na.edu": ["North American University", "North American University"],
    ".najah.edu": ["An-Najah National University"],
    ".naropa.edu": ["The Naropa Institute"],
    ".national.edu": ["National American University"],
    ".nau.edu": ["Northern Arizona University"],
    ".nayanova.edu": ["Nayanova University", "Nayanova University"],
    ".naz.edu": ["Nazareth College"],
    ".nbc.edu": ["Nazarene Bible College"],
    ".ncat.edu": [
        "North Carolina Agricultural and Technical State University"
    ],
    ".ncbc.edu": ["North Central Bible College"],
    ".nccu.edu": ["North Carolina Central University"],
    ".ncf.edu": ["New College of Florida"],
    ".ncmich.edu": ["North Central Michigan College"],
    ".ncmissouri.edu": ["North Central Missouri College"],
    ".ncssm.edu": ["North Carolina School of Science and Mathematics"],
    ".mail.ncstatecollege.edu": ["North Central State College"],
    ".ncsu.edu": ["North Carolina State University"],
    ".nctc.edu": [
        "North Central Texas College",
        "North Central Texas College",
    ],
    ".ncu.edu": ["Northcentral University"],
    ".ncuindia.edu": ["The NorthCap University"],
    ".ncwc.edu": ["North Carolina Wesleyan College"],
    ".ncwu.edu": [
        "North China University of Water Resources and Electric Power",
        "华北水利水电大学",
    ],
    ".nd.edu": ["University of Notre Dame"],
    ".ndc.edu": ["Notre Dame College of Ohio"],
    ".ndm.edu": ["College of Notre Dame of Maryland"],
    ".ndnu.edu": ["Notre Dame de Namur University"],
    ".ndsu.edu": ["North Dakota State University"],
    ".ndu.edu": ["National Defense University"],
    ".ndus.edu": ["North Dakota State University"],
    ".nebraska.edu": ["University of Nebraska (System)"],
    ".nebrwesleyan.edu": ["Nebraska Wesleyan University"],
    ".nec.edu": ["New England College"],
    ".student.necc.edu": ["Northern Essex Community College"],
    ".nechristian.edu": ["Nebraska Christian College"],
    ".neit.edu": ["New England Institute of Technology"],
    ".neiu.edu": ["Northeastern Illinois University"],
    ".nescom.edu": ["New England School of Communications"],
    ".netc.edu": ["Northeastern Technical College"],
    ".neu.edu": ["Northeastern University at Boston"],
    ".neumann.edu": ["Neumann College"],
    ".neumont.edu": ["Neumont College of Computer Science"],
    ".unlv.nevada.edu": ["University of Nevada, Las Vegas"],
    ".nevadastate.edu": ["Nevada State University"],
    ".newarka.edu": ["Newark Academy"],
    ".newberry.edu": ["Newberry College"],
    ".newbury.edu": ["Newbury College"],
    ".newcollege.edu": ["New College of California"],
    ".newhaven.edu": ["University of New Haven"],
    ".newhorizonindia.edu": ["New Horizon College of Engineering"],
    ".newpaltz.edu": ["State University of New York at New Paltz"],
    ".newriver.edu": ["New River Community and Technical College"],
    ".newschool.edu": ["The New School"],
    ".newschoolarch.edu": ["Newschool of Architecture and Design"],
    ".nhcc.edu": [
        "North Hennepin Community College",
        "North Hennepin Community College",
    ],
    ".nhu.edu": ["National Hispanic University"],
    ".niagara.edu": ["Niagara University"],
    ".nichols.edu": ["Nichols College", "Nichols College"],
    ".nist.edu": ["NIST University"],
    ".nitt.edu": ["National Institute of Technology, Tiruchirappalli"],
    ".niu.edu": ["Northern Illinois University"],
    ".njcu.edu": ["New Jersey City University"],
    ".njit.edu": ["New Jersey Institute of Technology"],
    ".nku.edu": ["Northern Kentucky University"],
    ".nl.edu": ["National-Louis University"],
    ".nlu.edu": ["Northeast Louisiana University"],
    ".nmc.edu": ["Northwestern Michigan College"],
    ".nmhu.edu": ["New Mexico Highlands University"],
    ".nmims.edu": ["NMIMS", "Narsee Monjee Institute of Management Studies"],
    ".nmsu.edu": ["New Mexico State University"],
    ".nmt.edu": ["New Mexico Institute of Mining and Technology"],
    ".nmu.edu": ["Northern Michigan University"],
    ".nnu.edu": ["Northwest Nazarene University"],
    ".nobles.edu": ["Noble and Greenough School"],
    ".noctrl.edu": ["North Central College"],
    ".nodak.edu": [
        "University of North Dakota",
        "Dickinson State University",
        "Mayville State University",
        "Minot State University",
        "North Dakota State University",
        "Tri-College University",
        "Valley City State University",
    ],
    ".noirlab.edu": [
        "NOIRLab :  National Optical-Infrared Astronomy Research Laboratory"
    ],
    ".normandale.edu": ['"Normandale Community College"', '"Normandale"'],
    ".spartan.northampton.edu": ["Northampton Community College"],
    ".northcentralcollege.edu": ["North Central College"],
    ".northeast.edu": ["Northeast Community College"],
    ".northeastern.edu": [
        "Northeastern University, Boston, MA, USA",
        "University front-page URL: https://www.northeastern.edu/",
    ],
    ".northeaststate.edu": ["Northeast State Community College"],
    ".northern.edu": ["Northern State University"],
    ".northgatech.edu": ["North Georgia Technical College"],
    ".northland.edu": ["Northland College"],
    ".northpark.edu": ["North Park University"],
    ".northsouth.edu": ["North South University"],
    ".northwell.edu": [],
    ".northwestcareercollege.edu": ["northwestcareercollege"],
    ".northwestern.edu": ["Northwestern University"],
    ".northwestms.edu": ["Northwest Mississippi Community College"],
    ".northwestu.edu": ["Northwest University"],
    ".northwood.edu": [
        "Northwood University, Florida Campus",
        "Northwood University",
        "Northwood University, Texas Campus",
    ],
    ".northwoodtech.edu": ["Northwood Technical College"],
    ".norwich.edu": ["Norwich University"],
    ".nova.edu": ["Nova Southeastern University"],
    ".nps.edu": ["Naval Postgraduate School"],
    ".nscc.edu": [
        "Nashville State Community College",
        "https://www.nscc.edu",
        "https://www.nscc.edu/academics/degrees-certificates/computer-information-technology-a-a-s",
    ],
    ".nsu.edu": ["Norfolk State University"],
    ".nsula.edu": ["Northwestern State University of Louisiana"],
    ".nsuok.edu": ["Northeastern State University"],
    ".ntc.edu": ["Northcentral Technical College"],
    ".ntcc.edu": ["Northeast Texas Community College"],
    ".nu.edu": ["National University"],
    ".nur.edu": ["Universidad NUR"],
    ".nus.edu": ["National University of Singapore"],
    ".nvcc.edu": [
        "Northern Virginia Community College",
        "Northern Virginia Community College",
    ],
    ".nwc.edu": ["Northwestern College St. Paul"],
    ".nwcc.edu": ["Northwest Christian College"],
    ".nwciowa.edu": ["Northwestern College Iowa"],
    ".nwmissouri.edu": ["Northwest Missouri State University"],
    ".webmail.nwscc.edu": ["Northwest-Shoals Community College"],
    ".nwtc.edu": ["Northeast Wisconsin Technical College"],
    ".nyaa.edu": [
        "New York Academy of Art, Graduate School of Figurative Art"
    ],
    ".nyackcollege.edu": ["Nyack College"],
    ".nycc.edu": ["New York Chiropractic College"],
    ".nycpm.edu": ["New York College of Podiatric Medicine"],
    ".nyfa.edu": ["New York Film Academy"],
    ".nyit.edu": ["New York Institute of Technology"],
    ".nyls.edu": ["New York Law School"],
    ".nymc.edu": ["New York Medical College"],
    ".nysid.edu": ["New York School of Interior Design"],
    ".nyu.edu": ["New York University, Abu Dhabi", "New York University"],
    ".oak.edu": ["Oakland City University"],
    ".oakland.edu": ["Oakland University"],
    ".oaklandcc.edu": ["oaklandcc.txt"],
    ".oakton.edu": ["Oakton Community College"],
    ".oakwood.edu": ["Oakwood College"],
    ".oberlin.edu": ["Oberlin College"],
    ".obu.edu": ["Ouachita Baptist University"],
    ".oc.edu": ["Oklahoma Christian University"],
    ".ocac.edu": ["Oregon College of Arts and Crafts"],
    ".occ.edu": ["Ozark Christian College"],
    ".occc.edu": ["Oklahoma City Community College"],
    ".students.ocean.edu": ["Ocean County College"],
    ".odu.edu": ["Old Dominion University"],
    ".ogi.edu": ["Oregon Graduate Institute of Science and Technology"],
    ".oglethorpe.edu": ["Oglethorpe University"],
    ".ohio-state.edu": [
        "Ohio State University",
        "Ohio State University - Lima",
        "Ohio State University - Mansfield",
        "Ohio State University - Marion",
        "Ohio State University - Newark",
    ],
    ".ohio.edu": ["Ohio University"],
    ".ohiodominican.edu": ["Ohio Dominican University"],
    ".ohiou.edu": [
        "Ohio University",
        "Ohio University - Chillicothe",
        "Ohio University - Eastern",
        "Ohio University - Lancaster",
        "Ohio University - Southern",
        "Ohio University - Zanesville",
    ],
    ".ohlone.edu": ["Ohlone College"],
    ".ohsu.edu": ["Oregon Health Sciences University"],
    ".oit.edu": ["Oregon Institute of Technology"],
    ".okbu.edu": ["Oklahoma Baptist University"],
    ".okcu.edu": ["Oklahoma City University"],
    ".okstate.edu": [
        "Oklahoma State University",
        "Oklahoma State University Center for Health Sciences",
    ],
    ".okwu.edu": ["Oklahoma Wesleyan University"],
    ".olc.edu": ["Oglala Lakota College"],
    ".oldwestbury.edu": [
        "State University of New York College at Old Westbury"
    ],
    ".olemiss.edu": ["University of Mississippi"],
    ".olin.edu": ["Olin College of Engineering"],
    ".olivet.edu": ["Olivet Nazarene University"],
    ".olivetcollege.edu": ["Olivet College"],
    ".olivetuniversity.edu": ["Olivet University"],
    ".ollusa.edu": ["Our Lady of the Lake University"],
    ".olympic.edu": ["Olympic College"],
    ".omorecollege.edu": ["O'More College of Design"],
    ".omsk.edu": [
        "Omsk State Pedagogical University",
        "Omsk State Pedagogical University",
    ],
    ".oneonta.edu": ["State University of New York College at Oneonta"],
    ".onu.edu": ["Ohio Northern University"],
    ".opsu.edu": ["Oklahoma Panhandle State University"],
    ".oregoncoast.edu": ["Oregon Coast Community College "],
    ".oregonstate.edu": ["Oregon State University"],
    ".orst.edu": ["Oregon State University"],
    ".oru.edu": ["Oral Roberts University"],
    ".ossm.edu": ["Oklahoma School of Science and Mathematics"],
    ".osu.edu": ["The Ohio State University"],
    ".osumc.edu": ["Ohio state university - college of medicine"],
    ".oswego.edu": ["State University of New York at Oswego"],
    ".student.otis.edu": ["Otis College of Art and Design"],
    ".ottawa.edu": ["Ottawa University"],
    ".otterbein.edu": ["Otterbein College"],
    ".ou.edu": ["University of Oklahoma"],
    ".ouhsc.edu": ["University of Oklahoma Health Sciences Center"],
    ".ovc.edu": ["Ohio Valley College"],
    ".owu.edu": ["Ohio Wesleyan University"],
    ".oxy.edu": ["Occidental College"],
    ".ozarks.edu": ["University of the Ozarks"],
    ".pace.edu": ["Pace University"],
    ".u.pacific.edu": ["University of the Pacific"],
    ".pacific.edu": ["University of the Pacific"],
    ".pacifica.edu": ["Pacifica Graduate Institute"],
    ".pacificoaks.edu": ["Pacific Oaks College"],
    ".pacificu.edu": ["Pacific University"],
    ".paine.edu": ["Paine College"],
    ".palmbeachstate.edu": ["Palm Beach State College"],
    ".palmer.edu": [
        "Palmer College of Chiropractic West",
        "Palmer College of Chiropractic",
    ],
    ".dragons.parisjc.edu": ["Paris Junior College"],
    ".parisjc.edu": ["Paris Junior College"],
    ".park.edu": ["Park College"],
    ".parsons.edu": ["Parsons School of Design"],
    ".pasadena.edu": ["Pasadena City College"],
    ".pba.edu": ["Palm Beach Atlantic University"],
    ".pbc.edu": ["Piedmont Baptist College"],
    ".my.pbsc.edu": ["Palm Beach State College"],
    ".pc.edu": ["Pikeville College"],
    ".pcc.edu": ["Portland Community College"],
    ".students.pcci.edu": ["Pensacola Christian College"],
    ".pcom.edu": ["Philadelphia College of Osteopathic Medicine"],
    ".pct.edu": ["Pennsylvania College of Technology"],
    ".pdx.edu": ["Portland State University"],
    ".peace.edu": ["Peace College"],
    ".peachnet.edu": ["Fort Valley State College", "North Georgia College"],
    ".pencol.edu": ["Peninsula College"],
    ".pennwest.edu": ["Pennsylvania Western University"],
    ".students.pensacolastate.edu": ["Pensacola State College"],
    ".pepperdine.edu": ["Pepperdine University"],
    ".peralta.edu": ["Peralta Community College District"],
    ".peru.edu": ["Peru State College"],
    ".pes.edu": ["Pepole's Education Society University"],
    ".pfeiffer.edu": ["Pfeiffer University"],
    ".pfw.edu": ["Purdue University Fort Wayne"],
    ".students.pgcc.edu": ["Prince George's Community College (PGCC)"],
    ".philau.edu": ["Philadelphia University"],
    ".phillips.edu": ["Phillips University"],
    ".phoenix.edu": ["University of Phoenix"],
    ".phoenixcollege.edu": ["Phoenix College"],
    ".student.phsc.edu": ["Pasco-Hernando State College"],
    ".pict.edu": ["Pune Institute of Computer Technology, Pune"],
    ".piedmont.edu": ["Piedmont College"],
    ".piercecollege.edu": ["Pierce College"],
    ".pierpont.edu": ["Pierpont Community & Technical College"],
    ".pinecrest.edu": ["Pine Crest School"],
    ".pisd.edu": [
        "Plano Independent School District",
        "Plano Senior High School",
        "Plano West High School",
        "Plano East High School",
        ".group",
    ],
    ".pit.edu": ["Pennsylvania Institute of Technology"],
    ".pitt.edu": [
        "University of Pittsburgh",
        "University of Pittsburgh at Bradford",
        "University of Pittsburgh at Greensburg",
        "University of Pittsburgh at Johnstown",
    ],
    ".pittstate.edu": ["Pittsburg State University"],
    ".pitzer.edu": ["Pitzer College"],
    ".planwel.edu": ["Planwel University"],
    ".plattsburgh.edu": [
        "State University of New York College at Plattsburgh"
    ],
    ".plcc.edu": ["Portage Lakes Career Center", "PLCC"],
    ".plu.edu": ["Pacific Lutheran University"],
    ".plymouth.edu": ["Plymouth State College"],
    ".pmu.edu": [],
    ".pnca.edu": ["Pacific Northwest College of Art"],
    ".pnu.edu": ["punsan university"],
    ".pnw.edu": ["Purdue University Northwest"],
    ".pnwu.edu": ["Pacific Northwest University of Health Sciences"],
    ".pointloma.edu": ["Point Loma Nazarene University"],
    ".pointpark.edu": ["Point Park University"],
    ".my.polk.edu": ["Polk State College"],
    ".poly.edu": [
        "Polytechnic University",
        "Polytechnic University, Long Island Campus",
        "Polytechnic University, Westchester Graduate Center",
    ],
    ".polytechnique.edu": ["Ecole Polytechnique, Palaiseau, France."],
    ".email.porterchester.edu": ["YTI Career Institute"],
    ".portervillecollege.edu": ["Porterville College"],
    ".post.edu": ["Post University of Waterbury"],
    ".postech.edu": ["Pohang University Of Science And Technology"],
    ".student.potomac.edu": ["University of the Potomac"],
    ".potsdam.edu": ["State University of New York College at Potsdam"],
    ".ppu.edu": ["Palestine Polytechnic University"],
    ".pqc.edu": ["Paul Quinn College"],
    ".pratt.edu": ["Pratt Institute"],
    ".presby.edu": ["Presbyterian College"],
    ".prescott.edu": [
        "Prescott College",
        "Prescott College, Center for Indian Bilingual Teacher Education",
    ],
    ".preston.edu": ["Preston University"],
    ".prin.edu": ["Principia College"],
    ".princeton.edu": ["Princeton University"],
    ".principia.edu": ["The Principia"],
    ".providence.edu": ["Providence College"],
    ".psgtech.edu": ["PSG College Of Technology, Coimbatore"],
    ".pstcc.edu": ["Pellissippi State Community College"],
    ".pstu.edu": [
        "Приазовський державний технічний університет",
        "Pryazovskyi State Technical University",
    ],
    ".psu.edu": [
        "Pennsylvania State University",
        "Pennsylvania State University, campuses: Abington, Altoona, Erie, Harrisburg, Delaware County, Great Valley, Lehigh Valley, Schuylkill",
    ],
    ".ptc.edu": ["Piedmont Technical College"],
    ".puc.edu": ["Pacific Union College"],
    ".pucpr.edu": ["Pontificia Universidad Catolica de Puerto Rico"],
    ".pugetsound.edu": ["University of Puget Sound"],
    ".pupr.edu": ["Universidad Politecnica de Puerto Rico"],
    ".purchase.edu": ["State University of New York College at Purchase"],
    ".purdue.edu": ["Purdue University", "Purdue University Calumet"],
    ".student.purdueglobal.edu": ["Purdue Global University"],
    ".purdueglobal.edu": ["Purdue Global University"],
    ".pvamu.edu": ["Prairie View Agricultural and Mechanical University"],
    ".qc.edu": ["City University of New York, Queens College"],
    ".qcc.edu": ["Quinsigamond Community College "],
    ".qou.edu": ["Al-Quds Open University"],
    ".students.quantic.edu": ["Quantic School of Business and Technology"],
    ".queens.edu": ["Queens College"],
    ".quincy.edu": ["Quincy University"],
    ".quincycollege.edu": ["Quincy College"],
    ".quinnipiac.edu": ["Quinnipiac College"],
    ".qvius.edu": ["Quantum-Veritas International University"],
    ".ravens.racc.edu": ["Reading Area Community College"],
    ".radford.edu": ["Radford University"],
    ".raiuniversity.edu": ["Rai University", "Rai University Ahmedabad"],
    ".rajagiri.edu": ["Rajagiri College of Social Sciences"],
    ".ramapo.edu": ["Ramapo College of New Jersey"],
    ".raritanval.edu": ["Raritan Valley Community College"],
    ".rasmussen.edu": [
        "Rasmussen College, Florida Campuses",
        "Rasmussen College, Illinois Campuses",
        "Rasmussen College, Minnesota Campuses",
        "Rasmussen College, North Dakota Campuses",
        "Rasmussen College, Wisconsin Campuses",
    ],
    ".rc.edu": ["Rochester College"],
    ".mymail.rcbc.edu": ["Rowan College at Burlington County"],
    ".rcbc.edu": ["Rowan College at Burlington County"],
    ".rccd.edu": ["Riverside City College"],
    ".student.rcsj.edu": [
        "Rowan College of South Jersey",
        "Cumberland Campus:",
        "3322 College Drive, Vineland, NJ 08360",
        "www.rcsj.edu",
        "username@student.rcsj.edu",
    ],
    ".students.rcsj.edu": ["Rowan College of South Jersey"],
    ".rctc.edu": ["Rochester Community and Technical College"],
    ".redlands.edu": ["University of Redlands"],
    ".mycr.redwoods.edu": ["mycr.redwoods.edu"],
    ".reed.edu": ["Reed College"],
    ".cla.reformation.edu": ["Christian Liberty Academy"],
    ".regent-college.edu": ["Regent College"],
    ".regent.edu": ["Regent University"],
    ".regents.edu": ["Excelsior College"],
    ".regis.edu": ["Regis University"],
    ".reinhardt.edu": ["Reinhardt College"],
    ".rhodes.edu": ["Rhodes College"],
    ".ric.edu": ["Rhode Island College"],
    ".rice.edu": ["Rice University"],
    ".richland.edu": ["Richland Community College"],
    ".richmond.edu": ["University of Richmond"],
    ".rider.edu": ["Rider University"],
    ".ringling.edu": ["Ringling College of Art and Design"],
    ".ripon.edu": ["Ripon College"],
    ".risd.edu": ["Rhode Island School of Design"],
    ".rit.edu": [
        "Rochester Institute of Technology, Dubai",
        "Rochester Institute of Technology",
    ],
    ".riverland.edu": ["Riverland Community College"],
    ".rivier.edu": ["Rivier College"],
    ".rknec.edu": ["Ramdeobaba University, Nagpur, Maharashtra, India"],
    ".rmc.edu": ["Randolph-Macon College"],
    ".rmcad.edu": ["Rocky Mountain College of Art and Design"],
    ".rmcil.edu": ["Robert Morris College of Chicago"],
    ".roanoke.edu": ["Roanoke College"],
    ".robert-morris.edu": ["Robert Morris College"],
    ".robeson.edu": ["Robeson Community College"],
    ".rochester.edu": ["University of Rochester"],
    ".rockefeller.edu": ["The Rockefeller University"],
    ".rockford.edu": ["Rockford College"],
    ".rockhurst.edu": [
        "Research College of Nursing - Rockhurst University",
        "Rockhurst College",
    ],
    ".rocky.edu": ["Rocky Mountain College"],
    ".rollins.edu": ["Rollins College"],
    ".mail.roosevelt.edu": ["Roosevelt University"],
    ".roosevelt.edu": ["Roosevelt University"],
    ".raider.rose.edu": ["Rose State College"],
    ".rose-hulman.edu": ["Rose-Hulman Institute of Technology"],
    ".rosemont.edu": ["Rosemont College"],
    ".rossmed.edu": ["Ross University, School of Medicine"],
    ".rossu.edu": [
        "Ross University Caribbean School of Medicine",
        "Ross University Caribbean School of Veterinary Medicine",
    ],
    ".students.rowan.edu": ["Rowan University"],
    ".rowan.edu": ["Rowan University"],
    ".rpi.edu": ["Rensselaer Polytechnic Institute"],
    ".rtc.edu": ["Renton Technical College"],
    ".runet.edu": ["Radford University"],
    ".rush.edu": ["Rush University"],
    ".rustcollege.edu": ["Rust College"],
    ".rutgers.edu": ["Rutgers University"],
    ".rvu.edu": ["Rocky Vista University"],
    ".rwc.edu": ["Roberts Wesleyan College"],
    ".rwu.edu": ["Roger Williams University"],
    ".sabanciuniv.edu": ["Sabancı Üniversitesi", "Sabanci University"],
    ".sac.edu": ["Santa Ana College"],
    ".sacn.edu": ["St. Anthony College of Nursing"],
    ".sacredheart.edu": ["Sacred Heart University"],
    ".saddleback.edu": ["Saddleback College"],
    ".sae.edu": ["SAE Creative Media Institute"],
    ".saeinstitute.edu": ["SAE Athens"],
    ".sage.edu": ["The Sage Colleges"],
    ".sagrado.edu": ["Universidad del Sagrado Corazon"],
    ".sagu.edu": ["Southwestern Assemblies of God University"],
    ".saic.edu": ["School Of The Art Institute Of Chicago"],
    ".saintjoe.edu": ["St. Joseph's College"],
    ".saintleo.edu": ["St. Leo College"],
    ".saintmarys.edu": ["St. Mary's College Indiana"],
    ".saintmeinrad.edu": ["St. Meinrad College"],
    ".my.saintpaul.edu": ["Saint Paul College"],
    ".saintpeters.edu": ["Saint Peters University"],
    ".salem.edu": ["Salem College"],
    ".salemstate.edu": ["Salem State University", "Salem State University"],
    ".linares.salesianos.edu": ["Colegio Salesianos Linares"],
    ".triana.salesianos.edu": ["CDP Salesianos San Pedro"],
    ".salesianos.edu": ['"Colegio Salesianos"'],
    ".gulls.salisbury.edu": ["Salisbury University"],
    ".salve.edu": ["Salve Regina University"],
    ".samford.edu": ["Samford University"],
    ".samuelmerritt.edu": ["Samuel Merritt College"],
    ".student.sandburg.edu": ["Carl Sandburg College"],
    ".sandhills.edu": [
        "Sandhills Community College",
        "Sandhills Community College",
    ],
    ".sandiego.edu": ["San Diego"],
    ".stu.sanjac.edu": ["San Jacinto College"],
    ".sanjuanbautista.edu": ["San Juan Bautista School of Medicine"],
    ".sans.edu": ["SANS Technology Institute"],
    ".bearcubs.santarosa.edu": ["Santa Rosa Junior College"],
    ".santarosa.edu": ["Santa Rosa Junior College"],
    ".sarahlawrence.edu": ["Sarah Lawrence College"],
    ".sasin.edu": [
        "Sasin Graduate Institute of Business Administration of Chulalongkorn University"
    ],
    ".sau.edu": ["St. Ambrose University"],
    ".saumag.edu": ["Southern Arkansas University"],
    ".sautech.edu": ["Southern Arkansas University Tech"],
    ".saxion.edu": ["Saxion Universities "],
    ".sbc.edu": ["Sweet Briar College"],
    ".sbccd.edu": ["San Bernardino Community College District"],
    ".sbs.edu": ["Swiss Business School Zurich (SBS)"],
    ".students.sbts.edu": ["The Southern Baptist Theological Seminary"],
    ".sbu.edu": ["St. Bonaventure University"],
    ".sbuniv.edu": ["Southwest Baptist University"],
    ".sc.edu": [
        "University of South Carolina",
        "University of South Carolina - Aiken",
        "University of South Carolina - Beaufort",
        "University of South Carolina - Lancaster",
        "University of South Carolina - Salkehatchie",
        "University of South Carolina - Union",
    ],
    ".scad.edu": ["Savannah College of Art and Design"],
    ".scccd.edu": ["State Center Community College District"],
    ".scciowa.edu": ["Southeastern Iowa Community College"],
    ".sccollege.edu": ["Santiago Canyon College"],
    ".sccsc.edu": ["Spartanburg Community College"],
    ".scf.edu": ["State College of Florida, Bradenton, Florida"],
    ".schiller.edu": ["Schiller International University"],
    ".schillermadrid.edu": ["Schiller International University, Madrid"],
    ".apps.schoolcraft.edu": ["Schoolcraft College"],
    ".schoolofvisualarts.edu": ["School of the Visual Arts"],
    ".schreiner.edu": ["Schreiner College"],
    ".sci.edu": ["Benedictine University, Springfield College in Illinois"],
    ".sciarc.edu": ["Southern California Institute of Architecture"],
    ".science.edu": ["International Academy of Science"],
    ".scit.edu": ["https://www.scit.edu/"],
    ".sckans.edu": ["Southwestern College Kansas"],
    ".sco.edu": ["Southern College of Optometry"],
    ".scranton.edu": ["University of Scranton"],
    ".scripps.edu": ["The Scripps Research Institute"],
    ".scrippscol.edu": ["Scripps College"],
    ".scsu.edu": ["South Carolina State University"],
    ".my.sctcc.edu": ["Saint Cloud Technical Community College"],
    ".scu.edu": ["Santa Clara University"],
    ".scusd.edu": ["Sacramento Unified School District"],
    ".sdc.edu": ["Sojourner-Douglass College"],
    ".student.sdccd.edu": ["San Diego Community College District"],
    ".sdccd.edu": ["San Diego Miramar College"],
    ".students.sdi.edu": [
        "Sonoran Desert Institute ",
        "Website Validity Verification",
        "https://sdi.edu/",
        "SDI Course Verification",
        "https://sdi.edu/programs/associate-degree-uncrewed-technology/",
        "SDI Email Domain Verification: near bottom |Get in Touch with Sdi|",
        "https://sdi.edu/about-us/#general-policies",
    ],
    ".sdsmt.edu": ["South Dakota School of Mines and Technology"],
    ".sdstate.edu": ["South Dakota State University"],
    ".sdsu.edu": ["San Diego State University"],
    ".sduis.edu": ["San Diego University for Integrative Studies"],
    ".seattlecolleges.edu": [
        "North Seattle College",
        "Seattle Central College",
    ],
    ".seattleu.edu": ["Seattle University"],
    ".sebc.edu": ["Southeastern Bible College"],
    ".sek.edu": ["Universidad Internacional SEK, Quito"],
    ".selu.edu": ["Southeastern Louisiana University"],
    ".live.seminolestate.edu": [
        "Name: Seminole State College of Florida",
        "Address: 100 Weldon Boulevard, Sanford, FL 32773",
        "Website: www.seminolestate.edu",
    ],
    ".semo.edu": ["Southeast Missouri State University"],
    ".sepr.edu": ["SEPR L'école des métiers"],
    ".setonhill.edu": ["Seton Hill College"],
    ".sewanee.edu": ["University of the South"],
    ".cougars.sf.edu": ["University of Saint Francis"],
    ".sfai.edu": ["San Francisco Art Institute"],
    ".sfasu.edu": ["Stephen F. Austin State University"],
    ".sfbc.edu": ["South Florida Bible College &amp; Theological Seminary"],
    ".alumni.sfbu.edu": ["San Francisco Bay University"],
    ".student.sfbu.edu": ["San Francisco Bay University"],
    ".sfc.edu": ["St. Francis College, Fort Wayne"],
    ".sfcc.edu": ["Santa Fe Community College"],
    ".sfcm.edu": ["San Francisco Conservatory of Music"],
    ".sgu.edu": ["St. George's University", "St. George's University"],
    ".shawnee.edu": ["Shawnee State University"],
    ".shawneecc.edu": ["Shawnee Community College"],
    ".shawu.edu": ["Shaw University"],
    ".shawuniversity.edu": ["Shaw University"],
    ".shc.edu": ["Spring Hill College"],
    ".shcp.edu": ["Sacred Heart Cathedral Preparatory"],
    ".shepherd.edu": ["Shepherd College"],
    ".sherman.edu": ["Sherman College of Straight Chiropractic"],
    ".shimer.edu": ["Shimer College"],
    ".ship.edu": ["Shippensburg University of Pennsylvania"],
    ".shoreline.edu": ["Shoreline Community College"],
    ".shorter.edu": ["Shorter College"],
    ".shsu.edu": ["Sam Houston State University"],
    ".shu.edu": ["Seton Hall University"],
    ".siam.edu": ["Siam University"],
    ".siena.edu": ["Siena College"],
    ".sierranevada.edu": ["Sierra Nevada College"],
    ".simmons.edu": ["Simmons University"],
    ".simons-rock.edu": ["Bard College at Simon's Rock"],
    ".simpson.edu": ["Simpson College Iowa"],
    ".sims.edu": ["Symbiosis Institute of Management Studies, Pune"],
    ".sinhgad.edu": [
        "NBN Sinhgad Technical Institute Campus",
        "NBN Sinhgad Technical Institute Campus",
    ],
    ".mail.sipi.edu": ["Southwestern Indian Polytechnic Institute"],
    ".sit.edu": ["School for International Training"],
    ".siu.edu": ["Southern Illinois University at Carbondale"],
    ".siue.edu": ["Southern Illinois University at Edwardsville"],
    ".sjc.edu": ["St. Joseph College"],
    ".sjca.edu": ["St. John's College Maryland"],
    ".sjcc.edu": ["San Jose City College"],
    ".sjcd.edu": ["San Jacinto College", "San Jacinto College"],
    ".sjcme.edu": ["St. Joseph's College of Maine"],
    ".sjcny.edu": [
        "St. Joseph's College New York",
        "St. Joseph's College New York, Suffolk Campus",
    ],
    ".mail.sjctni.edu": ["St Joseph's College(Autonomous)"],
    ".sjfc.edu": ["St. John Fisher College"],
    ".sjrstate.edu": ["St. Johns River State College"],
    ".sju.edu": ["St. Joseph's University"],
    ".skema.edu": ["skema business school", "skema business school"],
    ".skidmore.edu": ["Skidmore College"],
    ".sl.edu": ["Silver Lake College"],
    ".slc.edu": ["Sarah Lawrence College"],
    ".slcc.edu": ["Salt Lake Community College"],
    ".slu.edu": ["St. Louis University"],
    ".smc.edu": ["Santa Monica College"],
    ".smccd.edu": ["San Mateo County Community College District"],
    ".smccme.edu": ["Southern Maine Community College"],
    ".smcm.edu": ["St. Mary's College of Maryland"],
    ".smcvt.edu": ["St. Michael's College"],
    ".smith.edu": ["Smith College"],
    ".smsu.edu": [
        "Southwest Missouri State University",
        "Southwest Missouri State University - West Plains",
    ],
    ".smu.edu": ["Southern Methodist University"],
    ".smumn.edu": ["St. Mary's University of Minnesota"],
    ".smwc.edu": ["St. Mary-of-the-Woods College"],
    ".snc.edu": ["St. Norbert College"],
    ".snhu.edu": ["Southern New Hampshire University"],
    ".students.snow.edu": ["Snow College", "Snow College"],
    ".snow.edu": ["Snow College"],
    ".snu.edu": ["Southern Nazarene University"],
    ".sofia.edu": ["Sofia University", "Sofia University"],
    ".soka.edu": ["Soka University of America"],
    ".my.solacc.edu": ["South Louisiana Community College", "SolaCC", "SLCC"],
    ".somaiya.edu": [
        "Institute name: K.J Somaiya Institute of Engineering and Information Technology, Sion",
        "Institute website: https://kjsieit.somaiya.edu/",
    ],
    ".sonoma.edu": ["Sonoma State University"],
    ".sou.edu": ["Southern Oregon University"],
    ".south.edu": ["South University", "southuniversity.edu"],
    ".health.southalabama.edu": ["University of South Alabama"],
    ".jagmail.southalabama.edu": ["University of South Alabama"],
    ".southalabama.edu": [
        "University of South Alabama",
        "University of South Alabama",
    ],
    ".southeast.edu": ["Southeast Community College"],
    ".southeasternbaptist.edu": ["Southeastern Baptist College"],
    ".southeastmn.edu": ["Minnesota State College Southeast"],
    ".southeasttech.edu": ["Southeast Technical Institute"],
    ".southern.edu": ["Southern Adventist University"],
    ".southernchristian.edu": ["The Southern Christian University"],
    ".southernct.edu": ["Southern Connecticut State University "],
    ".southflorida.edu": ["South Florida State College"],
    ".southhills.edu": ["South Hills School of Business and Technology"],
    ".southseattle.edu": ["South Seattle College"],
    ".southtexascollege.edu": ["South Texas College"],
    ".southwestern.edu": ["Southwestern University"],
    ".spalding.edu": ["Spalding University"],
    ".spc.edu": ["St. Peter's College"],
    ".live.spcollege.edu": ["St. Petersburg College"],
    ".spcollege.edu": ["St. Petersburg College"],
    ".spelman.edu": ["Spelman College"],
    ".spertus.edu": ["Spertus Institute of Jewish Studies"],
    ".spokane.edu": ["Spokane community college"],
    ".springfieldcollege.edu": ["Springfield College"],
    ".spsu.edu": ["Southern Polytechnic State Univerisity"],
    ".spu.edu": ["Seattle Pacific University"],
    ".spuvvn.edu": ["Sardar Patel University"],
    ".srttu.edu": ["Shaheed Rajaei Teacher Training University"],
    ".sru.edu": ["Slippery Rock University"],
    ".ssc.edu": [
        "South Suburban College",
        "ssc.edu",
        "https://www.ssc.edu/academics/programs-of-study/department-of-business-programs-computer-technology/computer-information-sciences/",
    ],
    ".sscok.edu": ["Seminole State College"],
    ".sseriga.edu": ["Stockholm School of Economics in Riga"],
    ".ssu.edu": ["Salisbury State University"],
    ".st-aug.edu": ["St. Augustine's College North Carolina"],
    ".stac.edu": ["St. Thomas Aquinas College"],
    ".stamford.edu": ["Stamford International University"],
    ".stanford.edu": ["Stanford University"],
    ".starkstate.edu": ["Stark State College"],
    ".student.stcc.edu": ["Springfield Technical Community College"],
    ".stcc.edu": ["Springfield Technical Community College"],
    ".stcl.edu": ["South Texas College of Law"],
    ".stcloudstate.edu": ["St. Cloud State University"],
    ".stedwards.edu": ["St. Edwards University"],
    ".stefan-university.edu": ["Stefan University"],
    ".stephens.edu": ["Stephens College"],
    ".sterling.edu": ["Sterling College"],
    ".stetson.edu": ["Stetson University"],
    ".stevens-tech.edu": ["Stevens Institute of Technology"],
    ".stevens.edu": ["Stevens Institute of Technology"],
    ".stfrancis.edu": [
        "St. Joseph College of Nursing",
        "University of St. Francis",
    ],
    ".stikom.edu": ["Institut Bisnis dan Informatika Stikom Surabaya"],
    ".stillman.edu": ["Stillman College"],
    ".stjohns.edu": ["St. John's University"],
    ".stjohnsem.edu": ["St. John's Seminary"],
    ".stkate.edu": ["College of St. Catherine"],
    ".stlawu.edu": ["St. Lawrence University"],
    ".stlcop.edu": ["St. Louis College of Pharmacy"],
    ".stmartin.edu": ["St. Martin's College"],
    ".stmartins.edu": ["Saint Martin's Institute of Higher Education"],
    ".stmarys-ca.edu": ["St. Mary's College of California"],
    ".stmarytx.edu": ["St. Mary's University of San Antonio"],
    ".stmatthews.edu": ["St. Matthews University"],
    ".stockton.edu": ["Richard Stockton College of New Jersey"],
    ".stolaf.edu": ["St. Olaf College"],
    ".students.stonehill.edu": ["Stonehill College"],
    ".stonehill.edu": ["Stonehill College"],
    ".stonybrook.edu": ["State University of New York, Stony Brook"],
    ".stonybrookmedicine.edu": ["Stony Brook University School of Medicine"],
    ".strathmore.edu": ["Strathmore University"],
    ".my.strayer.edu": ["Strayer University"],
    ".stritch.edu": ["Cardinal Stritch University"],
    ".stthom.edu": ["University of St. Thomas, Houston"],
    ".stthomas.edu": ["University of St. Thomas, St. Paul"],
    ".stu.edu": ["Arizona Western College"],
    ".stvincent.edu": ["St. Vincent College"],
    ".su.edu": ["Shenandoah University"],
    ".suagm.edu": [
        "Sistema Universitario Ana G. Méndez",
        "Universidad Metropolitana",
    ],
    ".suffolk.edu": ["Suffolk University"],
    ".sullivan.edu": ["Sullivan College"],
    ".sulross.edu": ["Sul Ross State University"],
    ".sum.sum.edu": ["SUM Bible College and Theological Seminary"],
    ".suno.edu": ["Southern University - New Orleans"],
    ".suny.edu": ["Fashion Institute of New York"],
    ".sunyacc.edu": [
        "SUNY Adirondack (Adirondack Community College)",
        "SUNY Adirondack (Adirondack Community College)",
    ],
    ".acad.sunybroome.edu": ["SUNY Broome Community College"],
    ".sunybroome.edu": ["SUNY Broome Community College"],
    ".sunycentral.edu": ["State University of New York (SUNY)"],
    ".sunyempire.edu": ["SUNY Empire State University"],
    ".sunyit.edu": [
        "State University of New York Institute of Technology at Utica/Rome"
    ],
    ".sunyjcc.edu": ["Jamestown Community College"],
    ".sunymaritime.edu": ["State University of New York Maritime College"],
    ".sunyocc.edu": ["Onondaga Community College"],
    ".sunyopt.edu": ["State University of New York College of Optometry"],
    ".sunyorange.edu": ["Orange County Community College"],
    ".sunypoly.edu": ["State University of New York Polytechnic Institute"],
    ".sunyrockland.edu": ["Rockland Community College - SUNY"],
    ".sunysb.edu": ["State University of New York at Stony Brook"],
    ".mail.sunysuffolk.edu": [
        "The University of New York Suffolk County Community College"
    ],
    ".sunysuffolk.edu": ["Suffolk County Community College"],
    ".my.sunyulster.edu": ["SUNY Ulster Community College", ".group"],
    ".sunywcc.edu": ["Westchester Community College"],
    ".student.surry.edu": ["Surry Community College"],
    ".suscc.edu": ["Southern Union State Community College"],
    ".susla.edu": ["Southern University - Shreveport"],
    ".susqu.edu": ["Susquehanna University"],
    ".sussex.edu": ["Sussex County Community College"],
    ".sust.edu": ["Shahjalal University of Science and Technology"],
    ".sustech.edu": ["Sudan University for Science and Technology"],
    ".suu.edu": ["Southern Utah University"],
    ".sva.edu": ["School of Visual Arts"],
    ".svc.edu": ["Southern Vermont College"],
    ".svsu.edu": ["Saginaw Valley State University"],
    ".svu.edu": ["Southern Virginia University"],
    ".sw.edu": [
        "Southwest Virginia Community College",
        "https://sw.edu/information-systems-technology-associate-degree/",
    ],
    ".swarthmore.edu": ["Swarthmore College"],
    ".swau.edu": ["Southwestern Adventist University"],
    ".swbts.edu": ["Southwestern Baptist Theological Seminary"],
    ".swc.edu": ["Southwestern College Santa Fe"],
    ".swcu.edu": ["Southwestern Christian University"],
    ".student.swic.edu": ["Southwestern Illinois College"],
    ".swic.edu": ["Southwestern Illinois College"],
    ".swlaw.edu": ["Southwestern University School of Law"],
    ".swmich.edu": ["Southwestern Michigan College"],
    ".swosu.edu": ["Southwestern Oklahoma State University"],
    ".swu.edu": ["Southern Wesleyan University"],
    ".sxu.edu": ["St. Xavier University"],
    ".syr.edu": ["Syracuse University"],
    ".t-bird.edu": [
        "American Graduate School of International Management",
        "Cloud County Community College",
    ],
    ".tabor.edu": ["Tabor College"],
    ".tacomacc.edu": ["Tacoma Community College"],
    ".taliesin.edu": ["Frank Lloyd Wright School of Architecture"],
    ".talladega.edu": ["Talladega College"],
    ".tambcd.edu": ["Baylor College of Dentistry"],
    ".tamiu.edu": ["Texas A&amp;M International University"],
    ".tamu.edu": ["Texas A&M University"],
    ".tamuc.edu": ["Texas A&M University - Commerce", "TAMUC"],
    ".tamucc.edu": ["Texas A&amp;M University - Corpus Christi"],
    ".tamuct.edu": ["Texas A&M University - Central Texas", "TAMUCT"],
    ".tamuk.edu": ["Texas A&amp;M University - Kingsville"],
    ".tamusa.edu": ["Texas A&M University-San Antonio"],
    ".tamut.edu": ["Texas A&amp;M University - Texarkana"],
    ".tarleton.edu": ["Tarleton State University"],
    ".taylor.edu": ["Taylor University"],
    ".tayloru.edu": [
        "Taylor University",
        "Taylor University, Fort Wayne Campus",
    ],
    ".tbc2day.edu": ["Trinity Bible College"],
    ".student.tce.edu": ["Thiagarajar College of Engineering"],
    ".tci.edu": ["The College of Insurance"],
    ".tcnj.edu": ["The College of New Jersey"],
    ".tctc.edu": ["Tri-County Technical College"],
    ".tcu.edu": ["Texas Christian University"],
    ".temple.edu": ["Temple University"],
    ".tesc.edu": ["Thomas A. Edison State College"],
    ".tesu.edu": ["Thomas Edison State University"],
    ".texascollege.edu": ["Texas College"],
    ".tfc.edu": ["Toccoa Falls College", "domain:  tfc.edu"],
    ".thapar.edu": [
        "Thapar Institute of Engineering & Technology (TIET), Patiala"
    ],
    ".the-bac.edu": ["Boston Architectural Center"],
    ".thechicagoschool.edu": ["The Chicago School of Professional Psychology"],
    ".thecoo.edu": ["University of Sioux Falls"],
    ".thiel.edu": ["Thiel College"],
    ".thomas.edu": ["Thomas College Maine"],
    ".thomasaquinas.edu": ["Thomas Aquinas College"],
    ".thomasmore.edu": ["Thomas More College"],
    ".thomasmorecollege.edu": ["Thomas More College of Liberal Arts"],
    ".thomasu.edu": ["Thomas University"],
    ".tiffin.edu": ["Tiffin University"],
    ".tilburguniversity.edu": ["Tilburg University", "Tilburg University"],
    ".tiu.edu": ["Trinity International University (Excel), Miami"],
    ".tjhsst.edu": ["Thomas Jefferson High School for Science and Technology"],
    ".tju.edu": ["Thomas Jefferson University"],
    ".tmc.edu": ["Baylor College of Medicine"],
    ".my.tms.edu": ["The Masters Seminary"],
    ".tnstate.edu": ["Tennessee State University"],
    ".tntech.edu": ["Tennessee Technological University"],
    ".tntemple.edu": ["Tennessee Temple University"],
    ".toccoafalls.edu": ["Toccoa Falls College"],
    ".cs.toronto.edu": ["University of Toronto (Computer Science Department)"],
    ".tougaloo.edu": ["Tougaloo College"],
    ".touro.edu": ["Touro College"],
    ".towson.edu": ["Towson University"],
    ".transy.edu": ["Transylvania University"],
    ".trcc.edu": ["Three Rivers College"],
    ".trevecca.edu": ["Trevecca Nazarene University"],
    ".tricountyallied.edu": ["Tricounty Allied School"],
    ".trident.edu": ["Trident University", "Trident University"],
    ".tridenttech.edu": ["Trident Technical College"],
    ".trin.edu": ["Trinity International University"],
    ".trincoll.edu": ["Trinity College Connecticut"],
    ".my.trine.edu": ["Trine University"],
    ".trine.edu": ["Trine University"],
    ".trinity.edu": ["Trinity University"],
    ".trinitycollege.edu": ["Trinity College of Florida"],
    ".triton.edu": ["Triton College"],
    ".trnty.edu": ["Trinity Christian College"],
    ".troy.edu": [
        "Troy University",
        "Troy University, Dothan",
        "Troy University, Montgomery",
        "Troy University, Phenix City",
        "Troy University, Troy",
    ],
    ".truman.edu": ["Truman State University"],
    ".tsmu.edu": ["Tbilisi State Medical University"],
    ".tstc.edu": ["Texas State Technical College"],
    ".tsu.edu": ["Texas Southern University"],
    ".ttic.edu": ["Toyota Technological Institute at Chicago"],
    ".ttu.edu": ["Texas Tech University"],
    ".ttuhsc.edu": ["Texas Tech University Health Science Center"],
    ".tu.edu": ["Touro University"],
    ".tufts.edu": ["Tufts University"],
    ".tui.edu": ["The Union Institute"],
    ".tulane.edu": ["The Tulane University of New Orleans"],
    ".tulsacc.edu": ["Tulsa Community College"],
    ".tulsatech.edu": ["Tulsa Technology Center", "Tulsa Tech", "TulsaTech"],
    ".turing.edu": ["Turing School of Software and Design"],
    ".tusculum.edu": ["Tusculum College"],
    ".tuskegee.edu": ["Tuskegee University"],
    ".tvcc.edu": ["Trinity Valley Community College"],
    ".twcnet.edu": ["Tennessee Wesleyan College"],
    ".twsu.edu": ["Wichita State University"],
    ".twu.edu": ["Texas Woman's University"],
    ".txchiro.edu": ["Texas Chiropractic College"],
    ".txstate.edu": ["Texas State University"],
    ".txwes.edu": ["Texas Wesleyan University"],
    ".txwesleyan.edu": ["Texas Wesleyan University"],
    ".crimson.ua.edu": ["University of Alabama"],
    ".ua.edu": ["University of Alabama - Tuscaloosa"],
    ".uaa.edu": ["     Antillean Adventist University"],
    ".uab.edu": ["University of Alabama - Birmingham"],
    ".uaf.edu": ["University of Alaska - Fairbanks"],
    ".uafs.edu": [
        "University of Arkansas Fort Smith",
        "University of Arkansas Fort Smith",
    ],
    ".student.uagc.edu": ["University of Arizona Global Campus "],
    ".uagrantham.edu": [
        "University of Arkansas Grantham",
        "University of Arkansas Grantham",
    ],
    ".uah.edu": ["University of Alabama - Huntsville"],
    ".uaht.edu": [
        "Add University of Arkansas Hope-Texarkana",
        "Brittni.hardie@uaht.edu",
        "https://uaht.edu/staff/campus-directory.php",
    ],
    ".uakron.edu": ["University of Akron"],
    ".ualr.edu": ["University of Arkansas at Little Rock"],
    ".uamont.edu": ["University of Arkansas at Monticello"],
    ".uams.edu": ["University of Arkansas for Medical Sciences"],
    ".uandresbello.edu": ["Universidad Andres Bello", "UNAB"],
    ".uap-bd.edu": ["University of Asia Pacific, Dhanmondi"],
    ".uapar.edu": ["Universidad Adventista del Plata"],
    ".uapb.edu": ["University of Arkansas at Pine Bluff"],
    ".uaptc.edu": ["University of Arkansas – Pulaski Technical College"],
    ".uark.edu": ["University of Arkansas at Fayetteville"],
    ".uarts.edu": ["University of the Arts"],
    ".uasys.edu": ["University of Arkansas (System)"],
    ".uat.edu": ["University of Advancing Technology (UAT)"],
    ".ub.edu": ["Universitat de Barcelona"],
    ".ubaguio.edu": ["University of Baguio"],
    ".ubalt.edu": ["University of Baltimore"],
    ".ubi.edu": ["United Business Institute"],
    ".uc.edu": ["University of Cincinnati"],
    ".uca.edu": ["University of Central Arkansas"],
    ".ucam.edu": ["Universidad Católica San Antonio"],
    ".ucan.edu": ["Universidade Católica de Angola"],
    ".ucc.edu": ["Union College of Union County, NJ"],
    ".uccaribe.edu": ["Universidad Central del Caribe"],
    ".uccs.edu": [
        "Beth-El College of Nursing and Health Sciences",
        "University of Colorado at Colorado Springs",
    ],
    ".ucdavis.edu": ["University of California, Davis"],
    ".ucdenver.edu": [
        "University of Colorado Denver",
        "University of Colorado Denver",
    ],
    ".uceou.edu": ['"University College Of Engineering, Osmania University" '],
    ".ucf.edu": ["University of Central Florida"],
    ".uchastings.edu": ["University of California, Hastings College of Law"],
    ".uchc.edu": ["University of Connecticut Health Center"],
    ".uchicago.uchicago.edu": ["University of Chicago"],
    ".uchicago.edu": ["The University of Chicago"],
    ".uci.edu": ["University of California, Irvine"],
    ".ucjc.edu": [
        "Universidad Camilo Jose Cela",
        "Camilo Jose Cela University",
    ],
    ".ucla.edu": ["University of California, Los Angeles"],
    ".ucmerced.edu": ["University of California, Merced"],
    ".ucmo.edu": ["University of Central Missouri"],
    ".uco.edu": ["University of Central Oklahoma"],
    ".ucollege.edu": ["Union College Nebraska"],
    ".uconn.edu": [
        "University of Connecticut",
        "University of Connecticut at Avery Point",
        "University of Connecticut at Hartford",
        "University of Connecticut at Stamford",
        "University of Connecticut at Waterbury",
    ],
    ".ucop.edu": ["University of California, Oakland"],
    ".ucr.edu": ["University of California, Riverside"],
    ".ucsb.edu": ["University of California, Santa Barbara"],
    ".ucsc.edu": ["University of California Santa Cruz"],
    ".ucsd.edu": [
        "University of California, San Diego",
        "University of California San Diego",
    ],
    ".ucsf.edu": ["University of California, San Francisco"],
    ".uctm.edu": ["University of Chemical Technology and Metallurgy"],
    ".ucumberlands.edu": ["University of the Cumberlands"],
    ".udallas.edu": ["University of Dallas"],
    ".udayton.edu": ["University of Dayton"],
    ".udc.edu": ["University Of The District Of Columbia", "UDC"],
    ".udel.edu": ["University of Delaware"],
    ".udem.edu": ["Universidad de Monterrey"],
    ".udg.edu": ["Universitat de Girona", "University of Girona"],
    ".udmercy.edu": ["University of Detroit Mercy"],
    ".udo.edu": ["Technische Universität Dortmund", "TU Dortmund University"],
    ".students.ufairfax.edu": ["University of Fairfax", "ufairfax.edu"],
    ".ufairfax.edu": ["University of Fairfax"],
    ".ufl.edu": ["University of Florida"],
    ".ufm.edu": ["Universidad Francisco Marroquin"],
    ".uft.edu": ["Universidad Finis Terrae", "Finis Terrae University"],
    ".uga.edu": ["University of Georgia"],
    ".cougarnet.uh.edu": ["University of Houston"],
    ".uh.edu": ["University of Houston"],
    ".uhcl.edu": ["University of Houston Clear Lake"],
    ".uhv.edu": ["University of Houston - Victoria"],
    ".uib.edu": ["Batam International University"],
    ".uic.edu": ["University of Illinois at Chicago"],
    ".uidaho.edu": ["University of Idaho"],
    ".uillinois.edu": ["University of Illinois"],
    ".uindy.edu": ["University of Indianapolis"],
    ".uiowa.edu": ["University of Iowa"],
    ".uis.edu": ["University of Illinois at Springfield"],
    ".students.uit.edu": ["Usman Institute of Technology"],
    ".uiu.edu": ["Upper Iowa University"],
    ".uiuc.edu": ["University of Illinois at Urbana-Champaign"],
    ".uiw.edu": ["University of the Incarnate World"],
    ".student.uiwtx.edu": ["University of the Incarnate Word"],
    ".uj.edu": ["University of Jamestown"],
    ".ujmv.edu": ["Universidad José Maria Vargas"],
    ".uksw.edu": ["Universitas Kristen Satya Wacana"],
    ".uky.edu": ["University of Kentucky"],
    ".ulm.edu": ["University of Louisiana at Monroe"],
    ".umaine.edu": ["University of Maine, Orono"],
    ".umary.edu": ["University of Mary"],
    ".som.umaryland.edu": ["University of Maryland School of Medicine"],
    ".umaryland.edu": ["University of Maryland"],
    ".umass.edu": ["University of Massachusetts (Amherst)"],
    ".umassd.edu": ["University of Massachusetts (Dartmouth)"],
    ".umassmed.edu": ["UMass Chan Medical School"],
    ".umb.edu": ["University of Massachusetts (Boston)"],
    ".umbc.edu": ["University of Maryland, Baltimore County"],
    ".umc.edu": ["University of Mississippi Medical Center"],
    ".umd.edu": ["University of Maryland at College Park"],
    ".umdnj.edu": ["University of Medicine and Dentistry of New Jersey"],
    ".umes.edu": ["University of Maryland Eastern Shore"],
    ".umgc.edu": ["University of Maryland Global Campus"],
    ".umhb.edu": ["University of Mary Hardin-Baylor"],
    ".umich.edu": [
        "University of Michigan - Ann Arbor",
        "University of Michigan - Dearborn",
        "University of Michigan - Flint",
    ],
    ".umkc.edu": ["University of Missouri - Kansas City"],
    ".uml.edu": ["University of Massachusetts Lowell"],
    ".umm.edu": ["University of Maryland Medicine"],
    ".umn.edu": ["University of Minnesota"],
    ".umo.edu": ["University of Mount Olive"],
    ".umobile.edu": ["University of Mobile"],
    ".ums.edu": ["University of Maryland (System)"],
    ".umsl.edu": ["University of Missouri - Saint Louis"],
    ".est.umss.edu": ["Universidad Mayor de San Simón"],
    ".umsystem.edu": ["University of Missouri"],
    ".umt.edu": ["University of Montana"],
    ".umtweb.edu": ["University of Management &amp; Technology"],
    ".mail.umw.edu": ["University of Mary Washington"],
    ".umw.edu": ["University of Mary Washington"],
    ".umwestern.edu": ["University of Montana Western"],
    ".una.edu": ["University of North Alabama"],
    ".unai.edu": ["Universitas Advent Indonesia"],
    ".ingenieria.unam.edu": ["Universidad Nacional Autónoma de México"],
    ".unc.edu": ["University of North Carolina at Chapel Hill"],
    ".unca.edu": ["University of North Carolina at Asheville"],
    ".uncc.edu": ["University of North Carolina at Charlotte"],
    ".uncfsu.edu": ["Fayetteville State University"],
    ".uncg.edu": ["University of North Carolina at Greensboro"],
    ".unco.edu": ["University of Northern Colorado", "https://www.unco.edu/"],
    ".uncp.edu": ["University of North Carolina at Pembroke"],
    ".uncw.edu": ["University of North Carolina Wilmington"],
    ".und.edu": ["University of North Dakota"],
    ".unem.edu": ["Universidad Empresarial"],
    ".unf.edu": ["University of North Florida"],
    ".ung.edu": ["University of North Georgia "],
    ".unh.edu": [
        "University of New Hampshire",
        "University of New Hampshire - Manchester",
    ],
    ".student.uni-pr.edu": ["University of Prishtina"],
    ".studentet.uni-pr.edu": [
        'Universiteti i Prishtinës "Hasan Prishtina"',
        'University of Pristina "Hasan Prishtina"',
    ],
    ".uni-pr.edu": ["University of Prishtina"],
    ".uni.edu": ["University of Northern Iowa"],
    ".uniacc.edu": [
        "Universidad UNIACC, Santiago de Chile",
        "UNIACC University, Santiago of Chile",
    ],
    ".uniben.edu": ["University of Benin"],
    ".unicah.edu": ["Universidad Católica de Honduras"],
    ".uniminuto.edu": ["UNIMINUTO"],
    ".union.edu": ["Union College"],
    ".unionky.edu": ["Union College Kentucky"],
    ".uniq.edu": ["Université Quisqueya"],
    ".unity.edu": ["Unity College"],
    ".univalle.edu": ["University of the Valley, Bolivia"],
    ".univdhaka.edu": ["University of Dhaka"],
    ".universityofcalifornia.edu": ["University of California System"],
    ".univnorthco.edu": ["University of Northern Colorado"],
    ".unk.edu": ["University of Nebraska - Kearney"],
    ".unl.edu": ["University of Nebraska - Lincoln"],
    ".unlv.edu": ["University of Nevada - Las Vegas"],
    ".unm.edu": ["University of New Mexico"],
    ".unmc.edu": ["University of Nebraska Medical Center"],
    ".uno.edu": ["University of New Orleans"],
    ".unomaha.edu": ["University of Nebraska - Omaha"],
    ".unr.edu": ["University of Nevada - Reno"],
    ".unt.edu": [
        "Texas College of Osteopathic Medicine",
        "University of North Texas",
        "University of North Texas Health Science Center at Fort Worth",
    ],
    ".my.untdallas.edu": [
        "University of North Texas",
        "University of North Texas",
    ],
    ".unthsc.edu": ["University of North Texas Health Science Center"],
    ".biolac.unu.edu": [
        "UNU Biotechnology Programme for Latin America and the Caribbean, Caracas, VENEZUELA"
    ],
    ".cpr.unu.edu": ["UNU Centre for Policy Research, New York, U.S.A."],
    ".cris.unu.edu": [
        "UNU Institute on Comparative Regional Integration Studies, Brugge, BELGIUM"
    ],
    ".egov.unu.edu": [
        "UNU Operating Unit on Policy-driven Electronic Governance, Guimarães, PORTUGAL"
    ],
    ".ehs.unu.edu": [
        "UNU Institute for Environment and Human Security, Bonn, GERMANY"
    ],
    ".flores.unu.edu": [
        "UNU Institute for Integrated Management of Material Fluxes and of Resources, Dresden, GERMANY"
    ],
    ".ias.unu.edu": [
        "UNU Institute for the Advanced Study of Sustainability, Tokyo, JAPAN"
    ],
    ".iigh.unu.edu": [
        "UNU International Institute for Global Health, Kuala Lumpur, MALAYSIA"
    ],
    ".inra.unu.edu": [
        "UNU Institute for Natural Resources in Africa, Accra, GHANA"
    ],
    ".inweh.unu.edu": [
        "UNU Institute for Water, Environment and Health, Richmond Hill, Ontario, CANADA"
    ],
    ".macau.unu.edu": ["UNU Institute in Macau, Macau S.A.R., CHINA"],
    ".merit.unu.edu": [
        "UNU Maastricht Economic and Social Research Institute on Innovation and Technology, Maastricht, THE NETHERLANDS"
    ],
    ".vie.unu.edu": ["UNU Vice-Rectorate in Europe, Bonn, GERMANY"],
    ".wider.unu.edu": [
        "UNU World Institute for Development Economics Research, Helsinki, FINLAND"
    ],
    ".unva.edu": ["University of Northern Virginia"],
    ".unw.edu": ["University of Northern Washington"],
    ".unwsp.edu": ["University of Northwestern St. Paul"],
    ".uoc.edu": ["Universitat Oberta de Catalunya"],
    ".uofa.edu": ["University of Alanta"],
    ".uofk.edu": ["University of Khartoum"],
    ".uofn.edu": ["University of the Nations"],
    ".uofs.edu": ["University of Scranton"],
    ".uog.edu": ["University of Guam"],
    ".live.uona.edu": ["University of North America"],
    ".uopeople.edu": ["University of the People"],
    ".uoregon.edu": ["University of Oregon"],
    ".up.edu": ["University of Portland"],
    ".upal.edu": ["Universidad Privada Abierta Latinoamericana"],
    ".upb.edu": ["Universidad Privada Boliviana"],
    ".upc.edu": [
        "Universidad Politécnica de Cataluna",
        "Universitat Politècnica de Catalunya",
    ],
    ".upenn.edu": ["University of Pennsylvania"],
    ".upf.edu": ["Universitat Pompeu Fabra"],
    ".upi.edu": ["Universitas Pendidikan Indonesia"],
    ".upike.edu": ["University Of Pikeville"],
    ".upr.edu": [
        "Universidad de Puerto Rico, Cayey",
        "Universidad de Puerto Rico, Ciencias Medicas",
        "Universidad de Puerto Rico, Ponce",
    ],
    ".upra.edu": ["Universidad de Puerto Rico, Arecibo"],
    ".uprag.edu": ["Universidad de Puerto Rico, Aguadilla"],
    ".uprb.edu": ["Universidad de Puerto Rico, Bayamon"],
    ".uprm.edu": ["Universidad de Puerto Rico, Mayaguez"],
    ".uprrp.edu": ["Universidad de Puerto Rico, Rio Pedras"],
    ".uprutuado.edu": ["Universidad de Puerto Rico, Utuado"],
    ".ups.edu": ["University of Puget Sound"],
    ".upstate.edu": [
        "State University of New York Upstate Medical University "
    ],
    ".urbana.edu": ["Urbana University"],
    ".urbaniana.edu": ["Pontifcia Università Urbaniana"],
    ".urbe.edu": ["Universidad Dr. Rafael Belloso Chacín"],
    ".urgrgcc.edu": ["University of Rio Grande"],
    ".uri.edu": ["University of Rhode Island"],
    ".urich.edu": ["University of Richmond"],
    ".iqs-blanquerna.url.edu": [
        "Instituto Químico de Sarriá (Universidad Ramon Llull)"
    ],
    ".iqs.url.edu": ["Institus Químic de Sarrià"],
    ".salle.url.edu": ["La Salle Campus Barcelona - Universitat Ramon Llull"],
    ".ursinus.edu": ["Ursinus College"],
    ".ursuline.edu": ["Ursuline College"],
    ".uru.edu": ["Universidad Rafael Urdaneta"],
    ".usaim.edu": [
        "University of Seychelles - American Institute of Medicine"
    ],
    ".usao.edu": ["University of Science and Arts of Oklahoma"],
    ".usap.edu": ["Universidad de San Pedro Sula"],
    ".usc.edu": ["University of Southern California"],
    ".usca.edu": ["University of South Carolina Aiken "],
    ".uscga.edu": ["United States Coast Guard Academy"],
    ".uscsumter.edu": ["University of South Carolina - Sumter"],
    ".uscupstate.edu": ["University of South Carolina Upstate"],
    ".usd.edu": ["University of South Dakota"],
    ".usf.edu": ["University of South Florida"],
    ".usfca.edu": ["University of San Francisco"],
    ".usi.edu": ["University of Southern Indiana"],
    ".usip.edu": ["University of the Sciences in Philadelphia"],
    ".usiu.edu": ["United States International University"],
    ".usm.edu": ["University of Southern Mississippi"],
    ".usma.edu": ["United States Military Academy"],
    ".usmma.edu": ["United States Merchant Marine Academy"],
    ".usna.edu": ["United States Naval Academy"],
    ".usouthal.edu": ["University of South Alabama"],
    ".ussa.edu": ["United States Sports Academy"],
    ".ust.edu": ["University of Science and Technology Sana'a"],
    ".usu.edu": ["Utah State University"],
    ".usuniversity.edu": ["United States University"],
    ".usv.edu": ["University of Silicon Valley"],
    ".usw.edu": ["University of the Southwest"],
    ".ut.edu": ["University Of Tampa"],
    ".uta.edu": ["University of Texas at Arlington"],
    ".utah.edu": ["University of Utah"],
    ".utahtech.edu": ["Utah Tech University"],
    ".utampa.edu": ["University of Tampa"],
    ".utb.edu": ["University of Texas at Brownsville"],
    ".utc.edu": ["University of Tennessee - Chattanooga"],
    ".utdallas.edu": ["University of Texas at Dallas"],
    ".utdt.edu": ["Universidad Torcuato di Tella"],
    ".utep.edu": ["University of Texas at El Paso"],
    ".utepsa.edu": [
        "Universidad Tecnologica Privada de Santa Cruz (UTEPSA)",
        "Private Technological University of Santa Cruz (UTEPSA)",
    ],
    ".utesa.edu": [
        "Universidad Tecnológica de Santiago",
        "Universidad Tecnológica de Santiago",
    ],
    ".utexas.edu": ["University of Texas at Austin"],
    ".uthct.edu": ["University of Texas Health Center at Tyler"],
    ".uthouston.edu": ["University of Texas Health Center at Houston"],
    ".uthsc.edu": [
        "The University of Tennessee Health Science Center (UTHSC)",
        "The University of Tennessee Health Science Center (UTHSC)",
    ],
    ".uthscsa.edu": [
        "University of Texas Health Science Center at San Antonio"
    ],
    ".utk.edu": ["University of Tennessee - Knoxville"],
    ".utm.edu": ["University of Tennessee - Martin"],
    ".utmb.edu": ["University of Texas Medical Branch Galveston"],
    ".utoledo.edu": ["University of Toledo"],
    ".utpb.edu": ["University of Texas of the Permian Basin"],
    ".utrgv.edu": ["University of Texas at Rio Grande Valley"],
    ".utsa.edu": ["University of Texas at San Antonio"],
    ".utsi.edu": ["University of Tennessee Space Institute"],
    ".utsouthwestern.edu": [
        "University of Texas Southwestern Medical Center at Dallas"
    ],
    ".utsystem.edu": ["University of Texas"],
    ".uttyl.edu": ["University of Texas at Tyler"],
    ".patriots.uttyler.edu": ["The University of Texas at Tyler"],
    ".utulsa.edu": ["University of Tulsa"],
    ".uu.edu": ["Union University"],
    ".uvi.edu": ["University of the Virgin Islands"],
    ".uvm.edu": ["University of Vermont"],
    ".uvmnet.edu": [
        "Universidad del Valle de México",
        "Universidad del Valle de México",
    ],
    ".uvs.edu": ["Anton de Kom University"],
    ".uvu.edu": ["Utah Valley University"],
    ".uw.edu": ["University of Washington"],
    ".uwa.edu": ["University of West Alabama"],
    ".uwec.edu": ["University of Wisconsin - Eau Claire"],
    ".uwf.edu": ["University of West Florida"],
    ".uwgb.edu": ["University of Wisconsin - Green Bay"],
    ".mycavehill.uwi.edu": ["University of the West Indies at Cave Hill"],
    ".uwi.edu": ["University of The West Indies, Monas"],
    ".uwla.edu": ["University of West Los Angeles"],
    ".uwlax.edu": ["University of Wisconsin - La Crosse"],
    ".uwm.edu": ["University of Wisconsin - Milwaukee"],
    ".uwosh.edu": ["University of Wisconsin - Oshkosh"],
    ".uwp.edu": ["University of Wisconsin - Parkside"],
    ".uwplatt.edu": ["University of Wisconsin - Platteville"],
    ".uwrf.edu": ["University of Wisconsin - River Falls"],
    ".uwsp.edu": ["University of Wisconsin - Stevens Point"],
    ".uwstout.edu": ["University of Wisconsin - Stout"],
    ".uwsuper.edu": ["University of Wisconsin - Superior"],
    ".uww.edu": ["University of Wisconsin - Whitewater"],
    ".uwyo.edu": ["University of Wyoming"],
    ".valdosta.edu": ["Valdosta State University"],
    ".valenciacollege.edu": ["Valencia College"],
    ".vallauri.edu": ["IIS G. VALLAURI"],
    ".valpo.edu": ["Valparaiso University"],
    ".vanderbilt.edu": ["Vanderbilt University"],
    ".vandercook.edu": ["VanderCook College of Music"],
    ".vanguard.edu": ["Vanguard University of Southern California"],
    ".vassar.edu": ["Vassar College"],
    ".vc.edu": ["Virginia College"],
    ".my.vcccd.edu": ["Moorpark College ", "Moorpark College"],
    ".vccs.edu": ["Virginia Community Colleges"],
    ".vcu.edu": ["Virginia Commonwealth University"],
    ".vermontlaw.edu": ["Vermont Law School"],
    ".vermontstate.edu": ["Vermont State University"],
    ".vesalius.edu": ["Vesalius College"],
    ".villa.edu": ["Villa Maria College"],
    ".villanova.edu": ["Villanova University"],
    ".villanueva.edu": ["Centro Universitario Villanueva"],
    ".myvu.vinu.edu": ["Vincennes University"],
    ".vips.edu": ["Vivekananda Institute of Professional Studies"],
    ".virginia.edu": [
        "University of Virginia",
        "University of Virginia, College at Wise",
    ],
    ".vit.edu": ["Vishwakarma Institute of Technology, Pune"],
    ".viterbo.edu": ["Viterbo College"],
    ".viu.edu": ["Virginia International University"],
    ".vmi.edu": ["Virginia Military Institute"],
    ".volstate.edu": ["Volunteer State Community College"],
    ".voorhees.edu": ["Voorhees College"],
    ".vsc.edu": ["Vermont State Colleges"],
    ".vsu.edu": ["Virginia State University"],
    ".vt.edu": [
        "Virginia Polytechnic Institute and State University (Virginia Tech)"
    ],
    ".vtu.edu": ["Free University (Virginia Theological University)"],
    ".vuu.edu": ["Virginia Union University"],
    ".vwu.edu": ["Virginia Wesleyan University"],
    ".wab.edu": [
        "北京京西学校",
        "Western Academy of Beijing",
        "domain: wab.edu",
    ],
    ".wabash.edu": ["Wabash College"],
    ".wagner.edu": ["Wagner College"],
    ".waketech.edu": [
        "Wake Technical Community College",
        "Wake Tech Community College",
        "Wake Tech",
    ],
    ".waldenu.edu": ["Walden University"],
    ".wallawalla.edu": ["Walla Walla University"],
    ".walsh.edu": ["Walsh University"],
    ".warnborough.edu": ["Warnborough University", "Warnborough University"],
    ".warner.edu": ["Warner Southern College"],
    ".warnerpacific.edu": ["Warner Pacific College"],
    ".warren-wilson.edu": ["Warren Wilson College"],
    ".wartburg.edu": ["Wartburg College"],
    ".wasatch.edu": ["Wasatch High School"],
    ".washburn.edu": ["Washburn University"],
    ".washcoll.edu": ["Washington College"],
    ".washington.edu": [
        "University of Washington",
        "University of Washington, Tacoma",
    ],
    ".student.waubonsee.edu": ["Waubonsee Community College"],
    ".wayne.edu": ["Wayne State University, Detroit"],
    ".waynecc.edu": ["Wayne Community College"],
    ".waynesburg.edu": ["Waynesburg College"],
    ".wbcoll.edu": ["Williams Baptist College"],
    ".wbu.edu": ["Wayland Baptist University"],
    ".wcstudents.wc.edu": ["Weatherford College"],
    ".wccnet.edu": ["Washtenaw Community College"],
    ".student.wcjc.edu": ["Wharton County Junior College"],
    ".wcmo.edu": ["Westminster College Fulton"],
    ".wcs.edu": ["Williamson County School District", ".group"],
    ".wcslc.edu": ["Westminster College of Salt Lake City"],
    ".wcsu.edu": ["Western Connecticut State University"],
    ".my.wctc.edu": ["Waukesha County Technical College"],
    ".wctc.edu": ["Waukesha County Technical College"],
    ".wcu.edu": ["Western Carolina University"],
    ".wcupa.edu": ["West Chester University of Pennsylvania"],
    ".webber.edu": ["Webber College"],
    ".weber.edu": ["Weber State University"],
    ".webster.edu": ["Webster University North Florida", "Webster University"],
    ".issaquah.wednet.edu": ["Issaquah High School"],
    ".wells.edu": ["Wells College"],
    ".wesley.edu": ["Wesley College"],
    ".wesleyan-college.edu": ["Wesleyan College"],
    ".wesleyan.edu": ["Wesleyan University"],
    ".westcliff.edu": ["Westcliff University", "King's College"],
    ".u.westcoastuniversity.edu": ["West Coast University"],
    ".western.edu": ["Western State College"],
    ".westernbible.edu": ["Western Bible College"],
    ".westerntc.edu": [
        "Western Technical College",
        "formerly Western Wisconsin Technical College",
    ],
    ".westernu.edu": [
        "College of Osteopathic Medicine of the Pacific (Western University of Health Sciences)"
    ],
    ".westga.edu": ["State University of West Georgia"],
    ".student.westgatech.edu": ["West Georgia Technical College"],
    ".westminster.edu": ["Westminster College New Wilmington"],
    ".westminsteru.edu": ["Westminster University"],
    ".westmont.edu": ["Westmont College"],
    ".my.westmoreland.edu": [
        "Westmoreland County Community College",
        "145 Pavilion Lane, Youngwood, PA 15697",
        "www.westmoreland.edu",
    ],
    ".westpoint.edu": ["United States Military Academy (West Point)"],
    ".westvalley.edu": ["West Valley College"],
    ".westwood.edu": ["Westwood College"],
    ".wfu.edu": ["Wake Forest University"],
    ".wgu.edu": ["Western Governors University"],
    ".whatcom.edu": ["Whatcom Community College"],
    ".whccd.edu": [
        "Lemoore College or Coalinga College",
        "West Hills College - Lemoore / West Hills College - Coalinga / Lemoore College / Coalinga College",
    ],
    ".wheaton.edu": ["Wheaton College, IL"],
    ".wheatoncollege.edu": ["Wheaton College, Norton, MA, USA"],
    ".wheelock.edu": ["Wheelock College "],
    ".whitman.edu": ["Whitman College"],
    ".whittier.edu": ["Whittier College"],
    ".whitworth.edu": ["Whitworth College"],
    ".whoi.edu": ["Woods Hole Oceanographic Institution"],
    ".whu.edu": ["WHU - Otto Beisheim School of Management"],
    ".shockers.wichita.edu": ["Wichita State University"],
    ".wichita.edu": ["Wichita State University"],
    ".widener.edu": ["Widener University"],
    ".wilberforce.edu": ["Wilberforce University"],
    ".wileyc.edu": ["Wiley College"],
    ".wilkes.edu": ["Wilkes University"],
    ".willamette.edu": ["Willamette University"],
    ".williams.edu": ["Williams College"],
    ".my.wilmu.edu": ["Wilmington University"],
    ".wilmu.edu": ["Wilmington University"],
    ".wilson.edu": ["Wilson College"],
    ".windsor.edu": ["Windsor University School of Medicine"],
    ".wingate.edu": ["Wingate University"],
    ".winona.edu": ["Winona State University"],
    ".winsor.edu": ["The Winsor School"],
    ".winthrop.edu": ["Winthrop University"],
    ".wintu.edu": ["Western International University"],
    ".wisc.edu": ["University of Wisconsin–Madison"],
    ".wit.edu": ["Wentworth Institute of Technology"],
    ".wittenberg.edu": ["Wittenberg University"],
    ".wiu.edu": ["Western Illinois University"],
    ".wju.edu": ["Wheeling Jesuit University"],
    ".wku.edu": ["Western Kentucky University"],
    ".wlc.edu": ["Wisconsin Lutheran College"],
    ".wlu.edu": ["Washington and Lee University"],
    ".email.wm.edu": ["College of William and Mary"],
    ".wm.edu": ["College of William and Mary"],
    ".wmcarey.edu": ["William Carey College"],
    ".wmich.edu": ["Western Michigan University"],
    ".wmpenn.edu": ["William Penn College"],
    ".wnc.edu": ["Western Nevada College"],
    ".wncc.edu": ["Western Nebraska Community College"],
    ".wne.edu": ["Western New England University"],
    ".wnmu.edu": ["Western New Mexico University"],
    ".wofford.edu": ["Wofford College"],
    ".woodbury.edu": ["Woodbury University"],
    ".woodmontcollege.edu": ["Woodmont College"],
    ".wooster.edu": ["The College of Wooster"],
    ".worcester.edu": ["Worcester State University"],
    ".worwic.edu": ["Wor-Wic Community College"],
    ".wou.edu": ["Western Oregon University"],
    ".wpi.edu": ["Worcester Polytechnic Institute"],
    ".wpunj.edu": ["William Paterson University"],
    ".wright.edu": ["Wright State University"],
    ".senators.ws.edu": ["Walters State"],
    ".wsc.edu": ["Wayne State College"],
    ".email.wscc.edu": ["Washington State College of Ohio"],
    ".wssu.edu": ["Winston-Salem State University"],
    ".wsu.edu": [
        "Washington State University",
        "Washington State University, Spokane",
        "Washington State University, Tri-Cities",
        "Washington State University, Vancouver",
    ],
    ".wsulaw.edu": [
        "Western State University College of Law",
        "Western State University College of Law - Orange County",
    ],
    ".wsutech.edu": [
        "WSU Tech",
        "Wichita State University: Campus of Applied Sciences and Technology",
    ],
    ".wtamu.edu": ["West Texas A&amp;M University"],
    ".wub.edu": ["World University of Bangladesh (WUB)"],
    ".wust.edu": ["Washington University of Science and Technology"],
    ".wustl.edu": ["Washington University in St. Louis"],
    ".wvc.edu": ["Wenatchee Valley College", "Wenatchee Valley College"],
    ".wvm.edu": [
        "West Valley – Mission Community College District",
        "West Valley College",
        "Mission College",
        ".group",
    ],
    ".wvnet.edu": [
        "Bethany College West Virginia",
        "Bluefield State College",
        "Glenville State College",
        "Salem Teikyo University",
        "West Liberty State College",
        "West Virginia University Institute of Technology",
    ],
    ".wvsom.edu": ["West Virginia School of Osteopathic Medicine"],
    ".mix.wvu.edu": ["West Virginia University"],
    ".wvu.edu": ["West Virginia University"],
    ".wvup.edu": ["West Virginia University at Parkersburg"],
    ".wvwc.edu": ["West Virginia Wesleyan College"],
    ".wwu.edu": ["Western Washington University"],
    ".ewcmail.wy.edu": [
        "Name: Eastern Wyoming College",
        "Address: 3200 West C Street, Torrington, WY 82240",
        "ZIP Code: 82240",
        "Website: www.ewc.wy.edu",
    ],
    ".xavier.edu": ["Xavier University"],
    ".xu.edu": ["Xavier University"],
    ".xula.edu": ["Xavier University of Louisiana"],
    ".yale.edu": ["Yale University"],
    ".yccc.edu": ["York County Community College"],
    ".ycce.edu": ["Yeshwantrao Chavan College of Engineering (YCCE), Nagpur"],
    ".ycp.edu": ["York College of Pennsylvania"],
    ".york.edu": ["York College Nebraska"],
    ".student.yosemite.edu": ["Modesto Junior College"],
    ".yosemite.edu": ["Yosemite Community College District"],
    ".ysu.edu": ["Youngstown State University"],
    ".yu.edu": ["Yeshiva University"],
    ".yvcc.edu": ["Yakima Valley Community College"],
    ".zamorano.edu": ["Escuela Agricola Panamericana Zamorano"],
    ".abhome.education": ["ABhome Education"],
    ".adachi-gr.education": ["専門学校東京クールジャパン", "Tokyo Cool Japan"],
    ".aivancity.education": ["aivancity", "aivancity"],
    ".brucity.education": ["Institut Paul Hankar", "Paul Hankar Institut"],
    ".faculty.cacttus.education": ["Cacttus Education"],
    ".student.cacttus.education": ["Cacttus Education"],
    ".cast.education": ["Cambridge Academy for Science and Technology"],
    ".crescent.education": [
        "B.S.ABDUR RAHMAN CRESCENT INSTITUTE OF SCIENCE & TECHNOLOGY"
    ],
    ".eichendorffschule.education": ["Eichendorffschule Kelkheim"],
    ".elitech.education": ["Elitech International University"],
    ".esmt.education": ["European School of Management and Technology"],
    ".gfn.education": ["GFN", "GFN"],
    ".hybridge.education": ["Hybridge Education"],
    ".isicom.education": [
        "Higher Institute of Computer Science and Communication ",
        "Institut Superieur d'Informatique et de communication",
        "Democratic Republic Of Congo, KOLWEZI, province of LUALABA",
    ],
    ".jda-gex.education": [
        "Lycée Polyvalent Privé Jeanne d'Arc - Cessy, FR",
        "Joan of Arc Private Polyvalent High School - Cessy, FR",
    ],
    ".kings.education": ["King’s College Saint Michaels"],
    ".llm.education": ["Lycée Louis Massignon"],
    ".lycee-de-beauvoir.education": [
        "Lycée Simone de Beauvoir - Gragnague",
        "BTS CIEL - IR",
        "https://lycee-gragnague.mon-ent-occitanie.fr/",
    ],
    ".mai.education": [
        "федеральное государственное бюджетное образовательное учреждение высшего образования «Московский авиационный институт (национальный исследовательский университет)» ",
        "Moscow Aviation Institute (National Research University) ",
    ],
    ".midlothian.education": ["Newbattle High School"],
    ".mile.education": [
        "Lexicon Management Institute of Leadership and Excellence",
        "Lexicon Management Institute of Leadership and Excellence",
    ],
    ".mipolytech.education": [
        "Метінвест Політехніка",
        'Technical University "METINVEST POLYTECHNIKA"',
    ],
    ".msg-landau.education": ["Max-Slevogt-Gymnasium"],
    ".0720033v.paysdelaloire.education": [
        "Lycée Public Polyvalent GABRIEL TOUCHARD - GEORGE WASHINGTON"
    ],
    ".0851390z.paysdelaloire.education": ["Lycée Polyvalent LÉONARD DE VINCI"],
    ".student.rahn.education": [
        "Rahn Education - Freie Oberschule Leipzig",
        "Rahn Education - Freie Fachoberschule Leipzig",
        ".group",
    ],
    ".sabel.education": ["GBS Schulen München"],
    ".sterling.education": ["Sterling Education"],
    ".tac.education": ["The American Campus"],
    ".ueb.education": [
        "Universitatea ecologica din Bucuresti",
        "Ecological University from Bucharest",
    ],
    ".46.ukr.education": ["ХГ №46 им. М.В. Ломоносова"],
    ".chzosh2.ukr.education": [
        "Чорноморський ліцей № 2 Чорноморської міської ради Одеського району Одеської області"
    ],
    ".guzikschool.ukr.education": [
        "Авторська Школа М. П. Гузика",
        "Author's Guzik School",
    ],
    ".harmony.ukr.education": [
        'Боярський академічний ліцей "Гармонія"',
        'Boyarka Academic Lyceum "Harmony"',
    ],
    ".kfccte-nau.ukr.education": [
        "Київський коледж комп'ютерних технологій та економіки Національного авіаційного університету",
        "Kiev College of Computer Technologies and Economics of the National Aviation University",
    ],
    ".kg121.ukr.education": [
        "Криворізька гімназія №121 Криворізької міської ради",
        "Kryvyi Rih Gymnasium No. 121 of the Kryvyi Rih City Council",
    ],
    ".kg287.ukr.education": ["Kyiv gymnasium 287"],
    ".kkrnu.ukr.education": [
        "College of Kremenchug National University named after Mikhail Ostrogradsky"
    ],
    ".lgk.ukr.education": ["Heroes of Kruty State Lyceum of Lviv"],
    ".licej12.ukr.education": [
        "Івано-Франківський Ліцей №12 ім. Івана Франка",
        "Ivano-Frankivskyi Lyceum #12 by name of Ivan Franko",
    ],
    ".lutsk26.ukr.education": [
        "Комунальний заклад загальної середньої освіти «Луцький ліцей №26 Луцької міської ради»",
        "Municipal institution of general secondary education «Lutsk Lyceum №26 of Lutsk City Council»",
    ],
    ".lviv21.ukr.education": [
        "Ліцей №21 Львівської міської ради",
        "Lviv 21 liceum",
    ],
    ".oplba.ukr.education": [
        'State educational institution "Odesa Professional Lyceum of Construction and Architecture"'
    ],
    ".otfk.ukr.education": [
        "Одеський технічний фаховий коледж Одеського національного технологічного університету"
    ],
    ".sc1.ukr.education": [
        "Brovary School #1",
        "Brovary secondary school of I-III levels #1",
    ],
    ".uagimberegovo.ukr.education": [
        'Берегівський Ліцей "Платан"',
        'Berehivsʹkyy Litsey "Platan"',
    ],
    ".ukr.education": ["Ukrainian schools"],
    ".ametikool.ee": [
        "Kuressaare Ametikool",
        "Kuressaare Regional Training Centre",
    ],
    ".artun.ee": ["Estonian Academy of Arts"],
    ".eava.ee": ["Estonian Aviation Academy"],
    ".ebs.ee": ["Estonian Business School"],
    ".ema.edu.ee": ["Estonian Academy of Music and Theatre"],
    ".eek.ee": ["Estonian Entrepreneurship University of Applied Sciences"],
    ".emu.ee": ["Estonian University of Life Sciences"],
    ".euroakadeemia.ee": ["Euroakadeemia"],
    ".itcollege.ee": ["The Estonian Information Technology College"],
    ".kbfi.ee": [
        "Keemilise ja Bioloogilise Füüsika Instituut",
        "National Institute of Chemical Physics and Biophysics",
    ],
    ".khk.ee": ["Tartu Vocational School"],
    ".edu.lvrkk.ee": ["Lääne-Virumaa Rakenduskõrgkool"],
    ".nooruse.ee": ["Tartu Health Care College"],
    ".perg.ee": [
        "Pelgulinna Riigigümnaasium",
        "Pelgulinna State Upper Secondary School",
    ],
    ".rak.ee": ["Rakvere Ametikool", "Rakvere Vocational School"],
    ".opilane.ramkool.ee": ["Rocca al Mare kool"],
    ".sisekaitse.ee": ["Estonian Academy of Security Sciences"],
    ".taltech.ee": ["TalTech"],
    ".ag.tartu.ee": [
        "Tartu Täiskasvanute Gümnaasium",
        "Tartu Grownups’ Gymnasium",
    ],
    ".tktk.ee": ["University of Applied Sciences"],
    ".tlu.ee": ["Tallinn University"],
    ".tptlive.ee": ["Tallinn Polytechnic School"],
    ".tthk.ee": [
        "Tallinna Tööstushariduskeskus",
        "Tallinn Industrial Education Center",
    ],
    ".ttu.ee": ["Tallinn University of Technology"],
    ".ut.ee": ["University of Tartu"],
    ".vikk.ee": ["Viljandi Kutseõppekeskus"],
    ".viljandiwaldorf.ee": [
        "Viljandi Vaba Waldorfkool",
        "Viljandi Free Waldorf School",
    ],
    ".voco.ee": ["Tartu Rakenduslik Kolledž", "Tartu Vocational College"],
    ".westholm.ee": ["Jakob Westholmi Gümnaasium"],
    ".alex.edu.eg": ["Alexandria University"],
    ".alexmed.edu.eg": ["Faculty of Medicine, Alexandria University"],
    ".alsafwa.edu.eg": [
        "Safwa Higher Institute of Engineering and technology",
        "معهد الصفوة العالي للهندسة والتكنولوجيا",
    ],
    ".anu.edu.eg": [
        "جامعة الإسكندرية الأهلية",
        "Alexandria National University",
    ],
    ".aou.edu.eg": ["Arab Open University"],
    ".aru.edu.eg": ["جامعة العريش", "Arish University"],
    ".std.alsun.asu.edu.eg": ["Ain Shams University"],
    ".eng.aswu.edu.eg": ["Aswan University"],
    ".stu.aswu.edu.eg": ["aswan university"],
    ".aswu.edu.eg": ["Aswan University"],
    ".aun.edu.eg": ["Assiut University"],
    ".azhar.edu.eg": ["Al Azhar University", "Al Azhar University"],
    ".bhie.edu.eg": [
        "المعهد العالي للهندسة ببلبيس",
        "Belbes Higher institute of engineering",
    ],
    ".bisc.edu.eg": ["British International School Cairo"],
    ".cs.bnu.edu.eg": ["جامعة بنها الأهلية", "Benha National University"],
    ".btu.edu.eg": [
        "جامعة بني سويف التكنولوجية",
        "Beni-Suef Technological University",
    ],
    ".bue.edu.eg": ["The British University in Egypt"],
    ".cic-cairo.edu.eg": ["Canadian International College"],
    ".csi.edu.eg": [
        "culture and science city",
        "culture and science city",
        "domain: csi.edu.eg",
    ],
    ".eng1.cu.edu.eg": ["Faculty of Engineering, Cairo University"],
    ".cu.edu.eg": [
        "Cairo University",
        "Cairo University - Faculty of Computers and Artificial Intelligence",
    ],
    ".student.deraya.edu.eg": ["Deraya University", "Deraya University"],
    ".dhic.edu.eg": [
        "معهد الدلتا العالي لنظم المعلومات الإدارية والمحاسبية",
        "Delta higher institute for engineering and technology",
    ],
    ".dtu.edu.eg": ["Delta Technology University"],
    ".du.edu.eg": ["Damietta University"],
    ".eaeat-academy.edu.eg": [
        "الأكاديميه المصريه للهندسه و التكنولوجيا المتقدمه",
        "Egyptian Academy for Engineering and Advanced Technology",
    ],
    ".ecu.edu.eg": ["Egyptian Chinese University"],
    ".eia.edu.eg": [
        "المعهد المصرى العالى لأكاديمية الإسكندرية للإدارة والمحاسبة",
        "The Egyptian Higher Institute of Alexandria Academy for Management & Accounting",
    ],
    ".ejust.edu.eg": [
        "Egypt-Japan University of Science and Technology",
        "Egypt-Japan University of Science and Technology",
    ],
    ".elshoroukacademy.edu.eg": ["El Shorouk Academy"],
    ".engmet.edu.eg": [
        "معهد مصر العالي للهندسة والتكنولوجيا",
        "misr high institute for engineering and technology",
    ],
    ".eru.edu.eg": [
        "Egyptian Russian University",
        "Egyptian Russian University",
    ],
    ".eslsca.edu.eg": ["Eslsca University"],
    ".eui.edu.eg": ["Egypt University of Informatics"],
    ".fa-hists.edu.eg": [
        "Future Academy",
        "Higher Future Institute For Specialized Technological Studies",
    ],
    ".fayoum.edu.eg": ["fayoum", "Fayoum University"],
    ".stud.fci-cu.edu.eg": ["Cairo University"],
    ".fci-cu.edu.eg": [
        "Faculty of Computers and Artificial Intelligence Cairo University",
        "Faculty of Computers and Artificial Intelligence Cairo University",
    ],
    ".feps.edu.eg": [
        "كلية الاقتصاد و العلوم السياسية  جامعة القاهرة ",
        "faculty of economics and political science cairo university",
    ],
    ".fief.edu.eg": ["Future High Institute of Engineering in Fayoum", "FIEF"],
    ".fue.edu.eg": ["Future University in Egypt"],
    ".futureuniversity.edu.eg": ["Future University"],
    ".gei.edu.eg": [
        "معهد الجيزة العالي للهندسة والتكنولوجيا",
        "Giza Engineering Institute",
    ],
    ".gi.edu.eg": ["الجزيرة أكاديمى بالمقطم", "ELGazeera Academy"],
    ".gu.edu.eg": ["galala university", "galala university"],
    ".guc.edu.eg": ["German University in Cairo"],
    ".fci.helwan.edu.eg": ["Helwan University"],
    ".hnu.edu.eg": ["Helwan National University"],
    ".horus.edu.eg": [
        "Horus University – Private university in New Damietta, Egypt (horus.edu.eg)"
    ],
    ".hti.edu.eg": ["Higher Technological Institute"],
    ".iaet.edu.eg": ["Institute of aviation Engineering and technology "],
    ".kfs-hiet.edu.eg": [
        "المعهد العالي للهندسة والتكنولوجيا بكفرالشيخ",
        "Higher Institute of Engineering and Technology Kafrelsheikh",
    ],
    ".luxor.edu.eg": [
        "Luxor University",
        "جامعة الأقصر",
        "http://www.luxor.edu.eg/",
    ],
    ".madinagroups.edu.eg": ["Madina Academy"],
    ".mans.edu.eg": ["Mansoura University"],
    ".mau.edu.eg": [
        "Faculty of computers and artificial intelligence Matrouh universty"
    ],
    ".menofia.edu.eg": ["Menoufia University"],
    ".merit.edu.eg": ["Merit University"],
    ".mhiet.edu.eg": [
        "المعهد العالي للهندسه والتكنولوجيا",
        "the higher institute of engineering and technology",
    ],
    ".minia.edu.eg": ["Minia University"],
    ".CAI.minianu.edu.eg": [
        "جامعة المنيا الأهلية ",
        "Minia National University",
    ],
    ".miuegypt.edu.eg": ["Misr International University"],
    ".mns.edu.eg": ["Maadi Narmer School", "MNS"],
    ".ai.mnu.edu.eg": ["Menofia National University"],
    ".modern-academy.edu.eg": ["Modern academy for engineering & technology"],
    ".dakahliya3.moe.edu.eg": [
        "مدرسة النسايمة الاعدادية بنات",
        "Al-Nasaimeh Girls Secondary School",
    ],
    ".gharbeia1.moe.edu.eg": [
        "اللواء محمد نجيب الرسمية للغات",
        "Mohamed Naguib Language School",
    ],
    ".giza1.moe.edu.eg": [
        "مدرسة السعيدية الثانوية العسكرية بنين",
        "El Saidia Secondary Military School for Boys",
    ],
    ".giza2.moe.edu.eg": ["الاورمان", "Orman"],
    ".giza6.moe.edu.eg": ["Anglo American Semi International School, Giza"],
    ".monofeya1.moe.edu.eg": [
        "مدرسة أشمون الرسمية للغات",
        "Ashmoun Official Language School",
    ],
    ".qaliobia2.moe.edu.eg": [
        "Egyptian Ministry of Education - El-Manayel Mixed Secondary School ",
        "مدرسة المنايل الثانوية المشتركة",
        "Egyptian High School ",
    ],
    ".sohag2.moe.edu.eg": [
        "رفاعة الثانوية العسكرية",
        "Refaa Secondary Military School",
    ],
    ".stemalex.moe.edu.eg": ["Alexandria STEM School"],
    ".stemassiut.moe.edu.eg": ["Assiut STEM School"],
    ".stemobour.moe.edu.eg": [
        "مدرسة المتفوقين في العلوم و التكنولوجيا بالعبور",
        "Obour STEM High School",
        ".group",
    ],
    ".msa.edu.eg": ["October University for Sciences & Arts (MSA University)"],
    ".mtc.edu.eg": ["Military Technical College"],
    ".mti.edu.eg": ["Modern University For Technology and Information"],
    ".muc.edu.eg": ["May University in Cairo", "May University in Cairo"],
    ".must.edu.eg": ["Misr University for Sience and Technology"],
    ".nctu.edu.eg": ["New Cairo Technological University"],
    ".ndeti.edu.eg": [
        "المعهد العالي للهندسة والتكنولوجيا بدمياط الجديدة",
        "Higher Institute For Engineering & Technology in Damietta El-Gadeeda",
    ],
    ".ngu.edu.eg": [
        "Newgiza University",
        "Newgiza University",
        "https://www.ngu.edu.eg/",
    ],
    ".nileu.edu.eg": ["Nile University"],
    ".nmu.edu.eg": [
        "New Mansoura University",
        "جامعة المنصورة الجديدة",
        "New Mansoura University (Egypt)",
    ],
    ".nub.edu.eg": ["Nahda University", "Nahda University"],
    ".agr.nvu.edu.eg": ["جامعة الوادى الجديد ", "new valley university"],
    ".ohi.edu.eg": [
        "6 of October High Institute For Architecture Engineering"
    ],
    ".ohie.edu.eg": [
        "معهد العبور العالي للهندسة والتكنولوجيا",
        "Obour High Institute for Engineering and Technolog",
    ],
    ".student.ohins.edu.eg": [
        "October High Institute For Enginnering and Technology",
        "October High Institute For Enginnering and Technology",
    ],
    ".phi.edu.eg": [
        "معهد الأهرامات العالي للهندسة والتكنولوجيا",
        "Pyramids Higher Institute of Engineering and Technology",
    ],
    ".pua.edu.eg": ["Pharos International University"],
    ".rst.edu.eg": ["Al Ryada University For Science And Technology"],
    ".s-mu.edu.eg": ["جامعة المنيا", "Minia University"],
    ".sadatacademy.edu.eg": ["Sadat Academy for Management Sciences"],
    ".sgu.edu.eg": ["جامعة الصالحية", "El Salheya El Gadida"],
    ".sha.edu.eg": ["El Shrouk Academy", "el shrouk academy"],
    ".shams.edu.eg": ["Ain Shams University"],
    ".sinaieng.edu.eg": [
        "The Higher Institute of Engineering and Technology - AlArish"
    ],
    ".sis.edu.eg": [
        "Salahadin International School",
        "Salahadin International School",
    ],
    ".art.sohag.edu.eg": ["Sohag University"],
    ".fci.sohag.edu.eg": ["Sohag University"],
    ".science.sohag.edu.eg": [" Faculty of Science Sohag University"],
    ".techedu.sohag.edu.eg": ["sohag university", "sohag university"],
    ".sohag-univ.edu.eg": ["Sohag University"],
    ".su.edu.eg": ["Sinai University"],
    ".sue.edu.eg": [
        "جامعة السلام بمصر",
        "Alsalam University in Egypt",
        "Salam University",
        ".group",
    ],
    ".std.suezuniv.edu.eg": ["Suez University", "Suez University"],
    ".sut.edu.eg": ["El Sewedy University of Technology"],
    ".svnu.edu.eg": ["South Valley National University"],
    ".svu.edu.eg": ["South Valley University"],
    ".thebes.edu.eg": ["اكاديمية طيبة", "thebes academy"],
    ".thic.edu.eg": [
        "المعهد العالي للحاسبات والمعلومات الادارية وتكنولوجيا- ادارة بطنطا"
    ],
    ".tkh.edu.eg": ["The Knowledge Hub Universities"],
    ".ufe.edu.eg": ["Université Française d'Égypte"],
    ".uofcanada.edu.eg": ["universit of canada in Egypt"],
    ".usc.edu.eg": ["جامعة مدينة السادات", "University Of Sadat City"],
    ".zewailcity.edu.eg": ["Zewail City of Science and Technology"],
    ".ai.znu.edu.eg": [
        "جامعة الزقازيق الاهلية",
        "Zagazig National University",
    ],
    ".ais.znu.edu.eg": [
        "جامعة الزقازيق الاهلية",
        "Zagazig National University",
    ],
    ".meceng.znu.edu.eg": [
        "جامعة الزقازيق الاهلية",
        "Zagazig National University",
    ],
    ".medinf.znu.edu.eg": [
        "جامعة الزقازيق الاهلية",
        "Zagazig National University",
    ],
    ".seng.znu.edu.eg": [
        "جامعة الزقازيق الاهلية",
        "Zagazig National University",
    ],
    ".msa.eun.eg": ["Modern Sciences &amp; Arts University"],
    ".ahe.email": ["Akademia Humanistyczno-Ekonomiczna w Łodzi"],
    ".adaits.es": [
        "Instituto Tecnológico Superior - ADA (Sevilla)",
        "Higher Education Techlogical Institute - ADA (Sevilla)",
    ],
    ".alumnatflorida.es": ["Florida Universitaria"],
    ".alumni-eae.es": ["EAE Business School"],
    ".alumni-ieb.es": ["Instituto de Estudios Bursátiles"],
    ".alumnos-eneb.es": ["ENEB. Escuela de Negocios Europea de Barcelona"],
    ".alumnos-santagema.es": ["FP Santa Gema"],
    ".alumnosiesleliana.es": ["IES L'Eliana"],
    ".alzago.es": ["Alzago, Escuela de Nuevas Tecnologías"],
    ".campuscamara.es": [
        "ESTUDIOS UNIVERSITARIOS Y SUPERIORES DE ANDALUCIA, SLU"
    ],
    ".campusviu.es": [
        "Universidad Internacional de Valencia",
        "Valencian International University",
    ],
    ".canariaseducacion.es": [
        "Consejería de Educación, Universidades, Cultura y Deportes - Gobierno de Canarias",
        "Gobierno de Canarias",
        ".group",
    ],
    ".alu.ceacfp.es": [
        "CEAC (Centro de Estudios de Aparejadores por Correspondencia)",
        "CEAC Official Professional Training Institute",
    ],
    ".alumnos.cei.es": [
        "CEI - Design & Marketing School - Madrid",
        "CEI - Escuela de Diseño y Marketing- Madrid",
    ],
    ".centroseim.es": ["SEIM"],
    ".cesma.es": ["CESMA Business School"],
    ".ceu.es": [
        "Universidad Cardenal Herrera-CEU",
        "Universidad de San Pablo CEU",
    ],
    ".chabacier.es": [
        "IES Leonardo de Chabacier",
        "IES Leonardo de Chabacier",
    ],
    ".ciclosformativosceu.es": [
        "Escuela Superior de Enseñanzas Técnicas",
        "ESET Technical School of Engineering",
    ],
    ".cide.es": ["CIDE"],
    ".cifpcarballeira.es": ["CIFP A Carballeira"],
    ".cifpceuta.es": [
        "Centro Integrado de Formación Profesional nº 1",
        "CIFP1 Ceuta",
    ],
    ".aula.cifplalaboral.es": [
        "Centro Integral de Formacion Profesional La Laboral"
    ],
    ".cifpzonzamas.es": ["CIFP ZONZAMAS"],
    ".clpu.es": ["Centro de Láseres Pulsados"],
    ".cnic.es": [
        "Spanish National Center For Cardiovascular Research ",
        "CNIC",
    ],
    ".cnio.es": [
        "Centro Nacional de Investigaciones Oncológicas (CNIO) - Instituto de salud Carlos III",
        "Spanish National Cancer Research Center - Carlos III Health Institute",
    ],
    ".cragenomica.es": [
        "Centre de Recerca en Agrogènomica",
        "Centre for Research in Agrogenomics",
    ],
    ".deusto.es": ["Universidad de Deusto"],
    ".e-itaca.es": ["IES ITACA", "IES ITACA"],
    ".eae.es": ["EAE Business School"],
    ".easda.es": [
        "Escuela de Arte y Superior de Diseño de Alicante",
        "Alicante School of Art and College of Design",
    ],
    ".ecam.es": [
        "Escuela de Cinematografía y Audiovisual de la Comunidad de Madrid, ECAM"
    ],
    ".students.bsb.edu.es": ["British School of Barcelona"],
    ".fundacionpracticum.edu.es": [
        "\ufeffInstituto Practicum de Investigación Aplicada a la Educación en Ciencias de la Salud"
    ],
    ".ieschandomonte.edu.es": [
        "Instituto de Educación Secundaria Chan do Monte",
        "IES Chan do Monte",
    ],
    ".iesjuandelacierva.edu.es": ["I.E.S Juan de la Cierva"],
    ".inea.edu.es": [
        "Universidad de Valladolid - Escuela Universitaria de Ingeniería Agrícola"
    ],
    ".iunit.edu.es": [
        "Centro de educación superior de negocios, innovación y tecnología"
    ],
    ".ull.edu.es": ["Universidad de La Laguna"],
    ".upv.edu.es": ["Universidad Politécnica de Valencia"],
    ".g.educaand.es": ["Schools in Andalusia"],
    ".educantabria.es": ["I.E.S. Augusto Gonzalez Linares"],
    ".educarex.es": [
        "Institutos de Educación Secundaria de Extremadura (España)"
    ],
    ".educastillalamancha.es": [
        "Educación de Castilla-La Mancha",
        "Castilla-La Mancha's education",
        ".group",
    ],
    ".ehu.es": ["Universidad del País Vasco"],
    ".embl.es": [
        "European Molecular Biology Laboratory",
        "EMBL, Barcelona",
        "URL: https://www.embl.org/sites/barcelona/",
    ],
    ".eoi.es": ["Escuela de Organización Industrial"],
    ".esada.es": ["ESADA"],
    ".esat.es": ["Escuela Superior de Arte y Tecnologia (ESAT)"],
    ".escav.es": [
        "Escuela Superior de Comunicación Audiovisual",
        "High School of audiovisual communication",
    ],
    ".escolapiosdegetafe.es": ["La Inmaculada - Padres Escolapios"],
    ".escuelaestech.es": ["Escuela es[tech]"],
    ".esdmadrid.es": [
        "Escuela Superior de Diseño de Madrid",
        "Madrid School of Design",
    ],
    ".esic.es": ["Escuela Superior de Gestion Comercial y Marketing (ESIC)"],
    ".esne.es": [
        "Esne ( Escuela Universitaria de Diseño, Innovacion y Tecnologia), based in Madrid, Spain"
    ],
    ".profesor.esneasturias.es": ["ESNE"],
    ".eug.es": ["Escoles Universitàries Gimbernat i Tomàs Cerdà"],
    ".euncet.es": ["EUNCET Business School"],
    ".eusa.es": ["CAMPUS FORMATIVO DE LA CÁMARA DE COMERCIO DE SEVILLA"],
    ".correo.evg.es": ["Escuela Virgen de Guadalupe"],
    ".facultyue.es": ["Universidad Europea", "European University"],
    ".fesac.es": ["FESAC"],
    ".florida-uni.es": [],
    ".floridauniversitaria.es": ["Florida Universitaria"],
    ".formacionchios.es": ["Chios Formacion"],
    ".fpsumma.es": ["FP Summa"],
    ".fundacio.es": ["\ufeffUniversity of Valencia"],
    ".fundacionloyola.es": [
        "Colegio San José. (Fundación Loyola. Andalucía, Canarias y Extremadura. (FLACE))"
    ],
    ".fundacionsafa.es": ["Foundation SAFA"],
    ".alu.edu.gva.es": ["Students of Comunidad Valenciana, Spain"],
    ".edu.gva.es": ["Students and teachers of Comunidad Valenciana, Spain"],
    ".iac.es": ["Instituto de Astrofísica de Canarias"],
    ".icfo.es": ["The Institute of Photonic Sciences"],
    ".idecrea.es": ["Escuela de artes digitales Idecrea"],
    ".idep.es": ["Idep Barcelona - Escola Superior d'Imatge i Disseny"],
    ".iepgroup.es": ["IEP Group"],
    ".ies-azarquiel.es": ["I.E.S. Azarquiel"],
    ".iesalbarregas.es": ["IES ALBARREGAS"],
    ".iesalbujaira.es": [
        "Instituto de Educación Secundaria Albujaira",
        "Albujaira",
    ],
    ".iesandorra.es": ["Pablo Serrano", "Pablo Serrano"],
    ".iesbenigaslo.es": ["IES Benigaslo"],
    ".iescabanas.es": ["Instituto de Educación Secundaria Cabañas"],
    ".iescamas.es": ["IES Camas", "IES Camas"],
    ".iescamp.es": ["IES Camp de Morvedre"],
    ".alumno.ieselrincon.es": ["IES El Rincon"],
    ".ieselrincon.es": ["IES El Rincon"],
    ".iesfranciscodelosrios.es": [
        'Instituto de Educación Secundaria "Francisco de Los Ríos"'
    ],
    ".iesfuengirola1.es": [
        "IES Fuengirola Número 1",
        "Fuengirola Number 1 High School",
    ],
    ".iesgalileo.es": ["IES Galileo (Valladolid)"],
    ".iesiniesta.es": ["IES CAÑADA DE LA ENCINA"],
    ".iesjulianmarias.es": ["IES Julián Marías"],
    ".ieslavereda.es": ["IES La Vereda"],
    ".iesluisbraille.es": ["IES LUIS BRAILLE"],
    ".iesmartinezm.es": ["IES Martínez Montañés"],
    ".iesnervion.es": ["Instituto de Educación Secundaria Nervión."],
    ".iesoleana.es": ["IES Oleana"],
    ".iesoretania.es": ["I.E.S. ORETANIA"],
    ".iespacomolla.es": ["IES Poeta Paco Mollá"],
    ".iesprofesormaximotrueba.es": ["IES Profesor Máximo trueba"],
    ".iespuertasdelcampo.es": ["IES Puertas del Campo"],
    ".iessantaaurelia.es": ["IES Santa Aurelia"],
    ".iessantairene.es": ["IES  santa Irene"],
    ".iessoterohernandez.es": ["\ufeffIES Sotero Hernández"],
    ".iesteis.es": ["IES de Teis"],
    ".iestorredelrey.es": ["Torre del Rey"],
    ".informatica.iesvalledeljerteplasencia.es": [
        "IES Valle del Jerte (Plasencia)"
    ],
    ".iesvegademijas.es": ["IES Vega de Mijas (Málaga)"],
    ".student.ifp.es": ["Innovacion Formación Profesional"],
    ".ifp.es": ["IFP Innovación en Formación profesional", "ifp.es"],
    ".implika.es": ["Implika"],
    ".juntadeandalucia.es": ["IES Jaroso"],
    ".lasallefelipebenito.es": ["La Salle Felipe Benito"],
    ".students.lesroches.es": [
        "Les Roches International School of Hotel Management"
    ],
    ".linkiafp.es": ["Linkia FP - Formación Profesional Oficial a Distancia"],
    ".lmsf.es": ["La Milagrosa y Santa Florentina"],
    ".maristaslogrono.es": ["Colegio Maristas San Jose Logroño"],
    ".mascamarena.es": [
        "Complejo Educativo Mas Camarena",
        "Mas Camarena Educational Complex",
    ],
    ".alu.medac.es": ["MEDAC"],
    ".medac.es": ["MEDAC"],
    ".fp.mercedarias.es": ["Our Lady of Mercedes School Granada"],
    ".monlau.es": ["Monlau Centro de Estudios"],
    ".montessorischool.es": ["Montessori School La Florida, Madrid"],
    ".muni.es": ["Mondragon Univertsitatea"],
    ".alu.murciaeduca.es": ["Alumnos Región de Murcia alu.murciaeduca.es"],
    ".murciaeduca.es": ["Educación de la Región de Murcia"],
    ".educacion.navarra.es": ["Cuatrovientos centro integrado"],
    ".nebrija.es": ["Added Universidad Nebrija"],
    ".opendeusto.es": ["Universidad de Deusto"],
    ".riberadeltajo.es": ["IES Ribera del tajo", "IES Ribera del tajo"],
    ".roa.es": ["ROA Spanish Naval Observatory"],
    ".rtve.es": ["Instituto Radio Televisión Española"],
    ".hue.safanet.es": [
        "C.D.P. Escuelas Profesionales de la Sagrada Familia, SAFA-Funcadia"
    ],
    ".safareyes.es": ["Foundation SAFA"],
    ".estudiantes.salesianasnsp.es": ["nuestra señora del pilar salesianas"],
    ".sangabriel.es": ["Colegio San Gabriel", "Saint Gabriel School"],
    ".santamariadelosangeles.es": ["C.D.P. Santa María De Los Ángeles"],
    ".solcnou.es": ["Escola Solc Nou"],
    ".tecnun.es": [
        "TECNUN - Escuela Superior de Ingenieros de la Universidad de Navarra (UNAV)"
    ],
    ".tuniversformacion.es": ["Tunivers Formación"],
    ".ua.es": ["Universidad de Alicante"],
    ".uab.es": [
        "Universitat Autónoma de Barcelona",
        "Autonomous University of Barcelona",
    ],
    ".uah.es": ["Universidad de Alcalá de Henares"],
    ".ual.es": ["University of Almeria"],
    ".ualm.es": ["Universidad de Almería"],
    ".uam.es": ["Universidad Autónoma de Madrid"],
    ".uao.es": ["Universitat Abat Oliba", "Abat Oliba CEU University"],
    ".uax.es": ["Universidad Alfonso X El Sabio"],
    ".ub.es": ["Universitat de Barcelona"],
    ".ubu.es": ["Universidad de Burgos"],
    ".alumnos.uc3m.es": ["Universidad Carlos III de Madrid"],
    ".uc3m.es": ["Universidad Carlos III de Madrid"],
    ".uca.es": ["Universidad de Cádiz"],
    ".ucavila.es": [
        "Universidad Católica de Ávila",
        "Universidad Católica Santa Teresa de Jesús de Ávila",
        "UCAV",
    ],
    ".uchceu.es": ["Universidad Cardenal Herrera"],
    ".uclm.es": ["Universidad de Castilla La Mancha"],
    ".ucm.es": ["Universidad Complutense de Madrid"],
    ".uco.es": ["Universidad de Córdoba"],
    ".ucv.es": ["Universidad Católica de Valencia"],
    ".udc.es": ["Universidad de La Coruña"],
    ".udg.es": ["Universidad de Gerona"],
    ".udit.es": [
        "UDIT (Universidad de Diseño, Innovación y Tecnología)",
        "UDIT (University of Design, Innovation and Technology)",
    ],
    ".udl.es": ["Universitat de Lleida"],
    ".uem.es": ["Universidad Europea de Madrid"],
    ".uemc.es": ["Universidad Europea Miguel de Cervantes"],
    ".uf3ceu.es": ["Universidad CEU Fernando III"],
    ".ufv.es": ["Universidad Francisco de Vitoria"],
    ".ugr.es": ["University of Granada"],
    ".uhu.es": ["Universidad de Huelva"],
    ".ui1.es": ["Universidad Internacional Isabel I de Castilla"],
    ".uia.es": [
        "Universidad Internacional de Andalucía",
        "Universidad Internacional de Andalucía, Sede Antonio Machado de Baeza",
        "Universidad Internacional de Andalucía, Sede La Rábida",
    ],
    ".uib.es": ["Universitat de les Illes Balears"],
    ".uic.es": ["Universitat Intenacional de Catalunya"],
    ".uimp.es": ["Universidad Internacional Menéndez Pelayo"],
    ".ujaen.es": ["Universidad de Jaén"],
    ".uji.es": ["Universitat Jaume I de Castellón"],
    ".ull.es": ["Universidad de La Laguna"],
    ".al.uloyola.es": [
        "Universidad Loyola Andalucia",
        "Andalusian Loyola University",
    ],
    ".ulpgc.es": ["Universidad de Las Palmas de Gran Canaria"],
    ".um.es": ["Universidad de Murcia"],
    ".umh.es": ["Universidad Miguel Hernández de Elche"],
    ".unav.es": ["Universidad de Navarra"],
    ".unavarra.es": ["Universidad Pública de Navarra"],
    ".e.unavarrra.es": ["Universidad Publica de Navarra"],
    ".uneatlantico.es": [
        "Universidad Europea del Atlántico",
        "European University of Atlantic",
    ],
    ".uned.es": ["Universidad Nacional de Educación a Distancia"],
    ".unex.es": ["Universidad de Extremadura"],
    ".estudiante.unia.es": [
        "Universidad Internacional de Andalucía",
        "International University of Andalucía",
    ],
    ".unican.es": ["Universidad de Cantabria"],
    ".unileon.es": ["Universidad de León"],
    ".uniovi.es": ["Universidad de Oviedo"],
    ".unirioja.es": ["Universidad de La Rioja"],
    ".universidadeuropea.es": ["Universidad Europea de Madrid"],
    ".unizar.es": ["Universidad de Zaragoza"],
    ".unnet.es": ["Universidad Antonio de Nebrija"],
    ".uoc.es": ["Universitat Oberta de Catalunya"],
    ".upco.es": ["Universidad Pontificia Comillas"],
    ".upcomillas.es": ["Universidad Pontificia de Comillas"],
    ".upct.es": ["Universidad Politécnica de Cartagena"],
    ".upf.es": ["Universitat Pompeu Fabra"],
    ".fi.upm.es": ["UPM"],
    ".upm.es": [
        "Universidad Politécnica de Madrid",
        "Technical University of Madrid",
    ],
    ".upo.es": ["Universidad Pablo de Olavide"],
    ".upsa.es": ["Universidad Pontificia de Salamanca"],
    ".upv.es": ["Universidad Politécnica de Valencia"],
    ".urjc.es": ["Universidad Rey Juan Carlos"],
    ".url.es": ["Universitat Rámon Llull"],
    ".urv.es": ["Universitat Rovira I Virgili Tarragona"],
    ".us.es": ["Universidad de Sevilla"],
    ".usc.es": ["Universidad de Santiago de Compostela"],
    ".usj.es": ["Universidad San Jorge"],
    ".utamed.es": ["Universidad Tecnológica Atlántico Mediterráneo - UTAMED"],
    ".uv.es": ["Universidad de Valencia"],
    ".uva.es": ["Universidad de Valladolid"],
    ".uvic.es": ["Universitat de Vic"],
    ".uvigo.es": ["Universidad de Vigo"],
    ".xuqueralumnat.es": ["XÚQUER CENTRE EDUCATIU"],
    ".aait.edu.et": [
        "አዲስ አበባ ቴክኖሎጂ ኢንስቲትዩት",
        "Addis Ababa Institute of Technology",
        "AAiT",
    ],
    ".aastu.edu.et": [
        "አዲስ አበባ ሳይንስ እና ቴክኖሎጂ ዩኒቨርሲቲ",
        "Addis Ababa Science and Technology University",
        "AASTU",
    ],
    ".aastustudent.edu.et": [
        "አዲስ አበባ ሳይንስና ቴክኖሎጂ ዩኒቨርሲቲ",
        "Addis Ababa Science and Technology University",
    ],
    ".aau.edu.et": ["Addis Ababa University"],
    ".adu.edu.et": ["ዓዲግራት ዩኒቨርሲቲ", "Adigrat University"],
    ".ambou.edu.et": ["Ambo University"],
    ".astu.edu.et": ["Adama Science and Technology University"],
    ".bdu.edu.et": ["Bahir Dar University"],
    ".bhu.edu.et": ["Bule Hora University", "Bule Hora University"],
    ".bitscollege.edu.et": ["Bits College School Of  Systems And Technology "],
    ".dbu.edu.et": ["Debre Berhan University "],
    ".dillauniversity.edu.et": ["Dilla University"],
    ".dtu.edu.et": ["Debre Tabor University ", "Debre Tabor University"],
    ".hu.edu.et": ["Hawassa University"],
    ".jju.edu.et": ["Jigjiga University"],
    ".ju.edu.et": ["Jimma University"],
    ".mtu.edu.et": ["Mizan-Tepi University"],
    ".mu.edu.et": ["Mekelle University"],
    ".rayu.edu.et": ["Raya University", "ራያ ዩኒቨርሲቲ"],
    ".uog.edu.et": ["Gondar University"],
    ".wku.edu.et": ["Wolkite University"],
    ".wsu.edu.et": ["Wolaita Sodo University"],
    ".wu.edu.et": ["Wollo University "],
    ".ac-arcus.eu": [
        "Американски Колеж Аркус (АК-Аркус)",
        "American College Arcus (AC-Arcus)",
    ],
    ".aforp.eu": ["AFORP centre de formation industriel et technologique"],
    ".akademiasztuki.eu": [
        "Akademia Sztuki w Szczecinie",
        "Academy of Art in Szczecin",
    ],
    ".alma-realschule.eu": ["Albertus Magnus Realschule"],
    ".altesgymnasium.eu": ["Altes Gymnasium Oldenburg"],
    ".amgd.eu": ["Academy of Music Georghe Dima Cluj-Napoca"],
    ".apeiron-edu.eu": ["Panevropski Univerzitet Apeiron Banja Luka"],
    ".ash-berlin.eu": ["Alice Salomon Hochschule Berlin"],
    ".barcelonagse.eu": ["Barcelona Graduate School of Economics"],
    ".bbs-alfeld.eu": ["BBS Alfeld"],
    ".bbs-cux.eu": ["BBS Cuxhaven", "Vocational School Cuxhaven"],
    ".bbs-lingen-tg.eu": ["BBS Lingen Technik und Gestaltung"],
    ".bbs-papenburg.eu": ["BBS Papenburg"],
    ".bbs2-aurich.eu": ["BBS II Aurich"],
    ".bbsam.eu": ["Berufsbildende Schulen am Museumsdorf Cloppenburg"],
    ".bbssoltau.eu": ["Berufsbildende Schulen Soltau"],
    ".bk-beckum.eu": [
        "Berufskolleg Beckum des Kreises Warendorf Europaschule"
    ],
    ".bkb-europaschule.eu": ["Berufskolleg Barmen - Europaschule"],
    ".bkbocholt-west.eu": ["BK Bocholt-West", "BK Bocholt-West"],
    ".bottyan.eu": ["Bottyán János Szakgimnázium"],
    ".brexgata.eu": ["Brexgata University Academy"],
    ".c-a-g.eu": ["Clemens-August-Gymnasium Cloppenburg"],
    ".campusid.eu": ["Campus ID"],
    ".cifpfbmoll.eu": ["CIFP Francesc de Borja Moll"],
    ".york.citycollege.eu": ["University of York Europe Campus"],
    ".cnva.eu": [
        'Colegiul National "Vasile Alecsandri"',
        "Vasile Alecsandri National College",
    ],
    ".coleurope.eu": ["College of Europe"],
    ".cosmopolitanschool.eu": [
        "Berlin Cosmopolitan School",
        "Berlin Cosmopolitan School",
    ],
    ".csvvg.eu": ["CS Vincent van Gogh"],
    ".dallam.eu": [],
    ".damago.eu": ["Damago"],
    ".dauphine.eu": ["Université Paris-Dauphine (Paris IX)"],
    ".demet.eu": ["DE MET Leuven", "DE MET Katelijne", "DE MET Tielt-Winge"],
    ".demetkatelijne.eu": ["DE MET Katelijne"],
    ".demetleuven.eu": ["DE MET Leuven"],
    ".demettieltwinge.eu": ["DE MET Tielt-Winge"],
    ".dgkralupy.eu": ["Dvorakovo gymnazium a SOSE in Kralupy nad Vltavou"],
    ".e-studij.eu": ["B2 Visoka šola za poslovne vede, zavod", "B2"],
    ".eafcevere.eu": ["EAFC Evere", "https://eafcevere.eu/"],
    ".ebert-net.eu": ["Friedrich Ebert Gymnasium"],
    ".ecam-strasbourg.eu": ["Ecam Strasbourg"],
    ".ecm-meaux.eu": ["Lycée Bossuet"],
    ".apsb.edu.eu": [
        "The Asia Pacific School of Business (Private) Education Group",
        "APSB",
    ],
    ".uitm.edu.eu": [
        "University of Information Technology and Management in Rzeszow",
        "Wyższa Szkoła Informatyki i Zarządzania w Rzeszowie",
    ],
    ".educa-sos.eu": ["EDUCA SOS s.r.o. private high school"],
    ".eisti.eu": [
        "EISTI - Ecole Internationnale des Sciences du Traitement de l'Information"
    ],
    ".ensam.eu": ["Arts et Métiers ParisTech"],
    ".ensg.eu": ["Ecole Nationale des Sciences Géographiques"],
    ".ensiie.eu": [
        "École Nationale Supérieure d'Informatique pour l'Industrie et l'Entreprise"
    ],
    ".ensitech.eu": [
        "ENSITECH, école supérieure spécialisée en Développement & Innovation et Sécurité, Systèmes et Réseaux"
    ],
    ".ensup.eu": [
        "\ufeffENSUP, Ecole supérieure de Commerce dans le 78 et 95"
    ],
    ".epfc.eu": ["EPFC - Ecole de Promotion et de Formation Continue"],
    ".epitech.eu": ["École de l'Innovation et de l'Expertise Informatique"],
    ".esaintmichael.eu": ["St. Michael Foundation"],
    ".edu.escp.eu": ["ESCP Business School"],
    ".escp.eu": ["ESCP Business School"],
    ".escpeurope.eu": ["ESCP Europe"],
    ".esiee-amiens.eu": [
        "Ecole Supérieure d'Ingénieurs en Electronique et Electrotechnique - Amiens"
    ],
    ".eskola.eu": [
        "Střední škola technická a dopravní Gustava Habrmana Česká Třebová"
    ],
    ".essca.eu": ["Essca", "ESSCA School of Management"],
    ".estaca.eu": [
        "Ecole Supérieure des Techniques Aéronautiques et de Construction Automobile"
    ],
    ".eui.eu": ["European University Institute"],
    ".eursc.eu": [
        "European schools",
        "Ecoles européennes",
        "Europäische Schulen",
    ],
    ".fh-dresden.eu": [
        "Fachhochschule Dresden – University of Applied Sciences"
    ],
    ".get-mail.eu": ["Groupe ESC Troyes"],
    ".ggs-schenefeld.eu": ["Grund- und Gemeinschaftsschule Schenefeld"],
    ".gikn.eu": [
        'ЧПГИКН "Академик Благовест Сендов"',
        'CHPGIKN "Academic Blagovest Sendov"',
    ],
    ".gs-ldk.eu": ["Gewerbliche Schulen Dillenburg"],
    ".gym-old.eu": ["Gymnasium Oldenfelde"],
    ".gymcadca.eu": [
        "Gymnázium Jozefa Miloslava Hurbana v Čadci",
        "Grammar school of Jozef Miloslav Hurban in Čadca",
    ],
    ".student.gymkvary.eu": [
        "První české gymnázium v Karlových Varech",
        "First Czech grammar school in Karlovy Vary",
    ],
    ".gymnasium-ganderkesee.eu": ["Gymnasium Ganderkesee"],
    ".gymnasium-rhauderfehn.eu": ["Gymnasium Rhauderfehn"],
    ".student.handlowa.eu": [
        "WYŻSZA SZKOŁA HANDLOWA WE WROCŁAWIU",
        "UNIVERSITY OF BUSINESS IN WROCLAW",
    ],
    ".handlowa.eu": [
        "Wyższa Szkoła Handlowa we Wrocławiu",
        "University of Business in Wroclaw",
    ],
    ".hbbk.eu": ["Hans-Böckler-Berufskolleg Marl/Haltern, Germany"],
    ".stu.he-ferrer.eu": ["haute école francisco ferrer"],
    ".hetic.eu": ["HETIC", "Grande École d’HETIC, France"],
    ".hfm.eu": ["University of Music Karlsruhe"],
    ".horyzont.eu": ['Higher school of applied computer science "Horyzont"'],
    ".hsg-berlin.eu": ["Heinrich-Schliemann-Gymnasium"],
    ".hsrw.eu": ["Hochschule Rhein-Waal"],
    ".ibcmitrovica.eu": ["International Business College of Mitrovica"],
    ".ibss.eu": ["International Business School of Scandinavia"],
    ".student.idsb.eu": ["Internationale Deutsche Schule Brüssel"],
    ".ifom.eu": ["IFOM - ETS", "Institute For Molecular Oncology"],
    ".igs-kreyenbrueck.eu": ["Integrierte Gesamtschule Kreyenbrück"],
    ".igs-nienburg.eu": ["Integrierte Gesamtschule Nienburg"],
    ".ihl.eu": ["Internationale Hochschule Bad Liebenzell"],
    ".iisgalilei.eu": [
        'Istituto di Istruzione Secondaria Superiore "Galileo Galilei"'
    ],
    ".imc-krems.eu": ["FH University of Applied Sciences Krems"],
    ".imt-bs.eu": [
        "Institut Mines-Telecom Business School (ex-Telecom Ecole de Management)"
    ],
    ".internationalschoolofeurope.eu": ["International School of Europe"],
    ".isisdavinci.eu": [
        "Istituto Statale Istruzione Superiore Leonardo Da Vinci - Firenze"
    ],
    ".itdavinci.eu": ["itdavinci - Borgomanero"],
    ".itis-molinari.eu": ["ITT- LSA “Ettore Molinari”"],
    ".itiscuneo.eu": [
        "\"Istituto Tecnico Industriale Statale 'Mario Delpozzo' Cuneo\"",
        "\"Technical Industrial Institute 'Mario Delpozzo' Cuneo\"",
    ],
    ".students.jedlik.eu": [
        "Győri SZC Jedlik Ányos Gépipari és Informatikai Technikum és Kollégium",
        "website with a 2 year long course: https://jedlik.eu/kepzeseink/felnott-nappali/szoftverfejleszto-es-tesztelo",
        "proof of email: https://imgur.com/a/t7qyAPf",
    ],
    ".julianum.eu": ["Gymnasium Julianum"],
    ".kgs-leeste.eu": ["Kooperative Gesamtschule Leeste"],
    ".kgs-rastede.eu": ["KGS Rastede"],
    ".kgs-schneverdingen.eu": ["Kooperative Gesamtschule Schneverdingen"],
    ".kgshemmingen.eu": ["KGS Hemmingen"],
    ".kgslaatzen.eu": ["Albert Einstein Schule Laatzen"],
    ".4lo.kielce.eu": [
        "IV Liceum Ogólnokształcące w Kielcach",
        "High School no. 4 in Kielce",
    ],
    ".e-zsel.kielce.eu": [
        "Technikum nr 4 im. Ryszarda Kaczorowskiego w Kielcach",
        "Zespół Szkół Elektrycznych (ZSE) w Kielcach",
    ],
    ".zsnr3.kielce.eu": [
        "VII Liceum Ogólnokształcące im. Józefa Piłsudskiego i Technikum nr 8"
    ],
    ".kwr-hannover.eu": ["Kaiser- Wilhelm und Ratsgymnasium"],
    ".kwrg.eu": ["Kaiser- Wilhelm und Ratsgymnasium"],
    ".landfermann-gym.eu": ["Landfermann Gymnasium"],
    ".leafacademy.eu": [
        "Leaf Academy",
        "Leaf Academy (https://www.leafacademy.eu/)",
    ],
    ".leibnizschule-hannover.eu": ["Leibnizschule Hannover"],
    ".lgs-hu.eu": ["Ludwig-Geissler-Schule Hanau"],
    ".libertyhighschool.eu": [
        "Liberčio vidurinė mokykla",
        "Liberty High School",
    ],
    ".liceocassini.eu": ["Liceo Scientifico Gian Domenico Cassini"],
    ".liceolussana.eu": ["Liceo Scientifico Statale F. Lussana"],
    ".liceosabin.eu": ["Liceo Scientifico Statale Albert Bruce Sabin"],
    ".lider24.eu": [
        'Technical Secondary School "LIDER" in Lublin',
        'Technikum "LIDER" w Lublinie',
    ],
    ".edu.lublin.eu": [
        "Zintegrowany system jednostek oświatowych miasta Lublin",
        "Integrated system of educational units - city of Lublin",
    ],
    ".office.zsek.lublin.eu": [
        "Zespół Szkół Ekonomicznych im. A i J. Vetterów w Lublinie",
        "A and J. Vetter Economic School Complex in Lublin",
    ],
    ".gsuite.zsel.lublin.eu": [
        "Technikum Elektroniczne w Lublinie",
        "Electronical School Complex in Lublin",
    ],
    ".mruni.eu": ["Mykolo Romerio university"],
    ".student.mwsl.eu": [
        "Międzynarodowa Wyższa Szkoła Logistyki i Transportu we Wrocławiu",
        "The International University of Logistics and Transport in Wroclaw",
    ],
    ".nvna.eu": [
        "Nikola Vaptsarov Naval Academy - Bulgarian Maritime University"
    ],
    ".obs-sottrum.eu": ["Oberschule An der Wieste Sottrum"],
    ".osz-lise-meitner.eu": ["Lise Meitner Schule Berlin"],
    ".ozanam.eu": ["LYCEE OZANAM, LILLE"],
    ".pacr.eu": ["Police Academy of Czech Republic"],
    ".chartes.psl.eu": ["École Nationale des Chartes"],
    ".psl.eu": [
        "Paris Sciences and Letters",
        "Paris Sciences et Lettres",
        "PSL url: https://www.psl.eu/en",
    ],
    ".ptgtg.eu": [
        'ПТГ "Цар Симеон Велики"',
        "KING SIMEON THE GREAT VOCATIONAL TECHNICAL HIGH SCHOOL",
    ],
    ".pwsz.eu": ["Walcz College", "Walcz College"],
    ".reacollege.eu": ["REA College"],
    ".rmbk.eu": ["Rhein Maas Berufskolleg", "http://rmbk.de/"],
    ".saintemarie-cholet.eu": [
        "ESUPEC - Ecole Supérieure du Choletais",
        "ESUPEC - Higher School of Choletais",
    ],
    ".schloss-online.eu": ["Gymnasium am kurfuerstlichen Schloss Mainz"],
    ".schoolmath.eu": [
        'Математическа Гимназия "Акад. Кирил Попов" Пловдив',
        'High School of Mathematics "Acad. Kiril Popov"',
    ],
    ".sciencespo-lille.eu": [
        "Sciences Po Lille",
        "Lille Institute of political studies",
    ],
    ".sekundarschule-soest.eu": ["Sekundar Schule Soest"],
    ".seuniversity.eu": [
        "Vysoká škola zdravotníctva a sociálnej práce sv. Alžbety",
        "St. Elizabeth College of Health and Social Work",
    ],
    ".sghm.eu": [
        "Schiller-Gymnasium Hameln",
        "-Homepage: https://www.sghm.de",
        '  -The menu on the left hand side has the point Iserv sghm.eu. This is a reference to the domain, I want to register. It is used by Students in the Administration Program "IServ" at https://sghm.eu',
        "-MINT (STEM) Concept: https://www.sghm.de/Lernen_am_Schiller/mintbereich/index.htm",
        '  -In "Unterricht" (Top, Center) the Computer Science Course (Informatik, IF) is listed. It is offered from grade 8-11 and as an "Abitur"/Advanced Course in grades 12 and 13.',
        "In case of any questions regarding the registration process, please contact me under christoph.barth@sghm.eu or thiemann@sghm.eu",
    ],
    ".sgsintpaulus.eu": ["Sintpaulusschool"],
    ".citycollege.sheffield.eu": [
        "The University of Sheffield International Faculty, CITY College"
    ],
    ".spsbj.eu": ["SPŠT Bardejov"],
    ".spsjm.eu": ["Stredná priemyselná škola Jozefa Murgaša, Banská Bystrica"],
    ".spst.eu": ["Střední průmyslová škola, Třebíč"],
    ".sstebrno.eu": [
        "Střední škola technická a ekonomická Brno, Olomoucká, příspěvková organizace"
    ],
    ".steinbart-gym.eu": ["Steinbart Gymnasium Duisburg"],
    ".stlouis26-e.eu": ["Ensemble Scolaire Catholique Saint-Louis Crest"],
    ".stmf-elearn.eu": ["St. Michael Foundation"],
    ".teb-eu.eu": ["Thomas-Eßer-Berufskolleg Euskirchen"],
    ".telecom-bretagne.eu": ["Telecom Bretagne"],
    ".telecom-em.eu": ["Télécom École de Management"],
    ".telecom-sudparis.eu": ["Télécom SudParis"],
    ".telecomnancy.eu": ["TELECOM Nancy"],
    ".teleinformatika.eu": ["Střední škola teleinformatiky, Ostrava, p.o."],
    ".tismbree.eu": ["TISM Bree"],
    ".tls-giessen.eu": ["Theodor-Litt-Schule Gießen"],
    ".tmg-daun.eu": ["Thomas-Morus-Gymnasium", "Website: tmg-daun.de"],
    ".uib.eu": ["Universitat de les Illes Balears"],
    ".unifortunato.eu": ["Giustino Fortunato University"],
    ".unilodz.eu": ["Uniwersytet Łódzki"],
    ".unint.eu": ["UNINT Università degli Studi Internazionali di Roma"],
    ".uniroma2.eu": ["University of Tor Vergata"],
    ".utad.eu": ["Universidade de Trás-os-Montes e Alto Douro"],
    ".varosmajor.eu": [
        "Városmajori Gimnázium",
        "https://varosmajor.eu/ Varosmajor HighSchool",
    ],
    ".vpsmb.eu": [
        "Višja prometna šola Maribor, Slovenija",
        "Higher Transport School Maribor, Slovenia",
        "https://prometna.net/visja-sola",
        "https://prometna.net/visja-sola/about-vctt",
    ],
    ".vumk.eu": ["International University College"],
    ".wittenborg.eu": ["Wittenborg University"],
    ".student.wsinf.eu": [
        "University of Computer Sciences and Skills in Łódź"
    ],
    ".yschools.eu": ["Yschools"],
    ".zielone.eu": [
        "Zespół\xa0Szkół im. Jędrzeja Śniadeckiego w Pionkach",
        "Jędrzej Śniadecki School Complex in Pionki",
    ],
    ".zs710.eu": [
        "Zakladni skola Bucovice 710",
        "Primary School Bucovice 710",
    ],
    ".zsge.eu": [
        "Zespół Szkół Górniczo-Energetycznych im. Stanisława Staszica"
    ],
    ".zszatopkovych.eu": ["ZS Dany a Emila Zatopkovych, Trinec, prisp. org."],
    ".ikasle.aeg.eus": ["AEG Ikastetxea"],
    ".birt.eus": [
        "BIRTLH / CIFP de aprendizajes virtuales y digitalizados, Vitoria, Basque Country"
    ],
    ".doloresibarruribhi.eus": ["Dolores Ibarruri BHI"],
    ".ehu.eus": ["University of the Basque Country"],
    ".irakasle.eus": ["Escuela publica del Gobierno Vasco en el Pais Vasco"],
    ".maltuna.eus": ["CIFP Miguel Altuna LHII"],
    ".mendizabala.eus": ["010138 CIFP MENDIZABALA LHII"],
    ".olabide.eus": ["Olabide Ikastola Koop. Elk."],
    ".plaiaundi.eus": ["IES Plaiaundi BHI", "Plaiaundi Vocational Institute"],
    ".tolosaldealh.eus": ["Tolosaldealh"],
    ".uhei.eus": ["UHEI UVED"],
    ".uni.eus": ["IES Uni Eibar-Ermua BHI"],
    ".Prakticum.fi": ["Prakticum  framtidsskolan"],
    ".aalto.fi": ["Aalto University"],
    ".abo.fi": ["Abo Akademi University"],
    ".arcada.fi": ["Arcada University of Applied Sciences"],
    ".edu.bc.fi": [
        "Suomen Liikemiesten Kauppaopisto",
        "Business College Helsinki",
    ],
    ".bc.fi": [
        "Suomen Liikemiesten Kauppaopisto",
        "Business College Helsinki",
    ],
    ".careeria.fi": [
        "Careeria, Vocational school in finland",
        "https://careeria.fi/en/",
        "https://careeria.fi/koulutus/tieto-ja-viestintatekniikan-perustutkinto-ohjelmistokehittaja/",
        "https://careeria.fi/en/contact-information/",
    ],
    ".centria.fi": ["Centria University of Applied Sciences"],
    ".cou.fi": ["Central Ostrobothnia University of Applied Sciences"],
    ".diak.fi": ["Diaconia University of Applied Sciences"],
    ".eduespoo.fi": [
        "All schools in the city of Espoo, Finland",
        "    ",
        ".group",
    ],
    ".oppilas.eduhat.fi": ["Parolan Yhteiskoulu", "Parola Co-Educational"],
    ".eduouka.fi": ["The City of Oulu Department of Education"],
    ".eduvammalanlukio.fi": ["Vammala/Sastamala High School, Finland"],
    ".opp.eduvantaa.fi": [
        "Vantaan ammattiopisto Varia",
        "Vocational College Varia",
    ],
    ".eduvantaa.fi": [
        "Vantaan ammattiopisto Varia",
        "Vocational College Varia",
    ],
    ".engs.fi": ["The English School Helsinki"],
    ".edu.espoo.fi": ["All schools in the city of Espoo, Finland"],
    ".evtek.fi": ["EVTEK University of Applied Sciences"],
    ".gradia.fi": ["Gradia", "Jyväskylän koulutuskuntayhtymä Gradia"],
    ".haaga-helia.fi": ["HAAGA-HELIA University of Appliced Sciences"],
    ".hamk.fi": [
        "HAMK University of Applied Sciences",
        "Hämeen ammattikorkeakoulu",
    ],
    ".hanken.fi": ["Hanken School of Economics"],
    ".edu.hel.fi": ["All schools in the city of Helsinki, Finland"],
    ".helsinki.fi": ["University of Helsinki"],
    ".hive.fi": ["Hive Helsinki"],
    ".hkkk.fi": ["Helsinki School of Economics and Business Administration"],
    ".hut.fi": ["Helsinki University of Technology"],
    ".edu.hyria.fi": ["Hyria koulutus", "Hyria education"],
    ".oppilas.hyvinkaa.fi": ["Tapainlinnan Koulu"],
    ".inlive.fi": ["Ammattiopisto Live", "teachers email"],
    ".jamk.fi": ["JAMK University of Applied Sciences"],
    ".edu.jamsa.fi": ["Jämsän lukio", "Jämsä General Upper Secondary School"],
    ".edu.jarvenpaa.fi": [
        "Koulut Järvenpäässä",
        "Schools in Järvenpää, Finland",
    ],
    ".jedu.fi": ["Vocational school of Oulainen"],
    ".joensuu.fi": ["University of Joensuu"],
    ".jyu.fi": ["University of Jyväskylä"],
    ".koulut.kaarina.fi": ["All schools in the city of Kaarina, Finland"],
    ".edu.kalajoki.fi": ["Kalajoen koulut", "Schools in Kalajoki, Finland"],
    ".kamk.fi": ["Kajaani University of Applied Sciences"],
    ".karelia.fi": ["Karelia University of Applied Sciences"],
    ".edu.karstula.fi": [
        "Karstulan lukio, Karstula",
        "Karstula Upper Secondary School",
    ],
    ".student.karstula.fi": [
        "Karstulan lukio, Karstula",
        "Karstula Upper Secondary School",
    ],
    ".kauniaistenlukio.fi": ["High school of Kauniainen"],
    ".edu.kempele.fi": ["Kempeleen lukio"],
    ".kktavastia.fi": [
        "Koulutuskuntayhtymä Tavastia",
        "Tavastia Education Consortium",
    ],
    ".edu.kokkola.fi": ["All schools in the city of Kokkola, Finland"],
    ".edu.kotka.fi": ["All schools in the city of Kotka, Finland"],
    ".koudata.fi": ["Kouvola Region Vocational College"],
    ".koulu-isk.fi": ["Itä-Suomen koulu", "School of Eastern Finland"],
    ".kpedu.fi": [
        "Keski-Pohjanmaan ammattiopisto",
        "Central Ostrobothnia Vocational College",
    ],
    ".edu.kuopio.fi": ["Schools in the city of Kuopio"],
    ".kuva.fi": ["Academy of Fine Arts"],
    ".kyamk.fi": ["Kymenlaakso University of Applied Sciences"],
    ".student.lab.fi": ["LAB university of applied sciences"],
    ".edu.lahti.fi": ["All schools in the city of Lahti, Finland"],
    ".lamk.fi": ["Lahti Polytechnic"],
    ".edu.lao.fi": ["State-run vocational schools in Lapland"],
    ".lapinamk.fi": ["Lapland University of Applied Sciences"],
    ".lappee.fi": ["Lappeenrannan Lyseon lukio"],
    ".laurea.fi": [
        "Laurea University of Applied Science",
        "laurea ammattikorkeakoulu",
        "Website: https://www.laurea.fi/en",
        "Domains: @laurea.fi",
    ],
    ".liveopisto.fi": ["ammattiopisto live"],
    ".edu.lohja.fi": [
        "Lohjan Yhteislyseon lukio",
        "Lohja Upper Secondary School",
    ],
    ".edu.loimaa.fi": ["Schools in and near Loimaa,Finland"],
    ".edu.luksia.fi": [
        "Luksia, Länsi-Uudenmaan koulutuskuntayhtymä",
        "Luksia, Western Uusimaa Municipal Training and Education Consortium",
    ],
    ".lut.fi": ["Lappeenranta University of Technology"],
    ".lyk.fi": ["Lahden Yhteiskoulu"],
    ".mamk.fi": ["Mikkeli University of Applied Sciences"],
    ".mayk.fi": [
        "Maunula Secondary School and Helsinki Math School (Maunulan yhteiskoulu ja Helsingin matematiikkalukio)"
    ],
    ".metropolia.fi": ["Helsinki Metropolia University of Applied Sciences"],
    ".munkka.fi": ["Munkka Secondary School (Munkkiniemen Yhteiskoulu)"],
    ".edu.nivala.fi": ["Nivalan Sivistystoimi"],
    ".normaalilyseo.fi": ["Helsingin normaalilyseo"],
    ".edu.novia.fi": ["Novia University of Applied Sciences"],
    ".oamk.fi": ["Oulu Polytechnic"],
    ".omnia.fi": ["Omnia"],
    ".osao.fi": ["Oulu Vocational College"],
    ".oulu.fi": ["University of Oulu"],
    ".edu.petajavesi.fi": [
        "Petäjäveden lukio, Petäjävesi",
        "Petäjävesi Upper Secondary School",
    ],
    ".puv.fi": ["Vaasa University of Applied Sciences"],
    ".ramk.fi": ["Rovaniemi University of Applied Sciences"],
    ".edu.raseko.fi": ["Rasekon ammattiopisto", "Raseko Vocational School"],
    ".redu.fi": ["State-run vocational schools in Lapland"],
    ".edu.riveria.fi": ["Riveria"],
    ".roiedu.fi": ["State-run schools of Rovaniemi"],
    ".saimia.fi": ["Saimaa University of Applied Sciences"],
    ".sakky.fi": ["Savon ammattiopisto"],
    ".sallacampus.fi": ["Sallan lukio, Salla", "Salla Upper Secondary School"],
    ".salpaus.fi": ["Salpaus college"],
    ".samk.fi": ["Satakunta University Of Applied Scinces"],
    ".sasky.fi": [
        "SASKY koulutuskuntayhtymä",
        "SASKY Municipal Education and Training Consortium",
    ],
    ".savonia.fi": ["Savonia University of Applied Sciences"],
    ".scp.fi": ["South Carelian Polytechnic"],
    ".seamk.fi": ["Seinäjoki University of Applied Sciences"],
    ".shh.fi": [
        "Swedish School of Economics and Business Administration, Finland"
    ],
    ".siba.fi": ["Sibelius Academy"],
    ".edu.siikalatva.fi": ["Siikalatvan lukio"],
    ".syk.fi": [
        "Helsingin Suomalainen Yhteiskoulu",
        "Helsinki Finnish co-educational school",
        "https://syk.fi/ib-subjects-at-syk/",
        "https://syk.fi/syk/yhteystiedot/",
    ],
    ".taitajantie.fi": ["Aikuiskoulutus Taitaja"],
    ".tamk.fi": ["Tampere University of Applied Sciences "],
    ".edu.tampere.fi": [
        "Tampereen teknillinen lukio",
        "Tampere High School of Technology",
    ],
    ".teak.fi": ["Theatre Academy Finland"],
    ".tiedenorssi.fi": ["Oulun Normaalikoulu"],
    ".tpu.fi": ["Tampere Polytechnic"],
    ".tukkk.fi": ["Turku School of Economics and Business Administration"],
    ".tuni.fi": ["Tampere University, Tampere"],
    ".edu.turku.fi": ["Turku Schools"],
    ".turkuamk.fi": ["Turku University of Applied Sciences"],
    ".tut.fi": ["Tampere University of Technology"],
    ".edu.tuusula.fi": ["Tuuusulan Sivistystoimi"],
    ".tyk.fi": ["Töölön Yhteiskoulu"],
    ".uef.fi": ["University of Eastern Finland"],
    ".uku.fi": ["University of Kuopio"],
    ".ulapland.fi": ["University of Lapland"],
    ".uniarts.fi": ["University of the Arts Helsinki"],
    ".uta.fi": ["University of Tampere"],
    ".utu.fi": ["University of Turku"],
    ".uwasa.fi": ["University of Vaasa"],
    ".edu.vaao.fi": ["Valkeakosken Ammattiopisto"],
    ".student.vaasa.fi": [
        "Vamia",
        "vamia, vocational school in Vaasa, Finland",
    ],
    ".vamk.fi": ["Vaasa University of Applied Sciences"],
    ".xamk.fi": ["South-Eastern Finland University of Applied Sciences"],
    ".edu.ylojarvi.fi": [
        "\ufeffYlöjärven Yhtenäiskoulu",
        "Ylöjärvi's Comprehensive school",
    ],
    ".fnu.ac.fj": ["Fiji National University "],
    ".fsm.ac.fj": ["Fiji School of Medicine"],
    ".unifiji.ac.fj": ["University of Fiji"],
    ".comfsm.fm": ["College of Micronesia"],
    ".setur.fo": ["University of the Faroe Islands"],
    ".tsk.fo": ["Tekniski skúlin í klaksvík", "technical school in klaksvÍk"],
    ".18.06.fr": ["École 18.06"],
    ".3il.fr": ["ÉCOLE D'INGÉNIEURS EN INFORMATIQUE"],
    ".42.fr": ["Ecole 42"],
    ".42angouleme.fr": ["42 Angoulême"],
    ".student.42lehavre.fr": ["42 Le Havre", "https://www.42lehavre.fr"],
    ".student.42lyon.fr": ["42 LYON", "42 LYON"],
    ".42mulhouse.fr": [
        "42 Mulhouse",
        "42 Mulhouse Grand Est",
        "Ecole 42 Mulhouse",
        "School 42 Mulhouse",
    ],
    ".42nice.fr": ["42 Nice"],
    ".student.42perpignan.fr": ["42 Perpignan"],
    ".ac-aix-marseille.fr": ["Académie d'Aix-Marseille"],
    ".ac-amiens.fr": ["Adadémie d'Amiens"],
    ".ac-besancon.fr": ["Académie de Besançon"],
    ".ac-bordeaux.fr": ["Académie de Bordeaux"],
    ".ac-caen.fr": ["Académie de Caen"],
    ".ac-clermont.fr": ["Académie de Clermont-Ferrand"],
    ".ac-corse.fr": ["Académie de Corse"],
    ".ac-creteil.fr": ["Académie de Créteil"],
    ".ac-dijon.fr": ["Académie de Dijon"],
    ".ac-grenoble.fr": ["Académie de Grenoble"],
    ".ac-guadeloupe.fr": ["Académie de Guadeloupe"],
    ".ac-guyane.fr": ["Académie de la Guyane"],
    ".ac-lille.fr": ["Académie de Lille"],
    ".ac-limoges.fr": ["Académie de Limoges"],
    ".ac-lyon.fr": ["Académie de Lyon"],
    ".ac-martinique.fr": ["Académie de Martinique"],
    ".ac-mayotte.fr": ["Académie de Mayotte"],
    ".ac-montpellier.fr": ["Académie de Montpellier"],
    ".ac-nancy-metz.fr": ["Académie de Nancy-Metz"],
    ".ac-nantes.fr": ["Académie de Nantes"],
    ".ac-nice.fr": ["Académie de Nice"],
    ".ac-normandie.fr": ["Lycée Jean Rostand Caen"],
    ".ac-orleans-tours.fr": ["Académie d'Orléans-Tours"],
    ".ac-paris.fr": ["Académie de Paris", "ifocop"],
    ".ac-poitiers.fr": ["Académie de Poitiers"],
    ".ac-reims.fr": ["Académie de Reims"],
    ".ac-rennes.fr": ["Académie de Rennes"],
    ".ac-reunion.fr": ["Académie de la Réunion"],
    ".ac-rouen.fr": ["Académie de Rouen"],
    ".ac-strasbourg.fr": ["Académie de Strasbourg"],
    ".ac-toulouse.fr": ["Académie de Toulouse"],
    ".ac-versailles.fr": ["Académie de Versailles"],
    ".student.adatechschool.fr": ["Ada Tech School"],
    ".adatechschool.fr": ["Ada Tech School"],
    ".aege.fr": ["Ecole de guerre economique", "Economic Warfare School"],
    ".aformac.fr": ["aformac"],
    ".afpa-dev-pompey.fr": [
        "Agence nationale pour la Formation Professionnelle des Adultes"
    ],
    ".afpa-montpellier.fr": ["AFPA MONTPELLIER"],
    ".afpa.fr": [
        "Agence nationale pour la Formation Professionnelle des Adultes"
    ],
    ".app.afpma.fr": ["AFPMA", "AFPMA"],
    ".agro-bordeaux.fr": ["Bordeaux Sciences Agro"],
    ".agrocampus-ouest.fr": ["Agro Campus Ouest", "West Agro Campus"],
    ".agroparistech.fr": ["AgroParisTech"],
    ".algoudlaffemas.fr": ["Lycée Algoud Laffemas"],
    ".archi.fr": ["Ecole d'Architecture de Nancy"],
    ".artfx.fr": ["ArtFX Digital Arts school, Montpellier, France"],
    ".asparis.fr": ["American School of Paris"],
    ".aea.asso.fr": ["Ecole de l'Air"],
    ".arfp.asso.fr": ["Centre de Réadaptation de Mulhouse"],
    ".essca.asso.fr": ["Ecole Supérieure des Sciences Commerciales d'Angers"],
    ".fupl.asso.fr": [
        "Ecole Supérieure des Techniques Industrielles et des Textiles",
        "Institut Supérieur d'Agriculture Lille",
        "Université Catholique de Lille",
    ],
    ".lyon.ort.asso.fr": ["ORT Lyon Sup'"],
    ".toulouse-ort.asso.fr": [
        "ORT Toulouse",
        "# toulouse-ort.asso.fr",
        "# ...@toulouse-ort.asso.fr",
    ],
    ".audencia.fr": ["Audencia Nantes"],
    ".auon.fr": ["Aix-Uzes Occitanie Nord Universite"],
    ".aup.fr": ["American University of Paris"],
    ".ent.auvergnerhonealpes.fr": ["Lycée Des Horizons", "Human Booster"],
    ".auxlazaristeslasalle.fr": ["CPGE Aux Lazaristes"],
    ".bde-insa-lyon.fr": ["Institut National des Sciences Appliquées de Lyon"],
    ".berlyn.fr": ["Berlyn International Academy"],
    ".bginette.fr": [
        "Lycée Privée Sainte-Geneviève",
        "St-Genevieve preparatory classes",
        "Ginette ",
    ],
    ".bordeaux-inp.fr": ["Institut polytechnique de Bordeaux (Bordeaux INP)"],
    ".brgm.fr": [
        "BRGM, Service Géologique National",
        "French Geological Survey",
    ],
    ".bts-lachartreuse.fr": ["Étudiants en BTS au pôle la chartreuse"],
    ".bts-sio-eiffel.fr": ["Lycée Gustave Eiffel", "BTS SIO - cybersécurité"],
    ".campus-centre.fr": [
        "CCi Campus Centre",
        "-Chambre de Commerce et d'Industrie de l'Indre",
        "-Called aswell CCI Campus Centre",
        "Official website of the school:",
        "https://www.campus-centre.fr/",
    ],
    ".campus-eni.fr": [
        "http://www.eni-ecole.fr/",
        "Formations diplômantes aux métiers de l’informatique",
        "Titres homologués par l'Etat Bac+2 à Bac+5",
    ],
    ".campus-igs-toulouse.fr": [
        "Campus IGS Toulouse - Ecole en Informatique IPI"
    ],
    ".campus28.fr": [
        "Campus cci 28",
        "-Chambre de Commerce et d'Industrie de Chartres",
        "-Called aswell CCI Campus 28",
        "Official website of the school:",
        "https://www.campuscci.fr/",
    ],
    ".formation.aveyron.cci.fr": [
        "Chambre de Commerce et d'Industrie Aveyron"
    ],
    ".sudformation.cci.fr": ["CCI Sud Formation"],
    ".ccicampus.fr": [
        "-Chambre de Commerce et d'Industrie Colmar",
        "-Called aswell ccicampus",
        "-Mail are formatted like : studentId@campus28.fr",
        "Official website of the school:",
        "http://www.ccicampus.fr/",
    ],
    ".cciformation49.fr": ["CCI Formation 49"],
    ".cciformation72.fr": ["ekod"],
    ".centrale-marseille.fr": ["Ecole Centrale Marseille"],
    ".centrale.centralelille.fr": ["Ecole Centrale de Lille"],
    ".ig2i.centralelille.fr": [
        "Institut de génie informatique et industriel (Département de Centrale Lille)"
    ],
    ".centralelille.fr": ["Centrale Lille"],
    ".centralesupelec.fr": ["CentraleSupélec"],
    ".cesi.fr": ["Centre d'Etudes Supérieures Industrielles Paris"],
    ".cfa-afti.fr": [
        "École supérieure du Numérique Industriel",
        "http://www.cfa-afti.com/",
    ],
    ".cfa-insta.fr": ["Centre de formation d'apprenties Insta"],
    ".cfai-formation.fr": [
        "Institut des Techniques d'Ingénieur de l'Industrie (ITII)",
        "Conservatoire National des Arts et Métiers (CNAM)",
        "Centre de Formation d'Apprentis de l'Industrie (CFAI)",
    ],
    ".cfautec.fr": [
        "CFA - UTEC",
        "School website : ",
        "\thttps://www.utec77.fr/",
        "IT related course 1 :",
        "\thttps://www.utec77.fr/jeunes/diplomes-filiere/informatique/-technologies-numeriques/bts-services-informatiques-0",
        "IT related course 2 :",
        "\thttps://www.utec77.fr/jeunes/diplomes-filiere/informatique-technologies-numeriques-fibre-optique/developpeur-charge",
        "IT related course 3 :",
        "\thttps://www.utec77.fr/jeunes/diplomes-filiere/informatique/-technologies-numeriques/manager-ingenierie-informatique",
        "proof domain :",
        "\thttps://imgur.com/dq137sI",
    ],
    ".edu.cfi-formations.fr": ["CFI"],
    ".chu-bordeaux.fr": [
        "Centre Hospitalier Universitaire Bordeaux",
        " University Hospital Center of Bordeaux",
    ],
    ".clermont-sb.fr": ["Clermont School of Business"],
    ".cloud-campus.fr": ["CLOUD CAMPUS"],
    ".cnam-ara.fr": [
        "\ufeffConservatoire National des Arts et Métiers - Auvergne Rhône-Alpes"
    ],
    ".cnam-enjmin.fr": [
        "École nationale du jeu et des médias interactifs numériques"
    ],
    ".cnam-picardie.fr": [
        "Conservatoire National des Arts et Métiers - Picardie"
    ],
    ".cnam.fr": ["Conservatoire National des Arts et Métiers"],
    ".cnearc.fr": [
        "Centre National d'Etudes Agronomiques des Régions Chaudes"
    ],
    ".cnsmdp.fr": [
        "Conservatoire National Supérieur de Musique et de Danse de Paris"
    ],
    ".coding-academy.fr": ["Coding Academy"],
    ".cohl.fr": ["+École d'art Emile Cohl de Lyon"],
    ".college-de-france.fr": ["Collège de France", "Collège de France"],
    ".collegecharlespeguy.fr": [
        "Collège privé catholique Charles Peguy - EIC Tourcoing"
    ],
    ".collegekarr.fr": ["Collège Alphonse Karr"],
    ".cpe.fr": ["Ecole Supérieure de Chimie Physique Electronique de Lyon"],
    ".cs2i-lorient.fr": ["CCI 56 Ecole Supérieure d'Informatique CS2i"],
    ".csilyon.fr": [
        "Cité Scolaire Internationale de Gerland",
        "International City School of Gerland",
    ],
    ".curie.fr": [
        "Centre de lutte contre le cancer Curie - Université Pierre et Marie Curie"
    ],
    ".cy-tech.fr": [
        "CY Tech | CY Cergy Paris Université",
        "CY Tech | CY Cergy Paris University",
    ],
    ".etu.cyu.fr": ["CY Cergy Paris Université", "CY Cergy Paris Université"],
    ".cyu.fr": ["CY Cergy Paris Université", "CY Cergy Paris Université"],
    ".dauphine.fr": ["Université Paris-Dauphine (Paris IX)"],
    ".edu.ifa.delorozoy.fr": [
        "Institut de Formation par Alternance Robert Delorozoy"
    ],
    ".devinci.fr": ["Ecole Superieur d'Ingenieurs Leonard de Vinci"],
    ".diginamic.fr": ["Diginamic"],
    ".etu.digitalschool.fr": ["IEF2I - Digital School of Paris (DSP)"],
    ".malraux.paysdelaloire.e-lyco.fr": [
        "Lycée André Malraux - Allonnes",
        "André Malraux High School",
    ],
    ".eap.fr": ["Ecole Européen des Affaires"],
    ".ec-lille.fr": ["Ecole Centrale de Lille"],
    ".ec-lyon.fr": ["Ecole Centrale de Lyon"],
    ".ec-nantes.fr": ["Ecole Centrale de Nantes"],
    ".ecam.fr": ["ECAM La Salle"],
    ".ece.fr": ["Ecole Centrale d'Electronique - ECE"],
    ".edu.ecetech.fr": ["Ecole Centrale d'Electronique - ECE"],
    ".ecole-air.fr": [
        "+En: French Air Force Academy",
        "+Fr: Ecole de l'Air",
        "+",
        "+website: http://www.ecole-air.fr/",
    ],
    ".ecole-isitech.fr": [
        "+email domaine : ecole-isitech.fr ==> école d'expert en système d'information by  shoog",
        " +website : http://www.ecole-isitech.com",
    ],
    ".ecole-navale.fr": [
        "En: French Naval Academy",
        "Fr: Ecole Navale",
        "website: https://www.ecole-navale.fr/",
    ],
    ".ecole-webstart.fr": ["Webstart"],
    ".ecole404.fr": ["Ecole 404"],
    ".ecoledeturing.fr": ["École de Turing", "https://ecoledeturing.fr"],
    ".ecoledulouvre.fr": ["ECOLE DU LOUVRE"],
    ".etudiant.ecolemelies.fr": ["Ecole Georges Méliès"],
    ".ecp.fr": ["Centrale Paris"],
    ".etu.ecvdigital.fr": ["Ecv digital"],
    ".edenschool.fr": ["EDENSchool"],
    ".edmond-labbe.fr": ["Lycee Edmond Labbe "],
    ".edouardgand.fr": ["Lycée Édouard Gand", "Édouard Gand High School"],
    ".edu-groupesaintmichel.fr": ["Groupe Saint Michel"],
    ".eduhdf.fr": ["Lycée Edouard Branly Amiens"],
    ".eduprovence.fr": ["Collège Roy d'Espagne"],
    ".efficom-lille.fr": ["Efficom Lille"],
    ".efrei.fr": ["Ecole Française d'Electronique et d'Informatique"],
    ".eleve.ehesp.fr": ["Ecole des hautes études en santé publique"],
    ".ehess.fr": ["School for Advanced Studies in the Social Sciences"],
    ".eigsi.fr": ["Ecole d'ingénieurs"],
    ".eilco-ulco.fr": ["Ecole d'ingénieur du littoral côte d'opale"],
    ".eisti.fr": [
        "École internationale des sciences du traitement de l'information"
    ],
    ".eivp-paris.fr": ["Ecole des Ingénieurs de la Ville de Paris"],
    ".emse.fr": ["Ecole Nationale Supérieure des Mines de St-Etienne"],
    ".emweb.fr": ["L'école des métiers du web"],
    ".en3s.fr": ["Ecole Nationale Supérieure de Sécurité Sociale"],
    ".ena.fr": ["Ecole Nationale d'Administration"],
    ".enac.fr": ["Ecole Nationale de l'Aviation Civile"],
    ".enc-sorbonne.fr": ["École Nationale des Chartes"],
    ".enib.fr": ["École Nationale d'Ingénieurs de Brest"],
    ".enic.fr": ["ENIC Telecom Lille 1"],
    ".enim.fr": ["Ecole Nationale d'Ingénieurs de Metz"],
    ".enise.fr": ["Ecole Nationale d'Ingénieurs de Saint-Etienne"],
    ".enit.fr": ["Ecole Nationale d'Ingénieurs de Tarbes"],
    ".enitab.fr": [
        "Ecole Nationale d'Ingénieurs des Travaux Agricoles de Bordeaux"
    ],
    ".enitiaa-nantes.fr": [
        "Ecole Nationale d'Ingénieurs des Techniques des Industries Agricoles et Alimentaires"
    ],
    ".enpc.fr": ["Ecole Nationale des Ponts et Chausees"],
    ".ens-cachan.fr": ["Ecole Normale Supérieure de Cachan"],
    ".ens-fcl.fr": ["Ecole Normale Supérieure de Fontenay-Saint Cloud"],
    ".ens-lyon.fr": ["Ecole Normale Supérieure de Lyon"],
    ".ens-paris-saclay.fr": ["ENS Paris-Saclay"],
    ".ens-rennes.fr": ["École Nationale Supérieure de Rennes"],
    ".ens.fr": [
        "Ecole Normale Supérieure de Paris",
        "École Normale Supérieure de Paris",
    ],
    ".ens2m.fr": [
        "Ecole Nationale Supérieur de Mécaniques et des Microtechniques"
    ],
    ".ensae-paristech.fr": ["Paris Graduate School of Economics"],
    ".ensae.fr": [
        "Ecole Nationale de la Statistique et de l'Administration Economique"
    ],
    ".ensai.fr": [
        "Ecole Nationale de la Statistique et de l'Analyse de l'information"
    ],
    ".ensait.fr": [
        "Ecole Nationale Supérieure des Arts et Industries Textiles"
    ],
    ".ensam.fr": ["Ecole Nationale Supérieure d'Arts et Métiers de Paris"],
    ".ensat.fr": ["Ecole Nationale Supérieure Agronomique de Toulouse"],
    ".ensba-lyon.fr": ["ENSBA", "National School of Fine Arts of Lyon"],
    ".ensc-lille.fr": ["Ecole Nationale Supérieure de Chimie de Lille"],
    ".ensc-rennes.fr": ["Ecole Nationale Supérieure de Chimie de Rennes"],
    ".ensc.fr": ["Ecole Nationale Supérieure de Cognitique"],
    ".enscm.fr": ["Ecole Nationale Supérieure de Chimie de Montpellier"],
    ".ensea.fr": [
        "Ecole Nationale Supérieure de l'Electronique et de ses Applications"
    ],
    ".enseeiht.fr": [
        "Ecole Nationale Supérieure d'Electronique, d'Electrotechnique, d'Informatique et d'Hydraulique de Toulouse",
        "Ecole Nationale Supérieure en Electrotechnique, Electronique, Informatique et Hydraulique de Toulouse",
    ],
    ".enseignement-catholique-ledonien.fr": ["Collège et Lycées Sainte-Marie"],
    ".enseignementprive-lons.fr": ["Lycée Sainte-Marie Lons-le-Saunier jura"],
    ".enseirb-matmeca.fr": ["Bordeaux Institute of Technlogy"],
    ".enserg.fr": [
        "Ecole Nationale Supérieure d'Electronique et de Radioelectricite de Grenoble"
    ],
    ".ensiacet.fr": ["INP ENSIACET"],
    ".ensica.fr": [
        "Ecole Nationale Supérieur d'Ingénieurs de Constructions Aéronautique",
        "École Nationale Supérieure d'Ingénieurs de Constructions Aéronautiques",
    ],
    ".ensicaen.fr": ["Ecole Nationale Supérieure d'Ingénieurs de Caen"],
    ".ensiie.fr": [
        "École nationale supérieure d'informatique pour l'industrie et l'entreprise"
    ],
    ".ensimag.fr": ["Grenoble INP Ensimag"],
    ".ensm-ales.fr": ["Ecole Nationale Supérieure des Mines d'Alès"],
    ".ensm-douai.fr": ["Ecole Nationale Supérieure des Mines de Douai"],
    ".ensma.fr": ["Ecole Nationale Supérieur de Mécanique et d'Aéronautique"],
    ".ensmp.fr": ["Ecole Nationale Supérieure des Mines de Paris"],
    ".enssat.fr": [
        "École Nationale Supérieure des Sciences Appliquées et de Technologie",
        "advanced national college of applied science and technology",
    ],
    ".enssib.fr": [
        "École Nationale Supérieure des Sciences de l'Information et des Bibliothèques (ENSSIB)"
    ],
    ".enst-bretagne.fr": [
        "Ecole Nationale Supérieure des Telecommunications de Bretagne"
    ],
    ".enst.fr": ["Ecole Nationale Supérieure des Telecommunications de Paris"],
    ".ensta-bretagne.fr": ["ENSTA Bretagne"],
    ".ensta-paris.fr": ["Ecole Nationate Superieure des Techniques Avancées"],
    ".ensta-paristech.fr": ["ENSTA ParisTech"],
    ".ensta.fr": ["Ecole Nationale Supérieure de Techniques Avancées"],
    ".ent-st-joseph-hasparren.fr": [
        "Lycée Général Technologique et Professionnel Saint Joseph"
    ],
    ".entpe.fr": ["Ecole Nationale des Travaux Publics de l'Etat"],
    ".envt.fr": ["Ecole Nationale Vétérinaire de Toulouse"],
    ".epf.fr": ["EPF Ecole d'Ingénieurs"],
    ".epid-vauban.fr": [],
    ".epin.fr": ["EPIN"],
    ".epita.fr": ["École Pour l'Informatique et les Techniques Avancées"],
    ".epitech.fr": ["L'Ecole de l'innovation et de l'expertise informatique."],
    ".epsi.fr": ["Ecole Privée des Sciences Informatiques"],
    ".es-be.fr": ["Saint Michel des Batignolles"],
    ".esa-purpan.fr": ["Ecole Supérieure d'Agriculture de Purpan"],
    ".esad-pyrenees.fr": [
        "École supérieure d'art et de design des Pyrénées",
        "Pyrenees College of Art and Design",
    ],
    ".esadd.fr": ["Esadd école supérieur appliquée au design et au digital"],
    ".esadtpm.fr": [
        "Ecole supérieure d'art et de design Toulon métropole",
        "ESADTPM",
    ],
    ".esc-bordeaux.fr": ["Ecole Supérieure de Commerce de Bordeaux"],
    ".esc-brest.fr": ["Ecole Supérieure de Commerce de Brest"],
    ".esc-clermont.fr": ["Ecole Supérieure de Commerce de Clermont-Ferrand"],
    ".esc-grenoble.fr": ["Ecole Supérieure de Commerce de Grenoble"],
    ".esc-lille.fr": ["Ecole Supérieure de Commerce de Lille"],
    ".esc-pau.fr": ["Ecole Supérieure de Commerce de Pau"],
    ".esc-rouen.fr": ["Ecole Supérieure de Commerce de Rouen"],
    ".esc-toulouse.fr": ["Ecole Supérieure de Commerce de Toulouse"],
    ".escem.fr": ["Ecole Supérieure de Commerce et Management"],
    ".escna.fr": ["Ecole Supérieure de Commerce de Nantes-Atlantique"],
    ".escom.fr": ["Ecole Supérieure de Chimie Organique et Minérale"],
    ".escp.fr": ["Ecole Supérieure de Commerce de Paris"],
    ".eseo.fr": ["Ecole Supérieure d'Electronique de l'Ouest"],
    ".esg.fr": ["ESG - Ecole de commerce"],
    ".esgi.fr": ["\ufeffESGI (Ecole Supérieure de Génie Informatique)"],
    ".esh64.fr": ["Ensemble Scolaire Hazparne"],
    ".esi-metz.fr": ["ESI Metz, France"],
    ".esiae.fr": [
        "Ecole Supérieure Internationale d'Administration des Entreprises"
    ],
    ".et.esiea.fr": [
        "École Supérieure d'Informatique-Électronique-Automatique"
    ],
    ".esiea.fr": ["Ecole Supérieure d'Informatique-Electronique-Automatique"],
    ".esiee-amiens.fr": [
        "Ecole Supérieure d'Ingénieurs en Electronique et Electrotechnique - Amiens"
    ],
    ".edu.esiee-it.fr": ["CodingFactory Esiee-IT"],
    ".esiee.fr": [
        "Ecole Supérieure d'Ingénieurs en Electronique et Electrotechnique"
    ],
    ".esigelec.fr": ["Ecole Supérieure d'Ingénieurs en Génie Electrique"],
    ".esigetel.fr": [
        "Ecole d’ingénieur généraliste en systèmes numériques & objets communicants"
    ],
    ".esimed.fr": ["École supérieur d'informatique de la Méditerranée"],
    ".esitc-paris.fr": ["ESITC PARIS", "ESITC PARIS"],
    ".esme.fr": ["Ecole Spéciale de Mécanique et d'Electricité"],
    ".espci.fr": ["Ecole Supérieure de Physique et de Chimie Industrielles"],
    ".esqese.fr": [" ESQESE"],
    ".essb.fr": ["Ensemble scolaire Saint-Benoît", ".group"],
    ".essca.fr": ["ESSCA"],
    ".essec.fr": ["Ecole Supérieure des Sciences Economiques et Commerciales"],
    ".esta-belfort.fr": ["Ecole Supérieure de Technologie et des Affaires"],
    ".estei.fr": [
        "École Supérieure des Technologies Électronique, Informatique et Infographie"
    ],
    ".etu.estia.fr": [
        "École Supérieure des Technologies Industrielles Avancées"
    ],
    ".net.estia.fr": ["Ecole d’ingénieurs ESTIA"],
    ".estia.fr": [
        "ESTIA",
        "Ecole Supérieure des Technologies Industrielles Avancées",
        "ESTIA Institute of Technology",
    ],
    ".estp.fr": [
        "Ecole Spéciale des Travaux Publics du Bâtiment et de l'Industrie"
    ],
    ".etu-upsaclay.fr": ["Université Paris Saclay"],
    ".etu-webschoolfactory.fr": ["La Web School Factory"],
    ".accueil.etud-espas.fr": ["ESTICE"],
    ".etud-ices.fr": [
        "https://ices.fr/",
        "Institut Catholique d'Études Supérieures",
    ],
    ".etudiant-sornas.fr": ["EDTA SORNAS"],
    ".eudil.fr": ["Ecole Universitaire d'Ingénieurs de Lille"],
    ".eurecom.fr": ["Institut EURECOM"],
    ".fabriquenumerique.fr": ["La Fabrique Numérique Paloise"],
    ".fac-digital-campus.fr": ["ESG - Ecole de commerce"],
    ".fac-esarc-evolution.fr": ["ESG - Ecole de commerce"],
    ".fac-esg.fr": ["ESG - Ecole de commerce"],
    ".fblasalle.fr": ["Les Franc-Bourgeois Lasalle"],
    ".flst.fr": [
        "Faculté des Sciences et Technologies (Université Catholique de Lille)"
    ],
    ".formateursifa.fr": ["Metz Numeric School"],
    ".formation-cci.fr": ["CCI Formation - CCI Haute-Savoie"],
    ".formation-cci12.fr": [
        "3iL Ingénieurs",
        "ÉCOLE D'INGÉNIEURS EN INFORMATIQUE",
    ],
    ".formation-industries-fc.fr": [
        "Pôle Formation UIMM Franche-Comté - Site de Dole"
    ],
    ".cfai.formation-industries-pdl.fr": [
        "Fab'Academy UIMM",
        "Fab'Academy UIMM",
    ],
    ".formation-technologique.fr": ["CFA de l'Industrie 84"],
    ".g-4.fr": ["Institut G4 Marseille"],
    ".gastonberger.fr": ["Lycée Gaston Berger"],
    ".gobelins.fr": ["Gobelins, l'école de l'image"],
    ".st-cyr.terre-net.defense.gouv.fr": [
        "Académie Militaire de Saint-Cyr Coëtquidan"
    ],
    ".grenoble-em.fr": ["Grenoble Ecole de Management"],
    ".ensimag.grenoble-inp.fr": [
        "École Nationale Supérieure d'Informatique et de Mathématiques Appliquées de Grenoble"
    ],
    ".etu.esisar.grenoble-inp.fr": [
        "Ecole nationale supérieure d’ingénieurs en systèmes avancés et réseaux"
    ],
    ".esisar.grenoble-inp.fr": [
        "Ecole nationale supérieure d’ingénieurs en systèmes avancés et réseaux"
    ],
    ".grenoble-inp.fr": ["Grenoble INP"],
    ".greta-formations.fr": [
        "GRETA CFA Lorraine Nord",
        "GRETA CFA Lorraine Nord",
    ],
    ".greta-sud-aquitaine.fr": ["GRETA Sud Aquitaine"],
    ".groupe-esigelec.fr": [
        "Ecole Supérieure d'Ingénieurs en Génie Electrique"
    ],
    ".groupemontroland.fr": ["PASTEUR MONT ROLAND"],
    ".guardiaschool.fr": ["Gaming Campus Paris"],
    ".gustaveroussy.fr": [
        "Centre de lutte contre le cancer Gustave Roussy - Institut Français Supérieur de Biologie Médicale (IFSBM)"
    ],
    ".h3hitema.fr": ["HITEMA"],
    ".headn.fr": ["Headn Éducation", "Headn Education"],
    ".hec.fr": ["Ecole des Hautes Etudes Commerciales"],
    ".hei.fr": ["Ecole des Hautes Etudes Industrielles de Lille"],
    ".hetic.fr": ["Hetic"],
    ".iae-toulouse.fr": [
        "Institut d'Administration des Entreprises de Toulouse"
    ],
    ".icam.fr": [
        "Institut Catholique d'Arts et Métiers",
        "ICAM Lille",
        "ICAM Nantes",
        "ICAM Toulouse",
        "ICAM Paris-Sénart",
        "ICAM Bretagne",
        "ICAM Vendée",
    ],
    ".icea-edu.fr": ["Institut Catholique Européen des Antilles"],
    ".ices.fr": [
        "https://ices.fr/",
        "Institut Catholique d'Études Supérieures",
    ],
    ".icl-lille.fr": ["Institut Catholique de Lille"],
    ".icof.fr": [
        "Lycée technologique secondaire et supérieur privé sous contrat"
    ],
    ".icp.fr": ["Institut Catholique de Paris"],
    ".ict-edu.fr": ["Institut Catholique de Toulouse"],
    ".etudiant.ief2i.fr": ["INSTITUT F2I"],
    ".ieseg.fr": ["IESEG School Of Management"],
    ".ifma.fr": ["Institut Français de Mécanique Avancée"],
    ".ifp.fr": ["Ecole Nationale Supérieure du Pétrole et des Monteurs"],
    ".ig2i.fr": ["Institut de génie informatique et industriel"],
    ".ign.fr": ["Ecole Nationale des Sciences Géographiques"],
    ".iia-formation.fr": ["Insitut d'Informatique Appliquée"],
    ".iia-laval.fr": ["IIA Laval"],
    ".imag.fr": [
        "Ecole Nationale Superieure d'Informatique et de Mathematiques Appliquees de Grenoble"
    ],
    ".imie-paris.fr": ["IMIE : Ecole de la Filière Numérique"],
    ".imj-prg.fr": ["Institut de Mathématiques de Jussieu-Paris Rive Gauche"],
    ".imt-atlantique.fr": [
        "IMT Atlantique Bretagne-Pays de la Loire École Mines-Télécom"
    ],
    ".imt-lille-douai.fr": [
        "Ecole nationale superieure Mines-Telecom Lille-Douai"
    ],
    ".imt-mrs.fr": ["Ecole Supérieure d'Ingénieurs de Marseille"],
    ".imt-nord-europe.fr": [
        "IMT Nord Europe",
        "Institut Mines-Télécom Nord Europe",
    ],
    ".inalco.fr": [
        "Institut national des langues et civilisations orientales",
        "National Institute for Oriental Languages and Civilizations",
    ],
    ".inp-fc.fr": [
        "Ecole Nationale Supérieure d'Ingénieurs de Génie Chimique",
        "Institut National Polytechnique de Toulouse",
    ],
    ".etu.inp-n7.fr": ["ENSEEIHT INP", "ENSEEIHT INP"],
    ".inp-toulouse.fr": ["Institut national polytechnique de Toulouse"],
    ".inpg.fr": [
        "Ecole Française de Papeterie et des Industries Graphiques",
        "Ecole Nationale Supérieure d'Electrochimie et d'Electrométallurgie de Gernoble",
        "Ecole Nationale Supérieure de Physique de Grenoble",
        "Ecole Nationale Supérieure d'Hydraulique et de Mécanique de Grenoble",
        "Ecole Nationale Supérieure d'Ingenieurs Electriciens de Grenoble",
        "Institut National Polytechnique de Grenoble",
    ],
    ".inpl-nancy.fr": ["Institut National Polytechnique de Lorraine"],
    ".inra.fr": [
        "Ecole Nationale Supérieure d'Agronomie de Montpellier",
        "Ecole Nationale Supérieure d'Agronomie de Rennes",
        "Institut National Supérieur de Formation Agro-Alimentaire",
    ],
    ".inrae.fr": [
        "Ecole Nationale Supérieure d'Agronomie de Montpellier",
        "Ecole Nationale Supérieure d'Agronomie de Rennes",
        "Institut National Supérieur de Formation Agro-Alimentaire",
        "Agro campus Ouest",
    ],
    ".insa-cvl.fr": [
        "Institut National des Sciences Appliquées de Centre Val de Loire"
    ],
    ".insa-lyon.fr": ["Institut National des Sciences Appliquées de Lyon"],
    ".insa-rennes.fr": ["Institut National des Sciences Appliquées de Rennes"],
    ".insa-rouen.fr": ["Institut National des Sciences Appliquées de Rouen"],
    ".insa-strasbourg.fr": [
        "Institut National des Sciences Appliquées de Strasbourg"
    ],
    ".insa-toulouse.fr": [
        "Institut National des Sciences Appliquées de Toulouse"
    ],
    ".insta.fr": ["institut de technologies avancées"],
    ".institut-g4.fr": ["Institut G4"],
    ".institutdegenech.fr": ["Institut de Genech"],
    ".institutoptique.fr": ["Institut Optic Graduate School"],
    ".int-evry.fr": ["Institut National des Télécommunications"],
    ".intech-so.fr": ["IN'TECH", "IN'TECH"],
    ".intech-sud.fr": ["IN'TECH Sud"],
    ".et.intechinfo.fr": ["Ecole Supérieure d'Ingénierie Informatique"],
    ".intechinfo.fr": ["Ecole Supérieure d'Ingénierie Informatique"],
    ".ip-formation.fr": ["École Informatique IP Formation"],
    ".ip-paris.fr": [
        "Institut Polytechnique de Paris",
        "Institut Polytechnique de Paris",
    ],
    ".ipag.fr": ["IPAG Business School", "IPAG Business School"],
    ".ipb.fr": ["Institut Polytechnique de Bordeaux (ou INP Bordeaux)"],
    ".ipgp.fr": ["Institut de Physique du Globe de Paris"],
    ".ipsa.fr": ["École d'Ingénieurs de l'Air et de l'Espace"],
    ".ird.fr": [
        "Institut de Recherche pour le Développement",
        "French National Research Institute for Sustainable Development",
    ],
    ".irisa.fr": [
        "Institut de Recherche en Informatique et Systèmes Aléatoires"
    ],
    ".etu.isae-ensma.fr": ["ISAE ENSMA"],
    ".isae-supaero.fr": ["ISAE-SUPAERO"],
    ".isae-supmeca.fr": [
        "ISAE-Supméca — Institut supérieur de mécanique de Paris"
    ],
    ".isae.fr": ["ISAE-SUPAERO"],
    ".isara.fr": ["Institut Supérieur d'Agriculture Rhone-Alpes"],
    ".isefac.fr": ["isefac"],
    ".isen-bretagne.fr": [
        "ISEN - Institut Supérieur de l'Electronique et du Numérique",
        "http://www.isen.fr/",
    ],
    ".isen-lille.fr": [
        "ISEN Lille - Institut Supérieur de l'Electronique et du Numérique",
        "http://www.isen.fr/",
    ],
    ".isen.fr": ["Institut Supérieure d'Electronique du Nord"],
    ".isep.fr": ["Institut Supérieure d'Electronique de Paris"],
    ".isima.fr": [
        "Institut Supérieur d’Informatique, de Modélisation et de leurs Applications"
    ],
    ".ismcm-cesti.fr": [
        "Centre d'Etudes Supérieures des Techniques Industrielles"
    ],
    ".istef.fr": ["Ecole supérieure de formation en alternance à Toulouse"],
    ".it-akademy.fr": ["École Informatique IT-Akademy à Lyon"],
    ".it-students.fr": ["École Informatique IT-Akademy à Lyon"],
    ".itecboisfleury.fr": ["Lycée ItecBoisfleury"],
    ".itech.fr": ["Institut Textile et Chimique de Lyon"],
    ".itescia.fr": ["Ecole Itescia, Cergy, www.itescia.fr"],
    ".iut-rodez.fr": ["Institut Universitaire de Technologie de Rodez"],
    ".iut-tarbes.fr": ["Institut Universitaire de Technologie de Tarbes"],
    ".iut-tlse3.fr": [
        "Institut Universitaire Technologique Paul Sabatier (Toulouse III)"
    ],
    ".iut-valence.fr": ["Institut Universitaire de Technologie de Valence"],
    ".jbrel.fr": ["Lycée Professionnel Jacques Brel"],
    ".jdarc95.fr": ["Institution Jeanne D'Arc"],
    ".jeanne-darc-vitre.fr": ["Jeanne d'arc Vitré"],
    ".jp2-ploemeur.fr": ["Jean-Paul 2"],
    ".jussieu.fr": [
        "Ecole Nationale Supérieure de Chimie de Paris",
        "Université Denis Diderot (Paris VII)",
        "Université Pierre et Marie Curie (Paris VI)",
    ],
    ".keyce-academy.fr": [
        "Keyce International Academy",
        "Keyce International Academy",
    ],
    ".labom2iformation.fr": ["m2iformation", "m2iformation"],
    ".lacatholille.fr": ["Université Catholique de Lille"],
    ".lamanu-student.fr": ["La Manu"],
    ".lasalle-grenoble.fr": ["Collège La Salle L'Aigle - Grenoble"],
    ".lasalle63.fr": ["Lasalle Clermont"],
    ".lasallepantin.fr": ["St Joseph La Salle Pantin"],
    ".lbsi14.fr": ["La Bruyère Sainte Isabelle"],
    ".le-101.fr": ["Ecole le-101"],
    ".le-campus-numerique.fr": ["Le Campus Numérique"],
    ".les-2-rives.fr": ["Groupe Scolaire Les 2 Rives"],
    ".lgf09.fr": ["Lycée Général et Technologique Gabriel Fauré"],
    ".limayrac.fr": ["Institut Limayrac"],
    ".lip6.fr": ["Laboratoire d'informatique de Paris 6 (UPMC)"],
    ".lmdsio.fr": ["Lycée La Martinière Duchère de Lyon"],
    ".loritz.fr": ["Henri Loritz"],
    ".lprs.fr": ["LYCÉE PRIVÉ ET UFA ROBERT SCHUMAN", "Lycee Robert Schuman "],
    ".lyc-bonaparte.fr": ["Lycée Bonaparte", "Bonaparte High School"],
    ".lycam.fr": ["Lycée André Malraux", "André Malraux High School"],
    ".lycee-basch.fr": ["Lycée Victor et Hélène Basch - Rennes"],
    ".eleves.lycee-berthelot.fr": [
        "Lycée Marcelin Berthelot",
        "Marcelin Berthelot High School",
    ],
    ".lycee-cci-gard.fr": ["Lycée CCI de Nîmes"],
    ".lycee-monge.fr": ["Lycée Gaspard Monge", "Gaspard Monge High School"],
    ".lycee-nevers.fr": ["Lycée Nevers"],
    ".lycee-pardailhan.fr": ["Lycée polyvalent Pardailhan"],
    ".lyceecoetlogon.fr": ["Lycee Coetlogon ", "Académie de Renne"],
    ".lyceeconnecte.fr": ["Académie Bordeaux Mails for students"],
    ".lyceedelasalle.fr": ["lycee de La Salle"],
    ".lyceefulbert.fr": ["Lycée Fulbert", "Fulbert High School"],
    ".lyceegalilee.fr": ["Lycée professionnel public Galilée"],
    ".lyceepergaud.fr": ["Lycée Louis Pergaud - Besançon"],
    ".lyceesaintnicolas.fr": ["Lycée technique privé Saint Nicolas"],
    ".lyceesudmedoc.fr": ["Lycée Sud Médoc"],
    ".lyon-epsi.fr": ["EPSI Lyon"],
    ".mail-ecv.fr": ["Ecole de Communication Visuelle"],
    ".malrauxbethune.fr": [
        "Lycée André Malraux Bethune",
        "André Malraux High school (Bethune)",
    ],
    ".maol.fr": ["Universite Catholique de lOuest Litoral"],
    ".master-developpement-logiciel.fr": [
        "Master Developpement Logiciel - Université Paul Sabatier (Toulouse III)"
    ],
    ".master-stic.fr": ["Univ Savoie Stic"],
    ".mdnpedago.fr": [
        "Campus des Roses Groupe Scolaire La Madone Enseignement supérieur",
        "Groupe Scolaire La Madone",
    ],
    ".meteo.fr": ["Ecole Nationale de la Météorologie"],
    ".metznumericschool.fr": ["Metz Numeric School"],
    ".mewo-campus.fr": ["ESI Metz, France"],
    ".mewo.fr": ["ESI Metz, France"],
    ".toulouse.miage.fr": [
        "Université Paul Sabatier",
        "Paul Sabatier University",
    ],
    ".mines-albi.fr": ["École des Mines d'Albi"],
    ".mines-ales.fr": ["Ecole des Mines d'Alès"],
    ".mines-nantes.fr": ["École des Mines de Nantes"],
    ".mines-paristech.fr": ["MINES ParisTech"],
    ".minesdedouai.fr": ["Mines Douai"],
    ".mjm-design.fr": ["MJM Graphic Design"],
    ".edu.mnhn.fr": [
        "Muséum National d'Histoire Naturelle",
        "MNHN",
        "France Natural History Museum",
    ],
    ".monbureaunumerique.fr": ["Lycée Robert Schuman", ".group"],
    ".msw-lachartreuse.fr": ["Étudiants en BAC+3 MSW au pôle la chartreuse"],
    ".myges.fr": ["Réseau GES"],
    ".ndba.fr": ["Notre Dame de Bel Air"],
    ".neoma-bs.fr": ["Neoma Business School", "Neoma Business School"],
    ".nermont.fr": ["Lycee d'enseignement agricole prive de Nermont"],
    ".netocentre.fr": [
        "Environnement Numérique de Travail de la région Centre"
    ],
    ".next-u.fr": ["WebTech Institute", "WebTech Institute"],
    ".normandiewebschool.fr": ["Normandie Web School"],
    ".notredamevalenciennes.fr": ["Lycée Notre Dame "],
    ".novei.fr": ["La Manu"],
    ".obspm.fr": ["Observatoire de Paris"],
    ".oniris-nantes.fr": [
        "Oniris - Ecole Nationale Vétérinaire, Agroalimentaire et de l'Alimentation"
    ],
    ".onlineformapro.fr": ["onlineformapro"],
    ".opensourceschool.fr": ["Open Source School"],
    ".ort-france.fr": ["ORT-FRANCE", "ORT-FRANCE"],
    ".ortmontreuil.fr": ["Ort Montreuil"],
    ".oteria.fr": ["Oteria Cyber School"],
    ".i2bc.paris-saclay.fr": ["Institute for Integrative Biology of the Cell"],
    ".paris-sorbonne.fr": ["Université Paris-Sorbonne (Paris IV)"],
    ".parisdescartes.fr": ["University Paris Descartes "],
    ".parisnanterre.fr": ["Université Paris Nanterre"],
    ".pasteur.fr": ["Institut Pasteur"],
    ".piktura.fr": ["Piktura", "Ecole Piktura"],
    ".pole-lachartreuse.fr": ["Professeurs au pôle la chartreuse"],
    ".polytech-lille.fr": ["Ecole polytechnique universitaire de Lille"],
    ".polytechnique.fr": ["Ecole Polytechnique"],
    ".prof-webschoolfactory.fr": ["La Web School Factory"],
    ".promeo-alternaute.fr": ["Promeo"],
    ".promeo-formation.fr": ["Promeo"],
    ".promeo365.fr": ["Promeo"],
    ".purpan.fr": ["Ecole d'Ingenieurs de Purpan"],
    ".ri7.fr": ["École Ri7"],
    ".riviera.fr": ["University of Southern Europe (Monaco Business School)"],
    ".rouenbs.fr": [
        "Rouen Business School",
        "Ecole Supérieure de Commerce de Rouen",
    ],
    ".s-fx.fr": [
        "Saint-François-Xavier",
        "Jesuit School Saint-François-Xavier",
    ],
    ".saint-thom.fr": ["Saint-Thomas d'Aquin oullins-Veritas"],
    ".saintaubinlasalle.fr": ["Saint Aubin La Salle"],
    ".saintcharles-laprovidence.fr": ["Saint-Charles Laprovidence"],
    ".saintmichelannecy.fr": ["UFA Saint Michel"],
    ".sciencespo-aix.fr": ["Sciences Po Aix"],
    ".sciencespo-rennes.fr": [
        "Sciences Po Rennes",
        "Sciences-Po Rennes",
        "SciencesPo Rennes",
        "Institut d'études politiques de Rennes",
    ],
    ".sciencespo.fr": ["Institut d'Etudes Politiques de Paris (Sciences Po)"],
    ".sciencesu-lyon.fr": ["sciencesu-lyon"],
    ".seatech.fr": [
        "SeaTech - Ecole d'ingénieurs de l'Université de Toulon",
        "SeaTech - Engineering School of the University of Toulon",
    ],
    ".sigma-clermont.fr": ["Sigma Clermont"],
    ".sivard.fr": [
        "Lycée Sivard de Beaulieu",
        "Lycée Sivard de Beaulieu, 50500 Carentan-les-marais, France",
        "sivard.fr",
    ],
    ".sjc43.fr": ["Ensemble Scolaire St Jaques de Compostelle"],
    ".sorbon.fr": ["Ecole Superieure Robert de Sorbon"],
    ".sorbonne-nouvelle.fr": ["Université Sorbonne nouvelle"],
    ".sorbonne-universite.fr": [
        "Université de la Sorbonne",
        "https://www.sorbonne-universite.fr/",
    ],
    ".sornas.fr": ["EDTA Sornas"],
    ".st-nicolas.fr": [
        "La Salle Saint Nicolas ( ' st-nicolas.org , st-nicolas.fr')"
    ],
    ".stagiairesifa.fr": [
        "Metz Numeric School / IFA",
        "Metz Numeric School / IFA",
    ],
    ".stagiairesmns.fr": ["Metz Numeric School / MNS"],
    ".stanislas-paris.fr": ["Stanislas Paris"],
    ".steanne-sav.fr": ["Lycée Privé Sainte-Anne Savoisienne"],
    ".stfelixlasalle.fr": ["St Félix-La Salle"],
    ".stfrancoislaroche.fr": ["Saint François D'Assise"],
    ".stjolorient.fr": [
        "Lycee Saint Joseph La Salle Lorient",
        "http://www.st-joseph-lorient.org/",
    ],
    ".stu-digital-campus.fr": ["ESG - Ecole de commerce"],
    ".stu-esarc-evolution.fr": ["ESG - Ecole de commerce"],
    ".stu-esg.fr": ["ESG - Ecole de commerce"],
    ".stu-pstb.fr": [
        "PSTB - École d'Informatique et de Commerce à Paris",
        "Paris School of Technology and Business",
    ],
    ".student-cs.fr": ["CentraleSupélec"],
    ".student-oec.fr": ["Lycée Frédéric ozanam", "Ozanam High School"],
    ".studi.fr": [
        "75 Studi - Formation en ligne 155 rue de Charonne à 75011 Paris France",
        "https://www.studi.fr",
    ],
    ".student.studio-m.fr": ["Cime Art"],
    ".supaero.fr": [
        "Ecole Nationale Supérieure de l'Aéronautique et de l'Espace"
    ],
    ".supagro.fr": ["L'institut Agro | Montpellier SupAgro"],
    ".supbiotech.fr": ["École des Experts en Biotechnologies"],
    ".supco-amiens.fr": ["Groupe Sup de Co Amiens Picardie"],
    ".supco-montpellier.fr": ["Groupe Sup de Co Montpellier"],
    ".supdevinci-edu.fr": ["SUP DE VINCI "],
    ".supdevinci.fr": ["SUP DE VINCI"],
    ".supelec.fr": ["Ecole Supérieure d'Electricité"],
    ".supinternet.fr": ["École Supérieure des Métiers de l'Internet"],
    ".supmeca.fr": [" Institut supérieur de mécanique de Paris"],
    ".supwallon.fr": ["\ufeffLycée Henri Wallon - Valenciennes"],
    ".tbs-education.fr": ["Toulouse Business School"],
    ".telecom-lille.fr": ["Telecom Lille"],
    ".telecom-paris.fr": [
        "Telecom Paris",
        "Telecom ParisTech",
        "Télécom Paris",
        "Télécom ParisTech",
    ],
    ".telecom-paristech.fr": ["Télécom ParisTech"],
    ".telecom-st-etienne.fr": ["\ufeffTélécom Saint-Etienne"],
    ".thenuumfactory.fr": ["The Nuum Factory", "The Nuum Factory"],
    ".etu.toulouse-inp.fr": ["Institut national polytechnique de Toulouse"],
    ".toulouse-inp.fr": [
        "Institut national polytechnique de Toulouse",
        "National Polytechnic Institute of Toulouse",
    ],
    ".tsm-education.fr": ["Toulouse School of Management"],
    ".u-3mrs.fr": [
        "Ecole Nationale Supérieure de Physique de Marseille",
        "Université d'Aix-Marseille III",
    ],
    ".etu.u-bordeaux-montaigne.fr": [
        "Etudiant à l'Université Bordeaux Montaigne"
    ],
    ".iut.u-bordeaux-montaigne.fr": ["IUT Bordeaux Montaigne"],
    ".u-bordeaux-montaigne.fr": [
        "Université Bordeaux Montaigne",
        "Bordeaux Montaigne university",
    ],
    ".u-bordeaux.fr": [
        "Ecole Nationale Supérieure de Chimie et de Physique de Bordeaux",
        "Ecole Nationale Supérieure d'Electronique et de Radioelectricite de Bordeaux",
        "Institut d'Etudes Politiques de Bordeaux",
        "Université Bordeaux I",
        "Université Michel de Montaigne (Bordeaux III )",
        "Université Montesquieu (Bordeaux IV)",
    ],
    ".u-bordeaux2.fr": ["Université Victor Segalen (Bordeaux II)"],
    ".u-bordeaux3.fr": ["\ufeffUniversité Michel Montaigne (Bordeaux III)"],
    ".etu.u-bourgogne.fr": [
        "université de bourgogne",
        "University of Burgundy, Dijon, France",
        "Website : http://en.u-bourgogne.fr",
    ],
    ".u-bourgogne.fr": [
        "Ecole Nationale Supérieure de Biologie Appliquée à la Nutrition et à l'Alementation",
        "Université de Bourgogne",
    ],
    ".u-cergy.fr": ["Université de Cergy-Pontoise"],
    ".u-clermont1.fr": ["Université d'Auvergne (Clermont-Ferrand I)"],
    ".u-grenoble3.fr": ["Université Stendhal (Grenoble III)"],
    ".u-nancy.fr": [
        "Ecole Nationale Supérieur de Géologie de Nancy",
        "Ecole Nationale Supérieure d'Agronomie et des Industries Alimentaires",
        "Ecole Nationale Supérieure des Industries Chimiques de Nancy",
        "Ecole Nationale Supérieure des Mines de Nancy",
        "Ecole Nationale Supérieure Electricité et Mécanique",
        "Ecole Supérieure des Sciences et Technologie de l'Ingénieur de Nancy",
    ],
    ".etu.u-paris.fr": ["Université de Paris", "University of Paris"],
    ".u-paris.fr": ["Université Paris Cité"],
    ".u-paris10.fr": ["Université Paris Nanterre (Paris X)"],
    ".u-paris2.fr": ["Université Panthéon-Assas (Paris II)"],
    ".u-pe.fr": ["Paris-Est Créteil Val-de-Marne University"],
    ".u-pec.fr": ["Université Paris-Est Créteil"],
    ".u-pem.fr": ["\ufeffUniversité Paris Est Marne la Vallée"],
    ".u-picardie.fr": ["Université de Picardie Jules-Verne"],
    ".u-psud.fr": ["université paris saclay", "PARIS-SACLAY UNIVERSITY"],
    ".u-strasbg.fr": [
        "Ecole Européenne de Chimie, Polymères et Matériaux de Strasbourg",
        "Ecole Nationale du Génie de l'Eau et de l'Environnement de Strasbourg",
        "Ecole Nationale Supérieure de Physique de Strasbourg",
        "Ecole Nationale Supérieure des Arts et Industries de Strasbourg",
        "Université des Sciences Humaines (Strasbourg II)",
        "Université Louis Pasteur (Strasbourg I)",
        "Université Robert Schuman (Strasbourg III)",
    ],
    ".etu.ube.fr": ["Université Bourgogne Europe"],
    ".uca.fr": ["Université Clermont-Auvergne"],
    ".ucly.fr": ["UCLY"],
    ".uco.fr": ["Université Catholique de l' Ouest"],
    ".etu.udamail.fr": ["Université d'auvergne"],
    ".udamail.fr": ["Université d'Auvergne"],
    ".uha.fr": ["Université de Haute Alsace"],
    ".uhb.fr": ["Université Rennes II - Haute-Bretagne"],
    ".uhp-nancy.fr": ["Université Henri Poincaré (Nancy I)"],
    ".ujf-grenoble.fr": ["Université Joseph Fourier (Grenoble I)"],
    ".umontpellier.fr": ["Université de Montpellier"],
    ".unicaen.fr": ["Université de Caen Basse Normandie"],
    ".etu.unice.fr": ["Université Nice Sophia Antipolis"],
    ".unice.fr": ["Université de Nice-Sophia Antipolis"],
    ".etu.unilasalle.fr": ["UniLaSalle Amiens"],
    ".unilasalle.fr": ["UniLaSalle"],
    ".unilim.fr": ["Université de Limoges"],
    ".unimes.fr": ["Université de Nîmes"],
    ".unistra.fr": ["University of Strasbourg"],
    ".etu.univ-ag.fr": ["Université des Antilles"],
    ".univ-ag.fr": ["Université des Antilles"],
    ".etu.univ-amu.fr": [
        "Polytech Marseille (Aix-Marseille Université)",
        "Polytech Marseille (Engineering School, part of Aix-Marseille Academy)",
    ],
    ".univ-amu.fr": ["Aix-Marseille University"],
    ".univ-angers.fr": ["Université d'Angers"],
    ".etu.univ-antilles.fr": ["Université des Antilles"],
    ".univ-antilles.fr": ["Université des Antilles"],
    ".univ-artois.fr": ["Université d'Artois"],
    ".univ-avignon.fr": ["Université d'Avignon"],
    ".univ-bpclermont.fr": [
        "Ecole Nationale Supérieure de Chimie de Clermont-Ferrand",
        "Institut des Sciences de l'Ingénieur de Clermont-Ferrand",
        "Université Blaise Pascal (Clermont-Ferrand II)",
    ],
    ".univ-brest.fr": ["Université de Bretagne Occidentale"],
    ".univ-catholille.fr": ["Université Catholique de Lille"],
    ".univ-catholyon.fr": ["Université Catholique de Lyon"],
    ".univ-corse.fr": ["Università di Corsica Pasquale Paoli"],
    ".univ-cotedazur.fr": ["Université Côte d'Azur"],
    ".univ-eiffel.fr": [
        "Université Gustave Eiffel",
        "University Gustave Eiffel",
    ],
    ".univ-evry.fr": ["Université d'Evry Val d'Essonne"],
    ".univ-fcomte.fr": ["Université de Franche-Comté"],
    ".iut2.univ-grenoble-alpes.fr": [
        "IUT2 Informatique",
        "Science computing University Institute of Technology",
    ],
    ".univ-grenoble-alpes.fr": ["Université Grenoble Alpes"],
    ".univ-inpt.fr": ["Ecole Nationale Supérieure de Chimie de Toulouse"],
    ".univ-jfc.fr": ["Centre universitaire Jean-François Champollion"],
    ".univ-lehavre.fr": ["Université du Havre"],
    ".univ-lemans.fr": ["Université du Maine"],
    ".univ-lille.fr": ["Université de Lille"],
    ".univ-lille1.fr": [
        "Université des Sciences et Technologies de Lille (Lille I)"
    ],
    ".univ-lille2.fr": ["Université du Droit et de la Sante (Lille II)"],
    ".univ-lille3.fr": ["Université Charles-de-Gaulle (Lille III)"],
    ".univ-littoral.fr": ["Université du Littoral Cote d'Opale"],
    ".univ-lorraine.fr": ["Université de Lorraine"],
    ".etudiant.univ-lr.fr": ["Université de La Rochelle"],
    ".univ-lr.fr": ["Université de La Rochelle"],
    ".etu.univ-lyon1.fr": ["Université Claude Bernard Lyon 1"],
    ".univ-lyon1.fr": ["Université Claude Bernard (Lyon I)"],
    ".univ-lyon2.fr": ["Université Lumiére (Lyon II)"],
    ".univ-lyon3.fr": ["Université Jean Moulin (Lyon III)"],
    ".univ-metz.fr": ["Université de Metz"],
    ".univ-mlv.fr": ["Université de Marne la Vallée"],
    ".univ-montp1.fr": ["Université de Montpellier I"],
    ".univ-montp2.fr": [
        "Institut des Sciences de l'Ingénieur de Montpellier",
        "Université de Montpellier II",
    ],
    ".univ-montp3.fr": ["Université Paul Valéry (Montpellier III)"],
    ".univ-montpellier.fr": ["Université Paul Valery Montpellier 3"],
    ".univ-mrs.fr": ["Université de Provence (Aix-Marseille I)"],
    ".univ-mulhouse.fr": [
        "Ecole Nationale Supérieure de Chimie de Mulhouse",
        "Université de Haute-Alsace",
    ],
    ".univ-nancy2.fr": ["Université Nancy II"],
    ".univ-nantes.fr": ["Université de Nantes"],
    ".univ-orleans.fr": ["Université d'Orléans"],
    ".univ-paris-diderot.fr": ["Paris Diderot University"],
    ".univ-paris-est.fr": [
        "Université Paris-Est",
        "University of Paris-Est",
        "UPE",
    ],
    ".univ-paris1.fr": ["Université Panthéon-Sorbonne (Paris I)"],
    ".univ-paris12.fr": ["Université Val-de-Marne (Paris XII)"],
    ".univ-paris13.fr": ["Université Paris Nord (Paris XIII)"],
    ".univ-paris3.fr": ["Université Sorbonne-Nouvelle (Paris III)"],
    ".univ-paris5.fr": ["Université Paris Cité"],
    ".univ-paris7.fr": ["Université Paris Cité"],
    ".univ-paris8.fr": ["Université Vincennes Saint-Denis (Paris VIII)"],
    ".univ-pau.fr": ["Université de Pau et des Pays de l'Adour"],
    ".univ-perp.fr": ["Université de Perpignan"],
    ".univ-poitiers.fr": ["Université de Poitiers"],
    ".univ-reims.fr": ["Université de Reims Champagne-Ardenne"],
    ".etudiant.univ-rennes.fr": [
        "Université de Rennes",
        "University of Rennes",
    ],
    ".univ-rennes.fr": ["Université de Rennes", "University of Rennes"],
    ".univ-rennes1.fr": ["Université Rennes I"],
    ".univ-rennes2.fr": [
        "Université Rennes 2, FRANCE",
        "Rennes 2 university, FRANCE",
    ],
    ".univ-reunion.fr": ["Université de la Reunion"],
    ".univ-rouen.fr": ["Université de Rouen - Haute Normandie"],
    ".univ-savoie.fr": ["Université de Savoie"],
    ".univ-smb.fr": ["Université Savoie Mont Blanc"],
    ".etu.univ-st-etienne.fr": ["Université Jean Monnet"],
    ".univ-st-etienne.fr": ["Université Jean Monnet"],
    ".univ-tln.fr": ["Université du Sud, Toulon et Var"],
    ".univ-tlse1.fr": ["Université des Sciences Sociales (Toulouse I)"],
    ".univ-tlse2.fr": ["Université de Toulouse-le-Mirail (Toulouse II)"],
    ".univ-tlse3.fr": ["Université Paul Sabatier (Toulouse III)"],
    ".univ-toulouse.fr": ["Université de Toulouse"],
    ".univ-tours.fr": [
        "Ecole d'Ingénieurs en Informatique pour l'Industrie",
        "Université François Rabelais de Tours",
    ],
    ".univ-ubs.fr": ["Université de Bretagne Sud"],
    ".etu.univ-valenciennes.fr": [
        "Université de Valenciennes et du Hainaut-Cambrésis"
    ],
    ".univ-valenciennes.fr": [
        "Ecole Nationale Supérieure d'Ingénieurs en Mécanique et Energétique de Valenciennes",
        "Université de Valenciennes et du Hainaut-Cambrésis",
    ],
    ".universite-lyon.fr": ["Université de Lyon"],
    ".universite-paris-saclay.fr": ["Université Paris Saclay"],
    ".univmed.fr": ["Université de la Méditerranée (Aix Marseille II)"],
    ".uolen.fr": ["Universite Uolentec", "httpS://uolen.fr", "@uolen.fr"],
    ".etu.uphf.fr": ["Université Polytechnique des Hauts de France"],
    ".uphf.fr": ["Université Polytechnique des Hauts de France"],
    ".upmc.fr": ["Pierre-and-Marie-Curie University"],
    ".upmf-grenoble.fr": ["Université Pierre Mendes-France (Grenoble II)"],
    ".ups-tlse.fr": ["Université Paul Sabatier (Toulouse III)"],
    ".ut-capitole.fr": ["Université Toulouse 1 Capitole"],
    ".utbm.fr": ["Université de Technologie de Belfort Montbéliard"],
    ".utc.fr": ["Université de Technologie de Compiègne"],
    ".utt.fr": ["Université de Technologie de Troyes"],
    ".uvsq.fr": ["Université de Versailles Saint-Quentin-en-Yvelines"],
    ".vatel.fr": ["Vatel"],
    ".vet-alfort.fr": ["Ecole Nationale Vétérinaire d'Alfort"],
    ".vet-lyon.fr": ["Ecole Nationale Vétérinaire de Lyon"],
    ".vet-nantes.fr": ["Ecole Nationale Vétérinaire de Nantes"],
    ".viacesi.fr": [
        "CESI Enseignement Supérieur et Formation Professionnelle"
    ],
    ".webschoolfactory.fr": ["La Web School Factory"],
    ".hei.yncrea.fr": ["Ecole des Hautes Etudes Industrielles de Lille"],
    ".isen-ouest.yncrea.fr": [
        "Institut supérieur de l'électronique et du numérique Yncrea Ouest"
    ],
    ".isen.yncrea.fr": [
        "Institut supérieur de l'électronique et du numérique"
    ],
    ".student.yncrea.fr": [
        "Institut supérieur de l'électronique et du numérique (ISEN)"
    ],
    ".yncrea.fr": ["ISEN Yncréa Méditerranée"],
    ".yschools.fr": ["Yschools"],
    ".iesrodeira.gal": ["IES de Rodeira "],
    ".udc.gal": ["Universidade da Coruña"],
    ".edu.xunta.gal": ["Fernando Wirtz"],
    ".tamcc.edu.gd": ["T.A. Marryshow Community College"],
    ".bsu.ge": [
        "ბათუმის შოთა რუსთაველის სახელმწიფო უნივერსიტეტი",
        "Batumi Shota Rustaveli State University",
    ],
    ".agruni.edu.ge": ["Agricultural University of Georgia"],
    ".alte.edu.ge": ["Alte University"],
    ".art.edu.ge": [
        "თბილისის აპოლონ ქუთათელაძის სახელობის სახელმწიფო სამხატვრო აკადემია",
        "APOLLON KUTATELADZE TBILISI STATE ACADEMY OF ART",
    ],
    ".bsu.edu.ge": [
        "\ufeffბათუმის შოთა რუსთაველის სახელმწიფო უნივერსიტეტი",
        "Batumi Shota Rustaveli State University",
    ],
    ".btu.edu.ge": ["Business and Technology University, Tbilisi, Georgia"],
    ".ciu.edu.ge": ["Caucasus International University"],
    ".cu.edu.ge": ["Caucasus University"],
    ".efc.edu.ge": ["ECOLE FRANCAISE DU CAUCASE", "Caucasus French School"],
    ".eu.edu.ge": ["European university, Tbilisi, Georgia"],
    ".fesvebi.edu.ge": [
        'N187 საჯარო სკოლა "ფესვები"',
        'Public school N187 "Fesvebi"',
    ],
    ".freeuni.edu.ge": ["Free University of Tbilisi"],
    ".gau.edu.ge": ["Georgian-American University"],
    ".gruni.edu.ge": ["University of Grigol Robakidze"],
    ".gsau.edu.ge": ["Georgian Agricultural University"],
    ".gtu.edu.ge": ["Georgian Technical University"],
    ".gu.edu.ge": [
        "გორის სახელმწიფო სასწავლო უნივერსიტეტი",
        "GORI STATE TEACHING UNIVERSITY",
    ],
    ".ibsu.edu.ge": ["International Black sea University"],
    ".iliauni.edu.ge": ["Ilia Chavchavadze State University"],
    ".kiu.edu.ge": ["Kutaisi International University"],
    ".newton.edu.ge": ["ნიუტონის თავისუფალი სკოლა", "Newton Free School"],
    ".sabauni.edu.ge": [
        "სულხან-საბა ორბელიანის უნივერსიტეტი",
        "Sulkhan-Saba Orbeliani University",
    ],
    ".sangu.edu.ge": ["St. Andrew Georgian University"],
    ".sdasu.edu.ge": [
        "საქართველოს დავით აღმაშენებლის სახელობის უნივერსიტეტი",
        "David Agmashenebeli University of Georgia",
    ],
    ".seu.edu.ge": ["Georgian National University SEU"],
    ".sou.edu.ge": [
        "სოხუმის სახელმწიფო უნივერსიტეტი",
        "Sokhumi state university",
    ],
    ".ssu.edu.ge": ["Georgian Aviation University"],
    ".tesau.edu.ge": [
        "იაკობ გოგებაშვილის სახელობის თელავის სახელმწიფო უნივერსიტეტი",
        "IAKOB GOGEBASHVILI TELAVI STATE UNIVERSITY",
    ],
    ".tmk.edu.ge": [
        "სსიპ ″ილია წინამძღვრიშვილის სახელობის კოლეჯი″",
        "LEPL ″Ilia Tsinamdzgvrishvili College″",
    ],
    ".tsu.edu.ge": ["Tbilisi State University"],
    ".ug.edu.ge": ["University of Georgia in Tbilisi"],
    ".unik.edu.ge": ["Kutaisi University"],
    ".gipa.ge": ["Georgian Institute of Public Affairs"],
    ".gtu.ge": [
        "საქართველოს ტექნიკური უნივერსიტეტი",
        "Georgian Technical University",
    ],
    ".iset.ge": ["International School of Economics at TSU"],
    ".itvet.ge": [
        "ინფრომაციული ტექნოლოგიების აკადემია",
        "Information Technologies Academy",
    ],
    ".mziuri.ge": ["IT Center Mziuri"],
    ".newvision.ge": ["ნიუ ვიჟენ უნივერსიტეტი", "New Vision University"],
    ".tsu.ge": [
        "თბილისის სახელმწიფო უნივერსიტეტი",
        "Tbilisi State University",
    ],
    ".aamusted.edu.gh": [
        "Akenten Appiah-Menka University of Skills Training and Entrepreneurial Development",
        "AAMUSTED",
        "Website - https://aamusted.edu.gh",
        "Tech Programs offered",
        "  BsC Cyber Security",
        "  Bsc Information Technology",
    ],
    ".abs.edu.gh": ["Accra Business School", "ABS"],
    ".accramet.edu.gh": ["Accra Metropolitan University"],
    ".accrapolytechnic.edu.gh": ["Accra Polytechnic "],
    ".acity.edu.gh": ["Academic City University"],
    ".ait.edu.gh": [
        "Accra Institute of Technology",
        "AIT",
        "The university of the future",
    ],
    ".anuc.edu.gh": ["all nations university college"],
    ".ashesi.edu.gh": ["Ashesi University"],
    ".st.atu.edu.gh": [
        "Accra Technical University",
        "Accra Technical University",
    ],
    ".atu.edu.gh": ["Accra Technical University"],
    ".bluecrest.edu.gh": ["Bluecrest University College"],
    ".central.edu.gh": ["central university college"],
    ".cktutas.edu.gh": [
        "C. K. Tedam University of Technology and Applied Science (CKT-UTAS)"
    ],
    ".cug.edu.gh": ["catholic university college"],
    ".datalink.edu.gh": ["data link insitute"],
    ".gctu.edu.gh": ["Ghana Communication Technology University"],
    ".gcuc.edu.gh": ["garden city university college"],
    ".gimpa.edu.gh": [
        "Ghana Institute of Management and Public Administration (GIMPA)"
    ],
    ".gtuc.edu.gh": ["Ghana Telecom University College"],
    ".hcuc.edu.gh": ["Heritage Christian University"],
    ".htu.edu.gh": ["Ho Technical University"],
    ".st.knust.edu.gh": [
        "Kwame Nkrumah University of Science and Technology",
        "Kwame Nkrumah University of Science and Technology",
    ],
    ".kpoly.edu.gh": ["Kumasi Polytechnic "],
    ".kstu.edu.gh": ["Kumasi Technical University"],
    ".ktu.edu.gh": ["Koforidua Technical University"],
    ".mhtia.edu.gh": ["Methodist Health Training Institute Afosu Campus"],
    ".mucg.edu.gh": ["methodist university college"],
    ".pentvars.edu.gh": ["pentecost university college"],
    ".presbyuniversity.edu.gh": ["Presbyterian University College"],
    ".regent.edu.gh": ["regent university college"],
    ".rmu.edu.gh": ["regional maritime university"],
    ".tpoly.edu.gh": ["Takoradi Polytechnic "],
    ".ttu.edu.gh": [
        "Takoradi Technical University",
        "Takoradi Technical University",
    ],
    ".ucc.edu.gh": ["University of Cape Coast"],
    ".uds.edu.gh": ["University for Development Studies"],
    ".uenr.edu.gh": ["University of Energy and Natural Resources"],
    ".uew.edu.gh": [
        "University of Education, Winneba",
        "University of Education, Winneba",
    ],
    ".ug.edu.gh": ["University of Ghana"],
    ".umat.edu.gh": ["university of mines and technology"],
    ".upsa.edu.gh": ["University of Professional Studies, Accra (UPSA)"],
    ".vvu.edu.gh": ["Valley View University"],
    ".wiuc-ghana.edu.gh": ["wisconsin international university college"],
    ".ilisimatusarfik.gl": ["University of Greenland"],
    ".dwight.global": ["Dwight Global"],
    ".pl.goit.global": [
        "GoIT Polska (Neoversity)",
        "GoIT Poland (Neoversity)",
    ],
    ".aiu.edu.gm": [
        "American International University West Africa, The Gambia"
    ],
    ".iou.edu.gm": ["Islamic Online University"],
    ".student.fortbendisd.gov": ["Malala Yousafzai Elementary"],
    ".schools.nyc.gov": [
        "New York City Department of Education",
        "NYC DOE",
        ".group",
    ],
    ".acg.gr": ["American College of Greece"],
    ".aeath.gr": [
        "University Ecclesiastical Academy of Thessaloniki",
        "Ανώτατη Εκκλησιαστική Ακαδημία Θεσσαλονίκης",
    ],
    ".aegean.gr": ["Aegean University"],
    ".agsm.gr": ["Athens Graduate School of Management (AGSM)"],
    ".aktocollege.gr": ["AKTO College"],
    ".asfa.gr": ["Athens School of Fine Arts"],
    ".elec.aspete.gr": [
        "Ανώτατη Σχολή Παιδαγωγικής και Τεχνολογικής Εκπαίδευσης",
        " Higher School of Pedagogical and Technological Education",
    ],
    ".mec.aspete.gr": [
        "Ανώτατη Σχολή Παιδαγωγικής και Τεχνολογικής Εκπαίδευσης",
        "Higher School of Pedagogical and Technological Education",
    ],
    ".ta.aspete.gr": ["Aspete", "Aspete"],
    ".aspete.gr": [
        "Ανώτατη Σχολή Παιδαγωγικής και Τεχνολογικής Εκπαίδευσης",
        "Higher School of Pedagogical and Technological Education",
    ],
    ".athtech.gr": ["Athens Tech College"],
    ".aueb.gr": ["Athens University of Economics and Business"],
    ".csd.auth.gr": ["School of Informatics of AUTh"],
    ".ece.auth.gr": [
        "School of Electrical & Computer Engineering, Aristotle University of Thessaloniki"
    ],
    ".math.auth.gr": ["School of Mathematics of AUTH"],
    ".auth.gr": ["Aristotle University of Thessaloniki"],
    ".cityu.gr": ["City University Athens"],
    ".cti.gr": [
        "Ινστιτούτο Τεχνολογίας Υπολογιστών και Εκδόσεων “ΔΙΟΦΑΝΤΟΣ”",
        "Computer Technology Institute and Press “DIOPHANTUS” (CTI)",
        "Institute Official URL:",
        "https://www.cti.gr/",
    ],
    ".demokritos.gr": ["NCSR Demokritos"],
    ".duth.gr": ["Dimocritus University of Thrace"],
    ".alba.edu.gr": ["Athens Laboratory of Business Administration (ALBA)"],
    ".amcstudent.edu.gr": [
        "Μητροπολιτικό Κολλέγιο",
        "AMC - Metropolitan College",
    ],
    ".anatolia.edu.gr": ["Anatolia College"],
    ".athenscollege.edu.gr": ["HAEF - Athens College"],
    ".campion.edu.gr": ["Campion School"],
    ".dei.edu.gr": ["DEI Bachelor &amp; Master Degrees"],
    ".iceberg.edu.gr": ["ICEBERG. Θεσσαλίας", "ICEBERG of Thessaly"],
    ".iekakmi.edu.gr": ["ΙΕΚ ΑΚΜΗ"],
    ".iekdelta360.edu.gr": ["ΙΕΚ ΔΕΛΤΑ 360", "IEK DELTA 360"],
    ".ihu.edu.gr": ["International Hellenic University"],
    ".imd.edu.gr": [
        "Institute of Management Development - Ohrid",
        "Institute of Management Development, Ohrid",
    ],
    ".ist.edu.gr": ["Independent Studies of Science & Technology", "IST"],
    ".kessaris.edu.gr": ["ΕΚΠΑΙΔΕΥΤΗΡΙΑ ΚΑΙΣΑΡΗ", "Kessaris School"],
    ".medcollege.edu.gr": ["Mediterranean College"],
    ".mitropolitiko.edu.gr": [
        "Μητροπολιτικό Κολλέγιο",
        "AMC - Metropolitan College",
    ],
    ".parvis.edu.gr": ["Parvis Exeter Academy"],
    ".sivitanidios.edu.gr": [
        "Sivitanidios DSTE",
        "Sivitanidios Public School of Arts and Professions",
    ],
    ".teikav.edu.gr": ["Technological Education Institute of Kavala"],
    ".uindy.edu.gr": ["University of Indianapolis in Athens"],
    ".uom.edu.gr": ["University Of Macedonia"],
    ".forthnet.gr": ["Harokopio University"],
    ".grbc.gr": ["Greek Bible College"],
    ".hmu.gr": [
        "\ufeffHellenic Mediterranean University",
        "ΕΛΛΗΝΙΚΟ ΜΕΣΟΓΕΙΑΚΟ ΠΑΝΕΠΙΣΤΗΜΙΟ",
        "University Official URL:",
        "https://www.hmu.gr/",
        "University official webmail:",
        "https://webmail.edu.hmu.gr",
        "Master in Advanced Manufacturing, Automation and Robotics Link (2years):",
        "https://www.teicrete.gr/amsar/",
        "Msc in Informatics Engineering:",
        "https://www.hmu.gr/mscie/en",
        "Department of Informatics:",
        "https://www.teicrete.gr/en/stef/13802",
        "All the departments: ",
        "https://www.hmu.gr/hmu/8600",
        'Notes : Currently the unniversity is changing domain from the older "teicrete" to the new "hellenic mediteranean university" (hmu).',
    ],
    ".hua.gr": ["Harokopio University"],
    ".ihu.gr": [
        "Διεθνές Πανεπιστήμιο της Ελλάδος",
        "International Hellenic University",
    ],
    ".imese.gr": [
        "Institute of Management &amp; Enteurpreneurship of South East Europe"
    ],
    ".ionio.gr": ["Ionian University"],
    ".labaki.gr": ["Labaki Technology Center"],
    ".ntua.gr": ["National Technical University of Athens"],
    ".nyc.gr": ["New York College of Athens"],
    ".panteion.gr": [
        "Panteios University of Economics and Political Sciences Athens"
    ],
    ".pinewood-school.gr": ["Pinewood International American School"],
    ".students.puas.gr": [
        "Students of Piraeus University of Applied Sciences"
    ],
    ".puas.gr": ["Piraeus University of Applied Sciences"],
    ".sch.gr": ["15° ΓΕΛ Αθηνών", "15th high school of athens"],
    ".sse.gr": ["Hellenic Army Academy"],
    ".ssl-unipi.gr": ["Systems Security Laboratory, University of Piraeus"],
    ".teiath.gr": ["Technological Education Institute of Athens"],
    ".teicm.gr": ["Technological Educational Institute of Central Macedonia"],
    ".teicrete.gr": ["Technological Educational Institute of Crete"],
    ".teiemt.gr": ["Eastern Macedonia and Thrace Institute of Technology"],
    ".teiep.gr": ["Technological Education Institute of Epiros"],
    ".teiher.gr": ["Technological Education Institute of Heraklion"],
    ".teikal.gr": ["Technological Education Institute of Kalamata"],
    ".teikoz.gr": ["Technological Education Institute of Kozani"],
    ".teilam.gr": ["Technological Education Institute of Lamia"],
    ".teilar.gr": ["Technological Education Institute of Larissa"],
    ".teimes.gr": ["Technological Education Institute of Mesologgi"],
    ".teipat.gr": ["Technological Education Institute of Patras"],
    ".teipir.gr": ["Technological Education Institute of Piraeus"],
    ".teiser.gr": ["Technological Education Institute of Serres"],
    ".teiste.gr": ["Technological Education Institute of Sterea Ellada"],
    ".teithe.gr": ["Technological Education Institute of Thessaloniki"],
    ".teiwest.gr": ["Technological Educational Institute of Western Greece"],
    ".students.kastoria.teiwm.gr": [
        "University of Applied Science of Western Macedonia School Of Applied Science Departement Of Informatics Engineering"
    ],
    ".tuc.gr": ["Technical University of Crete"],
    ".ucg.gr": ["University of Central Greece"],
    ".unipi.gr": ["University of Piraeus"],
    ".uniwa.gr": ["Πανεπιστήμιο Δυτικής Αττικής", "UNIVERSITY OF WEST ATTICA"],
    ".uoa.gr": ["University of Athens"],
    ".edu.physics.uoc.gr": ["University of Crete Department of Physics"],
    ".uoc.gr": ["University of Crete"],
    ".uoi.gr": ["University of Ioannina"],
    ".uom.gr": ["University of Macedonia"],
    ".uop.gr": ["University of the Peloponnese"],
    ".icte.uowm.gr": [
        "University of Western Macedonia Department of Informatics & Telecommunications Engineering"
    ],
    ".uowm.gr": [
        "Πανεπιστήμιο Δυτικής Μακεδονίας",
        "University of Western Macedonia (UOWM)",
    ],
    ".upatras.gr": ["University of Patras"],
    ".uth.gr": ["University of Thessaly"],
    ".continentalamericano.edu.gt": [
        "Colegio Continental Americano",
        "Continental American College",
    ],
    ".cucv.edu.gt": ["Centro Universitario Ciudad Vieja"],
    ".cunoc.edu.gt": ["Centro Universitario de Occidente"],
    ".itics.edu.gt": ["ITICS Guatemala"],
    ".junkabal.edu.gt": ["Fundacion Junkabal", "Junkabal"],
    ".campusvirtual.lasallesantiago.edu.gt": ["Instituto Santiago La Salle"],
    ".mesoamericana.edu.gt": ["Universidad Mesoamericana Quetzaltenango"],
    ".miumg.edu.gt": ["Universidad Mariano Galvez de Guatemala"],
    ".udeo.edu.gt": ["Universidad de occidente", "western university"],
    ".ufm.edu.gt": ["Universidad Francisco Marroquín"],
    ".umes.edu.gt": ["Universidad Mesoamericana ", "MESOAMERICAN UNIVERSITY"],
    ".umg.edu.gt": ["Universidad Mariano Gálvez"],
    ".unis.edu.gt": ["Universidad del Istmo"],
    ".upana.edu.gt": ["Universidad Panamericana at Guatemala"],
    ".urural.edu.gt": ["Universidad Rural de Guatemala"],
    ".usac.edu.gt": ["Universidad de San Carlos de Guatemala"],
    ".alumno.uspg.edu.gt": [
        "Universidad San Pablo de Guatemala",
        "https://www.uspg.edu.gt",
        "https://uspg.edu.gt/usp/ingenieria-en-sistemas/",
    ],
    ".catedratico.uspg.edu.gt": [
        "Universidad San Pablo de Guatemala",
        "Universidad San Pablo de Guatemala",
    ],
    ".uvg.edu.gt": ["Universidad del Valle de Guatemala"],
    ".edu.gy": ["University of Guyana"],
    ".avh.hamburg": ["Alexander von Humboldt Gymnasium"],
    ".bs-citynord.hamburg": [
        "Berufliche Schule City Nord",
        "Homepage: https://www.bs28.hamburg/",
        "ContactSite: https://www.bs28.hamburg/kontakt/impressum.html",
        "Adress: Tessenowweg 3 22297 Hamburg Germany",
        "School Mail Example: example@bs-citynord.hamburg",
        "Reason for the Mail: School is using an Prowim/FirstClass https://www.prowim.de/login",
        "You can see contact Mail on the Homepage as a Proof At the Top on the right",
    ],
    ".c5.hk": ["Canossa primary school", "Canossa primary school"],
    ".cuhk.hk": ["Chinese University of Hong Kong"],
    ".bhjs.edu.hk": ["何明華會督銀禧中學", "Bishop Hall Jubilee School"],
    ".bhscmc.edu.hk": [
        "佛教孔仙洲紀念中學",
        "Buddhist Hung Sean Chau Memorial College",
    ],
    ".caisbv.edu.hk": ["Christian Alliance International School"],
    ".cccmmwc.edu.hk": [
        "中華基督教會蒙民偉書院",
        "C.C.C. Mong Man Wai College",
    ],
    ".cccmyc.edu.hk": [
        "中華基督教會銘賢書院",
        "The Church of Christ in China Ming Yin College",
    ],
    ".chuhai.edu.hk": ["Chu Hai College"],
    ".cihe.edu.hk": ["Caritas Institute of Higher Education"],
    ".student.cis.edu.hk": [
        "Chinese International School",
        "Chinese International School",
    ],
    ".cis.edu.hk": [
        "Chinese International School",
        "Chinese International School",
    ],
    ".my.cityu.edu.hk": ["City University of Hong Kong"],
    ".cityu.edu.hk": ["City University of Hong Kong"],
    ".clsmss.edu.hk": [
        "趙聿修紀念中學",
        "Chiu Lut Sau Memorial Secondary School",
    ],
    ".common.cpce-polyu.edu.hk": [
        "香港理工大學專業及持續教育學院",
        "College of Professional and Continuing Education, PolyU",
    ],
    ".cpce-polyu.edu.hk": [
        "College of Professional and Continuing Education, The Hong Kong Polytechnic University"
    ],
    ".link.cuhk.edu.hk": ["The Chinese University of Hong Kong"],
    ".cuhk.edu.hk": [
        "The Chinese University of Hong Kong",
        "The Chinese University of Hong Kong",
    ],
    ".student.cwgc.edu.hk": [
        "宣道會鄭榮之中學",
        "Christian Alliance Cheng Wing Gee Collage",
    ],
    ".cloud.elegantia.edu.hk": [
        "Elegantia College (Sponsored by Education Convergence)"
    ],
    ".stu.elegantia.edu.hk": [
        "Elegantia College (Sponsored by Education Convergence)"
    ],
    ".ms.fkyc.edu.hk": ["粉嶺救恩書院", "Fanling Kau Yan College"],
    ".flss.edu.hk": ["基督教香港信義會心誠中學"],
    ".gsas.edu.hk": [
        "香港高等研究院",
        "Hong Kong Graduate School of Advanced Studies",
    ],
    ".learning.gsis.edu.hk": ["German Swiss International School"],
    ".hkbu.edu.hk": ["Hong Kong Baptist University"],
    ".hkct.edu.hk": [
        "Hong Kong College of Technology",
        "Hong Kong College of Technology",
    ],
    ".hkis.edu.hk": ["Hong Kong International School"],
    ".hkmakslo.edu.hk": [
        "香港管理專業協會羅桂祥中學",
        "Hong Kong Management Association K S Lo College",
    ],
    ".hkmu.edu.hk": ["Hong Kong Metropolitan University"],
    ".hksyu.edu.hk": [
        "香港樹仁大學",
        "Hong Kong Shue Yan University",
        "https://ba.hksyu.edu/bba-hons-dm/programme-details",
    ],
    ".hsu.edu.hk": ["The Hang Seng University of Hong Kong"],
    ".student.icqm.edu.hk": [
        "國際基督教優質音樂中學暨小學",
        "International Christian Quality Music Sec. and Pri. School",
    ],
    ".ied.edu.hk": ["Hong Kong Institute of Education"],
    ".isf.edu.hk": ["The Independent Schools Foundation Academy "],
    ".island.edu.hk": ["Island School, Hong Kong"],
    ".is.kis.edu.hk": ["Korean International School"],
    ".ktklgss.edu.hk": [
        "觀塘功樂官立中學",
        "Kwun Tong Kung Lok Government Secondary School",
    ],
    ".la-salle.edu.hk": ["La salle primary school"],
    ".lkpfc.edu.hk": ["NLSI Lui Kwok Pat Fong College"],
    ".ln.edu.hk": ["Lingnan University"],
    ".student.nams.edu.hk": ["新亞中學", "New Asia Middle School"],
    ".ouhk.edu.hk": ["Open University of Hong Kong"],
    ".pkms.edu.hk": ["培僑中學", "Pui Kiu Middle School"],
    ".polyu.edu.hk": ["Hong Kong Polytechnic University"],
    ".pyc.edu.hk": ["Shatin Pui Ying College"],
    ".cloud.qes.edu.hk": ["Queen Elizabeth School"],
    ".sais.edu.hk": ["Stamford American School Hong Kong"],
    ".sfu.edu.hk": ["Saint Francis University"],
    ".sfxc.edu.hk": ["聖方濟書院", "St. Francis Xavier's College"],
    ".sjc.edu.hk": ["聖若瑟書院", "St. Joseph's College"],
    ".student.speed-polyu.edu.hk": [
        "Polyu Speed",
        "School of Professional Education and Executive Development",
    ],
    ".stc.edu.hk": [
        "天主教崇德英文書院",
        "Shung Tak Catholic English College",
    ],
    ".stlouis.edu.hk": ["St. Louis School"],
    ".tanghin.edu.hk": [
        "香港道教聯合會鄧顯紀念中學",
        "H.K.T.A. Tang Hin Memorial Secondary School",
    ],
    ".tkhc.edu.hk": ["Tai Kwong Hilary College"],
    ".tkogss.edu.hk": [
        "將軍澳官立中學",
        "Tseung Kwan O Government Secondary School",
    ],
    ".tmk.edu.hk": ["Hong Kong Tak Ming College"],
    ".twc.edu.hk": ["東華學院", "Tung Wah College"],
    ".twghlkss.edu.hk": ["Tung Wah Group of Hospitals Li Ka Shing College"],
    ".student.ucc.edu.hk": ["United Christian College"],
    ".mail.uic.edu.hk": ["北京师范大学-香港浸会大学联合国际学院", "UIC"],
    ".stu.vtc.edu.hk": [
        "Vocational Training Council",
        "Vocational Training Council",
    ],
    ".vtc.edu.hk": ["職業訓練局", "Vocational Training Council"],
    ".wahyan.edu.hk": ["Wah Yan College Hong Kong"],
    ".waying.edu.hk": ["Wa Ying College"],
    ".wis.edu.hk": ["West Island School"],
    ".eduhk.hk": ["The Education University of Hong Kong"],
    ".harrowschool.hk": [
        "香港哈羅國際學校",
        "Harrow International School Hong Kong",
    ],
    ".student.hkit.hk": [
        "香港科技專上書院",
        "Hong Kong Institute of Technology",
    ],
    ".learner.hkuspace.hku.hk": [
        "HKU School of Professional and Continuing Education"
    ],
    ".hku.hk": ["University of Hong Kong"],
    ".kgv.hk": ["King George V School"],
    ".kjs.hk": ["Kowloon Junior School"],
    ".ln.hk": ["Lingnan University"],
    ".nais.hk": ["Nord Anglia International School Hong Kong"],
    ".connect.polyu.hk": ["Hong Kong Polytechnic University"],
    ".ust.hk": ["Hong Kong University of Science and Technology"],
    ".ujcv.edu.hn": ["Universidad José Cecilio del Valle"],
    ".unimetro.edu.hn": ["Universidad Metropolitana de Honduras"],
    ".upnfm.edu.hn": ["Universidad Pedagógica Nacional Francisco Morazán"],
    ".unah.hn": ["National Autonomous University of Honduras"],
    ".uth.hn": ["Universidad Tecnológica de Honduras"],
    ".reddam.house": ["Reddam House Atlantic Seaboard"],
    ".algebra.hr": ["Visoko Učilište Algebra", "Algebra University Collage"],
    ".aspira.hr": ["Visoka škola Aspira"],
    ".bak.hr": ["University of Applied Sciences BALTAZAR"],
    ".net.doba.hr": ["DOBA Fakultet", "DOBA Business School"],
    ".efos.hr": ["University of Osijek Faculty of Economics"],
    ".efri.hr": [
        "Ekonomski Fakultet u Rijeci",
        "University of Rijeka, Faculty of Economics and Business",
    ],
    ".efst.hr": ["University of Split Faculty of Economics"],
    ".net.efzg.hr": [
        "Sveučilište u Zagrebu, Ekonomski fakultet",
        "University of Zagreb, Faculty of Economics and Business",
    ],
    ".etfos.hr": ["University of Osijek Faculty of Electrical Engineering"],
    ".fer.hr": [
        "University of Zagreb Faculty of Electrical Engineering and Computing"
    ],
    ".ferit.hr": ["University of Osijek Faculty of Electrical Engineering"],
    ".fesb.hr": [
        "University of Split Faculty of Electrical Engineering, Mechanical Engineering and Naval Architecture"
    ],
    ".ffos.hr": [
        "University of Osijek Faculty of humanities and social sciences"
    ],
    ".ffri.hr": [
        "University of Rijeka Faculty of Humanities and Social Sciences"
    ],
    ".ffst.hr": [
        "Faculty of Humanities and Social Sciences, University of Split"
    ],
    ".ffzg.hr": [
        "Faculty of Humanities and Social Sciences, University of Zagreb"
    ],
    ".fkit.hr": [
        "Fakultet kemijskog inženjerstva i tehnologije",
        "Faculty of chemical engineering and technology",
        "https://www.fkit.unizg.hr/ --> faculty home web page",
        "https://www.fkit.unizg.hr/predmet/muiuki --> AI methods in chemical engineering class ",
        "https://www.fkit.unizg.hr/diplomski/kemijsko_inzenjerstvo/kpi --> engineering master degree course",
    ],
    ".foi.hr": ["Faculty of Organization and Informatics"],
    ".fpz.hr": [
        "Faculty of Transport and Traffic Sciences, University of Zagreb "
    ],
    ".fsb.hr": [
        "Faculty of Mechanical Engineering and Naval Architecture, University of Zagreb"
    ],
    ".geof.hr": ["UNIVERSITY OF ZAGREB, FACULTY OF GEODESY"],
    ".gfos.hr": ["Faculty of civil engineering"],
    ".gfz.hr": [
        "University of Zagreb Faculty of Mathematics and Natural Sciences - Department of Geophysics"
    ],
    ".grad.hr": ["Faculty of Civil Engineering University of Zagreb"],
    ".gradst.hr": [
        "University of Split Faculty of Civil Engineering, Architecture and Geodesy"
    ],
    ".hrstud.hr": [
        "Fakultet hrvatskih studija, Sveuciliste u Zagrebu",
        "Faculty of Croatian Studies, University of Zagreb",
    ],
    ".kifos.hr": [
        "Kineziološki fakultet Osijek",
        "Faculty of kinesiology Osijek",
    ],
    ".math.hr": [
        "University of Zagreb Faculty of Mathematics and Natural Sciences - Department of Mathematics"
    ],
    ".mathos.hr": [
        "University of Osijek Department of Mathematics",
        "Sveučilište J. J. Strossmayera u Osijeku - Odjel za matematiku",
    ],
    ".mef.hr": ["Medicinski fakultet", "School of Medicine"],
    ".mefst.hr": [
        "Sveučilište u Splitu, Medicinski fakultet",
        "The School of Medicine in Split",
    ],
    ".mev.hr": ["Polytechnic of Međimurje in Čakovec"],
    ".pbf.hr": [
        "University of Zagreb Faculty of Food Technology and Biotechnology"
    ],
    ".pharma.hr": ["Farmaceutsko-biokemijski fakultet Sveučilišta u Zagrebu"],
    ".phy.hr": [
        "University of Zagreb Faculty of Mathematics and Natural Sciences - Department of Physics"
    ],
    ".pmf.hr": ["University of Zagreb Faculty of Science"],
    ".pmfst.hr": [
        "University of Split Faculty of Natural Sciences and Mathematics"
    ],
    ".pou.hr": ["Public Open University Zagreb"],
    ".student.pravo.hr": [
        "Pravni fakultet Sveučilišta u Zagrebu",
        "Faculty of Law of the University of Zagreb",
    ],
    ".pravos.hr": ["University of Osijek Faculty of Law"],
    ".racunarstvo.hr": ["University College for Applied Computer Engineering"],
    ".riteh.hr": ["University of Rijeka Faculty of Engineering"],
    ".skole.hr": ["Croatian Academic and Research network"],
    ".srce.hr": ["Unversity of Zagreb - University Computing Centre - Srce"],
    ".sumfak.hr": ["University of Zagreb Faculty of Forestry"],
    ".tvz.hr": ["Polytechnic of Zagreb"],
    ".ufzg.hr": ["University of Zagreb - Faculty of Teacher Education"],
    ".unidu.hr": ["University of Dubrovnik"],
    ".unin.hr": ["University North"],
    ".unios.hr": ["University of Osijek"],
    ".unipu.hr": ["University of Pula"],
    ".uniri.hr": ["University of Rijeka"],
    ".unist.hr": ["University of Split"],
    ".unizd.hr": ["University of Zadar"],
    ".unizg.hr": ["University of Zagreb"],
    ".veleri.hr": ["Polytechnic of Rijeka"],
    ".vern.hr": ["VERN University of applied sciences"],
    ".vernnet.hr": ["Vern University of Applied Sciences"],
    ".vevu.hr": ["Polytechnic Lavoslav Ružička Vukovar"],
    ".vsite.hr": ["College for Information Technologies"],
    ".vsmti.hr": ["Virovitica College"],
    ".vub.hr": [
        "Veleučilište u Bjelovaru",
        "Bjelovar University of Applied Sciences",
    ],
    ".vuv.hr": [
        "Veleučilište u Virovitici",
        "Virovitica University of Applied Sciences",
    ],
    ".vvg.hr": ["University of Applied Sciences Velika Gorica"],
    ".zsem.hr": [
        "Zagreb School of Economics and Management",
        "Zagrebačka škola ekonomije i managementa",
    ],
    ".inuka.edu.ht": ["universite inuka"],
    ".ueh.edu.ht": ["Université d'Etat d'Haiti"],
    ".student.aisb.hu": [
        "AISB (American International School of Budapest)",
        "student.aisb.hu (student address)",
        "aisb.hu (faculty address)",
        "https://www.aisb.hu/",
        "https://www.aisb.hu/en/learning/high-school (under sciences section: grade 11-12)",
    ],
    ".andrassyuni.hu": ["Andrassy Gyula German Speaking University Budapest"],
    ".arts7.hu": ["Hungarian Academy of Fine Arts Budapest"],
    ".aszevgim.hu": ["Aszódi Petőfi Lutheran Secondary School"],
    ".avicenna.hu": ["Avicenna International College"],
    ".bdtf.hu": ["Dániel Berzsenyi Teacher Training College"],
    ".benkoiskola.hu": [
        "Benkő István Református Általános Iskola és Gimnázium"
    ],
    ".berzsenyi.hu": [
        "Berzsenyi Dániel Gimnázium",
        "Berzsenyi Daniel Secondary School",
    ],
    ".bit-edu.hu": ["Biatorbágyi Innovatív Technikum és Gimnázium"],
    ".bjg.hu": ["Batsanyi Janos Gimnazium"],
    ".bke.hu": [
        "Budapest University of Economic Sciences and Public Administration"
    ],
    ".aut.bme.hu": [
        "Budapesti Műszaki és Gazdaságtudományi Egyetem",
        "Budapest University of Technology and Economics",
    ],
    ".db.bme.hu": [
        "Budapesti Műszaki és Gazdaságtudományi Egyetem",
        "Budapest University of Technology and Economics",
    ],
    ".edu.bme.hu": ["Budapest University of Technology and Economics"],
    ".emk.bme.hu": [
        "Budapesti Műszaki és Gazdaságtudományi Egyetem ",
        "Budapest University of Technology and Economics",
    ],
    ".epitesz.bme.hu": ["Budapest University of Technology and Economics"],
    ".fmt.bme.hu": [
        "Budapesti Műszaki és Gazdaságtudományi Egyetem ",
        "Budapest University of Technology and Economics",
    ],
    ".gpk.bme.hu": [
        "Budapesti Műszaki és Gazdaságtudományi Egyetem",
        "Budapest University of Technology and Economics",
    ],
    ".hit.bme.hu": ["Budapest University of Technology and Economics"],
    ".kjk.bme.hu": [
        "Budapest Műszaki és Gazdaságtudományi Egyetem",
        "Budapest University of Technology and Economics",
    ],
    ".math.bme.hu": ["Budapest University of Technology and Economics"],
    ".mm.bme.hu": [
        "Budapesti Műszaki és Gazdaságtudományi Egyetem",
        "Budapest University of Technology and Economics",
    ],
    ".mokk.bme.hu": [
        "Budapesti Műszaki és Gazdaságtudományi Egyetem ",
        "Budapest University of Technology and Economics",
    ],
    ".sch.bme.hu": [
        "Budapesti Műszaki és Gazdaságtudományi Egyetem",
        "Budapest University of Technology and Economics",
    ],
    ".szoc.bme.hu": [
        "Budapesti Műszaki és Gazdaságtudományi Egyetem ",
        "Budapest University of Technology and Economics",
    ],
    ".tmit.bme.hu": [
        "Budapesti Műszaki és Gazdaságtudományi Egyetem ",
        "Budapest University of Technology and Economics",
    ],
    ".vik.bme.hu": [
        "Budapesti Műszaki és Gazdaságtudományi Egyetem ",
        "Budapest University of Technology and Economics",
    ],
    ".bocskai11.hu": ["Újbudai Bocskai István Általános Iskola"],
    ".bolyai-szakkozep.hu": [
        "BMSZC Bolyai János Műszaki Technikum és Kollégium"
    ],
    ".boronkay.hu": [
        "Boronkay György Műszaki Technikum és Gimnázium",
        "György Boronkay Technical College and High School",
    ],
    ".brc.hu": [
        "HUN-REN Biological Research Center, Institute of Biochemistry"
    ],
    ".ceu.hu": ["Central European University"],
    ".ckik.hu": ["Ceglédi SZC Közgazdasági és Informatikai Technikum"],
    ".dng-bp.hu": ["Német Nemzetiségi Gimnázium és Kollégium"],
    ".dote.hu": ["University Medical School of Debrecen"],
    ".drk.hu": ["Reformed Theological Academy of Debrecen"],
    ".dszcberegszaszi.hu": ["DSZC Beregszászi Pál Technikum"],
    ".duf.hu": ["College of Dunaujvaros"],
    ".dszcbaross.edu.hu": [
        "Debreceni SZC Baross Gábor Technikum, Szakképző Iskola és Kollégium",
        "dszcbaross.edu.hu (student & faculty email)",
        "https://www.dszcbaross.hu/",
    ],
    ".zsoldos.edu.hu": [
        "Hódmezővásárhelyi SZC Szentesi Zsoldos Ferenc Technikum",
        "zsoldos.edu.hu (student & faculty email)",
        "https://www.zsoldos.edu.hu",
    ],
    ".efe.hu": ["University of Sopron"],
    ".ehf.hu": ["Esztergom Theological College"],
    ".elte.hu": ["Eötvös Lorand University", "Eötvös Loránd University"],
    ".eszi.hu": [
        "Energetikai Technikum és Kollégium Paks",
        "Energetic Technical College and College Paks",
    ],
    ".filmacademy.hu": ["Academy of Drama and Film"],
    ".gde.hu": ["Dennis Gabor University, Budapest"],
    ".neptun.gdf.hu": ["Gábor Dénes Főiskola"],
    ".gdf.hu": ["Gábor Dénes Főiskola", "Dennis Gabor College"],
    ".gdszeged.hu": [
        "Szegedi SZC Gábor Dénes Technikum és Szakgimnázium",
        "Szeged SZC Gábor Dénes Technical and Vocational High School",
    ],
    ".gr-szechenyi.hu": [
        "Székesfehérvári SZC Széchenyi István Műszaki Technikum ",
        "Székesfehérvár Vocational Training Center Széchenyi István Technical School of Engineering",
    ],
    ".hengersor.hu": [
        "Budapesti Gazdasági Szakképzési Centrum Pestszentlőrinci Közgazdasági és Informatikai Szakgimnáziuma"
    ],
    ".hiete.hu": ["Haynal Imre University of Health Sciences Budapest"],
    ".hupe.hu": ["Hungarian University of Physical Education"],
    ".ibs-b.hu": ["IBS International Business School, Budapest"],
    ".jedlik.hu": ["Jedlik Ányos Gimnázium"],
    ".jpte.hu": ["Janus Pannonius University"],
    ".ke.hu": ["University of Kaposvar"],
    ".kee.hu": ["University of Horticulture and Food Industry"],
    ".kefo.hu": ["Kecskemet College"],
    ".kgre.hu": ["Károl Gáspár University of the Reformed Church"],
    ".kkszki.hu": ["Miskolci SZC Kandó Kálmán Informatikai Technikum"],
    ".klte.hu": ["Kossuth Lajos University"],
    ".kodolanyi.hu": ["Kodolanyi Janos University College"],
    ".cloud.kre.hu": [
        "Károli Gáspár Református Egyetem",
        "Károli Gáspár University of the Reformed Church in Hungary ",
        "IT releated course: https://btk.kre.hu/index.php/tarsadalmi-viseledeselemzes-ma",
    ],
    ".kre.hu": [
        "Karoli Gaspar Reformatus Egyetem",
        "Karoli Gaspar University of the Reformed Church in Hungary",
    ],
    ".kulkergimi.hu": ["BZSH Külkereskedelmi Technikum"],
    ".kulkertechnikum.hu": ["BZSH Külkereskedelmi Technikum"],
    ".lanyiferenc.hu": ["Lányi Ferenc Technikum és Szakképző Iskola"],
    ".lauder.hu": ["Lauder Javne Jewish school"],
    ".levaygimnazium.hu": ["Lévay József Református Gimnázium és Diákotthon"],
    ".lfze.hu": ["Liszt Ferenc Academy of Music Budapest"],
    ".lonyayrefi.hu": [
        "Lónyay utcai Református gimnázium",
        "Lónyay utcai reformed high school",
    ],
    ".mail.lovassy.hu": [
        "Lovassy László Gimnázium",
        "Lovassy László High School",
    ],
    ".liveedu.mathiasz.hu": [
        "Siófoki SZC Mathiász János Technikum és Gimnázium"
    ],
    ".mcdaniel.hu": ["McDaniel College Budapest", "McDaniel College Budapest"],
    ".instructor.metropolitan.hu": [
        "Budapesti Metropolitan Egyetem",
        "Budapest Metropolitan University",
    ],
    ".student.metropolitan.hu": [
        "Budapesti Metropolitan Egyetem",
        "Budapest Metropolitan University",
    ],
    ".mif.hu": ["Hungarian Academy of Craft and Design"],
    ".mke.hu": ["Hungarian University of Fine Arts"],
    ".mome.hu": ["Moholy-Nagy University of Art and Design"],
    ".moriczref.hu": [
        "Móricz Zsigmond Református Kollégium, Gimnázium, Szakközépiskola és Általános Iskola",
        "Móricz Zsigmond Reformed College, High School, Vocational High School and Primary School",
    ],
    ".nytud.mta.hu": [
        "Research Institute for Linguistics of the Hungarian Academy of Sciences",
        "Magyar Tudományos Akadémia Nyelvtudományi Intézete",
    ],
    ".mtf.hu": ["Hungarian Dance Academy"],
    ".mzsg.hu": ["Móricz Zsigmond Gimnázium", "Móricz Zsigmond High School"],
    ".nejanet.hu": [
        "Neumann János Gimnázium, Technikum és Kollégium",
        "Neumann János High School, Vocational School and Dormitory",
    ],
    ".nje.hu": ["Neumann János Egyetem", "John von Neumann University"],
    ".njit.hu": [
        "BMSZC Neumann János Informatikai Technikum",
        "BMSZC John von Neumann Secondary School",
    ],
    ".njszg.hu": [
        "Budapesti Műszaki Szakképzési Centrum Neumann János Számítástechnikai Szakgimnáziuma"
    ],
    ".nye.hu": ["University of Nyíregyháza"],
    ".nyfbox.hu": ["University of Nyíregyháza"],
    ".nyme.hu": ["University of West Hungary"],
    ".pataky.hu": [
        "\ufeffBudapesti Műszaki Szakképző Centrum Pataky István Híradásipari és Informatikai Szakgimnáziuma",
        " ",
    ],
    ".petrik.hu": [
        "Budapesti Műszaki Szakképzési Centrum Petrik Lajos Két Tanítási Nyelvű Technikum"
    ],
    ".diak.budapest.piarista.hu": [
        "Piarista Gimnázium Budapest",
        "Piarist High School Budapest",
    ],
    ".pote.hu": ["University Medical School of Pécs"],
    ".ppke.hu": ["Pázmány Péter Catholic University"],
    ".pte.hu": ["University of Pecs"],
    ".puskas.hu": [
        "Budapesti Műszaki Szakképzési Centrum Puskás Tivadar Távközlési és Informatikai Technikum"
    ],
    ".scheiber.hu": [
        "Scheiber Sandor High School and Elementary School",
        "BZSH Scheiber Sándor Gimnázium és Általános Iskola",
    ],
    ".emk.semmelweis.hu": [
        "Semmelweis Egyetem Egészségügyi Menedzserképző Központ",
        "Health Services Management Training Centre, Semmelweis University",
    ],
    ".stud.semmelweis.hu": ["Semmelweis University"],
    ".semmelweis-univ.hu": ["Semmelweis University"],
    ".semmelweis.hu": ["Semmelweis University"],
    ".somer.hu": [
        "Scheiber Sandor High School and Elementary School",
        "BZSH Scheiber Sándor Gimnázium és Általános Iskola",
    ],
    ".sote.hu": ["Semmelweis University of Medical Sciences"],
    ".blathy-bp.sulinet.hu": [
        "Budapesti Műszaki Szakképzési Centrum Bláthy Ottó Titusz Informatikai Technikum"
    ],
    ".diak.szamalk-szalezi.hu": [
        "SZÁMALK-Szalézi Technikum és Szakgimnázium",
        "SZÁMALK-Salesian Technical School",
    ],
    ".szamalk-szalezi.hu": [
        "SZÁMALK-Szalézi Technikum és Szakgimnázium",
        "SZÁMALK-Salesian Technical School",
    ],
    ".szbi.hu": ["Szent Benedek Gimnázium", "Saint Benedict High School"],
    ".sze.hu": ["Széchenyi István University"],
    ".szegbp.hu": [
        "Budapest I. Kerületi Szilágyi Erzsébet Gimnázium",
        "Szilágyi Ezsébet Secondary School, Budapest 1st District",
    ],
    ".szentgyorgyi-nmszc.hu": [
        "Nógrád Megyei Szakképzési Centrum Szent-Györgyi Albert Technikum"
    ],
    ".diak.szigbp.hu": ["Szent István Gimnázium Budapest"],
    ".szilagyi-eger.hu": ["Egri Szilágyi Erzsébet Gimnázium és Kollégium"],
    ".szjgdebrecen.hu": [
        "Szent József Általános Iskola, Gimnázium, Szakgimnázium és Kollégium"
    ],
    ".szlgbp.hu": [
        "Kőbányai Szent László Gimnázium",
        "Kőbánya Szent László High School",
    ],
    ".szrg.hu": [
        "Szentendrei Református Gimnázium",
        "Szentendre Reformed High School",
    ],
    ".sztaki.hu": ["Számítástechnikai és Automatizálási Kutatóintézet"],
    ".tancsics.hu": ["Kaposvári Táncsics Mihály Gimnázium"],
    ".taszi.hu": [
        "Békéscsabai SZC Trefort Ágoston Szakgimnáziuma, Szakközépiskolája és Kollégiuma"
    ],
    ".tkbf.hu": ["Budapest Buddhist University"],
    ".apaczai.tmszc.hu": [
        "Tolna Vármegyei SZC Apáczai Csere János Technikum és Kollégium"
    ],
    ".u-szeged.hu": ["University of Szeged"],
    ".umszki.hu": ["BMSZC Újpesti Két Tanítási Nyelvű Műszaki Technikum"],
    ".uni-bge.hu": ["Budapest Business School"],
    ".uni-corvinus.hu": ["Corvinus University of Budapest"],
    ".uni-eszterhazy.hu": ["Eszterházy Károly University"],
    ".phd.uni-mate.hu": [
        "Magyar Agrár és Élettudományi egyetem",
        "Hungarian University of Agriculture and Life Sciences",
    ],
    ".stud.uni-mate.hu": [
        "Magyar Agrár- és Élettudományi Egyetem",
        "Hungarian University of Agriculture and Life Sciences",
    ],
    ".uni-mate.hu": [
        "Magyar Agrár- és Élettudományi Egyetem ",
        "Hungarian University of Agriculture and Life Sciences",
    ],
    ".uni-miskolc.hu": ["University of Miskolc"],
    ".uni-neumann.hu": ["John von Neumann University"],
    ".uni-nke.hu": ["National University of Public Service"],
    ".uni-obuda.hu": ["Óbuda University"],
    ".uni-pannon.hu": ["University of Pannonia"],
    ".uni-sopron.hu": ["University of Sopron"],
    ".hallgato.uni-szie.hu": [
        "Szent István Egyetem",
        "Szent István University",
    ],
    ".unideb.hu": [
        "Debrecen University of Agricultural Sciences",
        "University of Debrecen ",
    ],
    ".uniduna.hu": ["University of Dunaújváros"],
    ".unithe.hu": ["Tokaj-Hegyalja Egyetem", "University of Tokaj-Hegyalja"],
    ".univet.hu": ["University of Veterinary Science"],
    ".vargaszolnok.hu": [
        "Varga Katalin Gimnázium Szolnok",
        "Varga Katalin Secondary School Szolnok",
    ],
    ".ipari.vein.hu": ["Veszprémi Szakképzési Centrum Ipari Technikum"],
    ".verebelyszki.hu": [
        "BMSZC Verebély László Technikum",
        "Budapest Center of Technical Vocational Training, László Verebély Vocational School",
    ],
    ".vhf.hu": [
        "Veszprémi Érseki Hittudományi Főiskola",
        "Archepiscopal's Theological College of Veszprem",
    ],
    ".zipernowsky.hu": ["BMSZC Zipernowsky Károly Műszaki Technikum"],
    ".abulyatama.ac.id": ["Universitas Abulyatama", "Abulyatama University"],
    ".aisyahuniversity.ac.id": ["Aisyah University", "Aisyah University"],
    ".akakom.ac.id": ["STMIK Akakom Yogyakarta"],
    ".akb.ac.id": [
        "Akademi Komunitas Negeri Putra Sang Fajar Blitar",
        "State Community Academy Putra Sang Fajar Blitar",
    ],
    ".mhs.akba.ac.id": [
        "STMIK AKBA",
        "College of Informatics and Computer Management, AKBA",
    ],
    ".aknpacitan.ac.id": ["AKN Pacitan", "Pacitan Public Community College"],
    ".aknsumenep.ac.id": ["Akademi Komunitas Negeri Sumenep"],
    ".akprind.ac.id": ["Institut Sains &amp; Teknologi Akprind"],
    ".alfath.ac.id": ["Sekolah Tinggi Manajemen dan Ilmu Komputer Al-Fath"],
    ".almaata.ac.id": ["Universitas Alma Ata Yogyakarta"],
    ".amikmahaputra.ac.id": ["amikmahaputra.ac.id", "AMIK Mahaputra Riau"],
    ".amikom.ac.id": ["Universitas AMIKOM Yogyakarta"],
    ".mhs.amikompurwokerto.ac.id": [
        "Universitas AMIKOM Purwokerto",
        "AMIKOM Purwokerto University",
    ],
    ".students.amikompurwokerto.ac.id": [
        "Universitas Amikom Purwokerto",
        "Amikom Purwokerto University",
    ],
    ".mhs.amikomsolo.ac.id": [
        "STIMIK AMIKOM Surakarta",
        "STIMIK AMIKOM Surakarta",
    ],
    ".ar-raniry.ac.id": [
        "Universitas Islam Negeri Ar-Raniry Banda Aceh",
        "Islamic State University Ar-Raniry Banda Aceh",
    ],
    ".ars.ac.id": ["ARS University"],
    ".edu.asia.ac.id": ["Institut Teknologi dan Bisnis Asia Malang"],
    ".polman.astra.ac.id": ["Astra Polytechnic"],
    ".polytechnic.astra.ac.id": ["Astra Polytechnic"],
    ".atmajaya.ac.id": ["Universitas Katolik Indonesia Atma Jaya"],
    ".atmaluhur.ac.id": ["ISB Atma Luhur"],
    ".atmi.ac.id": ["Politeknik ATMI Surakarta", "ATMI Surakarta Polytechnic"],
    ".bakrie.ac.id": ["Universitas Bakrie"],
    ".stmik.banisaleh.ac.id": ["STMIK BANI SALEH"],
    ".binadarma.ac.id": ["Universitas Bina Darma"],
    ".binainsani.ac.id": ["Universitas Bina Insani", "Bina Insani University"],
    ".binawan.ac.id": ["Universitas Binawan"],
    ".borobudur.ac.id": [
        "Universitas Borobudur Jakarta",
        "BOROBUDUR UNIVERSITY JAKARTA",
    ],
    ".bsi.ac.id": ["Bina Sarana Informatika"],
    ".buddhidharma.ac.id": ["Universitas Buddhi Dharma"],
    ".budiluhur.ac.id": ["Universitas Budi Luhur"],
    ".bunghatta.ac.id": ["Universitas Bung Hatta"],
    ".cakrawala.ac.id": ["Universitas Cakrawala", "Cakrawala University"],
    ".calvin.ac.id": [
        "Calvin Institute of Technology",
        "Calvin Institute of Technology",
    ],
    ".cendekia.ac.id": ["Universitas Cendekia Abditama"],
    ".cic.ac.id": [
        "Universitas Catur Insan Cendekia",
        "Catur Insan Cendekia University",
    ],
    ".ciputra.ac.id": ["Universitas Ciputra"],
    ".cyber-univ.ac.id": [
        "Universitas Siber Indonesia",
        "Cyber University Indonesia",
    ],
    ".darmajaya.ac.id": ["Institut Informatika dan Bisnis Darmajaya"],
    ".del.ac.id": ["Institut Teknologi Del"],
    ".dinamika.ac.id": ["Universitas Dinamika", "Dinamika University"],
    ".dinus.ac.id": ["Universitas Dian Nuswantoro"],
    ".dipanegara.ac.id": [
        "STMIK Dipanegara",
        "College of Informatics and Computer Management, Dipanegara",
    ],
    ".driyarkara.ac.id": ["Sekolah Tinggi Filsafat Driyarkara"],
    ".esaunggul.ac.id": ["Universitas Indonusa Esa Unggul"],
    ".students.esqbs.ac.id": [
        "Sekolah Tinggi Ilmu Manajemen dan Ilmu Komputer ESQ",
        "ESQ School of Technology",
    ],
    ".mhs.fastikom-unsiq.ac.id": [
        "Universitas Sains Al - Qur'an",
        "University of Al - Qur'an Sciences",
    ],
    ".fisip-untirta.ac.id": [
        "Fakultas Ilmu Sosial dan Politik Universitas Sultan Ageng Tirtayasa",
        "Social and Polotical Sciences Sultan Ageng Tirtayasa University",
    ],
    ".ft-umt.ac.id": [
        "Universitas Muhammadiyah Tangerang",
        "Muhammadiyah University of Tangerang",
    ],
    ".ftumj.ac.id": ["universitas muhammadiyah jakarta"],
    ".global.ac.id": [
        "Institut Teknologi dan Bisnis Global",
        "Global Institute of Technology and Business",
    ],
    ".student.cs.unida.gontor.ac.id": [
        "Universitas Darussalam Gontor",
        "University of Darussalam Gontor",
    ],
    ".mhs.unida.gontor.ac.id": ["Universitas Darussalam Gontor"],
    ".gunadarma.ac.id": ["Universitas Gunadarma"],
    ".student.hamzanwadi.ac.id": ["Universitas Hamzanwadi"],
    ".hamzanwadi.ac.id": ["Universitas Hamzanwadi", "Hamzanwadi University"],
    ".student.handayani.ac.id": [
        "Sekolah Tinggi Manajemen Informatika Komputer Handayani"
    ],
    ".handayani.ac.id": ["Universitas Handayani Makassar"],
    ".krw.horizon.ac.id": ["STMIK Horizon Karawang"],
    ".htp.ac.id": ["Universitas Hang Tuah Pekanbaru"],
    ".iailm.ac.id": [
        "Institut Agama Islam Latifah Mubarokiyah",
        "Latifah Mubarokiyah Islamic Institute",
    ],
    ".ibbi.ac.id": ["Institut Bina Bisnis Indonesia"],
    ".ibik.ac.id": [
        "Institut Bisnis dan Informatika Kesatuan",
        "Kesatuan Institute of Business and Informatics",
    ],
    ".icpa-banyuwangi.ac.id": ["Akademi Penerbang Indonesia Banyuwangi"],
    ".idn.ac.id": ["Politeknik IDN Bogor", "POLITEKNIK IDN BOGOR"],
    ".ids.ac.id": ["STMIK IDS"],
    ".iikmpbali.ac.id": [
        "universitas bali internasional",
        "bali international university",
    ],
    ".instiki.ac.id": [
        "Institut Bisnis dan Teknologi Indonesia",
        "Indonesian Institute of Business and Technology",
    ],
    ".ipb.ac.id": ["Bogor Agricultural University"],
    ".ipem.ac.id": ["STMIK Insan Pembangunan"],
    ".isi.ac.id": [
        "Institut Seni Indonesia Yogyakarta",
        "Indonesia Institute of Arts Yogyakarta",
    ],
    ".ista.ac.id": ["Institut Sains dan Teknologi Al Kamal"],
    ".istts.ac.id": ["Institut Sains & Teknologi Terpadu Surabaya"],
    ".itats.ac.id": ["Institut Teknologi Adhi Tama Surabaya"],
    ".itb.ac.id": ["Institut Teknologi Bandung"],
    ".itbss.ac.id": ["Institute technology and business sabda setia"],
    ".student.itda.ac.id": [
        "Institut Teknologi Dirgantara Adisutjipto",
        "Adisutjipto Institute of Aerospace Technology",
    ],
    ".iteba.ac.id": ["Institut Teknologi Batam (ITEBA)"],
    ".itenas.ac.id": ["Institut Teknologi Nasional (ITENAS)"],
    ".itera.ac.id": ["Institut Teknologi Sumatera"],
    ".itg.ac.id": [
        "Institut Teknologi Garut",
        "Garut Institute of Technology",
    ],
    ".ithb.ac.id": ["Institut Teknologi Harapan Bangsa"],
    ".student.iti.ac.id": ["Institut Teknologi Indonesia"],
    ".itk.ac.id": ["Institut Teknologi Kalimantan"],
    ".scholar.itn.ac.id": ["Institut Teknologi Nasional Malang"],
    ".itn.ac.id": [
        "Institut Teknologi Nasional Malang",
        "National Institute of Technology Malang",
    ],
    ".itnb.ac.id": ["ITNB", "Institut Bisnis IT&B"],
    ".itp.ac.id": [
        "Institut Teknologi Padang",
        "Padang Institute of Technology",
    ],
    ".itpln.ac.id": [
        "Institut Teknologi PLN Jakarta",
        "Institute Of Technology PLN",
    ],
    ".itsm.ac.id": [
        "Institut Teknologi dan Sains Mandala",
        "Institute Technology and Science Mandala",
    ],
    ".itsnupadangsidimpuan.ac.id": ["ITS NU Padangsidimpuan"],
    ".itspku.ac.id": [
        "Institut Teknologi Sains dan Kesehatan PKU Muhammadiyah Surakarta"
    ],
    ".ittelkom-pwt.ac.id": [
        "Institut Teknologi Telkom Purwokerto",
        "Telkom Institute of Technology Purwokerto",
    ],
    ".student.if.ittelkom-sby.ac.id": [
        "Institute Teknologi Telkom Surabaya",
        "Telkom Institute of Technology Surabaya",
    ],
    ".student.ittelkom-sby.ac.id": [
        "Institut Teknologi Telkom Surabaya",
        "Telkom Institute of Technology Surabaya",
    ],
    ".itts.ac.id": [
        "Institut Teknologi Tangerang Selatan ",
        "Institute Technology South of Tangerang",
    ],
    ".iuli.ac.id": ["International University Liaison Indonesia"],
    ".jak-stik.ac.id": [
        "Sekolah Tinggi Manajemen Informatika dan Komputer Jakarta STI&K"
    ],
    ".jakstik.ac.id": [
        "Sekolah Tinggi Manajemen Informatika dan Komputer Jakarta STI&K"
    ],
    ".janabadra.ac.id": ["Universitas Janabadra"],
    ".jayabaya.ac.id": ["Universitas Jayabaya"],
    ".stmik.jayakarta.ac.id": ["STIE & STMIK Jayakarta"],
    ".kalbis.ac.id": ["Kalbis Institute"],
    ".kallabs.ac.id": ["Institut Teknologi dan Bisnis Kalla"],
    ".kharisma.ac.id": ["STMIK KHARISMA Makassar"],
    ".kwikkiangie.ac.id": [
        "Institut Bisnis dan Informatika Kwik Kian Gie",
        "Kwik Kian Gie Institute of Business and Informatics",
    ],
    ".likmi.ac.id": ["STMIK LIKMI", "STMIK LIKMI Bandung"],
    ".fellow.lpkia.ac.id": ["STIMIK & POLITEKNIK KOMPUTER BISNIS LPKIA"],
    ".machung.ac.id": ["Universitas Ma Chung"],
    ".maranatha.ac.id": ["Universitas Kristen Maranatha"],
    ".matanauniversity.ac.id": ["Universitas Matana", "Matana University"],
    ".mdp.ac.id": ["STMIK Global Informatika MDP"],
    ".mercubuana-yogya.ac.id": ["Universitas Mercubuana Yogyakarta"],
    ".methodist.ac.id": [
        "Universitas Methodist Indonesia",
        "Methodist University of Indonesia",
    ],
    ".metrouniv.ac.id": [
        "Institut Agama Islam Negeri Metro",
        "Metro National State Islamic Institute",
    ],
    ".mikroskil.ac.id": ["STMIK - STIE Mikroskil"],
    ".mmtc.ac.id": ["STMM MMTC", "MultiMedia Training Center"],
    ".mncu.ac.id": ["Universitas Media Nusantara Citra", "MNC University"],
    ".moestopo.ac.id": ["Universitas Dr. R. Moestopo"],
    ".narotama.ac.id": ["Universitas Narotama"],
    ".nurulfikri.ac.id": ["STT Nurul Fikri"],
    ".nusamandiri.ac.id": ["STMIK Nusamandiri"],
    ".nusaputra.ac.id": ["Universitas Nusa Putra", "Nusa Putra University"],
    ".palcomtech.ac.id": [
        "Institut Teknologi dan Bisnis PalComTech",
        "Palcomtech Institute of Technology and Business",
    ],
    ".pancabudi.ac.id": ["Universitas Pembangunan Panca Budi"],
    ".paramadina.ac.id": ["Universitas Paramadina Mulya"],
    ".mahasiswa.pcr.ac.id": ["Politeknik Caltex Riau"],
    ".pdbi.ac.id": ["Politeknik Digital Boash Indonesia"],
    ".mhs.pelitabangsa.ac.id": ["Pelita Bangsa University"],
    ".pelitabangsa.ac.id": ["Universitas Pelita Bangsa"],
    ".student.pelitaindonesia.ac.id": [
        "Institut Bisnis dan Teknologi Pelita Indonesia",
        "Institute of Business and Technology Pelita Indonesia",
    ],
    ".pens.ac.id": ["Politeknik Elektronika Negeri Surabaya"],
    ".mt.peradaban.ac.id": ["Universitas Peradaban", "Peradaban University"],
    ".perbanas.ac.id": ["Stie Perbanas Surabaya"],
    ".perbanasinstitute.ac.id": ["Abfi Institute Perbanas Jakarta"],
    ".permataindonesia.ac.id": ["Poltekkes Permata Indonesia Yogyakarta"],
    ".petra.ac.id": ["Universitas Kristen Petra"],
    ".piksi.ac.id": ["Politeknik PIKSI Ganesha", "PIKSI Ganesha Polytechnic"],
    ".piksiinputserang.ac.id": ["Politeknik PIKSI Input Serang"],
    ".pknstan.ac.id": ["Sekolah Tinggi Akuntansi Negara (STAN)"],
    ".plb.ac.id": ["Politeknik LP3I Bandung"],
    ".pmbs.ac.id": ["Prasetiya Mulya Business School"],
    ".pmsbe.ac.id": ["Universitas Prasetiya Mulya"],
    ".pnb.ac.id": ["Politeknik Negeri Bali", "Bali State Polytechnic"],
    ".pnc.ac.id": [
        "Politeknik Negeri Cilacap",
        "State Polytechnic of Cilacap",
    ],
    ".pnj.ac.id": ["Politeknik Negeri Jakarta"],
    ".pnk.ac.id": ["Politeknik Negeri Kupang", "Kupang Polytechnic"],
    ".pnl.ac.id": ["Politeknik Negeri Lhokseumawe"],
    ".pnm.ac.id": ["Politeknik Negeri Madiun"],
    ".polban.ac.id": ["Politeknik Negeri Bandung"],
    ".mahasiswa.poliban.ac.id": [
        "Politeknik Negeri Banjarmasin",
        "State Polytechnic of Banjarmasin",
    ],
    ".mhs.poliban.ac.id": [
        "Politeknik Negeri Banjarmasin",
        "State Polytechnic of Banjarmasin",
    ],
    ".students.polibatam.ac.id": [
        "Politeknik Negeri Batam",
        "State Polytechnic of Batam",
    ],
    ".polibatam.ac.id": ["Politeknik Negeri Batam", "Batam State Polytechnic"],
    ".polihasnur.ac.id": ["Politeknik Hasnur"],
    ".polije.ac.id": [
        "Politeknik Negeri Jember",
        "State Polytechnic Of Jember",
    ],
    ".polimdo.ac.id": ["Politeknik Negeri Manado", "Manado State Polytechnic"],
    ".polimedia.ac.id": [
        "Politeknik Negeri Media Jakarta",
        "Creative Media State Polytechnic",
    ],
    ".student.polindra.ac.id": ["Politeknik Negeri Indramayu"],
    ".polinema.ac.id": ["Politeknik Negeri Malang"],
    ".mhs.polines.ac.id": [
        "Politeknik Negeri Semarang",
        "State Polytechnic of Semarang",
    ],
    ".polines.ac.id": ["Politeknik Negeri Semarang"],
    ".polinpdg.ac.id": ["Politeknik Negeri Padang"],
    ".politala.ac.id": ["Politeknik Negeri Tanah Laut"],
    ".politanipyk.ac.id": ["Politeknik Pertanian Negeri Payakumbuh"],
    ".politap.ac.id": [
        "Politeknik Negeri Ketapang",
        "Polytechnic state of Ketapang",
    ],
    ".politeknik-sampit.ac.id": ["Politeknik Sampit"],
    ".politeknikbosowa.ac.id": ["Politeknik Bosowa", "Bosowa Polytechnic"],
    ".poliupg.ac.id": [
        "Politeknik Negeri Ujung Pandang",
        "State Polytechnic of Ujung Pandang",
    ],
    ".polka.ac.id": ["politeknik krakatau", " krakatau polytechnic"],
    ".mhs.polman-bandung.ac.id": [
        "Politeknik Manufaktur Bandung",
        "Bandung Polytechnic for Manufacturing",
    ],
    ".polmed.ac.id": ["Politeknik Negeri Medan"],
    ".polnep.ac.id": ["Politeknik Negeri Pontianak"],
    ".polsky.ac.id": ["Politeknik Sekayu"],
    ".polsri.ac.id": ["Politeknik Negeri Sriwijaya"],
    ".student.polsub.ac.id": ["Politeknik Negeri Subang"],
    ".poltek-furnitur.ac.id": [
        "Politeknik Industri Furniture dan Pengolahan Kayu",
        "Polytechnic of Furniture and Wood Processing Industry",
    ],
    ".poltek-kampar.ac.id": ["Politeknik Kampar", "Kampar Polytechnic"],
    ".poltekbangsby.ac.id": ["POLTEKBANG SURABAYA"],
    ".poltekkesbandung.ac.id": ["Poltekkes Kemenkes Bandung"],
    ".poltekkesjkt2.ac.id": [
        "Politeknik kesehatan kementrian kesehatan jakarta 2"
    ],
    ".polteknuklir.ac.id": [
        "Politeknik Teknologi Nuklir Indonesia",
        "Polytechnic of Nuclear Technology Indonesia",
    ],
    ".poltekpos.ac.id": ["Politeknik Pos Indonesia"],
    ".poltekssn.ac.id": [
        "Politeknik Siber dan Sandi Negara",
        "National Cyber and Crypto Polytechnic",
    ],
    ".poltektedc.ac.id": [
        "Politeknik TEDC Bandung",
        "Polytechnic TEDC Bandung",
    ],
    ".poltektegal.ac.id": [
        "Politeknik Harapan Bersama",
        "Harapan Bersama Polytechnic",
    ],
    ".potensi-utama.ac.id": [
        "Universitas Potensi Utama",
        "Potensi Utama University",
    ],
    ".student.ppkia.ac.id": ["STMIK PPKIA Tarakanita Rahmawati"],
    ".ppm-manajemen.ac.id": ["PPM School of Management"],
    ".student.ppns.ac.id": [
        "Politeknik Perkapalan Negeri Surabaya",
        "Shipbuilding Institute of Polytechnic Surabaya",
    ],
    ".student.pradita.ac.id": ["Pradita University", "Pradita University"],
    ".prasetiyamulya.ac.id": ["Universitas Prasetiya Mulya"],
    ".president.ac.id": ["President University"],
    ".primakara.ac.id": ["Primakara University", "Primakara University"],
    ".prisma.ac.id": ["Universitas Prisma", "Prisma University"],
    ".puterabatam.ac.id": ["Universitas Putera Batam"],
    ".radenfatah.ac.id": ["Universitas Negeri Islam Radenfatah"],
    ".radenintan.ac.id": ["University Raden Intan Lampung"],
    ".sari-mutiara.ac.id": [
        "Universitas Sari Mutiara Indonesia",
        "Sari Mutiara University of Indonesia",
    ],
    ".sbm-itb.ac.id": [
        "School of Business and Management - Institut Teknologi Bandung"
    ],
    ".setiabudi.ac.id": ["Universitas Setia Budi", "Setia Budi University"],
    ".sgu.ac.id": ["Swiss German University"],
    ".sibermu.ac.id": [
        "Universitas Siber Muhammadiyah",
        "Muhammadiyah Cyber University",
    ],
    ".sinus.ac.id": [
        "STMIK Sinar Nusantara Surakarta",
        "STMIK Sinar Nusantara Surakarta",
    ],
    ".staindirundeng.ac.id": [
        "Islamic State College Teungku Dirundeng Meulaboh",
        "Sekolah Tinggi Agama Islam Teungku Dirundeng Meulaboh",
    ],
    ".stan.ac.id": ["Sekolah Tinggi Akuntansi Negara (STAN)"],
    ".learning.stiebankbpdjateng.ac.id": [
        "Sekolah Tinggi Ilmu Ekonomi Bank BPD Jateng"
    ],
    ".stiegici.ac.id": ["STIE GICI Business School"],
    ".stiemj.ac.id": ["STIE Muhammadiyah Jakarta"],
    ".stiesia.ac.id": ["Sekolah Tinggi Ilmu Ekonomi Indonesia"],
    ".stiki-indonesia.ac.id": ["STMIK STIKOM Indonesia"],
    ".stiki.ac.id": ["Sekolah Tinggi Informatika dan Komputer Indonesia"],
    ".stikom-bali.ac.id": ["Institut Teknologi Dan Bisnis STIKOM Bali"],
    ".student.stikomyos.ac.id": ["Sekolah Tinggi Ilmu Komputer Yos Sudarso"],
    ".stikosa-aws.ac.id": [
        "Sekolah Tinggi Ilmu Komunikasi Almamater Wartawan Surabaya",
        "STIKOSA AWS",
    ],
    ".stimata.ac.id": ["STMIK PPKIA Pradnya Paramita"],
    ".stimednp.ac.id": ["STIMED Nusa Palapa"],
    ".stis.ac.id": [
        "Politeknik Statistika STIS",
        "STIS Polytechnic of Statistics",
    ],
    ".stit-buntetpesantren.ac.id": [
        "Sekolah Tinggi Ilmu Tarbiyah Buntet Pesantren"
    ],
    ".stiteknas.ac.id": ["Sekolah Tinggi Teknologi Nasional Jambi"],
    ".stitmadani.ac.id": [
        "Sekolah Tinggi Ilmu Tarbiyah Madani (STITMA) Yogyakarta"
    ],
    ".stkip-pgri-sumbar.ac.id": ["STKIP PGRI Sumatera Barat"],
    ".stkipahsingaraja.ac.id": ["STKIP Agama Hindu Singaraja"],
    ".mhs.stkipbjm.ac.id": [
        "UNIVERSITAS PGRI KALIMANTAN",
        "UNIVERSITY PGRI KALIMANTAN",
    ],
    ".stkipydb.ac.id": ["STKIP YDB Lubuk Alung"],
    ".stmik-amikbandung.ac.id": [
        "Sekolah Tinggi Manajemen dan Ilmu Komputer AMIKBANDUNG"
    ],
    ".stmik-indonesia-banjarmasin.ac.id": ["STMIK Indonesia Banjarmasin"],
    ".stmik-mi.ac.id": ["STMIK Mardira Indonesia"],
    ".mhs.stmik-sumedang.ac.id": ["STMIK Sumedang"],
    ".stmik-tasikmalaya.ac.id": [
        "Sekolah Tinggi Manajemen Informatika dan Komputer Tasikmalaya"
    ],
    ".stmik-time.ac.id": ["STMIK Time", "STMIK Time"],
    ".stmikbumigora.ac.id": [
        "STMIK Bumigora",
        "STMIK Bumigora University",
        "STMIK Bumigora Mataram",
    ],
    ".stmikibbi.ac.id": ["Universitas IBBI", "IBBI University"],
    ".stmikindonesia.ac.id": ["STMIK Indonesia Padang"],
    ".stmikjabar.ac.id": ["STMIK Jabar"],
    ".stmikku.ac.id": ["STMIK Kuwera", "School of Tecnopreneur Nusantara"],
    ".stmikpontianak.ac.id": ["STMIK Pontianak"],
    ".stmkg.ac.id": [
        "STMKG Sekolah Tinggi Meteorologi Klimatologi dan Geofisika"
    ],
    ".stp-bandung.ac.id": ["Sekolah Tinggi Pariwisata Bandung"],
    ".stpi-pajak.ac.id": ["Sekolah Tinggi Perpajakan Indonesia"],
    ".stptrisakti.ac.id": ["Trisakti Institute of Tourism "],
    ".sttbandung.ac.id": [
        "Sekolah Tinggi Teknologi Bandung",
        "Sekolah Tinggi Teknologi Bandung",
    ],
    ".sttcipasung.ac.id": ["Sekolah Tinggi Teknologi Cipasung"],
    ".sttdiakonos.ac.id": ["STT Diakonos Banyumas"],
    ".sttdumai.ac.id": ["Sekolah Tinggi Teknologi Dumai"],
    ".sttgarut.ac.id": [
        "Sekolah Tinggi Teknologi Garut",
        "Garut High School of Technology",
    ],
    ".sttpln.ac.id": ["Institut Teknologi PLN"],
    ".surya.ac.id": ["Universitas Surya"],
    ".student.tau.ac.id": ["student.tau.ac.id", "Tanri Abeng University"],
    ".tazkia.ac.id": [
        "Institut Agama Islam Tazkia",
        "Tazkia Islamic University College",
    ],
    ".teknokrat.ac.id": ["Universitas Teknokrat Indonesia"],
    ".telkomuniversity.ac.id": ["Institut Teknologi Telkom"],
    ".triatmamulya.ac.id": [
        "Universitas Triatma Mulya",
        "Triatma Mulya University",
    ],
    ".trigunadharma.ac.id": ["STMIK TRIGUNA DHARMA MEDAN"],
    ".trilogi.ac.id": ["Universitas Trilogi"],
    ".trisakti.ac.id": ["Universitas Trisakti"],
    ".trisaktimultimedia.ac.id": [
        "Trisakti School of Multimedia",
        "Trisakti School of Multimedia",
    ],
    ".student.trunojoyo.ac.id": [
        "Universitas Trunojoyo Madura",
        "Trunojoyo Madura University",
    ],
    ".tsu.ac.id": ["Tiga Serangkai University", "Tiga Serangkai University"],
    ".uad.ac.id": ["Universitas Ahmad Dahlan"],
    ".if.uai.ac.id": [
        "Universitas Al-Azhar Indonesia",
        "Al-Azhar University of Indonesia",
    ],
    ".student.uai.ac.id": [
        "Universitas Al-Azhar Indonesia",
        "Al-Azhar University of Indonesia",
    ],
    ".uajy.ac.id": ["Universitas Atma Jaya Yogyakarta"],
    ".uas.ac.id": [
        "Universitas Al-Falah As-Sunniyah",
        "Al-Falah As-Sunniyah University",
    ],
    ".ubaya.ac.id": ["Universitas Surabaya"],
    ".ubhara.ac.id": ["Universitas Bhayangkara Surabaya"],
    ".ubharajaya.ac.id": ["Universitas Bhayangkara Jakarta Raya"],
    ".ubl.ac.id": ["Universitas Bandar Lampung", "Bandar Lampung University"],
    ".ubm.ac.id": ["Universitas Bunda Mulia"],
    ".ubpkarawang.ac.id": ["Universitas Buana Perjuangan"],
    ".ubs.ac.id": ["Universitas Bani Saleh", "Bani Saleh University"],
    ".mail.uby.ac.id": ["Universitas Boyolali"],
    ".uc.ac.id": ["Universitas Ciputra"],
    ".udb.ac.id": ["Universitas Duta Bangsa"],
    ".uhamka.ac.id": [
        "Universitas Muhammadiyah Prof. Dr. Hamka",
        "Hamka University",
    ],
    ".uhb.ac.id": ["Universitas Harapan Bangsa", "Harapan Bangsa University"],
    ".uho.ac.id": ["Universitas Haluoleo"],
    ".ui.ac.id": ["Universitas Indonesia", "University of Indonesia"],
    ".uici.ac.id": ["Universitas Insan Cita Indonesia"],
    ".uid.ac.id": ["Universitas Islam Jakarta"],
    ".students.uigm.ac.id": [
        "Universitas Indo Global Mandiri",
        "Indo Global Mandiri University",
    ],
    ".uii.ac.id": ["Universitas Islam Indonesia"],
    ".uim-makassar.ac.id": ["Universitas Islam Makassar"],
    ".uim.ac.id": ["Universitas Islam Madura", "Islamic University of Madura"],
    ".uin-malang.ac.id": [
        "Universitas Islam Negeri Maulana Malik Ibrahim Malang"
    ],
    ".uin-suska.ac.id": ["Universitas Islam Negeri Sultan Syarif Kasim Riau"],
    ".uinjkt.ac.id": ["Universitas Islam Negeri Syarif Hidayatullah Jakarta"],
    ".uinmataram.ac.id": ["UIN Mataram"],
    ".student.uinsby.ac.id": [
        "Universitas Islam Negeri Sunan Ampel",
        "State Islamic University Sunan Ampel",
    ],
    ".uinsby.ac.id": ["UIN Sunan Ampel Surabaya"],
    ".uinsgd.ac.id": ["UIN Sunan Gunung Jati Bandung"],
    ".uinsu.ac.id": [
        "Univeristas Islam Negeri Sumatera Utara",
        "North Sumatra State Islamic University",
    ],
    ".uir.ac.id": ["Universitas Islam Riau"],
    ".uis.ac.id": ["Universitas Ibnu Sina"],
    ".student.uisi.ac.id": ["Universitas Internasional Semen Indonesia"],
    ".uisi.ac.id": ["Universitas Internasional Semen Indonesia"],
    ".uisu.ac.id": ["Universitas Islam Sumatera Utara"],
    ".ukdc.ac.id": ["Universitas Katolik Darma Cendika"],
    ".ukdw.ac.id": ["Universitas Kristen Duta Wacana"],
    ".uki.ac.id": ["Universitas Kristen Indonesia"],
    ".ukim.ac.id": [
        "Universitas Kristen Indonesia Maluku",
        "Indonesian Christian University in the Moluccas",
    ],
    ".ukrida.ac.id": ["Universitas Kristen Krida Wacana"],
    ".ukrim.ac.id": ["Universitas Kristen Immanuel"],
    ".ukrimuniversity.ac.id": ["Universitas Kristen Immanuel"],
    ".ukwms.ac.id": ["Universitas Katolik Widya Manadala"],
    ".ulbi.ac.id": ["Universitas Logistik dan Bisnis Internasional"],
    ".ulm.ac.id": [
        "Universitas Lambung Mangkurat",
        "Lambung Mangkurat University",
    ],
    ".ft.um-surabaya.ac.id": ["Universitas Muhammadiyah Surabaya"],
    ".um.ac.id": ["Universitas Negeri Malang"],
    ".staff.uma.ac.id": ["Universitas Medan Area", "University of Medan Area"],
    ".umaha.ac.id": ["Universitas Maarif Hasyim Latif"],
    ".umbanten.ac.id": ["Universitas Muhammadiyah Banten"],
    ".umc.ac.id": [
        "Universitas Muhammadiyah Cirebon",
        "Muhammadiyah University of Cirebon",
    ],
    ".umg.ac.id": ["Universitas Muhammadiyah Gresik"],
    ".umi.ac.id": ["Universitas Muslim Indonesia"],
    ".umj.ac.id": ["Universitas Muhammadiyah Jakarta"],
    ".umk.ac.id": ["Universitas Muria Kudus"],
    ".umku.ac.id": [
        "Universitas Muhammadiyah Kudus",
        "Muhamadiyah Kudus University",
    ],
    ".umkudus.ac.id": [
        "Universitas Muhammadiyah Kudus",
        "Muhammadiyah Kudus University",
    ],
    ".umm.ac.id": ["Universitas Muhammadiyah Malang"],
    ".ummgl.ac.id": ["Universitas Muhammadiyah Magelang"],
    ".ummi.ac.id": ["Universitas Muhammadiyah Sukabumi"],
    ".umn.ac.id": ["Universitas Multimedia Nusantara"],
    ".ump.ac.id": ["Universitas Muhammadiyah Purwokerto"],
    ".umpp.ac.id": [
        "Universitas Muhammadiyah Pekajangan Pekalongan",
        "Muhammadiyah University of Pekajangan Pekalongan",
    ],
    ".student.umrah.ac.id": ["UNIVERSITAS MARITIM RAJA ALI HAJI"],
    ".student.umri.ac.id": [
        "Universitas Muhammdiyah Riau",
        "Riau Muhammadiyah University",
    ],
    ".umri.ac.id": [
        "Universitas Muhammadiyah Riau",
        "Muhammadiyah University of Riau",
    ],
    ".ums.ac.id": ["Universitas Muhammadiyah Surakarta"],
    ".umsu.ac.id": ["Universitas Muhammadiyah Sumatra Utara"],
    ".umtas.ac.id": [
        "Universitas Muhammadiyah Tasikmalaya",
        "Muhammadiyah University of Tasikmalaya",
    ],
    ".umy.ac.id": ["Universitas Muhammadiyah Yogyakarta"],
    ".unair.ac.id": ["Universitas Airlangga"],
    ".unama.ac.id": [
        "Universitas Dinamika Bangsa",
        "Dinamika Bangsa University",
    ],
    ".unand.ac.id": ["Universitas Andalas"],
    ".unas.ac.id": ["Universitas Nasional Jakarta"],
    ".unbaja.ac.id": ["Universitas Banten Jaya"],
    ".undana.ac.id": ["Universitas Nusa Cendana"],
    ".undiknas.ac.id": ["undiknas university", "undiknas university"],
    ".undiksha.ac.id": [
        "Universitas Pendidikan Ganesha",
        "Ganesha University of Education",
    ],
    ".undip.ac.id": ["Universitas Diponegoro"],
    ".undipa.ac.id": ["Universitas Dipa Makassar", "Dipa Makassar University"],
    ".undira.ac.id": [
        "Universitas Dian Nusantara",
        "Dian Nusantara University",
    ],
    ".unej.ac.id": ["Universitas Jember"],
    ".unesa.ac.id": ["Universitas Negeri Surabaya"],
    ".ung.ac.id": ["Universitas Negeri Gorontalo"],
    ".unhamzah.ac.id": ["Universitas Amir Hamzah"],
    ".unhas.ac.id": ["Universitas Hasanuddin"],
    ".unib.ac.id": ["Universitas Bengkulu"],
    ".unibamadura.ac.id": ["Universitas Bahauddin Mudhary Madura"],
    ".mhs.unibi.ac.id": [
        "Universitas Informatika dan Bisnis Indonesia",
        "Indonesian University of Informatics and Business",
    ],
    ".student.unibi.ac.id": [
        "Universitas Informatika Dan Bisnis Indonesia (UNIBI)"
    ],
    ".unidha.ac.id": ["Universitas Dharma Andalas"],
    ".uniga.ac.id": ["Universitas Garut", "Garut University"],
    ".unigamalang.ac.id": ["Universitas Gajayana Malang"],
    ".unigoro.ac.id": ["Universitas Bojonegoro"],
    ".unik-kediri.ac.id": ["Universitas Kediri"],
    ".unika.ac.id": ["Universitas Katolik Soegijapranoto"],
    ".unikadelasalle.ac.id": ["Universitas Katolik De La Salle Manado"],
    ".unikal.ac.id": ["Universitas Pekalongan"],
    ".mhs.unikama.ac.id": ["universitas PGRI Kanjuruhan Malang"],
    ".unikom.ac.id": ["Universitas Komputer Indonesia"],
    ".uniku.ac.id": ["Universitas Kuningan", "Kuningan University"],
    ".unila.ac.id": ["Universitas Lampung"],
    ".unilak.ac.id": ["Universitas Lancang Kuning"],
    ".unima.ac.id": ["Universitas Negeri Manado"],
    ".mhs.unimal.ac.id": [
        "Universitas Malikussaleh",
        "Universitas Malikussaleh",
    ],
    ".unimed.ac.id": ["Universitas Negeri Medan"],
    ".unimerz.ac.id": ["Universitas Megarezky", "Megarezky University"],
    ".unimma.ac.id": ["Universitas Muhammadiyah Magelang"],
    ".unimus.ac.id": ["Universitas Muhammadiyah Semarang"],
    ".unindra.ac.id": ["Universitas Indraprasta", "Indraprasta University"],
    ".uninus.ac.id": ["Universitas Islam Nusantara"],
    ".unipasby.ac.id": ["Universitas PGRI Adi Buana"],
    ".unipdu.ac.id": ["Universitas Pesantren Darul Ulum Jombang"],
    ".unira.ac.id": ["Universitas Madura", "Madura Univercity"],
    ".unirow.ac.id": [
        "Universitas PGRI Ronggolawe",
        "UNIROW Tuban",
        "Ronggolawe University",
    ],
    ".unis.ac.id": ["Universitas Islam Syekh Yusuf Tangerang"],
    ".unisan.ac.id": ["Universitas Ichsan Gorontalo"],
    ".unisayogya.ac.id": ["Universitas 'Aisyiyah Yogyakarta"],
    ".unisba.ac.id": ["Universitas Islam Bandung"],
    ".unisbank.ac.id": ["Universitas Stikubank Semarang"],
    ".uniska-bjm.ac.id": [
        "Universitas Islam Kalimantan Muhammad Arsyad Al Banjari Banjarmasin",
        "Islamic University Of Kalimantan Muhammad Arsyad Al Banjari Banjarmasin",
    ],
    ".unisma.ac.id": ["Universitas Islam Malang"],
    ".unismuh.ac.id": ["Universitas Muhammadiyah Makassar"],
    ".unisnu.ac.id": ["Universitas Islam Nahdlatul Ulama Jepara"],
    ".unisri.ac.id": ["Universitas Slamet Riyadi Surakarta"],
    ".unissula.ac.id": ["Universitas Islam Sultan Agung"],
    ".unitama.ac.id": ["Universitas Teknologi Akba Makassar"],
    ".unitomo.ac.id": ["Unitomo Surabaya"],
    ".universitasbumigora.ac.id": ["Universitas Bumigora"],
    ".universitasmulia.ac.id": ["Universitas Mulia", "Mulia University"],
    ".universitaspahlawan.ac.id": ["Universitas Pahlawan Tuanku Tambusai"],
    ".universitaspertamina.ac.id": ["Universitas Pertamina"],
    ".univpancasila.ac.id": ["Universitas Pancasila"],
    ".univpgri-palembang.ac.id": ["Universitas PGRI Palembang"],
    ".unj.ac.id": ["Universitas Negeri Jakarta"],
    ".unja.ac.id": ["Universitas Jambi"],
    ".unjani.ac.id": ["Universitas Jenderal Achmad Yani"],
    ".ftti.unjaya.ac.id": ["Universitas Jenderal Achmad Yani Yogyakarta"],
    ".unkhair.ac.id": ["Universitas Khairun"],
    ".student.unklab.ac.id": ["Universitas Klabat", "Klabat University"],
    ".unkris.ac.id": ["Universitas Krisnadwipayana"],
    ".unla.ac.id": ["Universitas Langlangbuana", "Langlangbuana University"],
    ".unm.ac.id": ["Universitas Negeri Makassar"],
    ".unmer-madiun.ac.id": ["Universitas Merdeka Madiun"],
    ".unmermadiun.ac.id": ["Universitas Merdeka Madiun"],
    ".unmuhjember.ac.id": ["Universitas Muhammadiyah Jember"],
    ".unmuhpnk.ac.id": ["Universitas Muhammadiyah Pontianak"],
    ".unmul.ac.id": ["Universitas Mulawarman"],
    ".unmus.ac.id": ["Universitas Musamus Merauke"],
    ".unnes.ac.id": ["Universitas Negeri Semarang"],
    ".unp.ac.id": ["Universitas Negeri Padang"],
    ".unpacti.ac.id": ["Universitas Pancasakti", "Pancasakti University"],
    ".unpad.ac.id": ["Universitas Padjadjaran"],
    ".unpak.ac.id": ["Universitas Pakuan"],
    ".unpam.ac.id": ["Universitas Pamulang"],
    ".unpar.ac.id": ["Universitas Katolik Parahyangan"],
    ".unpas.ac.id": ["Universitas Pasundan"],
    ".unpatti.ac.id": ["Universitas Pattimura"],
    ".unper.ac.id": ["Universitas Perjuangan Tasikmalaya"],
    ".unr.ac.id": ["Universitas Ngurah Rai"],
    ".unram.ac.id": ["Universitas Mataram"],
    ".lecturer.unri.ac.id": ["Universitas Riau", "Riau University"],
    ".student.unri.ac.id": ["Universitas Negri Riau", "University of Riau"],
    ".uns.ac.id": ["Universitas Sebelas Maret"],
    ".unsada.ac.id": ["Universitas Darma Persada"],
    ".unsap.ac.id": [
        "universitas sebelas april sumedang",
        "university sebelas april sumedang",
    ],
    ".unsera.ac.id": ["universitas serang raya", "serang raya university"],
    ".unsia.ac.id": ["*.unsia.ac.id", "universitas siber asia"],
    ".unsika.ac.id": ["Universitas Singaperbangsa Karawang"],
    ".unsil.ac.id": ["Universitas Siliwangi"],
    ".mhs.unsiq.ac.id": ["Universitas Sains Al-quran"],
    ".unsiq.ac.id": [
        "Universitas Sains Al-Qur'an",
        "University of Sains Al-Qur'an",
        "UNSIQ",
    ],
    ".unsoed.ac.id": ["Universitas Jenderal Soedirman"],
    ".unsrat.ac.id": ["Universitas Sam Ratulangi"],
    ".unsri.ac.id": ["Universitas Sriwijaya"],
    ".unswagati.ac.id": ["Universitas Swadaya Gunung Djati"],
    ".unsyiah.ac.id": ["Universitas Syiah Kuala"],
    ".untad.ac.id": ["Universitas Tadulako"],
    ".untag-banyuwangi.ac.id": ["Universitas 17 Agustus 1945 Banyuwangi"],
    ".untag-sby.ac.id": ["Universitas 17 Agustus 1945 Surabaya"],
    ".untag-smd.ac.id": ["Universitas 17 Agustus 1945 Samarinda"],
    ".untagcirebon.ac.id": ["Universitas 17 Agustus 1945 Cirebon"],
    ".untagsmg.ac.id": ["Universitas 17 Agustus 1945 Semarang"],
    ".untan.ac.id": ["Universitas Tanjungpura"],
    ".untar.ac.id": ["Universitas Tarumanagara"],
    ".students.untidar.ac.id": ["Universitas Tidar", "Tidar University"],
    ".untirta.ac.id": ["Universitas Sultan Ageng Tirtayasa"],
    ".unu-jogja.ac.id": [
        "Universitas Nahdlatul Ulama Yogyakarta",
        "Yogyakarta Nahdlatul Ulama University",
    ],
    ".unud.ac.id": ["Universitas Udayana"],
    ".unugiri.ac.id": [
        "Universitas Nahdlatul Ulama Sunan Giri",
        "Nahdlatul Ulama Sunan Giri University",
    ],
    ".student.unusa.ac.id": [
        "Universitas Nahdlatul Ulama Surabaya",
        "Nahdlatul Ulama Surabaya University",
    ],
    ".unwaha.ac.id": [
        "Universitas KH. A. Wahab Hasbullah",
        "KH. A. Wahab Hasbullah University",
    ],
    ".unwahas.ac.id": ["Universitas Wahid Hasyim"],
    ".unwiku.ac.id": ["Universitas Wijaya Kusuma Purwokerto"],
    ".up45.ac.id": ["Universitas Proklamasi 45"],
    ".upbatam.ac.id": ["Universitas Putera Batam"],
    ".upg.ac.id": ["Primagraha University"],
    ".upgris.ac.id": ["Universitas PGRI Semarang"],
    ".upgrisba.ac.id": [
        "Universitas PGRI Sumatera Barat",
        "Universitas PGRI Sumatera Barat",
    ],
    ".upi-yai.ac.id": ["Universitas Persada Indonesia Y.A.I"],
    ".upiyptk.ac.id": ["Universitas Putra Indonesia"],
    ".student.upj.ac.id": [
        "Universitas Pembangunan Jaya",
        "Pembangunan Jaya University",
    ],
    ".upj.ac.id": ["Universitas Pembangunan Jaya"],
    ".upnjatim.ac.id": ["Universitas Pembangunan Nasional Veteran East Java"],
    ".upnvj.ac.id": ["Universitas Pembangunan Nasional Veteran Jakarta"],
    ".upnyk.ac.id": ["Universitas Pembangunan Nasional Veteran Yogyakarta"],
    ".upr.ac.id": ["Universitas Palangka Raya"],
    ".upri.ac.id": [
        "Universitas Pejuang Republik Indonesia",
        "Pejuang University of Republic of Indonesia",
    ],
    ".upstegal.ac.id": ["Universitas Pancasakti Tegal"],
    ".usahid.ac.id": ["universitas sahid jakarta", "sahid university jakarta"],
    ".usi.ac.id": ["Universitas Simalungun"],
    ".mhs.usk.ac.id": ["universitas syiah kuala"],
    ".usm.ac.id": ["Universitas Semarang"],
    ".ustjogja.ac.id": ["Universitas Sarjanawiyata Tamansiswa"],
    ".usu.ac.id": ["Universitas Sumatera Utara"],
    ".ut.ac.id": ["Universitas Terbuka"],
    ".utb-univ.ac.id": [
        "Universitas Teknologi Bandung",
        "Bandung University of Technology",
    ],
    ".mti.utdi.ac.id": ["Universitas Teknologi Digital Indonesia"],
    ".students.utdi.ac.id": ["Universitas Teknologi Digital Indonesia"],
    ".utm.ac.id": ["Universitas Tidar Magelang"],
    ".utmj.ac.id": [
        "Universitas Teknologi Muhammadiyah Jakarta",
        "Muhammadiyah University of Technology Jakarta",
    ],
    ".utp.ac.id": ["Universitas Tunas Pembangunan"],
    ".utsmakassar.ac.id": [
        "Universitas Teknologi Sulawesi",
        "University of Technology Sulawesi",
    ],
    ".uty.ac.id": ["Universitas Teknologi Yogyakarta"],
    ".uwks.ac.id": ["Universitas Wijaya Kusuma Surabaya"],
    ".uwp.ac.id": ["Universitas Wijaya Putra", "Wijaya Putra University"],
    ".student.walisongo.ac.id": ["UIN Walisongo Semarang"],
    ".walisongo.ac.id": ["UIN Walisongo Semarang"],
    ".wastukancana.ac.id": ["Sekolah Tinggi Teknologi Wastukancana"],
    ".wicida.ac.id": ["STMIK Widya Cipta Dharma Samarinda"],
    ".widyadharma.ac.id": [
        "Universitas Widya Dharma Pontianak",
        "Widya Dharma Pontianak University",
    ],
    ".widyagama.ac.id": ["Universitas Widya Gama Malang"],
    ".widyakarya.ac.id": ["Universitas Katolik Widya Karya"],
    ".simak.widyamataram.ac.id": ["Universitas Widya Mataram"],
    ".widyatama.ac.id": ["Universitas Widyatama"],
    ".wima.ac.id": ["Universitas Katolik Widya Manadala"],
    ".wisnuwardhana.ac.id": ["Universitas Wisnuwardhana"],
    ".yai.ac.id": ["Universitas Persada Indonesia Y.A.I"],
    ".yarsi.ac.id": ["Universitas Yarsi"],
    ".alqudwah.id": ["alqudwah.id", "Al-Qudwah Boarding School"],
    ".belajar.id": [
        "belajar.id",
        "Official Webmail from Indonesian Ministry of Education and Culture (for students and teachers)",
    ],
    ".kemenag.go.id": ["MAN 4 Jakarta Selatan"],
    ".alghifaribatanghari.or.id": [
        "Muhammadiyah Boarding School Abudzar Al-Ghifari"
    ],
    ".bisedu.or.id": ["Bandung Independent School"],
    ".bpkpenaburjakarta.or.id": [
        "SMAK BPK Penabur Jakarta",
        "SMAK BPK Penabur Jakarta",
    ],
    ".jisedu.or.id": ["Jakarta Intercultural School"],
    ".perbanas.id": ["perbanas.id", "Perbanas Institute"],
    ".adisanggoro.sch.id": [
        "SMK Adi Sanggoro",
        "Adi Sanggoro Vocational High School",
    ],
    ".ahsbali.sch.id": ["Amed Honeycomb School"],
    ".al-mizan.sch.id": [
        "Pondok Pesantren Modern Al-Mizan",
        "Al-Mizan Islamic Boarding School",
    ],
    ".bintangmulia.sch.id": ["SMA Bintang Mulia"],
    ".citraberkat.sch.id": ["Sekolah Citra Berkat"],
    ".citrakasih.sch.id": ["Sekolah Citra Kasih"],
    ".darmabangsa.sch.id": ["Sekolah Darma Bangsa", "Darma Bangsa School"],
    ".darul-hikmah.sch.id": ["MTs. Darul Hikmah Menganti"],
    ".diandidaktika.sch.id": ["Dian Didaktika"],
    ".dnm.sch.id": ["SDS IT Nur Muria"],
    ".ibnutaimiyah.sch.id": [
        "Pondok Pesantren Ibnu Taimiyah",
        "Pondok Pesantren Ibnu Taimiyah",
    ],
    ".karangturi.sch.id": ["Sekolah Karangturi"],
    ".latansa.sch.id": ["SMA La Tansa", "La Tansa Islamic Boarding School"],
    ".man10jakartabarat.sch.id": ["MAN 10 Jakarta Barat"],
    ".man2bulukumba.sch.id": [
        "MAN 2 Bulukumba",
        "High Islamic School 2 Bulukumba",
    ],
    ".mankotategal.sch.id": ["MAN Kota Tegal", "Islamic High School Tegal"],
    ".nurulfikri.sch.id": [
        "Sekolah Islam Terpadu Nurul Fikri",
        "Nurul Fikri Integrated Islamic School",
    ],
    ".sekolah.pahoa.sch.id": ["Sekolah Terpadu Pahoa"],
    ".pancabudi.sch.id": ["SMA PANCA BUDI", "Panca Budi High School"],
    ".smpsipbpk.penabur.sch.id": [
        "SMPK BPK Penabur Singgasana Pradana Bandung"
    ],
    ".student.pppkpetra.sch.id": ["Sekolah Kristen Petra 4"],
    ".praditadirgantara.sch.id": [
        "SMA Pradita Dirgantara",
        "Pradita Dirgantara High School",
    ],
    ".regentsschoolbali.sch.id": ["Regents Secondary School Bali"],
    ".santa-laurensia.sch.id": ["Santa Laurensia"],
    ".satubangsa.sch.id": ["Satubangsa School", "Satubangsa School"],
    ".sdi-aliks.sch.id": ["SD Islam Al-Ikhlas", "Al-Ikhlas elementary school"],
    ".sekolahathalia.sch.id": ["Sekolah Athalia", "Athalia School"],
    ".sekolahciputra.sch.id": ["Sekolah Ciputra"],
    ".ski.sch.id": ["SMK Kristen Immanuel Pontianak"],
    ".skkkslp.sch.id": ["Sekolah Kristen Kalam Kudus Selatpanjang"],
    ".sma1sidareja.sch.id": ["SMA NEGERI 1 Sidareja"],
    ".smaasbsolo.sch.id": ["SMA Al Azhar Syifa Budi Solo"],
    ".smafg.sch.id": ["SMA Future Gate Bekasi", "Future Gate High School"],
    ".smaitmiftahulkhoir.sch.id": ["Miftahul Khoir"],
    ".smalokon.sch.id": ["SMA LOKON ST.NIKOLAUS TOMOHON"],
    ".student.smamuhammadiyah1jkt.sch.id": ["SMA Muhammadiyah 1 Jakarta"],
    ".smamuhammadiyah1jkt.sch.id": ["SMA Muhammadiyah 1 Jakarta"],
    ".sman-modalbangsa.sch.id": ["SMA Negeri Modal Bangsa"],
    ".sman19bandung.sch.id": ["SMA NEGERI 19 BANDUNG"],
    ".sman1brebes.sch.id": ["Sekolah Menengah Atas Negeri 1 Brebes"],
    ".sman1cirebon.sch.id": ["SMA Negeri 1 Cirebon"],
    ".sman1julok.sch.id": ["SMAN 1 Julok"],
    ".sman1kendal.sch.id": ["SMA Negeri 1 Kendal", "High School 1 Kendal"],
    ".sman1kotamungkid.sch.id": ["SMA Negeri 1 Kota Mungkid"],
    ".sman1liwa.sch.id": ["SMAN 1 LIWA"],
    ".sman1salem.sch.id": ["SMA Negeri 1 Salem"],
    ".sman1samarinda.sch.id": ["SMA Negeri 1 Samarinda"],
    ".sman1serangbarujuara.sch.id": [
        "sman1serangbarujuara.sch.id",
        "SMA Negeri 1 Serang Baru",
    ],
    ".sman1sumedang.sch.id": ["SMA Negeri 1 Sumedang"],
    ".sman1tegal.sch.id": ["SMA Negeri 1 Tegal", "High School 1 Tegal"],
    ".sman1yogya.sch.id": [
        "SMA Negeri 1 Yogyakarta",
        "Yogyakarta 1 Public Senior High School",
    ],
    ".sman2-brebes.sch.id": [
        "SMA Negeri 2 Brebes",
        "Brebes State 2 Senior High School",
    ],
    ".sman24jakarta.sch.id": ["SMA Negeri 24 Jakarta"],
    ".sman2balige.sch.id": [
        "sman2balige.sch.id",
        "Yayasan Soposurung/SMA Negeri 2 Balige",
    ],
    ".sman2sukabumi.sch.id": ["Sekolah Menengah Atas Negeri 2 Sukabumi"],
    ".sman4tegal.sch.id": ["SMA Negeri 4 Tegal", "High School 4 Tegal"],
    ".sman5kotategal.sch.id": ["SMA Negeri 5 Tegal", "High School 5 Tegal"],
    ".smanjatinangor.sch.id": ["SMA Negeri Jatinangor"],
    ".smanmba.sch.id": [
        "SMAN Modal Bangsa Arun",
        "State Public School Modal Bangsa Arun",
    ],
    ".smansajulok.sch.id": [
        "Sekolah Menegah Atas 1 Julok",
        "High School 1 Julok",
    ],
    ".smantujuhkabtang.sch.id": ["SMA NEGERI 7 KABUPATEN TANGERANG"],
    ".smasantamaria1.sch.id": ["SMA Santa Maria 1 Bandung"],
    ".smatag45.sch.id": ["SMA 17 AGUSTUS 1945 SURABAYA"],
    ".smk2-yk.sch.id": ["SMK Negeri 2 Yogyakarta"],
    ".smkalbaisuny.sch.id": [
        "SMK Al-Baisuny",
        "Vocational High School Al-Baisuny",
    ],
    ".smkbinaessa.sch.id": ["SMK Bina Essa", "SMK Bina Essa"],
    ".smkbwutalaga.sch.id": ["SMKS Bina Wira Usaha Talaga", "SMKS BWU TALAGA"],
    ".smkcendana.sch.id": ["SMKS CENDANA ROKAN HILIR"],
    ".smkgama.sch.id": ["SMK GARUDA MAHADHIKA"],
    ".smkihsaniyahtegal.sch.id": [
        "SMK Ihsaniyah Tegal",
        "Vocational High School Ihsaniyah Tegal",
    ],
    ".smkitglobalmadani.sch.id": ["SMK IT GLOBAL MADANI"],
    ".smkmaliga.sch.id": [
        "SMK Maarif 5 Kotagajah",
        "Vocational High School Marif 5 Kotagajah",
    ],
    ".smkmtsm.sch.id": ["SMK MUHAMMADIYAH TASIKMALAYA"],
    ".smkmuhkarangmojo.sch.id": ["SMK Muhammadiyah Karangmojo"],
    ".smkmussi.sch.id": [
        "SMK Muhammadiyah Kesesi",
        "Vocational High School Muhammadiyah Kesesi",
    ],
    ".smkn1-cirebon.sch.id": ["SMK Negeri 1 Cirebon", "SMK Negeri 1 Cirebon"],
    ".smkn10jakarta.sch.id": [
        "SMKN 10 JAKARTA",
        "Vocational High School 10 Jakarta",
    ],
    ".smkn11malang.sch.id": ["SMKN 11 Kota Malang"],
    ".smkn1bontang.sch.id": ["SMK NEGERI 1 BONTANG"],
    ".smkn1cipeundeuy.sch.id": ["SMKN 1 Cipeundeuy"],
    ".smkn1dompu.sch.id": ["SMKN 1 DOMPU", "DOMPU VOCATION HIGH SCHOOL"],
    ".smkn1gombong.sch.id": [
        "SMK Negeri 1 Gombong",
        "Gombong Vocational State High School 1",
    ],
    ".smkn1kertajati.sch.id": [
        "SMKN 1 Kertajati",
        "Vocational High School 1 Kertajati",
    ],
    ".smkn1klk.sch.id": [
        "SMK Negeri 1 Klungkung",
        "Klungkung State Vocational School 1",
    ],
    ".smkn1pacitan.sch.id": [
        "SMK Negeri 1 Pacitan",
        "State Vocational High School 1 Pacitan",
    ],
    ".smkn1pml.sch.id": ["SMK Negeri 1 Pemalang"],
    ".smkn1subang.sch.id": ["SMK Negeri 1 Subang", "SMK Negeri 1 Subang"],
    ".smkn2banjarbaru.sch.id": ["SMK Negeri 2 Banjarbaru"],
    ".trust.smkn2malang.sch.id": ["SMK Negeri 2 Malang"],
    ".smkn2tabanan.sch.id": [
        "SMK Negeri 2 Tabanan",
        "Vocational Highschool 2 Tabanan",
    ],
    ".smkn4bdg.sch.id": ["SMKN 4 Bandung", "Vocational Highschool 4 Bandung"],
    ".smkn4bjm.sch.id": ["SMK Negeri 4 Banjarmasin"],
    ".smkn4bogor.sch.id": ["SMK Negeri 4 Bogor"],
    ".smkn6malang.sch.id": ["SMK Negeri 6 Malang", "SMK Negeri 6 Malang"],
    ".smkn6solo.sch.id": ["SMK Negeri 6 Surakarta"],
    ".smkn7-smr.sch.id": [
        "SMK Negeri 7 Samarinda",
        "Vocational High School 7 Samarinda",
    ],
    ".smknegeri1bagor.sch.id": ["SMK Negeri 1 Bagor"],
    ".smknegeri1garut.sch.id": [
        "SMKN Negeri 1 Garut",
        "State Vocational School 1 Garut",
    ],
    ".smkpasirian-lmj.sch.id": ["SMK Negeri Pasirian Lumajang"],
    ".smkpasundan2bdg.sch.id": [
        "SMK Pasundan 2 Bandung",
        "Pasundan 2 Vocational High School Bandung",
    ],
    ".smkpelitamadani.sch.id": ["SMK Pelita Madani Pringsewu"],
    ".smkpgringadirojo-pct.sch.id": [
        "SMK PGRI Ngadirojo",
        "SMK PGRI Ngadirojo",
    ],
    ".smkpgripekanbaru.sch.id": ["SMK PGRI Pekanbaru"],
    ".smkpusdikpal.sch.id": ["smk pusdikpal", "smk pusdikpal"],
    ".smkrus.sch.id": [
        "SMK Raden Umar Said Kudus",
        "E-Learning Vocational School Raden Umar Said Kudus",
        "https://smkrus.sch.id",
        "https://smkradenumarsaidkudus.sch.id",
        "Student email: smkradenumarsaidkudus.sch.id",
    ],
    ".smksatriakendari.sch.id": ["SMKS SATRIA KENDARI"],
    ".smktarpan1.sch.id": ["SMK Taruna Harapan 1 Cipatat"],
    ".smktarunatarik.sch.id": ["SMK Taruna Tarik"],
    ".smktelkom-mlg.sch.id": [
        "SMK Telkom Malang",
        "https://www.smktelkom-mlg.sch.id",
    ],
    ".smktelkommedan.sch.id": [
        "Sekolah Menengah Kejuruan Telkom Medan",
        "Telkom Medan Vocational High School",
    ],
    ".siswa.smktiannajiyah.sch.id": [
        "SMK TI ANNAJIYAH BU JOMBANG",
        "information technology vocational high school",
    ],
    ".smktiannajiyah.sch.id": [
        "SMK TI ANNAJIYAH BU JOMBANG",
        "information technology vocational high school",
    ],
    ".smkwikrama.sch.id": [
        "SMK Wikrama Bogor",
        "Wikrama Bogor Vocational School",
    ],
    ".smm.sch.id": ["Sekolah Murid Merdeka"],
    ".smpasbsolo.sch.id": ["SMP Al-Azhar Syifa Budi Surakarta"],
    ".smpblbekasi.sch.id": ["SMP BOEDI LUHUR BEKASI"],
    ".smpn1wungu.sch.id": ["SMP Negeri 1 Wungu"],
    ".sttdanaksholeh.sch.id": ["STTD Anak Sholeh"],
    ".sutomo-mdn.sch.id": ["YAYASAN PERGURUAN SUTOMO"],
    ".utschool.sch.id": ["United Tractors School", "United Tractors School"],
    ".ypnbrigjendkatamso.sch.id": [
        "yayasan pendidikan nasional brigjend katamso"
    ],
    ".ait.ie": ["Athlone Institute of Technology"],
    ".atu.ie": ["Atlantic Technological University"],
    ".ballinrobecs.ie": ["Ballinrobe Community School"],
    ".bfei.ie": ["blackrock further education institute"],
    ".carndonaghcs.ie": ["Carndonagh Community School"],
    ".cavaninstitute.ie": ["Cavan Institute"],
    ".cbcg.ie": ["Coláite Bhaile Chláir"],
    ".student.ccathlone.ie": ["Coláiste Chiaráin", "St Ciaran's College"],
    ".cct.ie": ["CCT College Dublin"],
    ".cdcfe.ie": ["Colaiste Dhulaigh College of Further Education"],
    ".whitehallcfe.cdetb.ie": [
        "Whitehall College of Further Education",
        "Whitehall College of Further Education",
    ],
    ".chanelcollege.ie": ["Chanel College"],
    ".cit.ie": ["Cork Institute of Technology"],
    ".clonkeencollege.ie": ["Clonkeen Collage"],
    ".cmetb.ie": ["Cavan Institute"],
    ".coccork.ie": ["College of Commerce", "Cork College of Commerce"],
    ".corketb.ie": ["Carrigtwohill Community College", ".group"],
    ".creaghcollege.ie": ["Creagh College"],
    ".dbs.ie": ["Dublin Business School"],
    ".dcu.ie": ["Dublin City University"],
    ".dfei.ie": ["Dun Laoghaire Further Education Institute"],
    ".dias.ie": ["Dublin Institute for Advanced Studies"],
    ".dit.ie": ["Dublin Institute of Technology"],
    ".dkit.ie": ["Dundalk Institute of Technology"],
    ".student.dorset-college.ie": ["Dorset College"],
    ".fingalcc.ie": ["Fingal Community College"],
    ".gcd.ie": ["Griffith College"],
    ".gmit.ie": ["Galway Mayo Institute of Technology"],
    ".gretb.ie": ["Galway & Roscommon Educational Training Board", "GRETB"],
    ".griffith.ie": ["Griffith College"],
    ".iadt.ie": ["Dún Laoghaire Institute of Art, Design and Technology"],
    ".itb.ie": ["Institute of Technology, Blanchardstown"],
    ".itcarlow.ie": ["Carlow Institute of Technology"],
    ".itsligo.ie": ["Institute of Technology, Sligo"],
    ".ittd.ie": ["Institue of Technology, Tallaght (legacy email accounts)"],
    ".ittdublin.ie": ["Institute of Technology, Tallaght"],
    ".ittralee.ie": ["Institue of Technology, Tralee"],
    ".kerrycollege.ie": ["Kerry College, Ireland"],
    ".learner.lcetb.ie": ["Limerick college of further education"],
    ".lit.ie": ["Limerick Institute of Technology"],
    ".lmetb.ie": [
        "Louth and Meath Education and Training Board",
        "https://www.lmetb.ie/",
        ".group",
    ],
    ".loetbstudent.ie": ["Portlaoise institute"],
    ".loretoletterkenny.ie": [
        "Loreto Secondary School",
        "Loreto Secondary girls school in Letterkenny, Co. Donegal",
    ],
    ".lsb.ie": ["LSB College"],
    ".lyit.ie": ["Letterkenny Institute of Technology"],
    ".may.ie": ["National University of Ireland, Maynooth"],
    ".mtu.ie": ["Munster Technological University"],
    ".mu.ie": ["Maynooth University"],
    ".mumail.ie": ["Maynooth University"],
    ".myccs.ie": ["Carrigaline Community School"],
    ".mycit.ie": ["Cork Institute of Technology"],
    ".mydbs.ie": ["Dublin Business School"],
    ".mydit.ie": ["Dublin Institute of Technology"],
    ".mytudublin.ie": ["TU Dublin - Blanchardstown Campus"],
    ".student.naascbs.ie": ["Méanscoil Iognáid Rís Nás na Riogh", "Naas CBS"],
    ".ncad.ie": ["National College of Art and Design"],
    ".ncirl.ie": ["National College of Ireland"],
    ".nui.ie": ["National University of Ireland"],
    ".nuigalway.ie": ["National University of Ireland, Galway"],
    ".nuim.ie": ["National Univerisity of Ireland, Maynooth"],
    ".palmerstowncs.ie": ["Palmerstown Community School"],
    ".pearsecollege.ie": ["Pearse College"],
    ".rathminescollege.ie": ["Rathmines College"],
    ".rcpi.ie": ["Royal College of Physicians of Ireland"],
    ".rcsi.ie": ["Royal College of Surgeons"],
    ".ricecollege.ie": ["Rice College Ennis"],
    ".sanctamaria.ie": ["Sanctamaria College Louisburgh"],
    ".setu.ie": ["South East technological university, Ireland"],
    ".students.st-andrews.ie": [
        "St. Andrew's College Dublin",
        "St. Andrew's College Dublin",
    ],
    ".stconleths.ie": ["St. Conleth's College"],
    ".stepasideetss.ie": ["Stepaside Educate Together Secondary School"],
    ".stfinianscc.ie": ["St Finian's Community College"],
    ".stjohnscollege.ie": ["St John's Central College, Cork, Ireland"],
    ".stlouishighschool.ie": ["St Louis High School"],
    ".stmc.ie": ["St. Michael's College", "www.stmc.ie"],
    ".stmunchinscollege.ie": ["St. Munchin's College"],
    ".tcd.ie": ["University of Dublin, Trinity College"],
    ".student.tcfe.ie": [
        "Coláiste Breisoideachais An Teampall Mór",
        "Templemore College of Further Education",
    ],
    ".tcfe.ie": [
        "Coláiste Breisoideachais An Teampall Mór",
        "Templemore College of Further Education",
    ],
    ".terenurecollege.ie": ["Terenure College"],
    ".tudublin.ie": ["Technological University Dublin"],
    ".tus.ie": ["Technological University of the Shannon"],
    ".tyndall.ie": ["Tyndall National Institute"],
    ".ucc.ie": ["University College Cork"],
    ".ucd.ie": ["University College Dublin"],
    ".ucdconnect.ie": ["University College Dublin"],
    ".ucg.ie": ["National University of Ireland, Galway"],
    ".ul.ie": ["University of Limerick"],
    ".universityofgalway.ie": ["University of Galway"],
    ".wicklowvec.ie": ["Bray Institute of Further Education"],
    ".wit.ie": ["Waterford Institute Of Technology"],
    ".afeka.ac.il": ["Afeka Tel Aviv Academic College of Engineering"],
    ".ariel.ac.il": ["Ariel University Center of Samaria"],
    ".bezalel.ac.il": ["Bezalel Academy of Art and Design"],
    ".bgu.ac.il": ["Ben-Gurion University of the Negev"],
    ".biu.ac.il": ["Bar-Ilan University"],
    ".braude.ac.il": ["ORT Braude College"],
    ".cs.colman.ac.il": [
        "College of Management",
        "College of Management Academic Studies",
        "המכללה למנהל",
        "המכללה למינהל",
        "המסלול האקדמי המכללה למנהל",
        "המסלול האקדמי המכללה למינהל",
    ],
    ".colman.ac.il": ["College of Management"],
    ".galilcol.ac.il": ["Galillee College"],
    ".haifa.ac.il": ["University of Haifa"],
    ".hit.ac.il": ["Holon Institute of Technology"],
    ".huji.ac.il": ["Hebrew University of Jerusalem"],
    ".idc.ac.il": ["The Interdisciplinary Center Herzliya"],
    ".post.jce.ac.il": ["Azrieli College of Engineering Jerusalem"],
    ".jce.ac.il": ["Azrieli College of Engineering Jerusalem"],
    ".jct.ac.il": ["Jerusalem College of Technology-Machon Lev"],
    ".mta.ac.il": [
        "The Academic College of Tel Aviv-Yaffo",
        "The Academic College of Tel Aviv-Yaffo (MTA)",
        "המכללה האקדמית תל אביב-יפו",
    ],
    ".ono.ac.il": ["Ono Academic College"],
    ".openu.ac.il": ["Open University of Israel"],
    ".sce.ac.il": ["Sami Shamoon College of Engineering"],
    ".shenkar.ac.il": ["Shenkar School of Engineering &amp; Design"],
    ".mail.tau.ac.il": ["Tel Aviv University"],
    ".tau.ac.il": ["Tel Aviv University"],
    ".campus.technion.ac.il": [
        "Russell Berrie Nanotechnology Institute",
        "Technion - Israel Institute of Technology",
        "Official Website - https://www.technion.ac.il/",
    ],
    ".technion.ac.il": [
        "Russell Berrie Nanotechnology Institute",
        "Technion - Israel Institute of Technology",
    ],
    ".weizmann.ac.il": ["Weizmann Institute of Science"],
    ".wgalil.ac.il": ["Western Galilee College"],
    ".yvc.ac.il": ["Emeq Yizrael College"],
    ".democrati.co.il": ["Nadav Democratic School"],
    ".gymnasia.co.il": ["הגימנסיה העברית הרצליה", "Hebrew Hertzila Gymnasia"],
    ".kdror.co.il": ["קרית חינוך דרור", "Kiryat Education Dror"],
    ".misgavhs.co.il": ["אסיף משגב", "asif misgav"],
    ".nahalal.co.il": ["chw nahalal"],
    ".nhs.co.il": ["אמית נחשון", "AMIT NAHSHON"],
    ".tiltan.co.il": [
        "תלתן - המכללה לעיצוב ולתקשורת חזותית",
        "Tiltan - College of Design and Visual Communication",
    ],
    ".volcani.agri.gov.il": [
        "Agricultural Research Organisation(ARO), Volcani Center"
    ],
    ".bs.amalnet.k12.il": [
        "תיכון רב-תחומי עמל רמות, באר שבע",
        "Amal Ramot Multidisciplinary High School, Beer Sheva",
    ],
    ".hd.amalnet.k12.il": [
        "הרב תחומי למדעים ואומניות עמל חדרה",
        "school website: http://hd.amalnet.k12.il/",
    ],
    ".ld.amalnet.k12.il": ["Amal Lady Davis High School"],
    ".na.amalnet.k12.il": [
        "Multidisciplinary science and arts Amal Nahariya",
        "הרב תחומי עמל מדעים ואומנויות נהריה",
    ],
    ".nb.amalnet.k12.il": ["Amal Shakim Nahariya High School"],
    ".a-y.org.il": ["Алоней Ицхак", "Alonei Yitzhak high school"],
    ".amirimvrd.org.il": ["amirim"],
    ".amit365.org.il": ['אמי"ת בנים מודיעין', "Amit Banim Modi'in"],
    ".big.atid.org.il": ["Atid Cramim Binyamina-Giv'at Ada High School"],
    ".cts.org.il": [
        "Technological and Engineering Education Center",
        "http://www.cts.org.il/english",
    ],
    ".edu-darom.org.il": ["גולדווטר", "Goldwater"],
    ".edu-haifa.org.il": ["Amal Hadera", "Amal Hadera"],
    ".educ.org.il": [
        "Israeli Ministry of Education provided email for all high-schools teachers"
    ],
    ".amirim.edum.org.il": ["Amirim Eroni Heh Rishon Lezion"],
    ".gsh.edum.org.il": ["תיכון גבעת שמואל", "Giv'at Shmuel High School"],
    ".mekifh.edum.org.il": ["Mekifh H Rishon Letsiyon"],
    ".emek-school.org.il": ["Emek Hahula High School"],
    ".hadash-holon.org.il": ["Campus Peres", "HTH"],
    ".haderahigh.org.il": ["Tichon Hadera"],
    ".haredi.org.il": ["תיכון חרדי משרד החינוך", "haredi"],
    ".hayovel.org.il": [
        " חטיבת היובל מבשרת ציון",
        "Hayovel Middle School, Israel",
    ],
    ".hityash.org.il": ["ויצו הדסים", "Hadassim"],
    ".iasa-school.org.il": [
        'י"אסא - התיכון הישראלי למדעים ולאמנויות',
        "IASA - Israeli Arts and Science Academy",
    ],
    ".ironialef.org.il": ["Ironi Alef Modiin"],
    ".jerschools.org.il": [
        "תיכון עירוני ג' על שם מוטה גור מודיעין",
        "ironi g named on mota gur modi'in",
    ],
    ".jerusalem365.org.il": [
        "משרד החינוך הישראלי - מחוז ירושלים",
        "Israeli Ministry of Education - Jerusalem District",
        ".group",
    ],
    ".kadoorie.org.il": ["Kadoorie"],
    ".manhischools.org.il": ["רנה קסין", "rene cassin"],
    ".bialik.ort.org.il": ["אורט ביאליק", "Ort Bialik"],
    ".ebin.ort.org.il": ["Ort Ebin High School"],
    ".gram.ort.org.il": ["מכללת אורט גבעת רם"],
    ".guttman.ort.org.il": ["אורט גוטמן", "ORT GUTTMAN"],
    ".holon.ort.org.il": [
        "אורט חולון",
        "Ort Holon",
        "https://holon.ort.org.il/",
    ],
    ".kramim.ort.org.il": ["ORT Kramin", "ORT Kramin"],
    ".kshapira.ort.org.il": ["אורט שפירא", "Ort Shapira"],
    ".one.ort.org.il": ["אורט שחר", "ort shahar"],
    ".ortarad.ort.org.il": ["Ort Arad High School"],
    ".pelech.ort.org.il": ["Ort Pelech Banim", "Ort Pelech School for Boys"],
    ".rehovot.ort.org.il": ["אורט רחובות", "Ort Rehovot"],
    ".shapira.ort.org.il": ["Ort Shapira High School"],
    ".yalon.ort.org.il": ["אורט יוקנעם", "ort yokneam"],
    ".sisma.org.il": ["מקיף א באר שבע (משרד החינוך)"],
    ".eylon.tad.org.il": ["Eylon high school Holon Israel"],
    ".ironihei.tad.org.il": ["Ironi Hei High School Tel Aviv"],
    ".thadash.tad.org.il": ["New High School Tel Aviv"],
    ".taded.org.il": ["תיכון שמעון בן צבי", "Shimon Ben Zvi High School"],
    ".tlvedu.org.il": ["עירוני ה", "Ironi H"],
    ".tzfonet.org.il": ["tzafonet", ".group"],
    ".zzv.org.il": ["College of Engineering"],
    ".iomc.ac.im": ["Isle of Man College"],
    ".ucm.ac.im": ["University College Isle of Man"],
    ".online.sch.im": ["Ballakermeen High School"],
    ".uaolen.im": ["Uralach Academy of Oceanic Life & Environmental Nexus"],
    ".uiied.im": ["University of the Isle of Interdisciplinary Excellence"],
    ".zjj.im": ["Hubei Industrial Polytechnic, Shiyan City"],
    ".abesit.in": ["ABES Institute of Technology, Ghaziabad"],
    ".acharya.ac.in": ["Acharya Institute of Technology (AIT), Bangalore"],
    ".aitmbgm.ac.in": ["Angadi Institute of Technology and Management"],
    ".allenhouse.ac.in": ["Allenhouse Institute of Technology"],
    ".amu.ac.in": ["Aligarh Muslim University, Aligarh"],
    ".apsshankarvihar.ac.in": ["Army Public School, Shankar Vihar"],
    ".bbit.ac.in": [
        "Bhailalbhai & Bhikhabhai Institute of Technology - BBIT, Vallabh Vidya Nagar, Anand, Gujarat"
    ],
    ".becs.ac.in": ["Bengal Engineering and Science University"],
    ".bitmesra.ac.in": ["Birla Institute of Technology - Mesra"],
    ".alumni.bits-pilani.ac.in": [
        "Birla Institute of Technology and Science (BITS), Pilani"
    ],
    ".dubai.bits-pilani.ac.in": [
        "Birla Institute of Technology and Science, Pilani – Dubai Campus"
    ],
    ".goa.bits-pilani.ac.in": [
        "Birla Institute of Technology and Science, Pilani – K K Birla Goa Campus"
    ],
    ".hyderabad.bits-pilani.ac.in": [
        "Birla Institute of Technology and Science, Pilani – Hyderabad Campus"
    ],
    ".online.bits-pilani.ac.in": [
        "  Birla Institute of Technology And Science, Pilani - Online Course"
    ],
    ".pilani.bits-pilani.ac.in": [
        "Birla Institute of Technology and Science, Pilani – Pilani Campus"
    ],
    ".wilp.bits-pilani.ac.in": [
        "Birla Institute of Technology and Science, Pilani – WILP Campus"
    ],
    ".bitsathy.ac.in": ["Bannari Amman Institute of Technology"],
    ".bmsce.ac.in": ["BMS College of Engineering (BMSCE), Bangalore"],
    ".bppimt.ac.in": [
        "B.P. Poddar Institute of Management & Technology, Kolkata"
    ],
    ".bvrit.ac.in": ["B. V. Raju Institute of Technology"],
    ".ccet.ac.in": ["Chandigarh College Of Engineering and Technology"],
    ".cekottarakkara.ac.in": ["COLLEGE OF ENGINEERING, KOTTARAKKARA"],
    ".cet.ac.in": ["College of Engineering, Trivandrum"],
    ".cgu-odisha.ac.in": ["C. V. Raman Global University"],
    ".charusat.ac.in": ["Charotar University Of Science And Technology"],
    ".chirec.ac.in": [
        "CHIREC International School, Hyderabad",
        "https://www.chirec.ac.in/",
    ],
    ".ciem.ac.in": [
        "Calcutta Institute of Engineering and Management, Kolkata"
    ],
    ".cmi.ac.in": ["Chennai Mathematical Institute"],
    ".cmrit.ac.in": ["CMR institute of technology"],
    ".cmrtc.ac.in": [
        "CMR Technical Campus",
        "CMRTC",
        "https://cmrtc.ac.in/",
        "https://cmrtc.ac.in/academics/courses-offered/",
    ],
    ".cns.ac.in": ["Chatrabhuj Narsee School"],
    ".coer.ac.in": ["College of Engineering Roorkee"],
    ".continental.ac.in": ["Continental Institute for International Studies"],
    ".cus.ac.in": [
        "Central University of Sikkim",
        "Central University of Sikkim",
    ],
    ".cvr.ac.in": ["CVR College of Enginnering"],
    ".cvsr.ac.in": [
        "C.V.S.R COLLEGE OF ENGINEERING #http://jntuhaac.in/Public/CollegeInformation/YbUuCGArQds%3D",
        "Anurag University #https://agi.anurag.edu.in/admission/contacts/",
    ],
    ".daiict.ac.in": [
        "Dhirubhai Ambani Institute of Information and Communication Technology"
    ],
    ".djsce.ac.in": ["Dwarkadas Jamnadas Sanghvi College of Engineering"],
    ".dsengg.ac.in": ["Dhanalakshmi Srinivasan Engineering College"],
    ".dseu.ac.in": ["Delhi Skill And Entrepreneurship University"],
    ".dsvv.ac.in": ["Dev Sanskriti Vishwavidyalaya"],
    ".dtu.ac.in": ["Delhi Technological University"],
    ".cvs.du.ac.in": [
        "College Of Vocational Studies, Delhi University",
        "College Of Vocational Studies, Delhi University",
    ],
    ".dsc.du.ac.in": [
        "Dyal Singh College, University Of Delhi, New Delhi, India - 110003",
        "Website URL >> (https://www.dsc.du.ac.in/)",
        "Long Term Course Offered (>1 Year) >> (https://www.dsc.du.ac.in/courses-offered) - Here Mentioned is BSc Physical Sciences(Computer Sciences)",
        "Domain Name is as shared in the 2nd line.",
    ],
    ".dypiemr.ac.in": [
        "DR. D. Y. PATIL INSTITUTE OF ENGINEERING,MANAGEMENT & RESEARCH AKURDI"
    ],
    ".famt.ac.in": [
        "Finolex Academy Management and Technology,Ratnagiri",
        "FAMT",
    ],
    ".galgotiasuniversity.ac.in": [
        "Galgotias University, Gautam Buddha Nagar, Greater Noida",
        "GALGOTIAS UNIVERSITY",
    ],
    ".ganpatuniversity.ac.in": ["Ganpat University, Mehsana, Gujarat"],
    ".gat.ac.in": ["Global Academy of Technology , Bangalore"],
    ".gauhati.ac.in": ["Gauhati University, Guwahati, Assam"],
    ".gbu.ac.in": ["GAUTAM BUDDHA UNIVERSITY"],
    ".gcek.ac.in": ["Government College of Engineering Kannur"],
    ".gcoeara.ac.in": [
        "Government College of Engineering and Research, Avasari Khurd"
    ],
    ".gecbh.ac.in": ["Government Engineering College Barton Hill"],
    ".gecg28.ac.in": ["Government Engineering College, Gandhinagar"],
    ".gecrajkot.ac.in": ["Government Engineering College (GEC), Rajkot"],
    ".gecskp.ac.in": ["Government Engineering College, Sreekrishnapuram"],
    ".gectcr.ac.in": ["Government Engineering College, Thrissur"],
    ".gehu.ac.in": ["Graphic Era Hill University, Dehradun"],
    ".gkv.ac.in": ["Gurukula Kangri"],
    ".gla.ac.in": ["GLA University, Mathura"],
    ".gmit.ac.in": [
        "GM Institute of Technology a hi-tech & Top Engineering college in Davangere"
    ],
    ".gndu.ac.in": ["Guru Nanak Dev University", "Guru Nanak Dev University"],
    ".govtsciencecollegedurg.ac.in": [
        "GOVT. V.Y.T.PG. AUTONOMOUS COLLEGE, DURG, CHHATTISGARH"
    ],
    ".gtbit.ac.in": ["Guru Tegh Bahadur Institute of Technology"],
    ".gtu.ac.in": ["Gujarat Technological University"],
    ".gujaratuniversity.ac.in": ["Gujarat University"],
    ".hbtu.ac.in": ["Harcourt Butler Technical University"],
    ".huroorkee.ac.in": [
        "Haridwar University formerly Roorkee College Of Engineering",
        "The website URL is https://huroorkee.ac.in/",
        "I am Debraj a first year undergrad at this university",
    ],
    ".iare.ac.in": ["Institute of Aeronautical Engineering, Hyderabad"],
    ".ietlucknow.ac.in": [
        "Institute of Engineering and Technology, Lucknow",
        "Institute of Engineering and Technology, Lucknow",
    ],
    ".iiests.ac.in": [
        "Indian Institute of Engineering Science and Technology, Shibpur"
    ],
    ".iiit-bh.ac.in": [
        "INTERNATIONAL INSTITUTE OF INFORMATION TECHNOLOGY, BHUBANESHWAR",
        "IIIT-BBSR",
        "IIIT BHUBANESHWAR",
        "The email we use is xyz@iiit-bh.ac.in",
        "Official College Website: (https://www.iiit-bh.ac.in/)",
        "URL of a page on the official website where a long-term (>1 year) IT related course is offered by the university: (https://www.iiit-bh.ac.in/admissions)",
        "URL of a page or some other proof (.pdf or a screenshot are OK) showing that the university recognizes the domain which you are submitting as an official email domain for the enrolled students: (https://docs.google.com/spreadsheets/d/1SpdPVOukm7BDEOY7X-Rr-HSlBBy5WKjkVEAqWu9YC_o/edit#gid=0)",
    ],
    ".iiit.ac.in": [
        "International Institute of Information Technology, Hyderabad"
    ],
    ".iiita.ac.in": ["Indian Institute of Information Technology Allahabad"],
    ".iiitb.ac.in": [
        "International Institute of Information Technology, Bangalore"
    ],
    ".iiitbh.ac.in": ["IIIT Bhagalpur"],
    ".iiitd.ac.in": ["Indraprastha Institute of Information Technology Delhi"],
    ".iiitdmj.ac.in": ["Indian Institute of Information Technology"],
    ".iiitdwd.ac.in": ["Indian Institute of Technology Dharwad"],
    ".iiitg.ac.in": ["Indian Institute of Information Technology Guwahati"],
    ".iiitkalyani.ac.in": [
        "Indian Institute of Information Technology Kalyani"
    ],
    ".iiitkota.ac.in": ["Indian Institute Of Information technology , Kota"],
    ".iiitkottayam.ac.in": [
        "Indian Institute of Information Technology ,Kottayam"
    ],
    ".iiitl.ac.in": [
        "Indian Institute of Information Technology, Lucknow",
        "IIITL",
    ],
    ".iiitm.ac.in": [
        "Atal Bihari Vajpayee Indian Institute of Information Technology and Management Gwalior"
    ],
    ".iiitmanipur.ac.in": [
        "Indian Institute of information of technology manipur"
    ],
    ".iiitn.ac.in": ["Indian Institute of Information Technology, Nagpur"],
    ".iiitp.ac.in": ["Indian Institute of Information Technology, Pune"],
    ".iiitr.ac.in": [
        "Indian Institute of Information Technology Raichur",
        "IIIT Raichur",
        "IIITR",
    ],
    ".iiitsonepat.ac.in": [
        "Indian Institute of Information Technology, Sonepat"
    ],
    ".iiitvadodara.ac.in": [
        "Indian Institute Of Information Technology, Vadodara"
    ],
    ".iima.ac.in": ["Indian Institute of Management Ahmedabad"],
    ".iimkashipur.ac.in": ["IIM Kashipur"],
    ".iiml.ac.in": ["IIM Lucknow"],
    ".iimraipur.ac.in": ["Indian Institute of Management Raipur"],
    ".iimranchi.ac.in": ["Indian Institute of Management Ranchi"],
    ".iisc.ac.in": ["Indian Institute Of Science"],
    ".iiserb.ac.in": [
        "Indian Institute of Science Education and Research Bhopal (IISER Bhopal)"
    ],
    ".iiserkol.ac.in": [
        "Indian Institute of Science Education and Research, Kolkata"
    ],
    ".iiserpune.ac.in": [
        "Indian Institute of Science Education and Research Pune"
    ],
    ".iisertvm.ac.in": [
        "Indian Institute of Science Education and Research Thiruvananthapuram (IISER TVM)"
    ],
    ".iitb.ac.in": ["Indian Institute of Technology Bombay"],
    ".iitbbs.ac.in": [
        "Indian Institute of Technology Bhubaneswar",
        "IIT Bhubaneswar",
    ],
    ".iitbhilai.ac.in": ["Indian Institute of Technology Bhilai"],
    ".iitbhu.ac.in": [
        "Indian Institute of Technology (Banaras Hindu University)"
    ],
    ".iitd.ac.in": ["Indian Institute of Technology, Delhi"],
    ".iitdh.ac.in": ["Indian Institute of Technology Dharwad"],
    ".iitg.ac.in": ["Indian Institute of Technology Guwahati"],
    ".iitgn.ac.in": ["Indian Institute of Technology Gandhinagar"],
    ".iith.ac.in": ["Indian Institute of Technology Hyderabad"],
    ".iiti.ac.in": ["Indian Institute of Technology Indore"],
    ".iitj.ac.in": ["Indian Institute of Technology Jodhpur"],
    ".iitjammu.ac.in": ["Indian Institute of Technology Jammu"],
    ".iitk.ac.in": ["Indian Institute of Technology Kanpur"],
    ".iitkgp.ac.in": [
        "Indian Institute of Technology Kharagpur",
        "Indian Institute of Technology - Kharagpur",
    ],
    ".iitm.ac.in": [
        "Indian Institute of Technology Madras",
        "Indian Institute of Technology - Madras",
    ],
    ".iitmandi.ac.in": ["Indian Institute of Technology Mandi"],
    ".iitp.ac.in": ["Indian Institute of Technology Patna"],
    ".iitpkd.ac.in": ["Indian Institute of Technology Palakkad"],
    ".iitr.ac.in": ["Indian Institute of Technology, Roorkee"],
    ".iitrpr.ac.in": ["Indian Institute of Technology Ropar"],
    ".iittp.ac.in": ["Indian Institute of Technology, Tirupati"],
    ".imit.ac.in": ["Institute of management and information technology"],
    ".ipu.ac.in": ["Guru Govind Singh Indra Prastha University"],
    ".isical.ac.in": ["Indian Statistical Institute"],
    ".ismdhanbad.ac.in": [
        "Indian Institute of Technology (Indian School of Mines), Dhanbad"
    ],
    ".itbhu.ac.in": [
        "Indian Institute of Technology (Banaras Hindu University)"
    ],
    ".iul.ac.in": ["Integral University, Lucknow"],
    ".jainuniversity.ac.in": ["Jain University"],
    ".jcboseust.ac.in": ["J.C Bose Ust YMCA"],
    ".jdcoem.ac.in": ["JD college of engineering and management nagpur"],
    ".jecrc.ac.in": ["Jaipur Engineering College & Research Centre"],
    ".jgec.ac.in": [
        "jgec.ac.in",
        "Jalpaiguri Government Engineering College, Jalpaiguri, West Bengal, India",
    ],
    ".jiit.ac.in": [
        "Jaypee Institute of Information Technology, Noida ",
        "https://www.jiit.ac.in/btech-information-technology",
    ],
    ".jjmcoe.ac.in": [
        "Dr. J J Magdum College of Engineering",
        "Dr. J J Magdum College of Engineering",
    ],
    ".jmi.ac.in": ["Jamia Millia Islamia, New Delhi"],
    ".jnctbhopal.ac.in": ["Jai Narain College of Technology"],
    ".cej.jntuh.ac.in": [
        "Jawaharlal Nehru Technological University Hyderabad"
    ],
    ".jssaten.ac.in": ["JSS Academy of Technical Education, Noida"],
    ".jyothyit.ac.in": ["Jyothy Institute of Technology"],
    ".kce.ac.in": ["Karpagam College of Engineering"],
    ".kct.ac.in": ["Kumaraguru college of Technology, Coimbatore"],
    ".keck.ac.in": ["Katihar Engineering College, katihar"],
    ".kgkite.ac.in": ["KGiSL Institute of Technology, Coimbatore"],
    ".kiit.ac.in": [
        "KIIT University, Bhubaneswar",
        "Kalinga Institute of Industrial Technology, Bhubaneswar",
    ],
    ".kitsw.ac.in": ["Kakatiya Institute of Technology and Science, Warangal"],
    ".kittiptur.ac.in": [
        "Kalpataru Institute of Technology (KIT), Tiptur, Karnataka"
    ],
    ".knit.ac.in": ["KNIT Sultanpur"],
    ".kongu.ac.in": ["Kongu Engineering College, Perundurai"],
    ".kpcoll.ac.in": ["Kanchrapara College", "Kanchrapara College"],
    ".krishnacollege.ac.in": ["Krishna Engineering College"],
    ".ksrce.ac.in": [
        "K.S.R College of Engineering",
        "K.S.R College of Engineering",
    ],
    ".kuk.ac.in": ["Kurukshetra University, Kurukshetra"],
    ".licet.ac.in": [
        "Loyola-ICAM College of Engineering and Technology, Chennai"
    ],
    ".lnct.ac.in": ["Lakshmi Narain College of Technology (LNCT), Bhopal"],
    ".lnmiit.ac.in": ["The LNM Institute Of Information Technology, Jaipur"],
    ".mace.ac.in": [
        "Mar Athanasius College of Engineering",
        "MACE",
        "MA College of Engineering",
    ],
    ".mait.ac.in": ["Maharaja Agrasen Institute of Technology, Delhi"],
    ".manit.ac.in": [
        "Maulana Azad National Institute of Technology , Bhopal , India"
    ],
    ".marwadiuniversity.ac.in": ["Marwadi University - Rajkot,Gujarat"],
    ".mbcet.ac.in": [
        "Mar Baselios College of Engineering and Technology, Thiruvananthapuram "
    ],
    ".mctrgit.ac.in": [
        "Manjara Charitable Trust's Rajiv Gandhi Institute of Technology, Mumbai",
        "aka Rajiv Gandhi Institute of Technology, Mumbai",
        "aka RGIT",
    ],
    ".mec.ac.in": ["Govt. Model Engineering College"],
    ".medicaps.ac.in": ["Medicaps University, Indore"],
    ".mgit.ac.in": [
        "www.mgit.ac.in",
        "Mahatma Gandhi Institute of Technology in Hyderabad, Telangana State, India",
    ],
    ".mitaoe.ac.in": ["MIT Academy of Engineering - Pune"],
    ".mitsgwl.ac.in": ["Madhav Institute of Technology & Science"],
    ".mmmut.ac.in": [
        "Madan Mohan Malaviya university of technology",
        "Madan Mohan Malaviya university of technology",
    ],
    ".mnit.ac.in": ["Malaviya National Institute of Technology, Jaipur"],
    ".mnnit.ac.in": [
        "Motilal Nehru National Institute of Technology Allahabad, Prayagraj"
    ],
    ".mrcet.ac.in": ["Malla Reddy College of Engineering and Technology"],
    ".msruas.ac.in": ["M S Ramaiah University of Applied Sciences"],
    ".myamu.ac.in": ["Aligarh Muslim University, Aligarh"],
    ".niecdelhi.ac.in": [" Northern India Engineering College, New Delhi"],
    ".nift.ac.in": ["National Institute of Fashion Technology"],
    ".nirmauni.ac.in": ["Nirma University"],
    ".nita.ac.in": ["National Institute Of Technology Agartala"],
    ".nitandhra.ac.in": ["National Institute of Technology, Andhra Pradesh"],
    ".nitap.ac.in": [
        "National Institute of Technology, Arunachal Pradesh",
        "National Institute of Technology, Arunachal Pradesh",
    ],
    ".nitc.ac.in": ["National Institute Of Technology Calicut"],
    ".nitdelhi.ac.in": ["National Institute of Technology, Delhi"],
    ".nitdgp.ac.in": ["National Institute of Technology, Durgapur"],
    ".nith.ac.in": ["National Institute of Technology, Hamirpur"],
    ".nitj.ac.in": [
        "Dr B R Ambedkar National Institute of Technology, Jalandhar"
    ],
    ".nitjsr.ac.in": ["National Institute of Technology, Jamshedpur"],
    ".nitkkr.ac.in": ["National Institute of Technology Kurukshetra"],
    ".nitm.ac.in": ["National Institute of Technology, Meghalaya"],
    ".nitmanipur.ac.in": ["National Institute of Technology Manipur"],
    ".nitp.ac.in": ["National Institute of Technology, Patna"],
    ".nitrkl.ac.in": ["National Institute Of Technology Rourkela"],
    ".nitrr.ac.in": ["National Institute of Technology, Raipur"],
    ".che.nits.ac.in": ["National Institute of Technology Silchar"],
    ".civil.nits.ac.in": ["National Institute of Technology Silchar"],
    ".cse.nits.ac.in": ["National Institute of Technology Silchar"],
    ".ece.nits.ac.in": ["National Institute of Technology Silchar"],
    ".ee.nits.ac.in": ["National Institute of Technology Silchar"],
    ".ei.nits.ac.in": ["National Institute of Technology Silchar"],
    ".hum.nits.ac.in": ["National Institute of Technology Silchar"],
    ".math.nits.ac.in": ["National Institute of Technology Silchar"],
    ".mba.nits.ac.in": ["National Institute of Technology Silchar"],
    ".mech.nits.ac.in": ["National Institute of Technology Silchar"],
    ".phy.nits.ac.in": ["National Institute of Technology Silchar"],
    ".nits.ac.in": ["National Institute of Technology, Silchar"],
    ".nitsikkim.ac.in": ["National Institute Of Technology Sikkim"],
    ".nitsri.ac.in": ["National Institute of Technology Srinagar"],
    ".nitw.ac.in": ["National Institute of Technology, Warangal"],
    ".nmit.ac.in": [
        "NITTE Meenakshi Institute of Technology, Bangalore, Karnataka, India"
    ],
    ".nsit.ac.in": ["Netaji Subhas Institute Of Technology"],
    ".nssce.ac.in": ["NSS College Of Engineering Palakkad"],
    ".nsut.ac.in": ["Netaji Subhas University of Technology, Delhi"],
    ".osgu.ac.in": [
        "Om Sterling Global University",
        "Om Sterling Global University",
    ],
    ".panimalar.ac.in": ["Panimalar Engineering College"],
    ".paruluniversity.ac.in": ["Parul University"],
    ".pbi.ac.in": ["Punjabi University, Patiala"],
    ".sls.pdpu.ac.in": [
        "Pandit Deendayal Energy University - School of Liberal Studies"
    ],
    ".sot.pdpu.ac.in": [
        "Pandit Deendayal Energy University - School of Technology"
    ],
    ".ppsu.ac.in": ["P.P Savani University", "P.P Savani University"],
    ".prist.ac.in": ["PRIST UNIVERSITY", "PRIST UNIVERSITY"],
    ".psgitech.ac.in": [
        "PSG Institute of Technology and Applied Research, Coimbatore"
    ],
    ".psgtech.ac.in": ["PSG College of Technology, Coimbatore"],
    ".ptu.ac.in": ["Punjab Technical University"],
    ".rguktn.ac.in": [
        "Rajiv Gandhi University of Knowledge Technologies, Nuzvid"
    ],
    ".rguktrkv.ac.in": [
        "Rajiv Gandhi University of Knowledge Technologies, Andhra Pradesh",
        "RK Valley Institute",
    ],
    ".rnsit.ac.in": ["RNS Institute of Technology"],
    ".royalschool.ac.in": ["Royal School of Management & Technology"],
    ".rtu.ac.in": ["Rajasthan Technical University"],
    ".saec.ac.in": ["saec.ac.in"],
    ".sastra.ac.in": ["Shanmugha Arts"],
    ".sathyabama.ac.in": [
        "Sathyabama Institute of Science and Technology",
        "Sathyabama University",
        "sathyabama.ac.in",
    ],
    ".scet.ac.in": [
        "Sarvajanik College of Engineering and Technology ",
        "Sarvajanik College of Engineering and Technology",
    ],
    ".sfit.ac.in": ["St. Francis Institute of Technology"],
    ".ug.sharda.ac.in": ["Sharda University"],
    ".sicsr.ac.in": ["Symbiosis Institute of Computer Studies and Research"],
    ".silicon.ac.in": ["Silicon University", "Silicon University"],
    ".silveroakuni.ac.in": ["Silver Oak University"],
    ".sit.ac.in": ["Siddaganga Institute of Technology"],
    ".sjc.ac.in": ["St Joseph's College (Autonomous) in Bengaluru, Karnataka"],
    ".sjce.ac.in": ["JSS Science and Technology University, Mysore"],
    ".sjcetpalai.ac.in": [
        "ST JOSEPH'S COLLEGE OF ENGINEERING AND TECHNOLOGY, PALAI"
    ],
    ".sjec.ac.in": ["St Joseph Engineering College"],
    ".skit.ac.in": ["Swami Keshvanand Institute of Technology"],
    ".smvdu.ac.in": ["Shri Mata Vaishno Devi University"],
    ".snsce.ac.in": ["SNS COLLEGE OF ENGINEERING"],
    ".spit.ac.in": [
        "Bharatiya Vidya Bhavans Sardar Patel Institute Of Technology"
    ],
    ".srec.ac.in": ["Sri Ramakrishna Engineering College"],
    ".sreedattha.ac.in": [
        "Sree Dattha Institute of Engineering and Science",
        "Sree Dattha Institute of Engineering and Science",
    ],
    ".srmcem.ac.in": [
        "Shri Ramswaroop Memorial College of Engineering and Management, Lucknow",
        "Shri Ramswaroop Memorial College of Engineering and Management, Lucknow",
    ],
    ".srmuniv.ac.in": ["SRM University"],
    ".srmuniversity.ac.in": [
        "SRM University, Sonipat",
        "aka SRM University, Haryana",
    ],
    ".ssmiet.ac.in": ["SSM INSTITUTE OF ENGINEERING AND TECHNOLOGY, DINDIGUL"],
    ".stcet.ac.in": ["St. Thomas' College of Engineering and Technology"],
    ".stjosephs.ac.in": ["St. Joseph's College of Engineering, Chennai"],
    ".coed.svnit.ac.in": [
        "Sardar Vallabhbhai National Institute of Technology, Surat",
        "Sardar Vallabhbhai National Institute of Technology, Surat",
    ],
    ".ternaengg.ac.in": [
        "Terna Engineering College",
        "Terna Engineering College",
    ],
    ".tezu.ac.in": ["Tezpur University,Assam,India"],
    ".tiss.ac.in": ["Tata Institute of Social Sciences, Mumbai."],
    ".tkmce.ac.in": ["TKM College of Engineering, Kollam"],
    ".uecu.ac.in": ["Ujjain Engineering College, Ujjain"],
    ".uktech.ac.in": ["Uttarakhand Technical University,Dehradun"],
    ".unipune.ac.in": ["University of Pune"],
    ".utu.ac.in": ["Uka Tarsadia University"],
    ".velsuniv.ac.in": [
        "Vels Institute of Science, Technology & Advanced Studies(VISTAS)",
        "Vels University",
        "velsuniv.ac.in",
    ],
    ".ves.ac.in": ["Vivekanand Education Society"],
    ".viit.ac.in": ["VIIT, Pune"],
    ".vit.ac.in": ["Vellore Institute of Technology"],
    ".vitalum.ac.in": ["Vit vellore"],
    ".vitap.ac.in": ["VIT-AP University"],
    ".vitapalum.ac.in": [
        "VIT University, AP",
        "VIT AP",
        ".group",
        "The official website of VIT Bangalore: https://vitap.ac.in/",
    ],
    ".vitapstudent.ac.in": [
        "VIT-AP (Vellore Institute of Technology - AP), Amaravati, Andhra Pradesh -- Student email domain"
    ],
    ".vitbhopal.ac.in": ["VIT BHOPAL University"],
    ".vitstudent.ac.in": ["Vellore Institute of Technology, Vellore"],
    ".vjti.ac.in": [
        "Veermata Jijabai Technological Institute, Mumbai",
        "aka VJTI",
    ],
    ".vnsgu.ac.in": ["Veer Narmad South Gujarat University"],
    ".vupune.ac.in": ["Vishwakarma University", "Vishwakarma University"],
    ".vvpedulink.ac.in": ["VVP Engineering College"],
    ".walchandsangli.ac.in": ["Walchand College Of Engineering Sangli"],
    ".xlri.ac.in": [
        "Xavier School of Management",
        "XLRI - Xavier School of Management",
    ],
    ".zhcet.ac.in": ["Zakir Husain College of Engineering and Technology"],
    ".acropolis.in": ["Acropolis Institute Of Technology and Research"],
    ".adcet.in": [
        "Annasaheb Dange College of Engineering and Technology,ashta"
    ],
    ".adhiyamaan.in": ["Adhiyamaan College of Engineering"],
    ".adtu.in": ["Assam Down Town University"],
    ".adypsoe.in": [
        "Ajeenkya DY Patil School of Engineering",
        "Ajeenkya DY Patil School of Engineering",
    ],
    ".aesl.in": ["Akash Institute", "Aakash Educational Services Limited"],
    ".aitindia.in": [
        "AHMEDABAD INSTITUTE OF TECHNOLOGY",
        "AHMEDABAD INSTITUTE OF TECHNOLOGY",
    ],
    ".ajce.in": ["Amal Jyothi College of Engineering, Kanjirappally"],
    ".alpha-cet.in": ["Alpha College Of Engneering"],
    ".amceducation.in": ["AMC Engineering College"],
    ".anjarakandy.in": [
        "Institute of Paramedical Sciences Kannur Medical College"
    ],
    ".aryacollege.in": ["Arya College of Engineering and I.T."],
    ".aryagurukul.in": ["Arya Gurukul"],
    ".aucet.in": [
        "University College of Engineering, Tindivanam",
        "University College of Engineering, Tindivanam",
    ],
    ".axiscolleges.in": [
        "Axis Institute of Technology and Management",
        "Axis Institute of Technology and Management",
    ],
    ".banasthali.in": ["Banasthali Vidyapith"],
    ".bmsit.in": ["BMS Institute of Technology and Management, Bengaluru"],
    ".bnmit.in": ["B. N. M. Institute of Technology"],
    ".bpibs.in": ["Bhai Parmanand DSEU Shakarpur Campus - II"],
    ".btup.in": ["Baruda Technological & Practical University"],
    ".bvcgroup.in": ["BVC Engineering College"],
    ".bvicam.in": [
        "Bharati Vidyapeeth's Institute of Computer Applications and Management"
    ],
    ".bvmcollege.in": [
        "Birla Vishvakarma Mahavidyalaya Engineering College",
        "BVM Engineering College",
    ],
    ".campusk.in": ["Campus K"],
    ".campusuvce.in": ["Univerity Visvesvaraya College of Engineering"],
    ".cgcjhanjeri.in": ["CGC Jhanjeri", "CGC Jhanjeri"],
    ".christuniversity.in": ["Christ University, Bangalore"],
    ".backstagepass.co.in": [
        "Backstage Pass Institute of Gaming and Technology"
    ],
    ".bibs.co.in": ["Bengal Institute Of Business Studies"],
    ".birlainstitute.co.in": ["Birla Institute of Applied Sciences, Bhimtal"],
    ".cdckids.co.in": ["Child Development Centre", "Child Development Centre"],
    ".dihe.co.in": ["Delhi Institute Of Higher Education"],
    ".dpsnoida.co.in": ["Delhi Public School Noida Uttarpradesh India"],
    ".ggct.co.in": ["Gyan Gang College of Technology"],
    ".lpu.co.in": ["Lovely Professional University"],
    ".nttf.co.in": ["Nettur Technical Training Foundation"],
    ".piet.co.in": ["Panipat Institute of Engineering & Technology"],
    ".blr.silveroaks.co.in": ["Silver Oaks International School"],
    ".hyd.silveroaks.co.in": ["Silver Oaks International School"],
    ".starexuniversity.co.in": [
        "Starex University, NH-48, Vill- Binola, P.O. Bhorakalan, Gurugram, Haryana 122413 (India)",
        "https://www.starexuniversity.com/",
        "https://www.starexuniversity.com/contact",
        "mail: admission@starexuniversity.co.in",
    ],
    ".coet.in": [
        "Mahatma Gandhi Mission's College of Engineering and Technology, Noida"
    ],
    ".csacademy.in": ["CS Academy", "CS Academy"],
    ".csiriicb.in": ["CSIR-Indian Institute of Chemical Biology"],
    ".csitgeu.in": [
        "Department of Computer Science and Information Technology, GEU"
    ],
    ".stu.ctgroup.in": ["Ct  Institute of Technology and Research"],
    ".ctuniversity.in": ["Chandigarh Technical University"],
    ".cuchd.in": ["Chandigarh University "],
    ".cumail.in": ["Chandigarh University"],
    ".cumminscollege.in": ["Cummins College [Pune]"],
    ".davvscsit.in": [
        "Devi Ahilya Vishwavidyalaya, Indore",
        "Devi Ahilya Vishwavidyalaya, Indore, Madhya Pradesh, India - 452001",
        "https://www.dauniv.ac.in/",
        "https://davvscsit.in/",
    ],
    ".dbit.in": [
        "Don Bosco Institute of Technology, Mumbai, Premier Automobiles Road Opp. HDIL Premier Exotica, Kurla, Mumbai, Maharashtra 400070"
    ],
    ".dypic.in": [
        "Ajeenkya DY Patil School of Engineering",
        "Ajeenkya DY Patil School of Engineering",
    ],
    ".e-p-s.in": ["Eastern Public School"],
    ".abesit.edu.in": [
        "ABES Institute of Technology, Ghaziabad",
        "ABES Institute of Technology, Ghaziabad",
    ],
    ".acoe.edu.in": [
        "aditya college of engineering",
        "aditya college of engineering",
    ],
    ".adypu.edu.in": ["Ajeenkya DY Patil University"],
    ".aec.edu.in": ["Aditya Engineering College"],
    ".ahduni.edu.in": ["Ahmedabad University", "Ahmedabad University"],
    ".aitpune.edu.in": ["Army Institute of Technology"],
    ".andhrauniversity.edu.in": ["andhrauniversity.edu.in"],
    ".anits.edu.in": ["Anil Neerukonda Institution of Technology", "Anits"],
    ".annauniv.edu.in": [
        "Anna University",
        "Anna University, Chennai",
        "அண்ணா பல்கலைக்கழகம்",
    ],
    ".anurag.edu.in": ["Anurag University, Hyderabad"],
    ".aot.edu.in": ["Academy Of Technology, Adisaptagram"],
    ".apsit.edu.in": ["A.P. Shah Institute of Technology"],
    ".ashoka.edu.in": ["Ashoka University"],
    ".atmiyauni.edu.in": ["Atmiya University", "Atmiya University"],
    ".bennett.edu.in": ["Bennett University, Greater Noida, India"],
    ".bmu.edu.in": ["Bml munjal university"],
    ".bpitindia.edu.in": ["Bhagwan Parshuram Institute of Technology"],
    ".bvucoep.edu.in": [
        "Bharati Vidyapeeth Deemed to be University, Department of Engineering and Technology, Navi Mumbai"
    ],
    ".cahcet.edu.in": ["C.Abdul Hakeem College of Engineering and Technology"],
    ".cambridge.edu.in": ["Cambridge Insitute of Technology"],
    ".ccis.edu.in": [
        "Cosmos Castle International School",
        "Cosmos Castle International School",
    ],
    ".centurionuniv.edu.in": [
        "Centurion University of Technology and Management"
    ],
    ".cet.edu.in": ["College Of Engineering and Technology, Bhubaneswar"],
    ".cgc.edu.in": ["Chandigarh Group of Colleges"],
    ".cgrinternationalschool.edu.in": ["CGR International School, India"],
    ".charusat.edu.in": ["Charotar University Of Science And Technology"],
    ".chitkara.edu.in": ["Chitkara University", "Chitkara University"],
    ".chitkarauniversity.edu.in": [
        "Chitkara University  ",
        "Chitkara University Himachal Pradesh  ",
        "chitkarauniversity.edu.in",
    ],
    ".cit.edu.in": ["CIT", "Coimbatore Institute of Technology, Coimbatore"],
    ".cmr.edu.in": [
        "CMR University",
        "https://www.cmr.edu.in/admissions/doctoral",
    ],
    ".cukashmir.edu.in": ["Central University of Kashmir, Ganderbal"],
    ".cvmu.edu.in": ["The Charutar Vidya Mandal (CVM) University"],
    ".depaul.edu.in": ["DePaul Institute of Science And Technology"],
    ".dituniversity.edu.in": ["DIT University,Dehradun"],
    ".djsce.edu.in": ["Dwarkadas Jamnadas Sanghvi College of Engineering"],
    ".drait.edu.in": ["Dr Ambedkar Institute of Technology"],
    ".dsatm.edu.in": [
        "Dayananda Sagar Academy of Technology and Management, Bengaluru"
    ],
    ".dsce.edu.in": ["Dayananda Sagar College of Engineering"],
    ".dypvp.edu.in": ["Dr. D. Y. Patil Institute of Technology"],
    ".flame.edu.in": ["Flame University"],
    ".galgotiasuniversity.edu.in": ["Galgotias University"],
    ".gift.edu.in": ["GIFT Autonomous College"],
    ".gmckannur.edu.in": ["Govt Medical College  Pariyaram"],
    ".gtu.edu.in": ["Gujarat Technological University"],
    ".gvpcdpgc.edu.in": [
        "Gayatri Vidya Parishad College for Degree and PG Courses"
    ],
    ".haps.edu.in": ["Holy Angels Public School"],
    ".heritageit.edu.in": ["Heritage Institute of Technology"],
    ".hkbk.edu.in": ["HKBK College of Engineering"],
    ".hnbgu.edu.in": [" Hemwati Nandan Bahuguna Garhwal University"],
    ".faculty.ictmumbai.edu.in": [
        "Emailing domain for faculty of Institute of Chemical Technology, Mumbai (Main Campus)"
    ],
    ".iocb.ictmumbai.edu.in": [
        "Institute of Chemical Technology, Mumbai (IndianOil Odisha Campus Bhubaneswar)"
    ],
    ".marj.ictmumbai.edu.in": [
        "Institute of Chemical Technology, Mumbai (Marathwada Campus, Jalna)"
    ],
    ".pg.ictmumbai.edu.in": [
        "Emailing domain for postgraduate students of Institute of Chemical Technology, Mumbai (Main Campus)"
    ],
    ".staff.ictmumbai.edu.in": [
        "Emailing domain for faculty of Institute of Chemical Technology, Mumbai (Main Campus)"
    ],
    ".staffiocb.ictmumbai.edu.in": [
        "Emailing domain for faculty of Institute of Chemical Technology, Mumbai (IndianOil Odisha Campus Bhubaneswar)"
    ],
    ".staffmarj.ictmumbai.edu.in": [
        "Emailing domain for faculty of Institute of Chemical Technology, Mumbai (Marathwada Campus, Jalna)"
    ],
    ".stuiocb.ictmumbai.edu.in": [
        "Emailing domain for students of Institute of Chemical Technology, Mumbai (IndianOil Odisha Campus Bhubaneswar)"
    ],
    ".stumarj.ictmumbai.edu.in": [
        "Emailing domain for students of Institute of Chemical Technology, Mumbai (Marathwada Campus, Jalna)"
    ],
    ".ug.ictmumbai.edu.in": [
        "Emailing domain for undergraduate students of Institute of Chemical Technology, Mumbai (Main Campus)"
    ],
    ".ictmumbai.edu.in": [
        "Institute of Chemical Technology, Mumbai (Main Campus)"
    ],
    ".iem.edu.in": ["INSTITUTE OF ENGINEERING & MANAGEMENT, KOLKATA"],
    ".ietdavv.edu.in": ["Institute of Engineering and Technology,DAVV"],
    ".ifim.edu.in": ["IFIM College", "IFIM College"],
    ".isquareit.edu.in": [
        "International Institute of Information Technology (I²IT)"
    ],
    ".iujharkhand.edu.in": [
        "ICFAI University of Jharkhand",
        "ICFAI University of Jharkhand",
    ],
    ".jecrcu.edu.in": [
        "Jaipur Engineering College and Research Centre University, Jaipur, Rajasthan, India"
    ],
    ".jspmrscoe.edu.in": [
        "JSPM's Rajarshi Shahu College of Engineering, Tathawade"
    ],
    ".kahedu.edu.in": [
        "Karpagam Academy Of Higher Education",
        "Karpagam Academy Of Higher Education",
    ],
    ".karunya.edu.in": ["Karunya University"],
    ".kccitm.edu.in": ["kcc institute of technology and management"],
    ".kdkce.edu.in": [
        "KDK COLLEGE OF ENGINEERING",
        "KARMAVEER DADASAHEB KANNAMWAR COLLEGE OF ENGINEERING",
    ],
    ".ksit.edu.in": ["K S Institute of Technology"],
    ".kssem.edu.in": ["K S School of Engineering and Management"],
    ".ldc.edu.in": ["Lady Doak College, Madurai"],
    ".littleflowercollege.edu.in": ["Little Flower College, Guruvayoor"],
    ".ljku.edu.in": [
        "L. J. University",
        "LJ University",
        "LJ Institute of Engineering and Technology",
    ],
    ".mahindrauniversity.edu.in": [
        "Ecole Centrale School of Engineering Mahindra University"
    ],
    ".mandsauruniversity.edu.in": ["Mandsaur University"],
    ".matrusri.edu.in": ["Matrusri Engineering College"],
    ".mbit.edu.in": ["mbit.edu.in"],
    ".meu.edu.in": ["Mandsaur University"],
    ".mituniversity.edu.in": ["MIT Art Design and Technology University Pune"],
    ".mitwpu.edu.in": ["MIT-World Peace University, Pune."],
    ".mlacw.edu.in": [
        "Maharani Lakshmi Ammanni College for Women",
        "Maharani Lakshmi Ammanni College for Women",
    ],
    ".mmcoe.edu.in": ["Marathwada Mitra Mandal's College of Engineering "],
    ".mmit.edu.in": ["Marathwada Mitra Mandal's Institute of Technology"],
    ".msit.edu.in": ["Meghnad Saha Institute of Technology"],
    ".mujonline.edu.in": ["Manipal University Jaipur"],
    ".mvit.edu.in": ["Manakula Vinayagar Institute of Technology", "MVIT"],
    ".mvn.edu.in": ["MVN University Palwal, India"],
    ".nalanda.edu.in": ["Nalanda Vidya Niketan"],
    ".nec.edu.in": ["National Engineering College"],
    ".nitk.edu.in": ["National Institute of Technology Karnataka"],
    ".niu.edu.in": ["Noida International University (NIU)"],
    ".pccegoa.edu.in": ["Padre Conceicao College of Engineering, Verna"],
    ".pec.edu.in": [
        '"Punjab Engineering College (Deemed to be university) Chandigarh"'
    ],
    ".plaksha.edu.in": ["Plaksha University"],
    ".rajagiri.edu.in": ["Rajagiri School of Engineering and Technology"],
    ".rajalakshmi.edu.in": ["RAJALAKSHMI ENGINEERING COLLEGE"],
    ".cit.reva.edu.in": ["Reva University"],
    ".reva.edu.in": ["REVA University"],
    ".ritchennai.edu.in": ["Rajalakshmi Instiute Of Technology"],
    ".eng.rizvi.edu.in": ["eng.rizvi.edu.in"],
    ".rvce.edu.in": ["R V College of Engineering"],
    ".sahyadri.edu.in": ["Sahyadri College of Engineering and Management"],
    ".sairamtap.edu.in": ["Sri SaiRam Institute Of Technology"],
    ".sandipuniversity.edu.in": ["Sandip University"],
    ".sanjivani.edu.in": ["Sanjivani University"],
    ".sbjit.edu.in": [
        "S. B. Jain Institute of Technology, Management & Research, Nagpur"
    ],
    ".gst.sies.edu.in": ["South Indian Education Society (sies)"],
    ".sitpune.edu.in": ["Symbiosis Institute of Technology, Pune"],
    ".sittechno.edu.in": [
        "Siliguri Institute of Technology (SIT), West Bengal",
        "Siliguri Institute of Technology (SIT), West Bengal",
    ],
    ".sithyd.siu.edu.in": ["sithyd.siu.edu.in"],
    ".sitnagpur.siu.edu.in": ["Symbiosis Institute of Technology"],
    ".sjcem.edu.in": ["St John College of Engineering and Management"],
    ".skct.edu.in": ["Sri Krishna College of Technology"],
    ".skpec.edu.in": ["SKP Engineering College"],
    ".student.slsh.edu.in": ["Symbiosis Law School, Hyderabad"],
    ".smit.smu.edu.in": ["Sikkim Manipal Institute of Technology"],
    ".smude.edu.in": ["Sikkim Manipal University"],
    ".snu.edu.in": ["Shiv Nadar University", "Shiv Nadar University"],
    ".socet.edu.in": ["Silver Oak College"],
    ".sowdambikaengg.edu.in": ["Sree Sowdambika College of Engineering"],
    ".sreenidhi.edu.in": ["Sreenidhi Institute of Science and Technology "],
    ".srkrec.edu.in": [
        "Sagi Rama Krishnam Raju Engineering College",
        "SRKR Engineering college",
    ],
    ".srmap.edu.in": ["SRM University, AP - Amaravati", "SRM AP"],
    ".srmist.edu.in": ["SRM Institute of Science and Technology"],
    ".srmuniv.edu.in": ["SRM University"],
    ".it.ssn.edu.in": ["SSN College of Engineering"],
    ".ssn.edu.in": ["Sri Sivasubramaniya Nadar College of Engineering"],
    ".sushantuniversity.edu.in": ["Sushant University"],
    ".svce.edu.in": ["Sri Venkateswara College of engineering"],
    ".svvv.edu.in": [
        "Shri Vaishnav Vidyapeeth Vishwavidyalaya, Indore",
        "Shri Vaishnav Institute of Technology and Science, Indore",
    ],
    ".sxca.edu.in": ["St. Xavier's College, Ahmedabad"],
    ".sxcce.edu.in": [
        "St. Xavier's Catholic College of Engineering, Nagercoil"
    ],
    ".taywadecollege.edu.in": ["Taywade College", "Taywade College"],
    ".tecb.edu.in": ["Techno Institute of Engineering and Management"],
    ".tib.edu.in": ["Techno International Batanagar"],
    ".vcet.edu.in": ["Vidyavardhini's college of engineering and technology"],
    ".velammalitech.edu.in": [
        "Velammal Institute of Technology",
        "Velammal Institute of Technology",
    ],
    ".vemanait.edu.in": [
        "Vemana Institute of Technology",
        "Vemana Institute of Technology",
    ],
    ".vipstc.edu.in": ["Vivekananda Institute of Professional Studies"],
    ".vishnu.edu.in": ["Vishnu Institute of Technology"],
    ".vit.edu.in": [
        "Vidyalankar Institute Of Technology,Mumbai",
        "Vidyalankar Institute Of Technology,Mumbai",
    ],
    ".iimahd.ernet.in": ["Indian Institute of Management, Ahmedabad"],
    ".iimb.ernet.in": ["Indian Institute of Management - Bangalore"],
    ".iisc.ernet.in": ["Indian Institute of Science"],
    ".iitd.ernet.in": ["Indian Institute of Technology - Delhi"],
    ".iitg.ernet.in": ["Indian Institute of Technology - Guwahati"],
    ".iitkgp.ernet.in": ["Indian Institute of Technology Kharagpur"],
    ".iitr.ernet.in": ["Indian Institute of Technology - Roorkee"],
    ".tezu.ernet.in": ["Tezpur University"],
    ".gitam.in": ["GITAM University"],
    ".gnkc.in": ["Guru Nanak Khalsa College"],
    ".doe.delhi.gov.in": ["Govt. Boys Sr. Sec. School, New Usmanpur, Delhi"],
    ".greatlakes.in": ["Great Lakes Institute of Management"],
    ".hetic.in": ["HETIC-India"],
    ".hindustanschools.in": [
        "Hindustan International School",
        "Hindustan International School",
        "https://hindustanschools.in/",
    ],
    ".igib.in": ["CSIR Institute of Genomics and Integrative Biology"],
    ".iiits.in": [
        "Indian Institute of Information Technology, Sri City",
        "Indian Institute of Information Technology, Bangalore",
    ],
    ".iict.indusuniversity.in": [
        "Institute of Information & Communication Technology, Ahmedabad"
    ],
    ".iite.indusuniversity.in": ["Indus University", "Indus University"],
    ".itmgoi.in": ["Institute of Technology and Management, Gwalior"],
    ".itmgwalior.in": ["Institute of Technology & Management, Gwalior"],
    ".itmvu.in": ["ITM Vocational University"],
    ".jadavpuruniversity.in": ["Jadavpur University"],
    ".jssstuniv.in": ["JSS Science And Technology University, Mysore, India"],
    ".juetguna.in": [
        "Jaypee University of Engineering and Technology",
        "JUET, Guna",
        "juet.ac.in",
    ],
    ".juitsolan.in": [
        "jaypee university of information technology , solan , himachal pradesh "
    ],
    ".jyotinivas.in": [
        "Jyoti Nivas College Autonomous",
        "Jyoti Nivas College Autonomous",
    ],
    ".kazirangauniversity.in": ["Kaziranga University"],
    ".kitcoek.in": [
        "Kolhapur Institue of Technology's College of Engineering, Kolhapur",
        "Kolhapur Institue of Technology's College of Engineering, Kolhapur",
    ],
    ".kluniversity.in": ["KL University"],
    ".kmmc.in": ["KM College of Music & Technology"],
    ".kvberhampur.in": ["Kendriya Vidyalaya Brahmapur"],
    ".kvsrodelhi.in": ["Kendriya Vidyalaya Sangathan"],
    ".kvsroguwahati.in": ["kendriya Vidyalaya Namrup"],
    ".ladybirdschool.in": ["Ladybird Public School"],
    ".lpu.in": ["Lovely Professional University"],
    ".ltce.in": ["Lokmanya Tilak College of Engineering"],
    ".mcet.in": [
        "Dr.Mahalingam College of Engineering and Technology, Pollachi."
    ],
    ".mcka.in": ["Marian College"],
    ".mespune.in": ["MES's IMCC"],
    ".micamail.in": ["MICA"],
    ".mietjammu.in": ["miet jammu"],
    ".mitmysore.in": ["Maharaja Institute of Technology Mysore"],
    ".mrce.in": ["Malla Reddy College of Engineering"],
    ".msajce-edu.in": ["Mohamed Sathak A.J college of engineering"],
    ".msit.in": ["Maharaja Surajmal Institute of Technology"],
    ".mspvl.in": [
        "MSP Velayutha Nadar Lakshmithaiammal Polytechnic College, Pavoorchatram"
    ],
    ".mssw.in": ["Madras School of Social Work"],
    ".mtmcollege.in": ["MTM Arts, Science and commerce of India"],
    ".gkmims.net.in": ["GKM institute of marine sciences and technology"],
    ".gniot.net.in": ["GREATER NOIDA INSTITUTE OF TECHNOLOGY"],
    ".iimtindia.net.in": ["IIMT"],
    ".nsit.net.in": ["Netaji Subhas Institute of Technology"],
    ".saicloudschool.net.in": ["SAI International School"],
    ".theheritageschool.net.in": ["The Heritage School"],
    ".uktech.net.in": ["Uttarakhand Technical University"],
    ".niituniversity.in": ["NIIT UNIVERSITY"],
    ".nmamit.in": ["NMAM Institute of Technology"],
    ".nmims.in": [],
    ".nsitonline.in": ["Netaji Subhas Institute of Technology"],
    ".dpsn.org.in": ["Delhi Public School Newtown"],
    ".gcetjammu.org.in": ["Government College of Engineering & Technology"],
    ".git.org.in": ["Gandhinagar Institute of Technology"],
    ".global.org.in": ["Global Nature Care Sangathan Group of Institution"],
    ".hsct.org.in": ["High School of Computer and Technology"],
    ".ipec.org.in": ["Inderprastha Engineering College"],
    ".msec.org.in": ["Mohamed Sathak Engineering College"],
    ".pravaraengg.org.in": ["Pravara Rural Engineering College"],
    ".rcciit.org.in": ["RCC Institute of Information Technology"],
    ".sanjivanicoe.org.in": [
        "Sajivani College of Engineering,Kopargaon",
        "Sajivani College of Engineering,Kopargaon",
    ],
    ".sce.org.in": ["Shivalik College of Engineering Dehradun"],
    ".siem.org.in": ["Sandip Institue Of Engineering And Management Nashik"],
    ".sitcoe.org.in": [
        "Sharad Institute of Technology College of Engineering, Ichalkaranji (Kolhapur)"
    ],
    ".skit.org.in": ["Sri Krishna Institute of Technology, Bengaluru"],
    ".svhce.org.in": [
        "Daita Madhusudana Sastry Sri Venkateswara Hindu College of Engineering, Machilipatnam "
    ],
    ".ovan.in": ["Odisha Vidyapeeth Academic Nexus"],
    ".pathways.in": ["Pathways World School Aravali"],
    ".pbis.in": ["Pushpalata British International School"],
    ".pccoer.in": [
        "Pimpri Chinchwad College of Engineering and Research , Ravet , Pune"
    ],
    ".pgmozecoepune.in": ["Parvatibai Genba Moze College of Engineering Pune"],
    ".presidencyuniversity.in": ["Presidency University"],
    ".puibm.in": [
        "IBM-Innovation Centre for Education, People's University, Bhopal (MP)"
    ],
    ".quantumeducation.in": ["Quantum University", "Quantum University"],
    ".raghuenggcollege.in": ["RAGHU ENGINEERING COLLEGE"],
    ".rathinam.in": ["Rathinam College Of Arts And Science"],
    ".rbunagpur.in": ["Ramdeobaba University"],
    ".acsir.res.in": ["Academy of Scientific and Innovative Research"],
    ".csiriicb.res.in": ["CSIR-Indian Institute of Chemical Biology"],
    ".dcb.res.in": [
        "Department of Computational Biology and Bioinformatics, University of Kerala"
    ],
    ".hri.res.in": ["Harish-Chandra Research Institute"],
    ".iiap.res.in": ["Indian Institute of Astrophysics "],
    ".iicb.res.in": ["CSIR-Indian Institute of Chemical Biology"],
    ".ils.res.in": ["DBT- Institute of Life Sciences, India"],
    ".imsc.res.in": ["The Institute of Mathematical Sciences Chennai "],
    ".ipr.res.in": ["Institute for Plasma Research"],
    ".ncbs.res.in": ["The National Centre for Biological Sciences (NCBS)"],
    ".tifr.res.in": ["Tata Institute of Fundamental Research"],
    ".ruob.in": ["Rashtriya Uchcha Open Bharatiya Vishwavidyalaya"],
    ".sageuniversity.in": ["SAGE University indore"],
    ".satiengg.in": ["Samrat Ashok Technological Institute"],
    ".sbcemail.in": [
        "sree buddha collage of engineering",
        "sree buddha collage of engineering",
    ],
    ".sdmit.in": [
        "Sri Dharmasthala Manjunatheshwara Institute of Technology",
        "SDM Institute of Technology",
    ],
    ".sgsitsindore.in": [
        "Shri Govindram Seksaria Institute of Technology and Science"
    ],
    ".siom.in": ["Symbiosis Institute of Operations Management"],
    ".sjissonipat.in": [
        "Shreejee International School",
        "Shreejee International School",
    ],
    ".sjmsom.in": ["Shailesh J. Mehta School of Management"],
    ".slrtce.in": ["Shree LR Tiwari College of Engineering"],
    ".snuindia.in": [
        "Sister Nivedita University",
        "Sister Nivedita University",
    ],
    ".sode-edu.in": [
        "Shri Madhwa Vadiraja Institute of Technology and Management"
    ],
    ".svims.in": ["Swami Vivekananda Institute of Modern Science"],
    ".svisss.in": ["Sri Venkateshwara International Senior Secondary School"],
    ".sxconlineclass.in": ["St. Xavier's College(Autonomous), Kolkata"],
    ".tcetmumbai.in": ["Thakur College of Engineering and Technology"],
    ".teamfuture.in": [
        "Future Institute of Engineering and management, Sonarpur, Kolkata"
    ],
    ".terii.in": [
        "TECHNOLOGY EDUCATION AND RESEARCH INTEGRATED INSTITUTE",
        "TECHNOLOGY EDUCATION AND RESEARCH INTEGRATED INSTITUTE",
    ],
    ".theglocaluniversity.in": ["Glocal University"],
    ".timscdrmumbai.in": [
        "Thakur Institute of Management Studies, Career Development & Research"
    ],
    ".tnu.in": ["THE NEOTIA UNIVERSITY"],
    ".uoen.in": [
        "Ushas-Odanta Engineering & Technology University, Northern Region"
    ],
    ".uudoon.in": ["Uttaranchal University"],
    ".veckavali.in": ["Visvodaya Engineering College"],
    ".vipsedu.in": ["Vivekananda Institute of Professional Studies"],
    ".vitbstudent.in": [
        "VIT University, Bangalore",
        "VIT Bangalore",
        ".group",
        "The official website of VIT Bangalore: https://vitbangalore.in/",
    ],
    ".vnrvjiet.in": ["VNR Vignana Jyothi Inst. of Eng. and Tech."],
    ".ycce.in": [
        "Yeshwantrao Chavan College of Engineering (YCCE), Nagpur",
        "Yeshwantrao Chavan College of Engineering (YCCE), Nagpur",
    ],
    ".128sou-sofia.info": [
        '128 СУ "Алберт Айнщайн"',
        "\x00",
        '\x00"\x00A\x00l\x00b\x00e\x00r\x00t\x00 \x00E\x00i\x00n\x00s\x00t\x00e\x00i\x00n\x00"\x00 \x00S\x00e\x00c\x00o\x00n\x00d\x00a\x00r\x00y\x00 \x00s\x00c\x00h\x00o\x00o\x00l\x00',
    ],
    ".blathy.info": ["\ufeffBláthy Ottó Titusz Informatikai Szakközépiskola"],
    ".bsregen.info": ["Fachoberschule Regen", "FOS Regen"],
    ".cfvw-gymnasium.info": [
        "Carl Friedrich von Weizsäcker-Gymnasium, Ratingen"
    ],
    ".diit.info": ["Daffodil Institute of Information & Technology"],
    ".dronacharya.info": ["DRONACHARYA COLLEGE OF ENGINEERING"],
    ".eci-liege.info": ["ECI - École de commerce et d'informatique"],
    ".egressy.info": [
        "Budapesti Műszaki Szakképzési Centrum Egressy Gábor Két Tanítási Nyelvű Technikum"
    ],
    ".fshnstudent.info": [
        "Faculty of Natural Sciences at University of Tirana"
    ],
    ".glenrosetigers.info": ["Glen Rose High School"],
    ".groupe-aen.info": ["Groupe AEN"],
    ".gyfa.info": ["Gymnasium Fallersleben"],
    ".gymsob.info": ["Gymnasium Schrobenhausen"],
    ".gymviechtach.info": ["Dominicus-von-Linprun-Gymnasium Viechtach"],
    ".hf-ict.info": [
        "Höhere Fachschule für Informations- und Kommunikationstechnologie"
    ],
    ".infomila.info": ["Milà i Fontanals"],
    ".kdfg.info": ["Kispesti Deák Ferenc Gimnázium"],
    ".ltioanjebelean.info": [
        'Liceul Teoretic "Ioan Jebelean"',
        '"Ioan Jebelean" Theoretical High School',
    ],
    ".mksumdu.info": [
        "Машинобудівний фаховий коледж Сумського державного університету",
        "Machine building professional college of Sumy State University",
    ],
    ".oldcolony.info": [
        "Old Colony Regional Vocational Technical High School"
    ],
    ".ozenne.info": ["ozenne", "Ozenne general and technological high school"],
    ".phw.info": ["Fachhochschule Pur"],
    ".pmit.info": ["Chernivtsi Polytechnic College"],
    ".raharja.info": ["Perguruan Tinggi Raharja"],
    ".sgma.info": [
        "Smolensk State Medical Academy",
        "Smolensk State Medical Academy",
    ],
    ".southern-bd.info": ["Southern University Bangladesh"],
    ".turgot-paris.info": [
        "Lycée TURGOT - BTS SIO",
        "TURGOT high school - SIO higher technician certificate (IT services to organizations)",
    ],
    ".ucrso.info": [
        "Universidad de Costa Rica, Sede Occidente",
        "University of Costa Rica, Western Headquarters",
    ],
    ".untagcirebon.info": ["Universitas 17 Agustus 1945 Cirebon"],
    ".usfx.info": ["Universidad San Francisco Xavier"],
    ".whsg.info": ["Westcliff Highschool for Girls"],
    ".edu.dsti.institute": ["Data ScienceTech Institute (DSTI) "],
    ".immune.institute": ["IMMUNE Technology Institute"],
    ".ispring.institute": ["Институт iSpring", "iSpring Institute"],
    ".3wa.io": ["3w Academy"],
    ".csie.io": ["國立中正大學", "National Chung Cheng University"],
    ".itgen.io": ["Айтигенио", "Itgenio"],
    ".laplateforme.io": ["LaPlatforme Coding School"],
    ".oclock.io": ["Ecole O'clock"],
    ".qwasar.io": ["Qwasar Silicon Valley"],
    ".albayan.edu.iq": ["Al-Bayan University"],
    ".alfarabiuc.edu.iq": [
        "كلية الفارابي الجامعة",
        "Al-Farabi University College",
    ],
    ".alkafeel.edu.iq": ["جامعة الكفيل", "University of Alkafeel"],
    ".almaaqal.edu.iq": [
        "جامعة المعقل الدولية",
        "Almaaqal International University",
        "Almaaqal Private University",
        "جامعة المعقل الاهلية",
        "AMIU",
    ],
    ".alrasheedcol.edu.iq": [
        "كلية الرشيد الجامعة",
        "Al Rasheed University Collage",
    ],
    ".alsafwa.edu.iq": ["AlSafwa University College"],
    ".alshaab.edu.iq": ["AlShaab University"],
    ".atu.edu.iq": [
        "Al Furat Al-Awsat Technical University",
        "Al Furat Al-Awsat Technical University",
    ],
    ".auib.edu.iq": ["The American University of Iraq - Baghdad"],
    ".baghdadcollege.edu.iq": [
        "Baghdad College of Economic Sciences University"
    ],
    ".chu.edu.iq": ["Charmo univeristy"],
    ".cihanuniversity.edu.iq": ["Cihan University"],
    ".coie-nahrain.edu.iq": [
        "coie-nahrain",
        "Al Nahrain University college of information  engineering ",
    ],
    ".duc.edu.iq": ["Dijlah University College", "Dijlah University College"],
    ".epu.edu.iq": ["ERBIL POLYTECHNIC UNIVERSITY"],
    ".esraa.edu.iq": ["Esraa University", "https://www.esraa.edu.iq/"],
    ".huc.edu.iq": ["كلية الهادي الجامعة", "Al-Hadi University College"],
    ".knu.edu.iq": ["Knowledge University", "Knowledge University"],
    ".komar.edu.iq": ["Komar University of Science and Technology"],
    ".mtu.edu.iq": ["الكلية التقنية الوسطى", "Middle Technical University"],
    ".muc.edu.iq": ["Mansour University College"],
    ".mustaqbal-college.edu.iq": ["Al mustaqbal College"],
    ".nahrainuniv.edu.iq": ["Al Nahrain University"],
    ".ntu.edu.iq": ["Northern technical university, Iraq"],
    ".nuc.edu.iq": ["Al-Nisour University College"],
    ".qu.edu.iq": ["جامعة القادسية ", "Qadisiyah University"],
    ".soran.edu.iq": ["Soran University"],
    ".spu.edu.iq": ["Sulaimaniya Polytechnic University"],
    ".tiu.edu.iq": [" Tishk International University (TIU)"],
    ".uhd.edu.iq": ["Univercity of human development", "UHD"],
    ".uniq.edu.iq": ["Qaiwan International University - UTM Franchise"],
    ".univsul.edu.iq": ["University of Sulaimani"],
    ".uoanbar.edu.iq": ["University of Anbar"],
    ".uob.edu.iq": ["University of Baghdad"],
    ".uobabylon.edu.iq": ["Uinversity of Babylon"],
    ".uobaghdad.edu.iq": ["University of Baghdad"],
    ".uobasrah.edu.iq": ["University of Basrah"],
    ".uodiyala.edu.iq": ["Diyala University"],
    ".uog.edu.iq": ["زانکۆی گۆیژە", "University College of Goizha"],
    ".uoh.edu.iq": ["University of Halabja"],
    ".uoitc.edu.iq": [
        "University of Information Technology and Communications"
    ],
    ".uokerbala.edu.iq": ["Kerbala University"],
    ".uokirkuk.edu.iq": ["University of Kirkuk"],
    ".uokufa.edu.iq": ["University of Kufa"],
    ".uomisan.edu.iq": ["Misan University"],
    ".uomosul.edu.iq": ["University of Mosul"],
    ".uomustansiriyah.edu.iq": ["University of Mustansiriyah"],
    ".stu.uoninevah.edu.iq": [
        "University Of Ninevah",
        "College Of Information Technology",
    ],
    ".uotechnology.edu.iq": ["University of Technology - Iraq"],
    ".uowa.edu.iq": ["University of Warith Alanbiyaa"],
    ".uowasit.edu.iq": ["University of Wassit"],
    ".uruk.edu.iq": ["uruk university"],
    ".utq.edu.iq": ["University of Thi-Qar", "جامعة ذي قار"],
    ".acmt.ac.ir": ["Amirkabir College of Managmant &amp; Technology"],
    ".adiban.ac.ir": ["Adiban Higher Education Institue"],
    ".ajums.ac.ir": ["Ahwaz Jondishapour University of Medical Sciences"],
    ".aliabadiau.ac.ir": ["Islamic Azad University, Aliabad "],
    ".arakmu.ac.ir": ["Arak University of Medical Sciences"],
    ".araku.ac.ir": ["Arak University"],
    ".art.ac.ir": ["Art University"],
    ".arums.ac.ir": ["Ardabil University of Medical Sciences"],
    ".atu.ac.ir": ["Allameh Tabatabaie University"],
    ".aut.ac.ir": ["Amirkabir University of Technology"],
    ".azad.ac.ir": ["Islamic Azad University, Tehran South"],
    ".basu.ac.ir": ["Bu Ali Sina University"],
    ".birjand.ac.ir": ["Birjand University"],
    ".bmsu.ac.ir": ["Baghyatoolah Medical Sciences University"],
    ".bojnourdiau.ac.ir": ["Islamic Azad University, Bojnourd"],
    ".bpums.ac.ir": ["Bushehr University of Medical Sciences"],
    ".bums.ac.ir": ["Birjand University of Medical Sciences"],
    ".fasau.ac.ir": ["Fasa University"],
    ".fums.ac.ir": ["Fasa Faculty of Medical Sciences"],
    ".gau.ac.ir": [
        "Gorgan University of Agricultural Sciences and Natural Resources"
    ],
    ".gmu.ac.ir": ["Gonabad University of Medical Sciences"],
    ".goums.ac.ir": ["Golestan University of Medical Sciences"],
    ".guilan.ac.ir": ["Guilan University"],
    ".gums.ac.ir": ["Guilan University of Medical Sciences"],
    ".hormozgan.ac.ir": ["University of Hormozgan"],
    ".hums.ac.ir": ["Hormozgan University of Medical Sciences"],
    ".iasbs.ac.ir": [
        "Zanjan Institute for Advanced Studies in Basic Sciences"
    ],
    ".iau-ahar.ac.ir": ["Islamic Azad University, Ahar"],
    ".iau-arak.ac.ir": ["Islamic Azad University, Arak"],
    ".iau-boukan.ac.ir": ["Islamic Azad University, Boukan"],
    ".iau-garmsar.ac.ir": ["Islamic Azad University, Garmsar"],
    ".iau-saveh.ac.ir": ["Islamic Azad University, Saveh"],
    ".iau-shahrood.ac.ir": ["Islamic Azad University, Shahrood"],
    ".iau-shirvan.ac.ir": ["Islamic Azad University, Shirvan"],
    ".iau-tnb.ac.ir": ["Islamic Azad University, North Tehran"],
    ".iauardabil.ac.ir": ["Islamic Azad University, Ardabil"],
    ".iauba.ac.ir": ["Islamic Azad University, Bandar Abbas"],
    ".iaubos.ac.ir": ["Islamic Azad University, Bostanabad"],
    ".iauctb.ac.ir": ["Islamic Azad University, Central Tehran Branch"],
    ".iauh.ac.ir": ["Islamic Azad University, Hamedan"],
    ".iauk.ac.ir": ["Islamic Azad University, Kerman"],
    ".iaumajlesi.ac.ir": ["Islamic Azad University, Majlesi"],
    ".iaun.ac.ir": ["Islamic Azad University, Najaf Abad"],
    ".iauq.ac.ir": ["Islamic Azad University, Quchan"],
    ".iausdj.ac.ir": ["Islamic Azad University, Sanandaj"],
    ".iaushab.ac.ir": [
        "Azad University of Shabestar",
        "Islamic Azad University, Shabestar",
    ],
    ".iaushiraz.ac.ir": ["Islamic Azad University, Shiraz"],
    ".iausr.ac.ir": ["Islamic Azad University, Shahr-e-rey Branch"],
    ".iaut.ac.ir": ["Islamic Azad University, Tabriz"],
    ".iautb.ac.ir": ["Islamic Azad University, Tafresh"],
    ".iautmu.ac.ir": ["Islamic Azad University, Tehran Medical"],
    ".iauvaramin.ac.ir": ["Islamic Azad University, Varamin"],
    ".iauyazd.ac.ir": ["Islamic Azad University, Yazd"],
    ".ikiu.ac.ir": ["Imam Khomeini International University"],
    ".ilam.ac.ir": ["Ilam University"],
    ".imamreza.ac.ir": ["Imam Reza University"],
    ".isu.ac.ir": ["Imam Sadiq University"],
    ".iums.ac.ir": ["Iran University of Medical Sciences"],
    ".iut.ac.ir": ["Isfahan University of Technology"],
    ".jami.ac.ir": ["Jami Institute of Technology"],
    ".jums.ac.ir": ["Jahrom University of Medical Sciences"],
    ".kashanu.ac.ir": ["Kashan University"],
    ".kau.ac.ir": ["Islamic Azad University, Kazeron"],
    ".khu.ac.ir": ["Kharazmi University of Tehran"],
    ".khuisf.ac.ir": ["Islamic Azad University, Khorasgan"],
    ".kiau.ac.ir": ["Islamic Azad University, Karaj"],
    ".kish.ac.ir": ["Sharif University of Technology, Kish Campus"],
    ".kmu.ac.ir": ["Kerman University of Medical Sciences"],
    ".kntu.ac.ir": ["K.N.Toosi University of Technology"],
    ".kums.ac.ir": ["Kermanshah University of Medical Sciences"],
    ".lu.ac.ir": ["Lorestan University"],
    ".lums.ac.ir": ["Lorestan University of Medical Sciences"],
    ".malayeru.ac.ir": ["Malayer University"],
    ".mamasaniiau.ac.ir": ["Mamasani University of Technology"],
    ".mau.ac.ir": ["Islamic Azad University, Mobarakeh"],
    ".medsab.ac.ir": ["Sabzevar School of Medical Sciences"],
    ".miu.ac.ir": ["Mustafa International University"],
    ".modares.ac.ir": ["Tarbiat Modares University"],
    ".mofidu.ac.ir": ["Mofid University"],
    ".mshdiau.ac.ir": ["Islamic Azad University, Mashhad"],
    ".mubabol.ac.ir": ["Babol University of Medical Sciences"],
    ".mui.ac.ir": ["Isfahan University of Medical Sciences"],
    ".muk.ac.ir": ["Kurdistan University of Medical Sciences"],
    ".mums.ac.ir": ["Mashhad University of Medical Sciences"],
    ".nit.ac.ir": ["Babol Noshirvani University of Technology"],
    ".pgu.ac.ir": ["Persian Gulf University"],
    ".piau.ac.ir": ["Islamic Azad University, Parand"],
    ".pnu.ac.ir": ["Payame Noor University"],
    ".pnum.ac.ir": ["University of Mashhad Pnu"],
    ".put.ac.ir": ["Petroleum University of Technology"],
    ".qom.ac.ir": ["Qom University"],
    ".qums.ac.ir": ["Qazvin University of Medical Sciences"],
    ".razi.ac.ir": ["Razi University"],
    ".rums.ac.ir": ["Rafsanjan University of Medical Sciences"],
    ".sadjad.ac.ir": ["Sadjad Institute of Technology"],
    ".sadra.ac.ir": ["Sadra University"],
    ".sbmu.ac.ir": ["Shaheed Beheshti University of Medical Sciences"],
    ".semnan.ac.ir": ["Semnan University"],
    ".semnaniau.ac.ir": ["Islamic Azad University, Semnan"],
    ".shahed.ac.ir": ["Shahed University"],
    ".shahroodut.ac.ir": ["Shahrood University of Technology"],
    ".shahryariau.ac.ir": ["Islamic Azad University, Shahryar"],
    ".shbu.ac.ir": ["Sheikhbahaee University"],
    ".shirazu.ac.ir": ["Shiraz University"],
    ".shomal.ac.ir": ["Shomal University"],
    ".sku.ac.ir": ["Shahrekord University"],
    ".skums.ac.ir": ["Shahrekord University of Medical Sciences"],
    ".spnu.ac.ir": ["Shiraz Payamnoor University"],
    ".srbiau.ac.ir": [
        "Islamic Azad University, Tehran Science &amp; Research Branch"
    ],
    ".ssu.ac.ir": ["Yazd Medical University"],
    ".sums.ac.ir": ["Shiraz University of Medical Sciences"],
    ".sut.ac.ir": ["Sahand University of Technology"],
    ".sutech.ac.ir": ["Shiraz University of Technology"],
    ".tabriziau.ac.ir": ["Tabriz Islamic Art University"],
    ".tabrizu.ac.ir": ["Tabriz University"],
    ".tbzmed.ac.ir": ["Tabriz University of Medical Sciences"],
    ".tct.ac.ir": ["Tabriz College of Technology"],
    ".tiau.ac.ir": ["Takestan Islamic Azad University"],
    ".tums.ac.ir": ["Tehran University of Medical Sciences"],
    ".uast.ac.ir": ["University of Applied Science and Technology"],
    ".ui.ac.ir": ["Isfahan University"],
    ".uk.ac.ir": ["Shahid Bahonar University of Kerman"],
    ".um.ac.ir": ["Ferdowsi University of Mashhad"],
    ".uma.ac.ir": ["University of Mohaghegh"],
    ".umsha.ac.ir": ["Hamadan University of Medical Sciences"],
    ".umsu.ac.ir": ["Urmia University of Medical Sciences"],
    ".umz.ac.ir": ["Mazandaran University of Iran"],
    ".uok.ac.ir": ["University of Kurdistan"],
    ".uoz.ac.ir": ["Zabol University"],
    ".urmia.ac.ir": ["Urmia University"],
    ".usb.ac.ir": ["Sistan &amp; Balouchestan University"],
    ".usc.ac.ir": ["University of Science and Culture"],
    ".ustmb.ac.ir": ["Mazandaran University of Science &amp; Technology"],
    ".uswr.ac.ir": [
        "University of Social Welfare and Rehabilitation Scinences"
    ],
    ".ut.ac.ir": ["University of Tehran"],
    ".uut.ac.ir": ["Urmia University of Technology"],
    ".vru.ac.ir": ["Vali-e-Asr University"],
    ".yu.ac.ir": ["Yasuj University"],
    ".yums.ac.ir": ["Yasuj University of Medical Sciences"],
    ".znu.ac.ir": ["Zanjan University"],
    ".zums.ac.ir": ["Zanjan University of Medical Sciences"],
    ".hbi.ir": ["Ilam University of Medical Sciences"],
    ".mrl-spl.ir": [
        "Mechatronics Research Laboratory, Islamic Azad University, Qazvin"
    ],
    ".bifrost.is": ["Bifrost School of Business"],
    ".fnv.is": ["Fjölbrautaskóli Norðurlands Vestra"],
    ".fss.is": ["Fjölbrautaskóli Suðurnesja"],
    ".hi.is": ["University of Iceland"],
    ".holar.is": ["Holar University College"],
    ".hsvest.is": ["University Centre of the Westfjords"],
    ".hvanneyri.is": ["Hvanneyri Agricultural University"],
    ".iti.is": ["Technological University of Iceland"],
    ".khi.is": ["Iceland University of Education"],
    ".lhi.is": ["Iceland Academy of the Arts"],
    ".ru.is": ["Reykjavík University"],
    ".tskoli.is": ["Tækniskólinn"],
    ".unak.is": ["University of Akureyri"],
    ".42firenze.it": ["42 Firenze", "42 Firenze Luiss", "42 Florence"],
    ".42roma.it": ["42 Roma Luiss", "42 Roma", "42 Rome"],
    ".ababrera.it": ["Accademia di Belle Arti di Brera, Milan, Italy"],
    ".studenti.abana.it": ["Accademia Belle Arti di Napoli"],
    ".studenti.abaroma.it": ["Accademia Belle Arti Di Roma"],
    ".accademiabari.it": ["Accademia di Belle Arti di Bari"],
    ".accademiasantagiulia.it": [
        "Accademia Di Belle Arti di Santa Giulia",
        "SantaGiulia Fine Arts Academy",
    ],
    ".afolmb.it": [
        "Centro Formazione Professionale Giuseppe Terragni - AFOL Monza Brianza, Via Tre Venezie 63, 20821 Meda (MB) Italia",
        "CFP Giuseppe Terragni Vocational Training Center - AFOL Monza Brianza, Via Tre Venezie 63, 20821 Meda (MB), Italy",
    ],
    ".afolmonzabrianza.it": [
        "Centro Formazione Professionale Giuseppe Terragni - AFOL Monza Brianza, Via Tre Venezie 63, 20821 Meda (MB) Italia",
        "CFP Giuseppe Terragni Vocational Training Center - AFOL Monza Brianza, Via Tre Venezie 63, 20821 Meda (MB), Italy",
    ],
    ".studenti.alberghetti.it": ["Alberghetti IIS"],
    ".alcampus.it": [
        "Università Campus Bio-Medico di Roma",
        "Campus Bio-Medico University of Rome",
        "https://www.unicampus.it/",
    ],
    ".studenti.apuliadigitalmaker.it": ["ITS Apulia Digital Maker"],
    ".avbo.it": ["Aldini Valeriani", "Aldini Valeriani"],
    ".bearzi.it": ['Istituto Tecnico Industriale "G. Bearzi", Udine'],
    ".belluzzifioravanti.it": ["IIS Belluzzi Fioravanti"],
    ".bertacchi.it": [
        'ISTITUTO ISTRUZIONE SUPERIORE - "G. BERTACCHI" LECCO',
        'HIGHER EDUCATION INSTITUTE - "G. BERTACCHI" LECCO',
    ],
    ".itis.biella.it": ["ITIS Q. SELLA"],
    ".bigrock.it": [
        "BigRock",
        "Computer Graphics Concept Art and Coding School",
    ],
    ".luxemburg.bo.it": [
        "Istituto Tecnico Commerciale Statale Rosa Luxemburg"
    ],
    ".chilesotti.it": ["ITT G. Chilesotti"],
    ".ciusa.it": ["Istituto Istruzione Superiore Francesco Ciusa"],
    ".cnr.it": [
        "Consiglio Nazionale delle Ricerche",
        "(Italian) National Research Council",
    ],
    ".cobianchi.it": ["IIS L. Cobianchi"],
    ".consalerno.it": [
        'Conservatorio di Musica "G. Martucci", Salerno (Italia)'
    ],
    ".consaq.it": [
        'Conservatorio di Musica "A. Casella" - L\'Aquila - Italia',
        'Conservatory of Music "A. Casella" - L\'Aquila - Italy',
    ],
    ".conservatoriocosenza.it": [
        'Conservatorio di Musica "Stanislao Giacomantonio" Cosenza'
    ],
    ".conservatoriosantacecilia.it": [
        'Conservatorio statale di Musica di Roma "Santa Cecilia"',
        'Public conservatory of music in Rome "Santa Cecilia"',
    ],
    ".consfi.it": [
        "Conservatorio di Musica Luigi Cherubini di Firenze, Italia",
        "Conservatory of Music Luigi Cherubini of Florence, Italy",
    ],
    ".dad.constp.it": ["Conservatorio Antonio Scontrino"],
    ".consvi.it": [
        "Conservatorio di Musica di Vicenza Arrigo Pedrollo, Italia",
        "Conservatory of Music Arrigo Pedrollo of Vicenza, Italy",
        "https://www.consvi.it/",
        "https://www.consvi.it/studenti/site/it/corsi_accademici_dettaglio/id_2261_corso_musica-elettronica-triennio.html",
    ],
    ".copernicopasoli.it": ["Copernico Pasoli"],
    ".cref.it": ["Centro Ricerche Enrico Fermi"],
    ".curiepergine.it": ['Istituto di istruzione "Marie Curie"'],
    ".davincifascetti.it": ["I.I.S L. da Vinci - Fascetti"],
    ".dbgameacademy.it": [
        "Digital Bros Game Academy",
        "Digital Bros Game Academy",
    ],
    ".didamatteifortunato.it": ["IIS Mattei-Fortunato"],
    ".donboscoborgo.it": ["Liceo Economico Sociale / Collegio Don Bosco"],
    ".donboscosandona.it": ["CFP don Bosco"],
    ".1circolopozzuoli.edu.it": [
        "I Circolo Didattico G. Marconi",
        "I Circolo Didattico G. Marconi",
    ],
    ".alessandrinimainardi.edu.it": ["E.ALESSANDRINI - MAINARDI"],
    ".antonioscarpa.edu.it": [
        "IS. A. Scarpa, Motta di Livenza (TV)",
        "ITIS A. Scarpa, Motta di Livenza (TV)",
    ],
    ".archimede.edu.it": [
        "IIS Archimede",
        "San Giovanni in Persiceto",
        "https://www.archimede.edu.it/",
    ],
    ".avoltapg.edu.it": [
        "Istituto Tecnico Tecnologico Statale Alessandro Volta Perugia",
        "State Technical Institute of Technology Alessandro Volta Perugia",
    ],
    ".bacheleteinstein.edu.it": ["I.I.S. EINSTEIN-BACHELET"],
    ".barsanti.edu.it": [
        "ITT E. Barsanti Castelfranco Veneto",
        "ITT E. Barsanti Castelfranco Veneto",
    ],
    ".barsantigalilei.edu.it": ["I.I.S. Barsanto Galilei"],
    ".battaglini.edu.it": [" Liceo Scientifico di Stato G. Battaglini"],
    ".boscardin.edu.it": ["IIS S. Bertilla Boscardin"],
    ".branchina.edu.it": ["ISTITUTO TECNICO STATALE Pietro Branchina"],
    ".calvino.edu.it": ["Istituto Italo Calvino"],
    ".capellinisauro.edu.it": [
        "Istituto di Istruzione Superiore G. Capellini N. Sauro"
    ],
    ".cesaris.edu.it": [
        "IIS Cesaris",
        'School (Istituto Istruzione Superiore "A.Cesaris")',
        "https://www.cesaris.edu.it/",
    ],
    ".convittonovara.edu.it": ['Liceo Scientifico "Carlo Alberto"'],
    ".corridoni-campana.edu.it": ["Istituto Ñorridoni Ñampana"],
    ".davinciagherbino.edu.it": ['IIS "Da Vinci – Agherbino", Noci (BA)'],
    ".davinciliceo.edu.it": [
        "Liceo Leonardo da Vinci",
        " Via Cavour, 6 - 40033 Casalecchio di Reno • Via Panfili, 17/3 - 40133 Bologna",
        " Tel: Sede Cavour: 051 591868 • fax 051 6130834 • Sede Panfili: 051 6194857• fax 051 3519779",
        " Email: bops080005@istruzione.it",
    ],
    ".davincimilazzo.edu.it": ["ITET Leonardo da Vinci"],
    ".deliguori.edu.it": ['I.I.S. "A. M. de\' Liguori"'],
    ".depretto.edu.it": ["ITIS De Pretto Schio"],
    ".einaudi-giordano.edu.it": [
        "Istituto Statale di Istruzione Superiore Einaudi - Giordano"
    ],
    ".euganeo.edu.it": ["Istituto di Istruzione Superiore EUGANEO (Este PD)"],
    ".fermibassano.edu.it": ["ITIS E.Fermi, Bassano del Grappa"],
    ".fermilecce.edu.it": [
        'Istituto Tecnico Industriale Statale "Enrico Fermi" - Lecce',
        'Industrial Technical Institute "Enrico Fermi" - Lecce',
    ],
    ".fermimn.edu.it": [
        "Istituto Superiore Enrico Fermi",
        "Enrico Fermi High School",
    ],
    ".ferrarismolfetta.edu.it": ["ITIS Ferraris Molfetta"],
    ".galileilivorno.edu.it": [
        "I.T.I.S. Galileo Galilei, Livorno",
        "Technical-Industrial Institute Galileo Galilei, Leghorn",
    ],
    ".galileimondragone.edu.it": [
        'Liceo Scientifico "Galileo Galilei" di Mondragone'
    ],
    ".galileiostiglia.edu.it": [],
    ".giua.edu.it": ['Istituto di Istruzione Superiore "Michele Giua"'],
    ".studenti.gobettivolta.edu.it": ["I.S.I.S P.Gobetti-A.Volta"],
    ".guidodonegani.edu.it": [
        "Istituto Tecnico Industriale Guido Donegani",
        "technical institute Industrial Guido Donegani",
    ],
    ".ic-rosmini.edu.it": ["IC Antonio Rosmini"],
    ".ic1mandela.edu.it": [
        "Istituto Comprensivo Mandela, Mogliano Veneto, Treviso, Italy"
    ],
    ".icantenoreguaccero.edu.it": ["Antenore Guaccero"],
    ".icdefinetti.edu.it": ["Istituto Comprensivo Bruno De Finetti"],
    ".icmolassanaeprato.edu.it": ["I.C. Molassana e Prato"],
    ".icorvietobaschi.edu.it": ["IC Orvieto-Baschi"],
    ".icpieroangela.edu.it": ["IC Piero Angela "],
    ".icsavona3.edu.it": ['Istituto Comprensivo Savona 3 "G. Manzino"'],
    ".icscarlofontana.edu.it": ["ICS - CARLO FONTANA"],
    ".icsmarconipalermo.edu.it": [
        "Istituto Comprensivo Guglielmo Marconi Palermo",
        "Comprehensive Institute Guglielmo Marconi Palermo",
    ],
    ".icstoppaniseregno.edu.it": [
        "S.M.I.M. Don Milani Seregno",
        "Don Milani Secondary School Seregno",
    ],
    ".ictassolatina.edu.it": [
        "Istituto Compressivo n.5 Torquato Tasso Latina"
    ],
    ".iis-silva-ricci.edu.it": [
        'Istituto di Istruzione Superiore "Giovanni Silva - Matteo Ricci"'
    ],
    ".iisbadoni.edu.it": [
        "Istituto di Istruzione Tecnico Antonio Badoni - IIS Badoni"
    ],
    ".iisbassi.edu.it": ["IIS Martino Bassi"],
    ".iisbuonarrotiguspini.edu.it": [
        'Istituto di Istruzione Superiore "Buonarroti Volta"',
        'Higher Education Institute "Buonarroti Volta"',
    ],
    ".iiscolombo.edu.it": ['IIS "Cristoforo Colombo" - Sanremo'],
    ".iiscopernico.edu.it": [
        "IIS N.Copernico A.Carpeggiani",
        "I.S. N.Copernico A.Carpeggiani",
        "ITI N.Copernico-A.Carpeggiani",
        "IPSIA Ercole I d'Este",
        ".group",
    ],
    ".iiseinaudiscarpa.edu.it": ["IIS Einaudi - Scarpa"],
    ".iiseuclide.edu.it": [
        "Euclide (Located in Bova Marina, Italy, RC)",
        "website = https://www.iiseuclide.edu.it/web/",
    ],
    ".studenti.iisfalcone-righi.edu.it": [
        "Istituto d'Istruzione Superiore Falcone Righi, Corsico (MI) Italy"
    ],
    ".iisfalcone-righi.edu.it": [
        "Istituto d'Istruzione Superiore Falcone Righi, Corsico (MI) Italy"
    ],
    ".iisfermisacconiceciap.edu.it": [
        "Istituto Istruzione Superiore Fermi Sacconi Ceci"
    ],
    ".iisgalileivetrone.edu.it": ['I.I.S "Galilei-Vetrone"'],
    ".iisgaribaldi.edu.it": [
        'ISTITUTO DI ISTRUZIONE SUPERIORE "G.GARIBALDI"',
        'HIGHER EDUCATION INSTITUTE "G.GARIBALDI"',
    ],
    ".iislagrange.edu.it": ["I.I.S. Giuseppe Luigi Lagrange"],
    ".iismajoranamoncalieri.edu.it": ["Liceo Majorana Moncalieri"],
    ".iismeuccimattei.edu.it": ["I.I.S. A.Meucci - E.Mattei"],
    ".iispaciolobracciano.edu.it": [
        "IIS Luca Paciolo",
        "Scientific high school",
    ],
    ".iispiscopo.edu.it": ["I.I.S. Don Geremia Piscopo"],
    ".iisponti.edu.it": ["IIS Andrea Ponti of Gallarate (VA), Italy"],
    ".iisscalamandrei.edu.it": [
        'I.I.S.S. "Piero Calamandrei"',
        'I.I.S.S. "Piero Calamandrei"',
    ],
    ".iissgiuliocesare.edu.it": ['I.I.S.S. "Giulio Cesare"'],
    ".iissvoltadegemmis.edu.it": ["I.I.S.S. Volta - De Gemmis"],
    ".iisteramo.edu.it": ["IIS Alessandrini Marino"],
    ".iistommasosalvini.edu.it": [
        "Istituto d'Istruzione Superiore Tommaso Salvini",
        "Educational Institute Tommaso Salvini",
    ],
    ".iisvicodevivo.edu.it": ["Istituto Istruzione superiore Vico-De Vivo"],
    ".iisvoltapescara.edu.it": ["IIS A. Volta Pescara, Italy"],
    ".ilpitagora.edu.it": ["Il pitagora liceo scientifico RC"],
    ".alu.isfalcone.edu.it": [
        'Istituto d\'Istruzione Secondaria Superiore "Giovanni Falcone" Loano'
    ],
    ".isfermiguttuso.edu.it": ['IIS "Fermi-Guttuso" Giarre(CT) -Italy'],
    ".isfrancescoredi.edu.it": [
        "I.I.S.S Francesco Redi Paternò",
        "I.I.S.S Francesco Redi Paternò",
    ],
    ".isgalilei.edu.it": ["IS Galilei Conegliano"],
    ".isgiancardigalileiaicardi.edu.it": [
        'IIS "Giancardi Galilei Aicardi" - Alassio'
    ],
    ".isisbernocchi.edu.it": ["ITIS A. Bernocchi", "High school"],
    ".isiscorbino.edu.it": ["ISIS E. Corbino"],
    ".isisfacchinetti.edu.it": ['I.S.I.S. "C. Facchinetti"'],
    ".isismarcianise.edu.it": [
        "ISIS Ferraris-Buccini",
        "official website: https://www.isismarcianise.edu.it/ferraris_buccini/",
        "3-year course in computer science and telecommunications: https://www.isismarcianise.edu.it/ferraris_buccini/didattica/offerta-formativa/",
    ],
    ".isissacilebrugnera.edu.it": [
        "Istituto Statale Istruzione Superiore Sacile Brugnera"
    ],
    ".isisvarchi.edu.it": ["I.S.I.S. Benedetto Varchi, Montevarchi"],
    ".isisvarese.edu.it": [
        'Istituto Statale di Istruzione Superiore "Isaac Newton"'
    ],
    ".isisvirgilio.edu.it": ["ISIS Virgilio"],
    ".ismarconi.edu.it": ["Istituto Superiore Guglielmo Marconi"],
    ".isradice.edu.it": ["I.I.S.S Benedetto Radice"],
    ".isrosselliaprilia.edu.it": ["Carlo e Nello Rosselli"],
    ".istituto8marzo.edu.it": ['ISTITUTO DI ISTRUZIONE SUPERIORE "8 MARZO"'],
    ".istitutobalducci.edu.it": [
        "Istituto Statale Superiore Ernesto Balducci"
    ],
    ".istitutoberetta.edu.it": ["iiscberetta"],
    ".istitutocarducci.edu.it": ["Liceo Statele Carducci "],
    ".istitutoeuropaunita.edu.it": [
        "Istituto Istruzione Superiore Europa Unita Chivasso"
    ],
    ".istitutofortuny.edu.it": [
        "I.I.S. Mariano Fortuny",
        "I.I.S. Mariano Fortuny",
    ],
    ".istitutoinsolera.edu.it": ["IISS Filadelfo Insolera"],
    ".istitutoistruzionesuperioremarconi.edu.it": [
        'IIS "G. Marconi" - Imperia'
    ],
    ".istitutolevi.edu.it": ["Istituto di Istruzione Superiore 'Primo Levi'"],
    ".istitutomontani.edu.it": ["Istituto Tecnico Industriale Montani"],
    ".istitutomoreschi.edu.it": [
        'Istituto di Istruzione Superiore "Nicola Moreschi"',
        '"Nicola Moreschi" High School',
    ],
    ".istitutopertiniafragola.edu.it": [
        "Istituto Sandro Pertini, Afragola",
        'I.S. "S. Pertini"',
        'I.S.I.S. "S. Pertini"',
    ],
    ".istitutovolterra.edu.it": ["ITTS Vito Volterra"],
    ".itepiovene.edu.it": [
        "Istituto Tecnico “Guido Piovene”, Vicenza, Italia",
        'Technical Institute "Guido Piovene", Vicenza, Italy',
    ],
    ".iti-marconi.edu.it": ['ITST "G. Marconi" Campobasso'],
    ".itifaraday.edu.it": ['Istituto Tecnico Industriale "Michael Faraday"'],
    ".itirenatoelia.edu.it": ["I.T.I. Renato Elia"],
    ".itisarmellini.edu.it": ["ITIS G. ARMELLINI - ROMA"],
    ".itiscannizzaro.edu.it": ["ITIS Stanislao Cannizzaro"],
    ".itiscannizzarocolleferro.edu.it": [
        "ITIS Stanislao Cannizzaro, Colleferro (Roma) Italy"
    ],
    ".itiscardanopv.edu.it": [
        "ITIS G. Cardano Pavia",
        "ITIS G. Cardano Pavia",
    ],
    ".itisdalmine.edu.it": ["I.T.I. G. Marconi"],
    ".itiseveripadova.edu.it": ["ITI Franceso Severi", "ITI Franceso Severi"],
    ".itisgrassi.edu.it": [
        "===> itis 'Carlo grassi' Mechatronics\\Informatics <===",
        "- Address : VIA VERONESE 305, 10100 TORINO (TO)",
        "- official website : https://www.itisgrassi.edu.it/pvw/app/TOIT0017/pvw_sito.php",
    ],
    ".itismorselli.edu.it": [
        "itismorselli.edu.it",
        "# Istituto tecnico tecnologico Emanuele Morselli",
        "# https://www.itismorselli.edu.it/",
    ],
    ".itisothoca.edu.it": ["itis othoca"],
    ".itispolistena.edu.it": [
        'ITIS "Michele Maria Milano" DI POLISTENA (RC)',
        "ITIS MICHELE MARIA MILANO of Polistena (RC)",
    ],
    ".itisravenna.edu.it": ["ITIS N.Baldini, Ravenna"],
    ".itisriva.edu.it": ["I.T.I.S. Giulio Riva"],
    ".itisvallauri.edu.it": [
        'Istituto Tecnico Industriale Statale "G.VALLAURI"'
    ],
    ".itiszuccante.edu.it": ['ITIS "C. Zuccante", Mestre (VE)'],
    ".itive3pa.edu.it": [
        "Istituto Tecnico Industriale Vittorio Emanuele III Palermo"
    ],
    ".itivolta.edu.it": [
        "ISTITUTO TECNICO TECNOLOGICO STATALE ALESSANDRO VOLTA",
        "official website https://itivolta.edu.it",
        "Long term (3 yrs) computer science course information: https://www.itivolta.edu.it/offerta-formativa-itts-volta/",
    ],
    ".ittfedifermi.edu.it": ['ITTS "Fedi-Fermi" - Pistoia (Italy)'],
    ".ittgiorgi.edu.it": ["Istituto Tecnico Tecnologico “G. GIORGI”"],
    ".ittsrimini.edu.it": [
        "Istituto Tecnico Tecnologico Statale “O. Belluzzi – L. da Vinci”"
    ],
    ".ittsscalfaro.edu.it": ['ISTITUTO TECNICO INDUSTRIALE "E.SCALFARO"'],
    ".ittvt.edu.it": ['ITT "LEONARDO DA VINCI" - VITERBO'],
    ".liceo-severi.edu.it": ["Liceo Scientifico Francesco Severi"],
    ".liceoalbertinapoli.edu.it": [
        "Liceo Scientifico Statale Leon Battista Alberti"
    ],
    ".liceoamaldi.edu.it": [
        "Liceo Scientifico Amaldi",
        "Scientific High School Amaldi",
    ],
    ".liceoartisticomannucci.edu.it": ['Liceo artistico "Edgardo Mannucci"'],
    ".liceoaselli.edu.it": ["Liceo Aselli", "Gaspare Aselli High School"],
    ".liceoboggiolera.edu.it": ["Liceo Enrico Boggio Lera Catania"],
    ".liceobonghi-rosmini.edu.it": [
        "Liceo Bonghi-Rosmini",
        "Lyceum Bonghi-Rosmini",
    ],
    ".liceobramante.edu.it": ["liceo bramante"],
    ".liceocavour.edu.it": ["Liceo Scientifico C. Cavour"],
    ".liceochinimichelangelo.edu.it": [
        "Istituto Istruzione Superiore Chini-Michelangelo - https://www.liceochinimichelangelo.edu.it/"
    ],
    ".liceodesio.edu.it": [
        'Liceo Statale Scientifico e Classico "Ettore Majorana" Desio'
    ],
    ".liceoeinsteinmilano.edu.it": [
        "Liceo Scientifico Statale Einstein Milano"
    ],
    ".liceofardellaximenes.edu.it": ["Liceo Fardella Ximenes"],
    ".liceofedericoquercia.edu.it": [
        "Liceo Federico Querica | Marcianise CE, Italy"
    ],
    ".liceofermiaversa.edu.it": [
        "Liceo Scientifico Enrico Fermi ",
        "High School Enrico Fermi",
    ],
    ".stu.liceofermibo.edu.it": ["Liceo Enrico Fermi Bologna"],
    ".liceofracastoro.edu.it": ["Girolamo Fracastoro"],
    ".liceofrancescodassisi.edu.it": ["Francesco d'Assisi"],
    ".liceogalileicatania.edu.it": [
        "Liceo Scientifico Statale Galileo Galilei - http://www.liceogalileicatania.edu.it/"
    ],
    ".liceogenoino.edu.it": ["Liceo Scientifico A. Genoino"],
    ".liceoischia.edu.it": ['Liceo Statale "Ischia"'],
    ".liceomonti.edu.it": [
        "Liceo Augusto Monti, Chieri (TO)",
        "Liceo Augusto Monti, Chieri (TO)",
    ],
    ".liceomossaolbia.edu.it": ["Liceo Scientifico Lorenzo Mossa Olbia"],
    ".liceonewton.edu.it": [
        "LICEO ISAAC NEWTON - Chivasso",
        "LICEO ISAAC NEWTON - Chivasso",
    ],
    ".liceopaleocapa.edu.it": ['Liceo Scientifico Statale "P. Paleocapa"'],
    ".liceopepecalamo.edu.it": ['Liceo Scientifico "Pepe Calamo"'],
    ".liceosocrate.edu.it": ["Liceo Classico e Scientifico Statale “Socrate”"],
    ".liceovailatigenzano.edu.it": [
        'Liceo Scientifico Statale "Giovanni Vailati"'
    ],
    ".lsdonegani.edu.it": ["Polo liceale città di Sondrio"],
    ".luigidellerba.edu.it": [
        'I.I.S.S. "Luigi Dell\'Erba", Castellana Grotte (BA), Italy'
    ],
    ".magistricumacini.edu.it": ["I.T.I.S. Magistri Cumacini"],
    ".maironidaponte.edu.it": [
        'Istituto Superiore Statale "Giovanni Maironi da Ponte"'
    ],
    ".majorana-giorgi.edu.it": [
        "Istituto Superiore Statale Majorana - Giorgi"
    ],
    ".marconibari.edu.it": ["Guglielmo Marconi Bari"],
    ".studenti.marconiverona.edu.it": [
        "Istituto Tecnico Industriale Statale G. Marconi Verona VRIT0007 - P.le R. Guardini 1, 37138 Verona"
    ],
    ".matteirho.edu.it": ["matteirho"],
    ".maxplanck.edu.it": ["I.T.I.S Max Planck"],
    ".messedaglia.edu.it": ['Liceo Scientifico "A. Messedaglia"'],
    ".meuccifanoli.edu.it": [
        'I.I.S. “Antonio Meucci"',
        'I.I.S. “Antonio Meucci"',
    ],
    ".nerviferrari.edu.it": ['LICEO "P. NERVI - G. FERRARI" - Morbegno (SO)'],
    ".newtonpertini.edu.it": [
        "Istituto di Istruzione Superiore Newton-Pertini",
        "Upper secondary school Newton-Pertini",
    ],
    ".ocbonsignori.edu.it": [
        "È un istituto tecnico industriale Telecomunicazioni e Informatica"
    ],
    ".pacinottiarchimede.edu.it": [
        "IIS Pacinotti-Archimede",
        "IIS Pacinotti-Archimede",
    ],
    ".pacinottitaranto.edu.it": [
        'Istituto Tecnico Industriale Statale "A. Pacinotti"'
    ],
    ".panettipitagora.edu.it": ["ITT Panetti - Pitagora"],
    ".paolosarpi.edu.it": ["ISIS Paolo Sarpi"],
    ".paschinilinussio.edu.it": ["ISIS Paschini-Linussio, Tolmezzo"],
    ".poloagroindustriale.edu.it": [
        '"Itis Galileo Galilei" High school - http://poloagroindustriale.edu.it/'
    ],
    ".polocodigoro.edu.it": [
        'Istituto di Istruzione Superiore "Guido Monaco di Pomposa" - Codigoro (FE) - Italy',
        "https://polocodigoro.edu.it",
    ],
    ".baldessano.roccati.edu.it": [
        "IISS Baldessano-Roccati",
        "IISS Baldessano-Roccati",
    ],
    ".scaruffilevitricolore.edu.it": [
        'Istituto Tecnico Economico Superiore "Scaruffi Levi Tricolore" Reggio Emilia - RE'
    ],
    ".scuolesuperioridizagarolo.edu.it": [
        'IIS "Paolo Borsellino e Giovanni Falcone" di Zagarolo'
    ],
    ".silvioceccato.edu.it": ["IIS Silvio Ceccato"],
    ".studenti-ittfedifermi.edu.it": ['ITTS "Fedi-Fermi" - Pistoia'],
    ".studenti8marzo.edu.it": ['ISTITUTO DI ISTRUZIONE SUPERIORE "8 MARZO"'],
    ".terradilavoro.edu.it": ["ISISS TERRA DI LAVORO"],
    ".tulliobuzzi.edu.it": ["ITS Tullio Buzzi di Prato"],
    ".voltafr.edu.it": [
        "I.I.S. (Istituto di Istruzione superiore) Alessandro Volta, Frosinone",
        "Alessandro Volta Higher Education Institute, Frosinone",
    ],
    ".vonneumann.edu.it": ["IISS J. Von Neumann"],
    ".einaudicorreggio.it": [
        'ISTITUTO TECNICO STATALE "LUIGI EINAUDI"',
        "Luigi Einaudi secondary school",
    ],
    ".embl.it": [
        "EMBL, Rome",
        "European Molecular Biology Laboratory",
        "URL: https://www.embl.it",
        "Courses: https://www.embl.org/training/",
    ],
    ".fermielearning.it": [
        "Istituto Tecnico Tecnologico Enrico Fermi",
        " Enrico Fermi Technological Technological Institute",
    ],
    ".cellini.fi.it": [
        "Istituto di Istruzione Superiore Benvenuto Cellini di Firenze"
    ],
    ".isiadesign.fi.it": [
        "Istituto Superiore per le Industrie Artistiche di Firenze"
    ],
    ".fondazionebiotecnologie.it": [
        "ITS Nuove Tecnologie della Vita",
        "ITS Nuove Tecnologie della Vita",
    ],
    ".fossatidapassano.it": [
        "Istituto Tecnico Commerciale e Tecnologico Fossati-Da Passano",
        "Technical Commercial and Technological Institute Fossati-Da Passano",
    ],
    ".accademiabellearti.fr.it": ["Frosinone Academy of Fine Arts"],
    ".galileo.galileicrema.it": ["IIS Galileo Galilei Crema"],
    ".galileimirandola.it": [
        "Istituto Superiore Statale Galileo Galilei Mirandola"
    ],
    ".calvino.ge.it": ["Istituto Italo Calvino"],
    ".giovannixxiiicosentino.it": [
        "Istituto\xa0Tecnico\xa0Industriale\xa0Giovanni\xa0XXIII-Cosentino"
    ],
    ".gonzagapalermo.it": ["Gonzaga Campus - Palermo"],
    ".barsanti.gov.it": [
        '"ITT Eugenio Barsanti" High school - http://www.barsanti.gov.it/'
    ],
    ".fossatidapassano.gov.it": [
        "Istituto Tecnico Commerciale e Tecnologico Fossati-Da Passano"
    ],
    ".studenti.gobettivolta.gov.it": ["I.S.I.S P.Gobetti-A.Volta"],
    ".icstoppaniseregno.gov.it": [
        "S.M.I.M. Don Milani Seregno",
        "Don Milani Secondary School Seregno",
    ],
    ".iisgiorgimilano.gov.it": [
        '"IIS Giovanni Giorgi Milano" High School - http://iisgiorgimilano.gov.it/'
    ],
    ".isisfacchinetti.gov.it": ["ISIS Cipriano Facchinetti"],
    ".ispascalcomandini.gov.it": [
        "Isituto Superiore Statale Pascal-Comandini - https://www.ispascalcomandini.gov.it/"
    ],
    ".issgreppi.gov.it": [
        '"Alessandro Greppi" High School - http://www.issgreppi.gov.it/'
    ],
    ".itiszuccante.gov.it": ["ITIS Carlo Zuccante"],
    ".liceovinci.gov.it": [
        "Liceo Leonardo Da Vinci Casalecchio di Reno Bologna Italy",
        "High Scool Leonardo Da Vinci Casalecchio di Reno Bologna Italy",
        "-----",
        "Via Cavour, 6 - 40033 Casalecchio di Reno • Tel. 051 591868 - Fax 051 6130834",
        "Via Panfili, 17/3 - 40133 Bologna • Tel. 051 6194857 - Fax 051 3519779",
        "-----",
        "https://www.liceovinci.edu.it/",
        "https://www.liceovinci.gov.it/",
    ],
    ".paciolo-dannunzio.gov.it": [
        "IISS Paciolo D'Annunzio - http://www.paciolo-dannunzio.gov.it"
    ],
    ".poloagroindustriale.gov.it": [
        '"Itis Galileo Galilei" High school - http://poloagroindustriale.gov.it/'
    ],
    ".racchettidavinci.gov.it": [
        '"Liceo Racchetti da Vinci"  https://www.racchettidavinci.gov.it'
    ],
    ".gssi.it": ["Gran Sasso Science Institute"],
    ".iaad.it": ["Istituto d'Arte Applicata e Design"],
    ".icatt.it": ["Catholic University of the Sacred Heart"],
    ".iccamera.it": ["Istituto Comprensivo Camera Sala Consilina (Salerno)"],
    ".icgiuseppegaribaldi.it": ["Istituto Comprensivo Giuseppe Garibaldi"],
    ".ictp.it": ["International Centre for Theoretical Physics"],
    ".iisaltierospinelli.it": [
        "Institute of Higher Education Altiero Spinelli (IIS Altiero Spinelli)",
        "Institute of Higher Education Altiero Spinelli (IIS Altiero Spinelli)",
    ],
    ".iiscuriesraffa.it": ["IIS Curie Sraffa Milano"],
    ".iisenzoferrari.it": ["IIS Ferrari-Hertz"],
    ".iismarconipieralisi.it": [
        'Istituto Istruzione Superiore "Marconi Pieralisi" - Jesi'
    ],
    ".iisruffini.it": ['IIS "G. RUFFINI" - IMPERIA'],
    ".iissgravina.it": ["IISS BAchelet - Galilei"],
    ".iisstecnicomonopoli.it": [
        "Technical Institute Vito Sante Longo in Monopoli(BA), Italy"
    ],
    ".iistorriani.it": ["IIS Janello Torriani"],
    ".iisvaldagno.it": ["IIS MARZOTTO-LUZZATTI Valdagno (VI)"],
    ".iisve.it": ["IIS Volterra Elia", "Volterra Elia Education Institute"],
    ".iisvolta.it": [
        "IIS A. Volta",
        "Institute of higher education Alessandro Volta",
    ],
    ".iit.it": ["Istituto Italiano di Tecnologia"],
    ".imiberg.it": ['LICEO SCIENTIFICO "MARIA IMMACOLATA - IMIBERG"'],
    ".marconi.imperia.it": ['IIS "G. Marconi" - Imperia'],
    ".ruffini.imperia.it": ['IIS "G. RUFFINI" - IMPERIA'],
    ".imtlucca.it": ["Institute for Advanced Studies Lucca"],
    ".isii.it": [
        "Istituto Superiore di Istruzione Industriale Guglielmo Marconi "
    ],
    ".isiltp.it": ["Istruzione Liceale Tecnica e Professionale"],
    ".isissacilebrugnera.it": [
        "Istituto Statale Istruzione Superiore Sacile Brugnera"
    ],
    ".isitgo.it": ["ISIS GALILEI FERMI PACASSI"],
    ".ispascalcomandini.it": ["Istituto Superiore Pascal Comandini "],
    ".issgreppi.it": [
        ' "Alessandro Greppi" High School  -  http://www.issgreppi.gov.it/'
    ],
    ".istitutoacerbo.it": ['Istituto Tecnico "Tito Acerbo", Pescara'],
    ".istitutocorni.it": [
        "Istituto di Istruzione Superiore F. Corni",
        "F. Corni High School",
    ],
    ".istitutofortuny.it": [
        "I.I.S. Mariano Fortuny",
        "I.I.S. Mariano Fortuny",
    ],
    ".istitutofreud.it": ["St. Freud Private School"],
    ".istitutolevi.it": ["Istituto di Istruzione Superiore 'Primo Levi'"],
    ".istitutomasterform.it": ["Istituto Masterform"],
    ".istitutopilati.it": ['Istituto Tecnico "Carlo Antonio Pilati"'],
    ".istitutoriva.it": [
        "Istituto Superiore Serafino Riva di Sarnico",
        "Serafino Riva Higher Institute of Sarnico",
    ],
    ".istitutosalvini.it": [
        "Istituto d'Istruzione Superiore Tommaso Salvini",
        "Educational Institute Tommaso Salvini",
    ],
    ".istitutoscolasticomoravia.it": [
        "Ististuto Paritario A.Moravia",
        "Ististuto Paritario A.Moravia",
    ],
    ".istitutovolta.it": ["Istituto Volta"],
    ".posta.istruzione.it": [
        "ISISS Guglielmo Marconi",
        "official website: https://isissmarconi.edu.it/",
        "3-year course in computer science and telecommunications: https://isissmarconi.edu.it/offerta-formativa/",
    ],
    ".scuola.istruzione.it": [
        "All school teachers in Italy",
        "ITET Girolamo Caruso",
        "official website: https://gcaruso.edu.it/",
        ".group",
    ],
    ".aldini.istruzioneer.it": ["Aldini Valeriani ", "Aldini Valeriani"],
    ".berenini.istruzioneer.it": [
        "Domain of IISS Agostino Berenini | e-mail example: studlsa-<last_name>-<birth_year>@berenini.istruzioneer.it"
    ],
    ".cattaneodallaglio.istruzioneer.it": [
        "IIS Cattaneo Dall' Aglio",
        "https://www.cattaneodallaglio.edu.it/",
        "https://www.cattaneodallaglio.edu.it/tecnici-informatica-e-telecomunicazioni/",
        "https://www.cattaneodallaglio.edu.it/wp-content/uploads/2020/11/Indirizzi-e-mail-istituzionali-Docenti-a.s.20-21.pdf",
    ],
    ".copernicobo.istruzioneer.it": [
        "Liceo Niccolo' Copernico - Bologna - Italia",
        "High Scool Niccolo' Copernico - Bologna - Italy",
    ],
    ".iccodigoro.istruzioneer.it": [
        "Istituto Comprensivo di Codigoro (FE) - Italy",
        "https://iccodigoro.edu.it",
    ],
    ".lsoriani.istruzioneer.it": ["Liceo Scientifico Alfredo Oriani"],
    ".paciunzio.istruzioneer.it": [
        "Domain of IISS Paciolo Dannunzio | e-mail example: <last_name>.<first_name>@paciunzio.istruzioneer.it"
    ],
    ".roiti.istruzioneer.it": ["Liceo Scientifico A. Roiti Ferrara"],
    ".itarchimede.it": ["I.T. Archimede", "I.T. Archimede"],
    ".itbramantegenga.it": ['ITET "Bramante Genga", Pesaro'],
    ".itclevi.it": [
        "ITC Primo Levi",
        "I.T.C. Primo Levi",
        "Istituto Tecnico Commerciale Primo Levi",
        "ITC Levi",
        'Istituto d\'Istruzione Superiore "Primo Levi"',
    ],
    ".itczappa.it": ["ITCS Gino Zappa - Saronno"],
    ".itesdagomari.it": [
        "Istituto di Istruzione Superiore – Paolo Dagomari – Prato"
    ],
    ".iticopernico.it": [
        "IIS N.Copernico A.Carpeggiani",
        "I.S. N.Copernico A.Carpeggiani",
        "ITI N.Copernico-A.Carpeggiani",
        "IPSIA Ercole I d'Este",
        ".group",
    ],
    ".itimedi.it": ["Istituto Tecnico Industriale, E. Medi"],
    ".itimonaco.it": [
        'Istituto Tecnico Industriale "Monaco", Cosenza',
        '"Monaco" Industrial Technical Institute, Cosenza',
    ],
    ".itisandria.it": ['ITIS "Sen. O. Jannuzzi" Andria', "ITIS Jannuzzi"],
    ".studenti.itisavogadro.it": ["IIS Amedeo Avogadro"],
    ".itiscastelli.it": ["ITIS Castelli, Brescia"],
    ".itisff.it": ["ITIS E.Fermi Francavilla Fontana"],
    ".itisgalileiroma.it": ["ITIS Galileo Galilei Roma"],
    ".itisguidodorso.it": ["ITT Guido Dorso"],
    ".itispaleocapa.it": ["ITIS PALEOCAPA"],
    ".itispascal.it": ["ITIS Biagio Pascal, Roma (RM)"],
    ".itispininfarina.it": ["ITIS Pininfarina, Moncalieri (TO)"],
    ".itisravenna.it": ["ITIS N.Baldini, Ravenna"],
    ".itisurbino.it": ['ITIS "E. Mattei"'],
    ".itisvc.it": ["ITI G.C. FACCIO"],
    ".its-ictpiemonte.it": ["ITS for ICT Piemonte"],
    ".stud.itsaltoadriatico.it": ["ITS Alto Adriatico"],
    ".itsincom.it": ["ITS Incom"],
    ".itsjobs.it": ['Fondazione Istituto Tecnico Superiore "Steve Jobs" '],
    ".itsmeccatronico.it": ["ITS Meccatronico Veneto"],
    ".itsos-mariecurie.it": [
        "Istituto Tecnico Itsos Marie Curie,via Masaccio,20063 Cernusco sul Naviglio (Milan Area)",
        "Institutional mail : info@itsos-mariecurie.it",
        "Institutional code : MITD400008",
    ],
    ".edu.itspiemonte.it": ["ITS for ICT Piemonte"],
    ".itsrizzoli.it": ["ITS Angelo Rizzoli"],
    ".itstechtalentfactory.it": ["ITS Technologies Talent Factory"],
    ".itsumbria.it": [
        "ITS Umbria Academy - Istituto Tecnico Superiore Nuove Tecnologie per il Made in Italy"
    ],
    ".iuav.it": ["University IUAV of Venice"],
    ".iue.it": ["European University Institute"],
    ".iulm.it": ["University Institute of Modern Languages"],
    ".iuo.it": ["University Institute of Oriental Studies"],
    ".iusspavia.it": ["Istituto Universitario di Studi Superiori"],
    ".jhubc.it": ["Johns Hopkins University, SAIS Bologna Center"],
    ".liceoariosto.it": ["Liceo Ludovico Ariosto Ferrara"],
    ".liceocaronapoli.it": [
        'LLICEO SCIENTIFICO STATALE "TITO LUCREZIO CARO" Napoli   '
    ],
    ".liceocattaneotorino.it": [
        "Liceo Scientifico Statale Carlo Cattaneo",
        '"Carlo Cattaneo" State Scientific High School',
    ],
    ".liceoconegliano.it": [
        'Liceo "Guglielmo Marconi", Conegliano',
        'High school "Guglielmo Marconi", Conegliano',
    ],
    ".liceocroce.it": [
        'Liceo Scientifico "Benedetto Croce" - Palermo',
        'Scientific High School "Benedetto Croce" - Palermo',
    ],
    ".studenti.liceofermipadova.it": ["Liceo Scientifico Enrico Fermi Padova"],
    ".liceogalfer.it": ['Liceo Scientifico Statale "G. Ferraris", Torino'],
    ".liceokennedy.it": ["Liceo Scientifico Statale J. F. Kennedy"],
    ".liceolugo.it": [
        "Liceo Scientifico Statale G.Ricci Curbastro",
        "State Scientific High School G. Ricci Curbastro",
    ],
    ".liceomelipalermo.it": [
        'Liceo Classico Internazionale "G.Meli"',
        '"G.Meli" International Classical High School',
    ],
    ".liceorighi.it": ["Liceo Scientifico Augusto Righi"],
    ".liceosabin.it": ["Liceo Scientifico Statale Albert Bruce Sabin"],
    ".liceoscacchibari.it": ["Liceo Scacchi Bari", "Scacchi"],
    ".liceoscafati.it": [
        "Liceo Scientifico Statale Renato Caccioppoli - Scafati"
    ],
    ".linkstudents.it": ["Link Campus University", "Link Campus University"],
    ".liuc.it": ["Free University Institute Carlo Cattaneo"],
    ".lsamaldi.it": ["Liceo Scientifico E. Amaldi"],
    ".luiss.it": ["Free International University of Social Studies"],
    ".studenti.lum.it": [
        'Università LUM "Giuseppe Degennaro"',
        'LUM University "Giuseppe Degennaro"',
    ],
    ".lum.it": [
        'Università LUM "Giuseppe Degennaro"',
        'LUM University "Giuseppe Degennaro"',
    ],
    ".lumsa.it": ["Free University Maria Santissima Assunta"],
    ".lumsastud.it": ["Libera Università Maria Santissima Assunta (LUMSA)"],
    ".magistricumacini.it": [
        "Istituto Tecnico Industriale Statale Magistri Cumacini"
    ],
    ".marconi-galletti.it": [
        "Istituto d’Istruzione Superiore “Marconi-Galletti-Einaudi”"
    ],
    ".marconicloud.it": ["IIS G. Marconi Civitavecchia"],
    ".marconigorgonzola.it": ["Istituto Guglielmo Marconi"],
    ".marconirovereto.it": ["Istituto Tecnico Tecnologico Guglielmo Marconi"],
    ".mcurie.it": [
        'Istituto di Istruzione Secondaria Superiore "Marie Curie", Via Togliatti 5, 47039 Savignano sul Rubicone (FC)',
        "Institutional mail : fois001002@istruzione.it",
        "Institutional code : FOIS001002",
        "Official website: https://www.mcurie.gov.it/",
        "URL of courses with IT: https://www.mcurie.gov.it/quadro-orario-liceo.html (The second table)",
        "PDF about official email domain for students: https://www.mcurie.gov.it/component/k2/item/download/3351_a9700b4d7736f885529319f0c15520e0.html",
    ],
    ".maxwell.mi.it": ["IIS J.C. Maxwell Milano"],
    ".fermi.mo.it": ['Istituto Tecnico Industriale "Enrico Fermi" - Modena'],
    ".itivinci.mo.it": [
        'Istituto Tecnico Industriale "Leonardo Da Vinci", Carpi (MO), Italia'
    ],
    ".unisob.na.it": [
        "University Institute of Teacher Training Suor Orsola Benincasa"
    ],
    ".naba.it": ["NABA - Nuova Accademia di Belle Arti, Milan"],
    ".olivelliputelli.it": [
        'Istituto d\'istruzione superiore "Olivelli Putelli"',
        'Institute of Higher Education "OLIVELLI Putelli"',
        "School official website: https://www.olivelliputelli.edu.it",
        "IT related course offered by the school: https://www.olivelliputelli.edu.it/indirizzi-di-studio/indirizzo-tecnologico",
        " ",
    ],
    ".liceomarconi.parma.it": ["Liceo Scientifico Guglielmo Marconi"],
    ".lyv.pdit.it": ["Padua Institute of Technology"],
    ".peano.it": ["IIS Peano"],
    ".avolta.pg.it": [
        "Istituto Tecnico Tecnologico Statale Alessandro Volta Perugia",
        "State Technical Institute of Technology Alessandro Volta Perugia",
    ],
    ".poliba.it": ["Polytechnic Institute of Bari"],
    ".polimi.it": ["Polytechnic Institute of Milan"],
    ".polito.it": ["Polytechnic Institute of Turin"],
    ".polotecnologicoimperiese.it": ["I.I.S. POLO TECNOLOGICO IMPERIESE"],
    ".itis.pr.it": ["ITIS Leonardo da Vinci"],
    ".primolevitorino.it": ["IIS Primo Levi"],
    ".pul.it": [
        "Pontificia Università Lateranense",
        "Pontifcia Universitas Lateranensis",
    ],
    ".pusc.it": ["Pontificia Università della Santa Croce"],
    ".rgtfo-me.it": ["Realgymnasium und Technologische Fachoberschule Meran"],
    ".risikamente.it": [
        "Istituto Tecnico Tecnologico Statale Alessandro Volta Perugia",
        "State Technical Institute of Technology Alessandro Volta Perugia",
    ],
    ".studenti.salesianimilano.it": [
        "Istituto Salesiano S. Ambrogio Opera don Bosco Milano"
    ],
    ".santannapisa.it": [
        "Scuola Superiore Sant'Anna",
        "Sant'Anna School of Advanced Studies",
    ],
    ".sissa.it": ["International Higher School for Advanced Studies Trieste"],
    ".snets.it": ["Schulnetz Südtirol"],
    ".sns.it": ["School of Education Pisa"],
    ".sssrome.it": ["St. Stephens School Rome"],
    ".sssup.it": ["Higher School of University and Advanced Studies Pisa"],
    ".studbocconi.it": ["Bocconi University"],
    ".unibs.studenti.it": [
        "Università degli studi di Brescia",
        "University of Brescia",
    ],
    ".unige.studenti.it": [
        "Università degli studi di Genova",
        "University of Genoa",
    ],
    ".studentipinin.it": ["ITIS Pininfarina, Moncalieri (TO)"],
    ".schule.suedtirol.it": ["Oberschulzentrum J. Ph. Fallmerayer"],
    ".tecnicosuperiorekennedy.it": ["Istituto Tecnico Superiore Kennedy"],
    ".artigianelli.tn.it": ["Istituto Pavoniano Artigianelli"],
    ".buonarroti.tn.it": ["Istituto Tecnico Tecnologico Buonarroti-Pozzo"],
    ".mat.tn.it": ["Marconi Altaforazione Tecnologica"],
    ".ictp.trieste.it": [
        "Abdus Salam international centre for theoretical physics"
    ],
    ".univ.trieste.it": ["University of Trieste"],
    ".volta.ts.it": [
        "Istituto Tecnico Statale A. Volta",
        "A. Volta State Technical Institute",
    ],
    ".tuascuola.it": ['Centro Scolastico "TuaScuola"'],
    ".studenti.malignani.ud.it": ["ISIS A.Malignani"],
    ".malignani.ud.it": ["ISIS Arturo Malignani"],
    ".unian.it": ["University of Ancona"],
    ".uniba.it": ["University of Bari"],
    ".unibas.it": ["Basilicata University Potenza"],
    ".unibg.it": ["University of Bergamo"],
    ".unibo.it": [
        "Università di Bologna - Italy",
        "University of Bologna - Italy",
    ],
    ".unibocconi.it": [
        'Università Commerciale "L. Bocconi"',
        "Bocconi University",
    ],
    ".unibs.it": ["University of Brescia"],
    ".unibz.it": ["Free University of Bozen"],
    ".unica.it": ["University of Cagliari"],
    ".unical.it": ["University of Calabria"],
    ".unicam.it": ["University of Camerino"],
    ".unicampania.it": ['University of Campania "Luigi Vanvitelli"'],
    ".unicampus.it": ["Campus Bio-Medico University of Rome"],
    ".unicas.it": ["University of Cassino"],
    ".unicatt.it": ["Catholic University of the Sacred Heart"],
    ".unich.it": ["University of Chieti"],
    ".unict.it": ["University of Catania"],
    ".unicz.it": ["University Magna Graecia of Catanzaro"],
    ".studenti.uniecampus.it": ["Università E-Campus", "E-Campus University"],
    ".uniecampus.it": ["Università degli Studi eCampus"],
    ".unier.it": ["Università Europea di Roma", "European University of Rome"],
    ".uniese.it": ["European School of Economics"],
    ".unife.it": ["University of Ferrara"],
    ".unifg.it": ["University of Foggia"],
    ".unifi.it": ["University of Florence"],
    ".unigre.it": ["Pontifica Università Gregoriana"],
    ".unikore.it": ['Università degli Studi di Enna "Kore"'],
    ".unikorestudent.it": ['Università degli Studi di Enna "Kore"'],
    ".unile.it": ["University of Lecce"],
    ".unilink.it": ["Link Campus University of Malta"],
    ".unimarconi.it": ["University  Guglielmo Marconi"],
    ".unimc.it": ["University of Macerata"],
    ".unime.it": ["University of Messina"],
    ".unimercatorum.it": [
        "Università Mercatorum",
        "https://www.unimercatorum.it/",
    ],
    ".unimi.it": ["University of Milan"],
    ".unimib.it": ["University of Milan - Bicocca"],
    ".unimo.it": ["University of Modena"],
    ".unimol.it": ["University of Molise"],
    ".unimore.it": ["University of Modena and Reggio Emilia"],
    ".unina.it": ["University of Naples Federico II"],
    ".unina2.it": ["Second University of Naples"],
    ".uninav.it": ["University Institute of Naval Studies"],
    ".uninsubria.it": ["University of Insubria"],
    ".unipa.it": ["University of Palermo"],
    ".uniparthenope.it": ['Università degli studi di Napoli "Parthenope"'],
    ".unipd.it": ["University of Padua"],
    ".studenti.unipegaso.it": [
        'Università Telematica "Pegaso"',
        "Pegaso University",
    ],
    ".unipg.it": ["University of Perugia"],
    ".studenti.unipi.it": ["Università di Pisa", "University of Pisa"],
    ".unipi.it": ["University of Pisa"],
    ".unipmn.it": ["University of Piemonte Orientale"],
    ".unipr.it": ["University of Parma"],
    ".unipv.it": ["University of Pavia"],
    ".unirc.it": ["University of Reggio Calabria"],
    ".diag.uniroma1.it": ["Sapienza, University of Rome"],
    ".uniroma1.it": ["University of Rome, I"],
    ".uniroma2.it": ["University of Roma Tor Vergata"],
    ".uniroma3.it": ["Third University of Rome"],
    ".uniroma5.it": ["Università telematica san raffaele"],
    ".unisa.it": ["University of Salerno"],
    ".unisal.it": ["Università Pontificia Salesiana"],
    ".unisalento.it": ["University of Salento"],
    ".unisannio.it": ["University of Sannio"],
    ".unisg.it": ["University of Gastronomic Sciences"],
    ".unisi.it": ["University of Siena"],
    ".docenti.unisr.it": [
        "Università Vita-Salute San Raffaele (Milan, Italy)",
        "Vita-Salute San Raffaele University, (Milan, Italy)",
    ],
    ".studenti.unisr.it": [
        "Universita' Vita-Salute San Raffaele",
        "San Raffaele Vita-Salute University",
    ],
    ".uniss.it": ["University of Sassari"],
    ".unistrapg.it": [
        "University of Italian Studies for Foreigners of Perugia"
    ],
    ".unistrasi.it": ["University of Italian Studies for Foreigners of Siena"],
    ".unite.it": ["University of Teramo"],
    ".studenti.unitelmasapienza.it": [
        "Università telematica UNITELMA Sapienza"
    ],
    ".unitn.it": ["University of Trento"],
    ".unito.it": ["University of Turin"],
    ".units.it": ["University of Trieste"],
    ".unitus.it": ["Viterbo State University"],
    ".spes.uniud.it": [
        "University of Udine, Udine, Italy",
        "Università degli Studi di Udine, Udine, Italia",
    ],
    ".uniud.it": ["University of Udine"],
    ".studenti.uniupo.it": [
        'Università del Piemonte Orientale "Amedeo Avogadro", Alessandria - Novara - Vercelli, Italia'
    ],
    ".uniupo.it": [
        'Università del Piemonte Orientale "Amedeo Avogadro", Alessandria - Novara - Vercelli, Italia'
    ],
    ".uniurb.it": ["University of Urbino"],
    ".univaq.it": ["University of Aquila"],
    ".univda.it": ["University of Valle d'Aosta"],
    ".stud.unive.it": ["Università Ca' Foscari", "Ca' Foscari University"],
    ".unive.it": [
        "University Institute of Architecture Venice",
        "University of Venice",
    ],
    ".universitadipavia.it": ["University of Pavia"],
    ".univpm.it": ["Marche Politecnic University"],
    ".univr.it": ["University of Verona"],
    ".urbe.it": [
        "Pontificio Istituto Orientale",
        "Pontifcia Università Gregoriana",
        "Pontifcia Universitas a S.Thomas Aquinate in Urbe",
        "Università Pontifcia Salesiana",
    ],
    ".mail.scuole.vda.it": ["Monte Emilius 1", "Medium school"],
    ".veronatrento.it": ["IIS Verona Trento"],
    ".itisrossi.vi.it": ["ISTITUTO TECNICO INDUSTRIALE STATALE A.ROSSI"],
    ".voltaweb.it": ['LICEO SCIENTIFICO STATALE "A. VOLTA"'],
    ".mymbcc.edu.jm": ["Montego Bay Community College"],
    ".ncu.edu.jm": ["Northern Caribbean University"],
    ".stu.ucc.edu.jm": ["University of the Commonwealth\xa0Caribbean"],
    ".uwimona.edu.jm": ["University of the West Indies, Mona"],
    ".aabu.edu.jo": ["Al al-Bayt University"],
    ".aau.edu.jo": ["Amman Arab University for Higher Studies"],
    ".ahu.edu.jo": ["Al Hussein Bin Talal University"],
    ".anu.edu.jo": ["Ajloun National University"],
    ".aou.edu.jo": ["Arab Open University"],
    ".asu.edu.jo": [
        "Applied Science University",
        "Applied Science Private University",
        "Applied Science Private University, Jordan",
    ],
    ".std.aum.edu.jo": [
        "American University of Madaba",
        "American University of Madaba",
    ],
    ".gju.edu.jo": ["German Jordanian University"],
    ".htu.edu.jo": ["جامعة الحسين التقنية", "Al Hussein Technical University"],
    ".hu.edu.jo": ["Hashemite University"],
    ".ics.edu.jo": ["International Community School, Jordan"],
    ".inu.edu.jo": ["Irbid National University"],
    ".iu.edu.jo": ["Isra University "],
    ".jadara.edu.jo": ["Jadara University"],
    ".jam.edu.jo": ["Jordan Academy of Music / Higher Institute of Music"],
    ".stu.jpu.edu.jo": ["Jerash University"],
    ".jpu.edu.jo": ["Jerash University", "JPU"],
    ".jsg.edu.jo": ["مجموعة مدارس الجامعة", "Al Jami'a Schools Group"],
    ".jss.edu.jo": ["مدارس الجزيرة ", "Al jazeera School"],
    ".ju.edu.jo": ["Jordan University"],
    ".cit.just.edu.jo": ["Jordan University of Science and Technology"],
    ".mashrek.edu.jo": [
        "مدرسة المشرق الدولية",
        "Mashrek International School",
    ],
    ".meu.edu.jo": ["Middle East University"],
    ".mutah.edu.jo": ["Mu' tah University"],
    ".psut.edu.jo": ["Princess Sumaya University for Technology"],
    ".std-zuj.edu.jo": [
        "جامعة الزيتونة الاردنية",
        "Al-Zaytoonah University of Jordan",
    ],
    ".ttu.edu.jo": ["Tafila Technical University "],
    ".uop.edu.jo": ["University of Petra"],
    ".wise.edu.jo": ["The World Islamic Sciences &amp; Education University"],
    ".yu.edu.jo": ["Yarmouk University"],
    ".zuj.edu.jo": [
        "جامعة الزيتونة الاردنية",
        "Al-Zaytoonah University of Jordan",
    ],
    ".student.42tokyo.jp": ["42tokyo"],
    ".aasa.ac.jp": ["Aichi Shukutoku University"],
    ".abu.ac.jp": ["Aichi Bunkyo University"],
    ".aichi-edu.ac.jp": ["Aichi University of Education"],
    ".aichi-fam-u.ac.jp": [
        "Aichi Prefectural University of Fine Arts &amp; Music"
    ],
    ".aichi-gakuin.ac.jp": ["Aichi Gakuin University"],
    ".aichi-med-u.ac.jp": ["Aichi Medical University"],
    ".aichi-pu.ac.jp": ["Aichi Prefectural University"],
    ".aichi-u.ac.jp": ["Aichi University"],
    ".aiit.ac.jp": ["Advanced Institute of Industrial Technology"],
    ".aikoku-u.ac.jp": ["Aikoku Gakuen University"],
    ".aitech.ac.jp": ["Aichi Institute of Technology"],
    ".akita-u.ac.jp": ["Akita University"],
    ".anan-nct.ac.jp": ["National Institute of Technology, Anan College"],
    ".aomori-u.ac.jp": ["Aomori University"],
    ".aomoricgu.ac.jp": ["Aomori Chuoh Gakuin University"],
    ".aoyama.ac.jp": ["Aoyama Gakuin University"],
    ".asahi-u.ac.jp": ["Asahi University"],
    ".asahikawa-med.ac.jp": ["Asahikawa Medical College"],
    ".asahikawa-u.ac.jp": ["Asahikawa University"],
    ".ashitech.ac.jp": ["Ashikaga Institute of Technology"],
    ".ashiya-u.ac.jp": ["Ashiya University"],
    ".asia-u.ac.jp": ["Asia University"],
    ".asu.ac.jp": ["Aichi Sangyo University"],
    ".atomi.ac.jp": ["Atomi College"],
    ".auhw.ac.jp": ["Aomori University of Health and Welfare"],
    ".azabu-u.ac.jp": ["Azabu University"],
    ".baika.ac.jp": ["Baika Women's College"],
    ".baiko.ac.jp": ["Baiko Women's College"],
    ".beppu-u.ac.jp": ["Beppu University"],
    ".budo-u.ac.jp": ["International Budo University"],
    ".bukkyo-u.ac.jp": ["Bukkyo University"],
    ".bunka-wu.ac.jp": ["Bunka Women's University"],
    ".bunkyo.ac.jp": ["Bunkyo University"],
    ".cgu.ac.jp": ["Chuo Gakuin University"],
    ".chiba-u.ac.jp": ["Chiba University"],
    ".chikushi.ac.jp": ["Chikushi Jogakuen University"],
    ".chubu-gu.ac.jp": ["Chubu Gakuin University &amp; Chubu Women's College"],
    ".chubu.ac.jp": ["Chubu University"],
    ".chukyo-u.ac.jp": ["Chukyo University"],
    ".chukyogakuin-u.ac.jp": ["Chukyo Gakuin University"],
    ".g.chuo-u.ac.jp": ["Chuo University"],
    ".chuo-u.ac.jp": ["Chuo University"],
    ".cku.ac.jp": ["Chiba Keizai University"],
    ".cuc.ac.jp": ["Chiba University of Commerce"],
    ".daido-it.ac.jp": ["Daido Institute of Technology"],
    ".daiichi-cps.ac.jp": ["Daiichi College of Pharmaceutical Sciences"],
    ".daiichi-koudai.ac.jp": ["Dai Ichi University, College of Technology"],
    ".daito.ac.jp": ["Daito Bunka University"],
    ".dendai.ac.jp": ["Tokyo Denki University"],
    ".do-johodai.ac.jp": ["Hokkaido Information University"],
    ".doho.ac.jp": ["Doho University"],
    ".dohto.ac.jp": ["Dohto University"],
    ".dokkyo.ac.jp": ["Dokkyo University"],
    ".dokkyomed.ac.jp": ["Dokkyo University School of Medicine"],
    ".doshisha.ac.jp": [
        "Doshisha University",
        "Doshisha Women's College of Liberal Arts",
    ],
    ".edogawa-u.ac.jp": ["Edogawa University"],
    ".ehime-u.ac.jp": ["Ehime University"],
    ".eiyo.ac.jp": ["Kagawa Institute of Nutrition"],
    ".eum.ac.jp": ["Elisabeth University of Music"],
    ".fdcnet.ac.jp": ["Fukuoka Dental College"],
    ".ferris.ac.jp": ["Ferris University"],
    ".fit.ac.jp": ["Fukuoka Institute of Technology"],
    ".fmu.ac.jp": ["Fukushima Medical College"],
    ".fpu.ac.jp": ["Fukui Prefectural University"],
    ".fujijoshi.ac.jp": ["Fuji Women's College"],
    ".fujita-hu.ac.jp": ["Fujita Health University"],
    ".fukui-med.ac.jp": ["Fukui Medical School"],
    ".fukui-ut.ac.jp": ["Fukui University of Technology"],
    ".fukuoka-edu.ac.jp": ["Fukuoka University of Education"],
    ".fukuoka-int-u.ac.jp": ["Fukuoka International University"],
    ".fukuoka-pu.ac.jp": ["Fukuoka Prefectural University"],
    ".fukuoka-u.ac.jp": ["Fukuoka University"],
    ".fukushima-u.ac.jp": ["Fukushima University"],
    ".fukuyama-u.ac.jp": ["Fukuyama University"],
    ".fwu.ac.jp": ["Fukuoka Women's University"],
    ".gakusen.ac.jp": ["Aichi Gakusen University"],
    ".gakushuin.ac.jp": ["Gakushuin University"],
    ".gifu-keizai.ac.jp": ["Gifu Keizai University"],
    ".gifu-pu.ac.jp": ["Gifu Pharmaceutical University"],
    ".gifu-u.ac.jp": ["Gifu University"],
    ".gijodai.ac.jp": ["Gifu Women's University"],
    ".gpwu.ac.jp": ["Gunma Prefectural Women's University"],
    ".gunma-u.ac.jp": ["Gunma University"],
    ".h-bunkyo.ac.jp": ["Hiroshima Bunkyo Women's University"],
    ".hachinohe-u.ac.jp": ["Hachinohe University"],
    ".hakodate-u.ac.jp": ["Hakodate University"],
    ".hakuoh.ac.jp": ["Hakuoh University"],
    ".hal.ac.jp": ["Hal Tokyo"],
    ".hama-med.ac.jp": ["Hamamatsu University School of Medicine"],
    ".hanazono.ac.jp": ["Hanazono University"],
    ".hannan-u.ac.jp": ["Hannan University"],
    ".ca.harada-gakuen.ac.jp": ["Kagoshima Career Design College"],
    ".heisei-u.ac.jp": ["Fukuyama Heisei University"],
    ".hi-tech.ac.jp": ["Hachinohe Institute of Technology"],
    ".hijiyama-u.ac.jp": ["Hijiyama University"],
    ".himeji-du.ac.jp": ["Himeji Dokkyo University"],
    ".hirogaku-u.ac.jp": ["Hirosaki Gakuin University"],
    ".hirokoku-u.ac.jp": ["Hiroshima International University"],
    ".hirosaki-u.ac.jp": ["Hirosaki University"],
    ".hiroshima-cu.ac.jp": ["Hiroshima City University"],
    ".hiroshima-u.ac.jp": ["Hiroshima University"],
    ".hit-u.ac.jp": ["Hitotsubashi University"],
    ".hit.ac.jp": ["Hokkaido Institute of Technology"],
    ".hiu.ac.jp": ["Heisei International University"],
    ".hju.ac.jp": ["Hiroshima Jogakuin University"],
    ".hkg.ac.jp": ["Hiroshima Kokusai Gakuin University"],
    ".hokkai-s-u.ac.jp": ["Hokkaigakuen University"],
    ".hokkyodai.ac.jp": ["Hokkaido University of Education"],
    ".hoku-iryo-u.ac.jp": ["Hokkaido University of Health Sciences"],
    ".hokudai.ac.jp": ["Hokkaido University"],
    ".hokuriku-u.ac.jp": ["Hokuriku University"],
    ".hokusei.ac.jp": ["Hokusei Gakuen University"],
    ".hokuyakudai.ac.jp": ["Hokkaido Institute of Pharmaceutical Sciences"],
    ".hoshi.ac.jp": ["Hoshi University"],
    ".hue.ac.jp": ["Hiroshima University of Economics"],
    ".hus.ac.jp": ["Hokkaido University of Science"],
    ".hyo-med.ac.jp": ["Hyogo College of Medicine"],
    ".hyogo-dai.ac.jp": ["Hyogo University"],
    ".hyogo-u.ac.jp": ["Hyogo University of Education"],
    ".vc.ibaraki.ac.jp": ["IBARAKI UNIVERSITY", "茨城大学"],
    ".ibaraki.ac.jp": ["Ibaraki University"],
    ".icc.ac.jp": ["Ibaraki Christian College"],
    ".icu.ac.jp": ["International Christian University"],
    ".internet.ac.jp": ["Tokyo Online University"],
    ".ipu.ac.jp": ["Ibaraki Prefectural University of Health Sciences"],
    ".isenshu-u.ac.jp": ["Ishinomaki Senshu University"],
    ".it-chiba.ac.jp": ["Chiba Institute of Technology"],
    ".it-hiroshima.ac.jp": ["Hiroshima Institute of Technology"],
    ".iuhw.ac.jp": ["International University of Health and Welfare"],
    ".iuj.ac.jp": ["International University of Japan"],
    ".iuk.ac.jp": ["International University of Kagoshima"],
    ".iwakimu.ac.jp": ["Iwaki Meisei University"],
    ".iwate-med.ac.jp": ["Iwate Medical University"],
    ".iwate-pu.ac.jp": ["Iwate Prefectural University"],
    ".iwate-u.ac.jp": ["Iwate University"],
    ".jaist.ac.jp": ["Japan Advanced Institute of Science and Technology"],
    ".jichi.ac.jp": ["Jichi Medical School"],
    ".jikei.ac.jp": ["Jikei University School of Medicine"],
    ".jissen.ac.jp": ["Jissen Women's University"],
    ".jiu.ac.jp": ["Josai International University"],
    ".jobu.ac.jp": ["Jobu University"],
    ".josai.ac.jp": ["Josai University"],
    ".juen.ac.jp": ["Joetsu University of Education"],
    ".juntendo.ac.jp": ["Juntendo University"],
    ".jwu.ac.jp": ["Japan Women's University"],
    ".k-junshin.ac.jp": ["Kagoshima Immaculate Heart University"],
    ".kagawa-u.ac.jp": ["Kagawa University"],
    ".kagoshima-u.ac.jp": ["Kagoshima University"],
    ".kamakura-u.ac.jp": ["Kamakura Women's College"],
    ".kanagawa-it.ac.jp": ["Kanagawa Institute of Technology"],
    ".kanazawa-bidai.ac.jp": ["Kanazawa College of Art"],
    ".kanazawa-gu.ac.jp": ["Kanazawa Gakuin University"],
    ".kanazawa-it.ac.jp": ["Kanazawa Institute of Technology"],
    ".kanazawa-med.ac.jp": ["Kanazawa Medical University"],
    ".kanazawa-u.ac.jp": ["Kanazawa University"],
    ".kansai-u.ac.jp": ["Kansai University"],
    ".kanto-gakuen.ac.jp": ["Kanto Gakuen University"],
    ".kanto-gakuin.ac.jp": ["Kanto Gakuin University"],
    ".kawasaki-m.ac.jp": [
        "Kawasaki Medical School",
        "Kawasaki University of Medical Care",
    ],
    ".stu.kbc.ac.jp": ["International Electronic Business College"],
    ".kbu.ac.jp": ["Kyoto Bunkyo University"],
    ".kcua.ac.jp": ["Kyoto City University of Arts"],
    ".keio.ac.jp": ["Keio University"],
    ".keisen.ac.jp": ["Keisen Jogaku-en College"],
    ".keiwa-c.ac.jp": ["Keiwa College"],
    ".kgwu.ac.jp": ["Kawamura Gakuen Woman's University"],
    ".kindai.ac.jp": ["Kinki University"],
    ".kinjo-u.ac.jp": ["Kinjo Gakuin University"],
    ".kit.ac.jp": ["Kyoto Institute of Technology"],
    ".kitakyu-u.ac.jp": ["Kitakyushu University"],
    ".kitami-it.ac.jp": ["Kitami Institute of Technology"],
    ".kitasato-u.ac.jp": ["Kitasato University"],
    ".kiu.ac.jp": ["Kyushu International University"],
    ".kiui.ac.jp": ["Kibi International University"],
    ".kms.ac.jp": ["Kagawa Medical School"],
    ".kmu.ac.jp": ["Kansai Medical University"],
    ".kobe-c.ac.jp": ["Kobe Jogakuin University"],
    ".kobe-cufs.ac.jp": ["Kobe City University of ForeignStudies"],
    ".kobe-du.ac.jp": ["Kobe Design University"],
    ".kobe-kiu.ac.jp": ["Kobe International University"],
    ".kobe-shinwa.ac.jp": ["Kobe Shinwa Women's University"],
    ".kobe-u.ac.jp": ["Kobe University"],
    ".kobe-wu.ac.jp": ["Kobe Women's University"],
    ".kobedenshi.ac.jp": ["Kobe Institute of Computing"],
    ".kobegakuin.ac.jp": ["Kobe Gakuin University"],
    ".kobepharma-u.ac.jp": ["Kobe Pharmaceutical University"],
    ".kochi-ms.ac.jp": ["Kochi Medical School"],
    ".kochi-tech.ac.jp": ["Kochi University of Technology"],
    ".kochi-u.ac.jp": ["Kochi University"],
    ".kogakkan-u.ac.jp": ["Kogakkan University"],
    ".kogakuin.ac.jp": ["Kogakuin University"],
    ".koka.ac.jp": ["Koka Women's College"],
    ".kokugakuin.ac.jp": ["Kokugakuin University"],
    ".kokushikan.ac.jp": ["Kokushikan University"],
    ".komazawa-u.ac.jp": ["Komazawa University"],
    ".konan-u.ac.jp": ["Konan University"],
    ".konan-wu.ac.jp": ["Konan Women's University"],
    ".korea-u.ac.jp": ["Korea University"],
    ".koriyama-kgc.ac.jp": ["Koriyama Women's University and College"],
    ".koshien.ac.jp": ["Koshien University"],
    ".koyasan-u.ac.jp": ["Koyasan University"],
    ".kpu-m.ac.jp": ["Kyoto Prefectural University of Medicine"],
    ".kpu.ac.jp": ["Kyoto Prefectural University"],
    ".ksu.ac.jp": ["Kurashiki Sakuyo University"],
    ".kufs.ac.jp": ["Kyoto University of Foreign Studies"],
    ".kuins.ac.jp": ["Kansai University of International Studies"],
    ".kuis.ac.jp": ["Kanda University of International Studies"],
    ".kumagaku.ac.jp": ["Kumamoto Gakuen University"],
    ".kumamoto-u.ac.jp": ["Kumamoto University"],
    ".kunitachi.ac.jp": ["Kunitachi College of Music"],
    ".kurume-it.ac.jp": ["Kurume Institute of Technology"],
    ".kurume-u.ac.jp": ["Kurume University"],
    ".kusa.ac.jp": ["Kurashiki University of Science and the Arts"],
    ".kushiro-pu.ac.jp": ["Kushiro Public University of Economics"],
    ".kusw.ac.jp": ["Kansai University of Social Welfare"],
    ".kwansei.ac.jp": ["Kwansei Gakuin University"],
    ".kwassui.ac.jp": ["Kwassui Women's College"],
    ".kwuc.ac.jp": ["Kyushu Women's University"],
    ".kyokyo-u.ac.jp": ["Kyoto University of Education"],
    ".kyorin-u.ac.jp": ["Kyorin University"],
    ".kyoritsu-wu.ac.jp": ["Kyoritsu Woman's University"],
    ".kyoto-art.ac.jp": ["Kyoto University of Art and Design"],
    ".kyoto-phu.ac.jp": ["Kyoto Pharmaceutical University"],
    ".kyoto-seika.ac.jp": ["Kyoto Seika University"],
    ".kyoto-su.ac.jp": ["Kyoto Sangyo University"],
    ".kyoto-u.ac.jp": ["Kyoto University"],
    ".kyoto-wu.ac.jp": ["Kyoto Women's University"],
    ".kyotogakuen-u.ac.jp": ["Kyoto Gakuen University"],
    ".kyu-dent.ac.jp": ["Kyushu Dental College"],
    ".kyukyo-u.ac.jp": ["Kyushu Kyoritsu University"],
    ".kyusan-u.ac.jp": ["Kyushu Sangyo University"],
    ".kyushu-ns.ac.jp": ["Kyushu University of Nursing and SocialWelfare"],
    ".kyushu-u.ac.jp": ["Kyushu University"],
    ".kyutech.ac.jp": ["Kyushu Institute of Technology"],
    ".matsuyama-u.ac.jp": ["Matsuyama University"],
    ".mdu.ac.jp": ["Matsumoto Dental University"],
    ".meiji-u.ac.jp": ["Meiji University of Oriental Medicine"],
    ".meiji.ac.jp": ["Meiji University"],
    ".meijo-u.ac.jp": ["Meijo University"],
    ".meikai.ac.jp": ["Meikai University"],
    ".meikei.ac.jp": ["Meikei High School"],
    ".meio-u.ac.jp": ["Meio University"],
    ".meisei-u.ac.jp": ["Meisei University"],
    ".mejiro.ac.jp": ["Mejiro University"],
    ".metro-cit.ac.jp": [
        "Tokyo Metropolitan College of Industrial Technology"
    ],
    ".mgu.ac.jp": ["Miyagi Gakuin Women's College"],
    ".mie-u.ac.jp": ["Mie University"],
    ".mimasaka.ac.jp": ["Mimasaka Women's College"],
    ".miyakyo-u.ac.jp": ["Miyagi University of Education"],
    ".miyazaki-med.ac.jp": ["Miyazaki Medical College"],
    ".miyazaki-mu.ac.jp": ["Miyazaki Municipal University"],
    ".miyazaki-u.ac.jp": ["Miyazaki University"],
    ".morioka-u.ac.jp": ["Morioka College"],
    ".mpu.ac.jp": ["Miyazaki Prefectural Nursing University"],
    ".mukogawa-u.ac.jp": ["Mukogawa Women's University"],
    ".muroran-it.ac.jp": ["Muroran Institute of Technology"],
    ".musabi.ac.jp": ["Musashino Art University"],
    ".musashi.ac.jp": ["Musashi University"],
    ".musashino-music.ac.jp": ["Musashino Academy of Music"],
    ".musashino-u.ac.jp": ["Musashino University"],
    ".my-pharm.ac.jp": ["Meiji College of Pharmacy"],
    ".myu.ac.jp": ["Miyagi University"],
    ".nagano.ac.jp": ["Nagano University"],
    ".nagaokaut.ac.jp": ["Nagaoka University of Technology"],
    ".nagasaki-u.ac.jp": ["Nagasaki University"],
    ".nagasakipu.ac.jp": ["Nagasaki Prefectural University"],
    ".nagoya-cu.ac.jp": ["Nagoya City University"],
    ".nankyudai.ac.jp": ["Minamikyushu University"],
    ".nda.ac.jp": ["National Defense Academy"],
    ".nebuta.ac.jp": ["Aomori Public College"],
    ".nias.ac.jp": ["Nagasaki Institute of Applied Science"],
    ".numazu-vtc.ac.jp": ["Numazu Vocational Training Center"],
    ".osaka-cu.ac.jp": ["Osaka City University"],
    ".osaka-u.ac.jp": ["Osaka University"],
    ".ouj.ac.jp": ["The Open University of Japan"],
    ".pu-kumamoto.ac.jp": ["Kumamoto Prefectural University"],
    ".redcross.ac.jp": ["Japanese Red Cross College of Nursing"],
    ".y.seijo.ac.jp": ["Seijo University"],
    ".shibaura-it.ac.jp": ["Shibaura Institute of Technology"],
    ".shinshu-u.ac.jp": ["Shinshu University"],
    ".shitennoji.ac.jp": ["International Buddhist University"],
    ".shoin.ac.jp": ["Kobe Shoin Women's University"],
    ".shotoku.ac.jp": ["Gifu Shotoku Gakuen University"],
    ".shudo-u.ac.jp": ["Hiroshima Shudo University"],
    ".soken.ac.jp": ["Graduate University for Advanced Studies"],
    ".sophia.ac.jp": ["Sophia University"],
    ".tachibana-u.ac.jp": ["Kyoto Tachibana Women's University"],
    ".tdj.ac.jp": ["Todaiji Gakuen High School"],
    ".titech.ac.jp": ["Tokyo Institute of Technology"],
    ".al.tiu.ac.jp": ["Tokyo International University", "東京国際大学"],
    ".tmu.ac.jp": ["Tokyo Metropolitan University"],
    ".tohoku.ac.jp": ["Tohoku University", ".group"],
    ".tokuyama.ac.jp": ["National Institute of Technology, Tokuyama College"],
    ".tonichi-kokusai-u.ac.jp": ["Higashi Nippon International University"],
    ".tut.ac.jp": ["Toyohashi University of Technology"],
    ".u-aizu.ac.jp": ["The University of Aizu"],
    ".u-gakugei.ac.jp": ["Tokyo Gakugei University"],
    ".u-keiai.ac.jp": ["Keiai University"],
    ".u-tokai.ac.jp": ["Hokkaido Tokai University"],
    ".u-tokyo.ac.jp": ["University of Tokyo", "The University of Tokyo"],
    ".uec.ac.jp": ["電気通信大学", "The University of Electro-Communications"],
    ".yamaguchi-u.ac.jp": ["Yamaguchi University"],
    ".ynu.ac.jp": ["Yokohama National University"],
    ".aoyama.jp": ["Aoyama Gakuin University"],
    ".c-league.jp": ["NSG college league"],
    ".chiba-u.jp": ["Chiba University"],
    ".p.chibakoudai.jp": ["Chiba Institute of Technology"],
    ".s.chibakoudai.jp": ["Chiba Institute of Technology."],
    ".termnet.co.jp": ["Fuji University"],
    ".denpa.jp": ["名古屋工学院専門学校"],
    ".g.kochinet.ed.jp": ["Sukumo technical high school"],
    ".gl.pen-kanagawa.ed.jp": [
        "Kanagawa-Sogo-Sangyo Senior High School",
        ".group",
    ],
    ".spec.ed.jp": ["Saitama Prefecture Schools", ".group"],
    ".fsgcl.jp": ["学校法人国際総合学園", "Kokusai sogo gakuen"],
    ".hgu.jp": ["Hokkai Gakuen University"],
    ".it-neec.jp": ["Japan Institute of Technology"],
    ".jc-21.jp": ["東北電子専門学校", "Tohoku Computer College", ".group"],
    ".jindai.jp": ["Kanagawa University"],
    ".kadai.jp": ["Kagoshima University"],
    ".kaiseigakuen.jp": [
        "開成中学校・高等学校",
        "Kaisei Junior & Senior High School",
    ],
    ".kait.jp": ["神奈川工科大学", "Kanagawa Institute of Technology"],
    ".kansaigaidai.jp": [],
    ".keio.jp": ["Keio University"],
    ".fukui.kosen-ac.jp": ["National Institute of Technology, Fukui College"],
    ".fukushima.kosen-ac.jp": [
        "National Institute of Technology, Fukushima College"
    ],
    ".gunma.kosen-ac.jp": ["National Institute of Technology, Gunma College"],
    ".hachinohe.kosen-ac.jp": [
        "National Institute of Technology, Hachinohe College"
    ],
    ".hakodate.kosen-ac.jp": [
        "函館工業高等専門学校",
        "National Institute of Technology, Hakodate College.",
    ],
    ".kagawa.kosen-ac.jp": [
        "National Institute of Technology, Kagawa College"
    ],
    ".kisarazu.kosen-ac.jp": [
        "National Institute of Technology, Kisarazu College"
    ],
    ".kumamoto.kosen-ac.jp": [
        "National Institute of Technology, Kumamoto College",
        "- http://www.kumamoto-nct.ac.jp/ (Homepage)",
        "- @g.kumamoto-nct.ac.jp and @kumamoto.kosen-ac.jp (Student's email address)",
    ],
    ".kurume.kosen-ac.jp": [
        "National Institute of Technology, Kurume College"
    ],
    ".kushiro.kosen-ac.jp": [
        "釧路工業高等専門学校",
        "National Institute of Technology, Kushiro College",
    ],
    ".nara.kosen-ac.jp": [
        "奈良工業高等専門学校",
        "National Institute of Technology, Nara College",
    ],
    ".niihama.kosen-ac.jp": [
        "National Institute of Technology, Niihama College"
    ],
    ".numazu.kosen-ac.jp": [
        "National Institute of Technology, Numazu College"
    ],
    ".oita.kosen-ac.jp": [
        "大分工業高等専門学校",
        "National Institute of Technology, Oita College",
    ],
    ".oyama.kosen-ac.jp": [
        "小山工業高等専門学校",
        "National Institute of Technology (Kosen), Oyama College",
    ],
    ".sendai.kosen-ac.jp": [
        "仙台高等専門学校",
        "National Institute of Technology, Sendai College",
    ],
    ".toba.kosen-ac.jp": ["National Institute of Technology, Toba College"],
    ".tokuyama.kosen-ac.jp": [
        "徳山工業高等専門学校",
        "National Institute of Technology, Tokuyama College",
    ],
    ".tokyo.kosen-ac.jp": ["National Institute of Technology, Tokyo College"],
    ".tomakomai.kosen-ac.jp": [
        "National Institute of Technology, Tomakomai College"
    ],
    ".toyama.kosen-ac.jp": [
        "富山高等専門学校（射水キャンパス）",
        "National Institute of Technology, Toyama College (Imizu Campus)",
    ],
    ".toyota.kosen-ac.jp": [
        "National Institute of Technology, Toyota College"
    ],
    ".tsuyama.kosen-ac.jp": [
        "National Institute of Technology, Tsuyama College"
    ],
    ".yuge.kosen-ac.jp": ["National Institute of Technology, Yuge College"],
    ".kyoto-msc.jp": ["京都医療科学大学", "Kyoto College of Medical Science"],
    ".kyoto-u.jp": ["Kyoto University"],
    ".kyudai.jp": ["Kyushu University"],
    ".mail.kyutech.jp": ["Kyushu Institute of Technology"],
    ".n-jr.jp": ["N中等部", "N Middle School"],
    ".nagoya-u.jp": ["Nagoya University"],
    ".naist.jp": ["Nara Institute of Science and Technology"],
    ".nitech.jp": ["Nagoya Institute of Technology"],
    ".npoksk-nagano.jp": ["Nagano Kyoiku College"],
    ".nsgcl.jp": ["新潟コンピュータ専門学校", "Niigata Computer College"],
    ".oecu.jp": ["Osaka Electro-Communication University"],
    ".oic.jp": ["Osaka Information and Computer Science College"],
    ".oist.jp": ["Okinawa Institute of Science and Technology"],
    ".oiu.jp": ["Osaka International University"],
    ".ous.jp": ["Okayama University of Science"],
    ".reitaku.jp": ["University of Reitaku"],
    ".seian.jp": ["Seian University of Art and Design"],
    ".seig-boys.jp": ["Seigakuin Junior and Senior High School"],
    ".sendai-nct.jp": ["Sendai National College of Technology"],
    ".senshu-u.jp": ["Senshu University"],
    ".soka-u.jp": ["Soka University", "創価大学"],
    ".sophia.jp": ["Sophia University"],
    ".suntech.jp": ["専門学校サンテクノカレッジ", "Sun Techno College"],
    ".mail.tokai-u.jp": ["TOKAI Univercity"],
    ".tokai-u.jp": ["TOKAI University"],
    ".tokai.jp": ["TOKAI University"],
    ".toyo.jp": ["Toyo University"],
    ".tut.jp": ["豊橋技術科学大学", "Toyohashi University of Technology"],
    ".uwcisak.jp": ["United World Colleges ISAK Japan"],
    ".waseda.jp": ["WASEDA University"],
    ".edu.wasedasaga.jp": [
        "早稲田佐賀中学校・高等学校",
        "Waseda Saga Junior and Senior High School",
    ],
    ".ynu.jp": ["Yokohama National University"],
    ".aiu.ac.ke": ["Africa International University"],
    ".mcampus.amref.ac.ke": [
        "Amref International University",
        "Amref International University",
    ],
    ".anu.ac.ke": ["Africa Nazarene University"],
    ".chuka.ac.ke": ["CHUKA UNIVERSITY"],
    ".student.cuk.ac.ke": ["The Co-operative University Of Kenya"],
    ".daystar.ac.ke": ["Daystar University"],
    ".dkut.ac.ke": ["Dedan Kimathi university of science and Technology"],
    ".egerton.ac.ke": ["Egerton University"],
    ".ejooust.ac.ke": [
        "Jaramogi Oginga Odinga University of Science and Technology"
    ],
    ".student.embuni.ac.ke": ["Embu University"],
    ".gau.ac.ke": ["Garissa university"],
    ".gretsauniversity.ac.ke": ["Gretsa University"],
    ".inteluni.ac.ke": ["INtel College"],
    ".jkuat.ac.ke": ["Jomo Kenyatta University of Agriculture and Technology"],
    ".jooust.ac.ke": [
        "Jaramogi Oginga Odinga University of Science and Technology"
    ],
    ".kabarak.ac.ke": ["Kabarak University"],
    ".students.kabianga.ac.ke": [
        "University of Kabianga",
        "University of Kabianga",
    ],
    ".s.karu.ac.ke": ["Karatina University"],
    ".kcau.ac.ke": ["KCA University"],
    ".kemu.ac.ke": ["Kenya Methodist University"],
    ".kibu.ac.ke": ["Kibabii University"],
    ".students.kisiiuniversity.ac.ke": [
        "Kisii University",
        "Kisii University",
    ],
    ".kisiiuniversity.ac.ke": ["Kisii University"],
    ".kisumupoly.ac.ke": ["The Kisumu National Polytechnic"],
    ".kmtc.ac.ke": ["Kenya Medical Training College"],
    ".teams.ksl.ac.ke": ["Kenya School of Law"],
    ".ku.ac.ke": ["Kenyatta University"],
    ".kwust.ac.ke": ["Kiriri Womens University of Science and Technology"],
    ".students.kyu.ac.ke": ["Kirinyaga University"],
    ".student.laikipia.ac.ke": ["Laikipia University"],
    ".laikipia.ac.ke": ["Laikipia University"],
    ".maseno.ac.ke": ["Maseno University"],
    ".mksu.ac.ke": ["Machakos University"],
    ".mku.ac.ke": ["Mount Kenya University"],
    ".mmarau.ac.ke": ["Maasai Mara University"],
    ".mmu.ac.ke": [
        "Multimedia University of Kenya",
        "Multimedia University of Kenya",
    ],
    ".mmust.ac.ke": ["Masinde Muliro University of Science and Technology"],
    ".mnp.ac.ke": ["Meru National Polytechnic"],
    ".students.mnu.ac.ke": [
        "MAMA NGINA UNIVERSITY COLLEGE",
        "School of Pure and Applied Science",
    ],
    ".mpesafoundationacademy.ac.ke": ["Mpesa Foundation Academy"],
    ".mu.ac.ke": ["Moi University"],
    ".students.must.ac.ke": ["Meru University of Science and Technology"],
    ".must.ac.ke": ["Meru University of Science and Technology"],
    ".student.mut.ac.ke": ["Murang'a University of Technology"],
    ".mut.ac.ke": ["Murang'a University of Science and Technology"],
    ".nibs.ac.ke": ["Nibs Technical College", "Nibs Technical College"],
    ".northcoastmtc.ac.ke": [
        "North Coast Medical Training College",
        "North Coast Medical Training College",
    ],
    ".students.ouk.ac.ke": ["Open University of Kenya"],
    ".pu.ac.ke": ["Pwani University College", "PU"],
    ".students.puea.ac.ke": ["Presbyterian University of East Africa"],
    ".riarauniversity.ac.ke": ["Riara University"],
    ".students.scott.ac.ke": ["Scott Christian University"],
    ".seku.ac.ke": ["South Eastern Kenya University"],
    ".spu.ac.ke": ["St. Paul’s University"],
    ".students.teau.ac.ke": ["The East African University "],
    ".student.tharaka.ac.ke": ["Tharaka University"],
    ".students.ttu.ac.ke": [
        "Taita Taveta University",
        "Taita Taveta University",
    ],
    ".students.tukenya.ac.ke": ["The Technical University of Kenya"],
    ".tukenya.ac.ke": [
        "The Technical University of Kenya",
        "The Technical University of Kenya",
    ],
    ".students.tum.ac.ke": ["Technical University of Mombasa"],
    ".ueab.ac.ke": ["University of Eastern Africa, Baraton"],
    ".students.umma.ac.ke": ["UMMA UNIVERSITY"],
    ".uoeld.ac.ke": ["University of Eldoret"],
    ".uonbi.ac.ke": ["University of Nairobi"],
    ".usiu.ac.ke": ["Unites States International University Africa"],
    ".kism.or.ke": [
        "Kenya Institute of Supplies Management",
        "Kenya Institute of Supplies Management",
    ],
    ".atk.kg": [
        "К.И. Скрябин атындагы Кыргыз улуттук агрардык университетине караштуу Султан Ибраимов атындагы Агротехникалык колледжи"
    ],
    ".auca.kg": ["American University of Central Asia"],
    ".bhu.kg": ["Bishkek State University", "Bishkek State University"],
    ".btk.kg": [
        "Бишкек Техникалык Колледжи",
        "Бишкекский Технический Колледж",
        "Bishkek Technical College",
    ],
    ".atk.com.kg": [
        "К.И. Скрябин атындагы Кыргыз улуттук агрардык университетине караштуу Султан Ибраимов атындагы Агротехникалык колледжи"
    ],
    ".adam.edu.kg": ["Adam University", "Adam University"],
    ".alatoo.edu.kg": ["Ala-Too International University "],
    ".asmi.edu.kg": [
        "S.TENTISHEV ASIAN MEDICAL INSTITUTE",
        "S.TENTISHEV ASIAN MEDICAL INSTITUTE",
    ],
    ".bafe.edu.kg": [
        "Bishkek Academy of Finance end Economics",
        "Bishkek Academy of Finance end Economics",
    ],
    ".iaau.edu.kg": ["International Ataturk Alatoo University"],
    ".krsu.edu.kg": ["Kyrgyz Russian Slavic University"],
    ".manas.edu.kg": ["Kyrgyz Turkish Manas University"],
    ".stu.msu.edu.kg": ["密歇根州立大学", "Michigan State University"],
    ".pc.edu.kg": [
        "Политехнический колледж Международного Университета Кыргызстана",
        "Polytechnic College of the International University of Kyrgyzstan",
    ],
    ".pk.edu.kg": [
        "Professional College at the Kyrgyz National University named after Zhusup Balasagyn",
        "Профессиональный колледж при Кыргызском Национальном университете имени Жусупа Баласагына",
        "Professional'nyy kolledzh pri Kyrgyzskom Natsional'nom universitete imeni Zhusupa Balasagyna",
    ],
    ".sapat.edu.kg": [
        "Tokmok high school “Umut”",
        "Tokmok high school “Umut”",
    ],
    ".iksu.kg": [
        "Иссык-Кульский Государственный университет имени Касыма Тыныстанов",
        "Issyk-Kul State University after Kasym Tynystanov",
    ],
    ".inai.kg": [
        "Кыргызско-Германский институт прикладной информатики",
        "Kyrgyz-German Institute of Applied Informatics",
    ],
    ".intuit.kg": [
        "международный университет инновационных технологий",
        "international university innovative technologies",
    ],
    ".iuca.kg": ["International University of Cental Asia"],
    ".iuk.kg": ["International University of Kyrgyzstan"],
    ".kiu.kg": [
        "Islamic Unversity of Kyrgystan (Исламский университет Кыргызстана)",
        "Islamic Unversity of Kyrgystan",
    ],
    ".knau.kg": ["Kyrgyz National Agrarian University"],
    ".knu.kg": ["Jusup Balasagyn Kyrgyz National University"],
    ".krsu.kg": [
        "Кыргызско-Российский Славянский университет имени Б.Н. Ельцина",
        "Kyrgyz-Russian Slavic University named after the First President of Russian Federation B.N. Yeltsin",
    ],
    ".ksmu.kg": ["Kyrgyz State University of Geology"],
    ".kstu.kg": [
        "Кыргызский Государственный Технический Университет имени Исхака Раззакова",
        "Kyrgyz State Technical University named after I. Razzakov",
    ],
    ".ksucta.kg": [
        "Кыргызский государственный университет строительства, транспорта и архитектуры",
        "Kyrgyz State University of Construction, Transportation and Architecture",
    ],
    ".manas.kg": ["Kyrgyz Turkish  Manas University"],
    ".oshsu.kg": [
        "Ошский государственный университет",
        "Osh State University",
    ],
    ".tsiauca.kg": ["Technical School of Innovation AUCA"],
    ".university.kg": ["Jusup Balasagyn Kyrgyz National University"],
    ".aeu.edu.kh": ["Asia Europe University"],
    ".angkor.edu.kh": ["Angkor University"],
    ".aupp.edu.kh": ["American University Of Phnom Penh"],
    ".bbu.edu.kh": ["Build Bright University"],
    ".cadt.edu.kh": [
        "Cambodia Academy of Digital Technology",
        "Cambodia Academy of Digital Technology",
    ],
    ".camtech.edu.kh": ["CamTech University"],
    ".ciaschool.edu.kh": ["CIA First International School"],
    ".cisp.edu.kh": ["Canadian International School of Phnom Penh"],
    ".cup.edu.kh": ["Chamreun University of Poly Technology"],
    ".cus.edu.kh": ["Cambodia University of Specialties"],
    ".diu.edu.kh": ["សាកលវិទ្យាល័យអន្តរជាតិ ឌូវី", "Dewey International University"],
    ".iu.edu.kh": ["International University"],
    ".kit.edu.kh": ["Kirirom Institute of Technology"],
    ".lifeun.edu.kh": ["Life University"],
    ".mekong.edu.kh": ["Cambodian Mekong University"],
    ".npic.edu.kh": ["National Polytechnic Institute of Cambodia"],
    ".num.edu.kh": ["National University of Management"],
    ".paragoniu.edu.kh": ["Paragon International University"],
    ".ppiu.edu.kh": [
        "Phnom Penh International University",
        "Phnom Penh International University",
    ],
    ".puc.edu.kh": ["Pannnasatra University of Cambodia"],
    ".puthisastra.edu.kh": ["Puthisastra University"],
    ".rua.edu.kh": ["Royal University of Agriculture"],
    ".rufa.edu.kh": ["Royal University of Fine Arts"],
    ".sru.edu.kh": ["Svey Reong University"],
    ".uc.edu.kh": ["University of Cambodia"],
    ".western.edu.kh": ["Western University"],
    ".st.midocean.edu.km": ["Midocean University"],
    ".uni.kn": ["University of Konstanz"],
    ".o365-bfw.koeln": ["Berufsförderungswerk Köln"],
    ".schule.koeln": [
        "Georg-Simon-Ohm-Berufskolleg",
        "Georg-Simon-Ohm-Vocational College",
    ],
    ".student.42gyeongsan.kr": [
        "42 경산 (경산 이노베이션 아카데미)",
        "42 Gyeongsan",
    ],
    ".student.42seoul.kr": ["42 서울 (이노베이션 아카데미)", "42 Seoul"],
    ".42seoul.kr": ["42서울", "42SEOUL"],
    ".ajou.ac.kr": ["Ajou University"],
    ".andong.ac.kr": ["Andong National University"],
    ".ansan.ac.kr": ["Ansan University"],
    ".student.anu.ac.kr": [
        "Andong National University",
        "Andong National University",
    ],
    ".anu.ac.kr": ["국립안동대학교", "Andong National University"],
    ".stud.assist.ac.kr": ["서울과학종합대학원대학교", "aSSIST University"],
    ".assist.ac.kr": ["aSSIST University"],
    ".g.baewha.ac.kr": ["배화여자대학교"],
    ".o.baewha.ac.kr": ["배화여자대학교"],
    ".bau.ac.kr": ["백석예술대학교"],
    ".365.bc.ac.kr": ["부천대학교", "Bucheon National University"],
    ".bdu.ac.kr": ["부산디지털대학교", "Busan Digital University"],
    ".bible.ac.kr": ["한국성서대학교", "Korean Bible University"],
    ".go.bist.ac.kr": [
        "부산과학기술대학교",
        "Busan Institute of Science and Technology",
    ],
    ".o365.bist.ac.kr": [
        "산과학기술대학교 ",
        "Busan Institute of Science and Technology ",
    ],
    ".bnu.ac.kr": ["Pusan National University"],
    ".student.bnue.ac.kr": ["부산교육대학교"],
    ".bscu.ac.kr": ["백석문화대학교", "Baekseok Culture University"],
    ".bsks.ac.kr": ["Busan Kyungsang College"],
    ".bufs.ac.kr": ["부산외국어대학교", "Busan University of Foreign Studies"],
    ".busan.ac.kr": ["Pusan National University"],
    ".ca.ac.kr": ["청암대학교", "Cheongam College"],
    ".cataegu.ac.kr": ["Catholic University of Taegu-Hyosung"],
    ".catholic.ac.kr": ["가톨릭대학교", "Catholic University of Korea"],
    ".cbnu.ac.kr": ["충북대학교", "Chungbuk National University"],
    ".cbu.ac.kr": ["충북대학교"],
    ".cha.ac.kr": ["차의과학대학교"],
    ".changwon.ac.kr": ["Changwon National University"],
    ".chauniv.ac.kr": ["차의과학대학교", "CHA University"],
    ".cheju.ac.kr": ["Cheju National University"],
    ".chodang.ac.kr": ["Chodang University"],
    ".chonbuk.ac.kr": ["Chonbuk National University"],
    ".chongju.ac.kr": ["Chongju University"],
    ".chongshin.ac.kr": ["총신대학교", "CHONGSHIN UNIVERSITY"],
    ".chonnam.ac.kr": ["Chonnam National University"],
    ".chosun.ac.kr": ["Chosun University"],
    ".o365.chsu.ac.kr": [
        "충북보건과학대학교북보건과학대학교",
        "Chungbuk Health & Science University",
    ],
    ".chu.ac.kr": ["제주한라대학교", "CHEJU HALLA UNIVERSITY"],
    ".chugye.ac.kr": ["Chugye University for the Arts"],
    ".chungbuk.ac.kr": ["Chungbuk National University"],
    ".chungnam.ac.kr": ["Chungnam National University"],
    ".chungwoon.ac.kr": ["청운대학교", "ChungWoon University"],
    ".comm.cje.ac.kr": [
        "청주교육대학교",
        "Cheongju National University of Education",
    ],
    ".office.cje.ac.kr": [
        "청주교육대학교",
        "Cheongju National University of Education",
    ],
    ".cje.ac.kr": [
        "청주교육대학교",
        "CHEONGJU NATIONAL UNIVERSITY OF EDUCATION",
    ],
    ".cju.ac.kr": ["청주대학교", "Cheongju University"],
    ".g.cnc.ac.kr": ["Chosun University", "조선대학교"],
    ".cnsu.ac.kr": ["충남도립대학교"],
    ".s.cntu.ac.kr": ["전남과학대학교", "Chunnam Techno University"],
    ".g.cnu.ac.kr": ["Chungnam National University", "충남대학교"],
    ".mail.cnu.ac.kr": ["Chungnam National University", "충남대학교"],
    ".cnu.ac.kr": ["Chungnam National University", "충남대학교"],
    ".student.cnue.ac.kr": [
        "춘천교육대학교",
        "Chuncheon National University of Education",
    ],
    ".cs.ac.kr": ["창신대학교", "Chongshin University"],
    ".cst.ac.kr": ["조선이공대학"],
    ".csu.ac.kr": ["총신대학교"],
    ".cu.ac.kr": ["Daegu Catholic University"],
    ".cufs.ac.kr": [
        "한국사이버외국어대학교",
        "Cyber Hankuk University of Foreign Studies",
    ],
    ".cuk.ac.kr": ["Catholic University of Korea"],
    ".student.cup.ac.kr": ["부산가톨릭대학교", "Catholic University of Pusan"],
    ".gs.cwnu.ac.kr": ["국립창원대학교", "Changwon national university"],
    ".email.daelim.ac.kr": ["대림대학교", "DAELIM UNIVERSITY COLLEGE"],
    ".daelim.ac.kr": ["대림대학교"],
    ".daewon.ac.kr": ["대원대학교", "Daewon University"],
    ".dankook.ac.kr": ["Dankook University"],
    ".dcu.ac.kr": ["대구사이버대학교", "Daegu Cyber University"],
    ".deu.ac.kr": ["DONG-EUI University", "동의대학교"],
    ".dgist.ac.kr": ["DGIST", "DGIST"],
    ".dhc.ac.kr": ["대구보건대학교"],
    ".dhu.ac.kr": ["\ufeffDaegu Haany University"],
    ".student.dist.ac.kr": ["동원과학기술대학교"],
    ".dju.ac.kr": ["Daejeon University"],
    ".dmu.ac.kr": ["dongyang university"],
    ".donga.ac.kr": ["Dong-A University"],
    ".dongduk.ac.kr": ["Dongduk Women's University"],
    ".dongeui.ac.kr": ["Dong Eui University"],
    ".dongguk.ac.kr": ["Dongguk University"],
    ".student.dongnam.ac.kr": ["동남보건대", "DONGNAM HEALTH UNIVERSITY"],
    ".dongseo.ac.kr": ["Dongseo University"],
    ".dongshinu.ac.kr": ["Dongshin University"],
    ".dongyang.ac.kr": ["Dongyang University"],
    ".office.doowon.ac.kr": ["두원공과대학교", "DOOWON TECHNICAL UNIVERSITY"],
    ".doowon.ac.kr": ["두원공과대학교", "DOOWON TECHNICAL UNIVERSITY"],
    ".ds.ac.kr": ["덕성여자대학교"],
    ".i.dst.ac.kr": [
        "대전과학기술대학교",
        "Daejeon Institute of Science and Technology",
    ],
    ".dsuci.ac.kr": ["Dongseo University", "동서대학교"],
    ".du.ac.kr": ["동서울대학교", "DONG SEOUL UNIVERSITY"],
    ".ducksung.ac.kr": ["덕성여자대학교"],
    ".duksung.ac.kr": ["Duksung Women's University"],
    ".dwu.ac.kr": ["덕성여자대학교"],
    ".dytc.ac.kr": ["Dong Yang University of Technology"],
    ".dyu.ac.kr": ["동양대학교", "Dongyang University"],
    ".ekgu.ac.kr": ["경기대학교 원격 교육원"],
    ".g.eulji.ac.kr": ["을지대학교", "Eulji University"],
    ".stuoffice.eulji.ac.kr": ["을지대학교", "Eulji_University"],
    ".eumc.ac.kr": [
        "이화여자대학교 의료원",
        "Ewha Womans University Medical Center",
    ],
    ".ewha.ac.kr": ["Ewha Women's University"],
    ".gachon.ac.kr": ["Gachon University"],
    ".gangdong.ac.kr": ["Gangdong University"],
    ".gangseo.ac.kr": ["강서대학교", "Gangseo University"],
    ".gcu.ac.kr": ["김천대학교", "Gimcheon University "],
    ".ghent.ac.kr": ["Ghent University Global Campus"],
    ".ghu.ac.kr": ["광주보건대학교"],
    ".ginue.ac.kr": [
        "경인교육대학교",
        "Gyeong-In National University of Education",
    ],
    ".gm.gist.ac.kr": [
        "광주과학기술원",
        "Gwangju Institute of Science and Technology",
    ],
    ".gist.ac.kr": [
        "광주과학기술원",
        "Gwangju Institute of Science and Technology",
    ],
    ".gjcu.ac.kr": ["국제사이버대학교", "gjcu"],
    ".gknu.ac.kr": [
        "경국대학교",
        "Gyeongkuk National University",
        "https://www.gknu.ac.kr",
        "https://www.gknu.ac.kr/global/index.do",
    ],
    ".gnu.ac.kr": [],
    ".gsnu.ac.kr": ["Gyeongsang National University"],
    ".gumi1.ac.kr": ["구미대학교", "GUMI UNIVERSITY"],
    ".gw.ac.kr": ["강원도립대학교"],
    ".gwangju.ac.kr": ["광주대학교", "Gwang-ju university"],
    ".gwnu.ac.kr": ["Gangneung-Wonju University"],
    ".hu.halla.ac.kr": ["한라대학교", "Halla  University"],
    ".hallym.ac.kr": ["Hallym University"],
    ".hanbat.ac.kr": ["국립한밭대학교", "Hanbat National University"],
    ".handong.ac.kr": ["한동대학교", "Handong Global University"],
    ".hangkong.ac.kr": ["Hankuk Aviation University"],
    ".hannam.ac.kr": ["Hannam University"],
    ".hansei.ac.kr": ["Hansei University"],
    ".hanseo.ac.kr": ["Hanseo University"],
    ".hanshin.ac.kr": ["Hanshin University"],
    ".hansung.ac.kr": ["Hansung University Seoul"],
    ".hanyang.ac.kr": ["Hanyang University"],
    ".s.hit.ac.kr": ["대전보건대학교"],
    ".hknu.ac.kr": ["한경국립대학교", "Hankyong National University"],
    ".m365.hnu.ac.kr": ["한남대학교", "hannam university"],
    ".honam.ac.kr": ["Honam University"],
    ".hongik.ac.kr": ["Hongik University"],
    ".hoseo.ac.kr": ["Hoseo University"],
    ".howon.ac.kr": [
        "Chonbuk Sanup University of Technology (Howon University)"
    ],
    ".hs.ac.kr": ["한신대학교", "Hanshin University"],
    ".office.hsc.ac.kr": ["한림성심대학교", "Hallym Polytechnic University"],
    ".hycu.ac.kr": ["Hanyang Cyber University"],
    ".hyejeon.ac.kr": ["Hyejeon College"],
    ".hyupsung.ac.kr": ["Hyupsung University"],
    ".ianyang.ac.kr": ["연성대학교"],
    ".ict.ac.kr": ["ICT폴리텍대학"],
    ".icu.ac.kr": ["Information and Communications University"],
    ".idas.ac.kr": [
        "홍익대학교 IDAS",
        "Hongik University International Design School for Advanced Studies",
    ],
    ".ikw.ac.kr": ["경운대학교", "Kyungwoon University"],
    ".incheon.ac.kr": ["Incheon National University"],
    ".office.induk.ac.kr": ["인덕대학교", "Induk University"],
    ".induk.ac.kr": ["인덕대학교", "Induk University"],
    ".inha.ac.kr": ["Inha University"],
    ".inhatc.ac.kr": ["인하공업전문대학교", "Inha Technical College"],
    ".oasis.inje.ac.kr": ["Inje University"],
    ".inje.ac.kr": ["Inje University"],
    ".inu.ac.kr": ["Incheon National University"],
    ".iscu.ac.kr": ["서울사이버대학교", "Seoul Cyber University"],
    ".jbnu.ac.kr": ["전북대학교"],
    ".jbu.ac.kr": ["전북대학교"],
    ".o365.jeiu.ac.kr": ["재능대학교"],
    ".jeonju.ac.kr": ["Jeonju University"],
    ".office.jj.ac.kr": ["전주대학교", "Jeonju University"],
    ".jj.ac.kr": ["전주대학교", "jeonju university"],
    ".jnu.ac.kr": ["전남대학교", "Chonnam National University"],
    ".jvision.ac.kr": ["전주비전대학교", "jvision.ac.kr"],
    ".kaist.ac.kr": [
        "Korea Advanced Institute of Science and Technology",
        "KAIST",
    ],
    ".kangnam.ac.kr": ["Kangnam University"],
    ".kangnung.ac.kr": ["Kangnung National University"],
    ".kangwon.ac.kr": ["Kangwon National University"],
    ".karts.ac.kr": ["Korea National University of Arts"],
    ".kau.ac.kr": ["한국항공대학교", "Korea Aerospace Universicy"],
    ".kaya.ac.kr": ["Kaya University"],
    ".kaywon.ac.kr": ["계원예술대학교", "Kaywon University"],
    ".kbtus.ac.kr": [
        "한국침례신학대학교",
        "Korea Baptist Theological University/Seminary",
    ],
    ".kbu.ac.kr": ["경복대학교", "Kyungbok University"],
    ".kdischool.ac.kr": ["KDI School of Public Policy and Management"],
    ".kdu.ac.kr": ["극동대학교", "far east university"],
    ".kduniv.ac.kr": ["경동대학교", "Kyungdong University"],
    ".keimyung.ac.kr": ["Keimyung University"],
    ".kentech.ac.kr": [
        "한국에너지공과대학교",
        "Korea Institute of Energy Technology",
    ],
    ".khcu.ac.kr": ["Kyung Hee Cyber University"],
    ".khu.ac.kr": ["Kyung Hee University", "Global campus"],
    ".kiu.ac.kr": ["경일대학교", "Kyungil University"],
    ".office.kiwu.ac.kr": ["경인여대"],
    ".kku.ac.kr": ["Konkuk University", "Glocal campusß"],
    ".kmaritime.ac.kr": ["Korea Maritime University"],
    ".kmcu.ac.kr": ["계명문화대학교"],
    ".g.kmou.ac.kr": [],
    ".kmou.ac.kr": [
        "국립한국해양대학교",
        "National Korea Maritime & Ocean University",
    ],
    ".stu.kmu.ac.kr": ["계명대학교"],
    ".knou.ac.kr": ["Korea National Open University"],
    ".m365.knsu.ac.kr": ["한국체육대학교"],
    ".knsu.ac.kr": ["한국체육대학교", "Korea National Sport University"],
    ".knu.ac.kr": ["Kyungpook National University"],
    ".knua.ac.kr": ["Korea National University of Arts"],
    ".knupe.ac.kr": ["Korea National University of Physical Education"],
    ".office.koje.ac.kr": ["거제대학교", "Geoje(Koje) University"],
    ".konkuk.ac.kr": ["Konkuk University"],
    ".konyang.ac.kr": ["Konyang University"],
    ".kookje.ac.kr": ["국제대학", "Kookje University"],
    ".kookmin.ac.kr": ["Kookmin University"],
    ".office.kopo.ac.kr": [
        "한국폴리텍대학교(인천캠퍼스)",
        "Korea Polytechics of University",
    ],
    ".kopo.ac.kr": ["한국폴리텍대학", "Korea Polytechnics"],
    ".korea.ac.kr": ["Korea University"],
    ".koreait.ac.kr": ["한국IT직업전문학교", "Korea IT Vocational School"],
    ".koreatech.ac.kr": ["한국기술교육대학교", "Koreatech"],
    ".office.kornu.ac.kr": ["나사렛대학교"],
    ".kosin.ac.kr": ["Kosin University"],
    ".mail.kua.ac.kr": ["국제예술대학교", "Kukje Universty of Arts"],
    ".kumoh.ac.kr": ["Kumoh National Institute of Technology"],
    ".kunsan.ac.kr": ["Kunsan National Universiy"],
    ".kw.ac.kr": ["광운대학교", "Kwangwoon University"],
    ".kwangju.ac.kr": ["Kwangju University"],
    ".kycu.ac.kr": ["KONYANG CYBER UNIVERSITY"],
    ".kyuh.ac.kr": ["Konyang university"],
    ".kyungbok.ac.kr": ["Kyungbok University"],
    ".kyunghee.ac.kr": ["Kyunghee University"],
    ".kyungmin.ac.kr": ["경민대학교", "kyungmin"],
    ".kyungnam.ac.kr": ["경남대학교", "Kyungnam University"],
    ".kyungpook.ac.kr": ["Kyungpook National University"],
    ".kyungsung.ac.kr": ["Kyungsung University"],
    ".kyungwon.ac.kr": ["Kyungwon University"],
    ".mjc.ac.kr": ["명지전문대학"],
    ".mju.ac.kr": ["Myongji University", "명지대학교"],
    ".mmu.ac.kr": ["Mokpo National Maritime University"],
    ".mokpo.ac.kr": ["Mokpo National University"],
    ".mts.ac.kr": ["감리신학대학교"],
    ".mtu.ac.kr": ["감리신학대학교"],
    ".mu.ac.kr": ["목원대학교", "Mokwon University"],
    ".myongji.ac.kr": ["Myongji University"],
    ".nsu.ac.kr": ["남서울대학교", "Namseoul University"],
    ".nuch.ac.kr": [
        "한국전통문화대학교",
        "Korea National University of Heritage",
    ],
    ".mail.ocu.ac.kr": [
        "한국열린사이버대학교",
        "Open Cyber University of Korea",
    ],
    ".ocu.ac.kr": ["한국열린사이버대학교", "OPEN CYBER UNIVERSITY OF KOREA"],
    ".ok.ac.kr": ["충청대학교", "chungcheong university"],
    ".paichai.ac.kr": ["Paichai University"],
    ".pcu.ac.kr": ["배재대학교", "paichai university"],
    ".pknu.ac.kr": ["Pukyong National University"],
    ".pnu.ac.kr": ["부산대학교"],
    ".police.ac.kr": ["Korean Police National University"],
    ".postech.ac.kr": ["Pohang University of Science and Technology"],
    ".pro.ac.kr": ["한국영상대학교", "KOREA UNIVERSITY OF MEDIA ARTS"],
    ".pufs.ac.kr": ["Pusan University of Foreign Studies"],
    ".pukyong.ac.kr": ["PUKYONG NATIONAL UNIVERSITY", "부경대학교"],
    ".pusan.ac.kr": ["Pusan National University"],
    ".puts.ac.kr": ["Presbyterian University and Theological Seminary, Korea"],
    ".sangji.ac.kr": ["Sang Ji University"],
    ".member.scau.ac.kr": ["서울문화예술대학교"],
    ".sch.ac.kr": ["Soonchunhyang University"],
    ".stu.scjc.ac.kr": ["청암대학교", "Cheongam College"],
    ".scnu.ac.kr": ["국립순천대학교", "Sunchon National University"],
    ".office.sehan.ac.kr": ["세한대학교", "SEHAN UNIVERSITY"],
    ".sejong.ac.kr": ["Sejong University"],
    ".sem.ac.kr": ["세명대학교"],
    ".semyung.ac.kr": ["Semyung University"],
    ".seoil.ac.kr": ["서일대학교"],
    ".student.seoularts.ac.kr": ["서울예술대학교"],
    ".seowon.ac.kr": ["Seowon University"],
    ".sewc.ac.kr": ["숭의여자대학교"],
    ".mysg.shingu.ac.kr": ["신구대학교"],
    ".shinhan.ac.kr": ["Shinhan University"],
    ".o365.shu.ac.kr": ["삼육보건대학교", "Sahmyook Health University"],
    ".shu.ac.kr": ["삼육보건대학교"],
    ".silla.ac.kr": ["Silla University"],
    ".sillain.ac.kr": ["신라대학교"],
    ".sjcu.ac.kr": ["세종사이버대학교", "Sejong Cyber University"],
    ".office.skhu.ac.kr": ["Sungkonghoe University"],
    ".skhu.ac.kr": ["SungKongHoe University"],
    ".skku.ac.kr": ["Sung Kyun Kwan University"],
    ".skuniv.ac.kr": ["Seokyeong University"],
    ".sm.ac.kr": ["숙명여자대학교"],
    ".snu.ac.kr": ["Seoul National University"],
    ".student.snue.ac.kr": [
        "서울교육대학교",
        "Seoul National University of Education",
    ],
    ".snue.ac.kr": ["서울교육대학교"],
    ".snut.ac.kr": ["Seoul National University of Technology"],
    ".sogang.ac.kr": ["Sogang University"],
    ".student.solbridge.ac.kr": [
        "솔브릿지 국제경영대학",
        "SolBridge International School of Business",
    ],
    ".songeui.ac.kr": [
        "가톨릭대학교 성의교정",
        "The Catholic University of Korea - Songeui Campus",
    ],
    ".office.songwon.ac.kr": ["송원대학교", "Songwon University"],
    ".sookmyung.ac.kr": ["Sookmyung Women's University"],
    ".soongsil.ac.kr": ["Soongsil University"],
    ".sou.ac.kr": ["서영대학교", "SEOYEONG University"],
    ".office.ssc.ac.kr": ["수원과학대학교", "suwon science college"],
    ".ssc.ac.kr": ["수원과학대학교"],
    ".ssu.ac.kr": ["Soongsil University"],
    ".stu.ac.kr": ["제주대학교", "Jeju National University"],
    ".suncheon.ac.kr": ["국립순천대학교"],
    ".sungkyul.ac.kr": ["Sungkyul University"],
    ".sungshin.ac.kr": ["Sungshin Women's University"],
    ".suwon.ac.kr": ["Suwon University"],
    ".svu.ac.kr": ["서울벤처대학원대학교", "SEOUL VENTURE UNIVERSITY"],
    ".swu.ac.kr": ["Seoul Women's University"],
    ".staff.swwu.ac.kr": ["수원여자대학교"],
    ".student.swwu.ac.kr": ["수원여자대학교"],
    ".swwu.ac.kr": ["수원여자대학교", "Suwon Woman's University"],
    ".syu.ac.kr": ["삼육대학교", "Sahmyook University"],
    ".syuin.ac.kr": ["삼육대학교 ", "Sahmyook University"],
    ".taegu.ac.kr": ["Taegu University"],
    ".taejae.ac.kr": ["태재대학교", "TAEJAE University"],
    ".tu.ac.kr": ["동명대학교", "Tongmyong University"],
    ".tw.ac.kr": ["동원대학교", "Tongwon Univercity"],
    ".u1.ac.kr": ["유원대학교", "Yu-Won University"],
    ".office.uc.ac.kr": ["울산과학대학교", "Ulsan College"],
    ".office.uhs.ac.kr": ["협성대학교", "Hyupsung University"],
    ".ulsan.ac.kr": ["Ulsan University"],
    ".unist.ac.kr": ["Ulsan National Institute of Science and Technology"],
    ".uos.ac.kr": ["Seoul City University"],
    ".a.ut.ac.kr": [
        "한국교통대학교",
        "Korea National University of Transportation",
    ],
    ".g.ut.ac.kr": [
        "한국교통대학교",
        "Korea National University of Transportation",
    ],
    ".ut.ac.kr": [],
    ".livemail.wdu.ac.kr": ["원광디지털대학교"],
    ".wku.ac.kr": ["원광대학교", "WONKWANG UNIVERSITY"],
    ".wonkwang.ac.kr": ["Wonkwang University"],
    ".woosuk.ac.kr": ["Woosuk University"],
    ".live.wsu.ac.kr": ["우송대학교", "Woosong University"],
    ".wsu.ac.kr": ["우송대학교", "woosong university"],
    ".wu.ac.kr": ["원광보건대학교", "WONKWANG HEALTH SCIENCE UNIVERSITY"],
    ".yasu.ac.kr": ["용인예술과학대학교", "YONG-IN ARTS & SCIENCE UNIVERSITY"],
    ".st.yc.ac.kr": ["연암공과대학교", "Yonam Institute of Technology"],
    ".yc.ac.kr": ["연암공과대학교", "Yonam Institute of Technology"],
    ".yeonsung.ac.kr": ["연성대학교", "Yeonsung University"],
    ".yeungnam.ac.kr": ["Yeungnam University"],
    ".yi.ac.kr": ["용인 대학교", "Yongin University"],
    ".yit.ac.kr": ["여주대학교"],
    ".yiu.ac.kr": ["Yongin University"],
    ".yjc.ac.kr": ["영진전문대학교"],
    ".g.yju.ac.kr": ["영진전문대학교", "YEUNGJIN UNIVERSITY"],
    ".yju.ac.kr": ["영진전문대"],
    ".ync.ac.kr": ["영남이공대학교", "Yeungnam University College"],
    ".ynu.ac.kr": ["Yeungnam University"],
    ".yonam.ac.kr": ["연암대학교", "Yonam College"],
    ".yonsei.ac.kr": ["Yonsei University", "연세대학교"],
    ".office.ysu.ac.kr": ["영산대학교"],
    ".ysu.ac.kr": ["영산대학교", "YOUNGSAN UNIVERSITY"],
    ".yuhan.ac.kr": ["유한대학", "yuhan colledge"],
    ".bnu.kr": ["부산대학교", "Pusan National University"],
    ".cau.kr": ["Chung-Ang University"],
    ".chosun.kr": ["Chosun University"],
    ".cju.kr": ["청주대학교", "Cheongju University"],
    ".djwondang.cneo365.kr": ["원당중학교", "wondang middle school"],
    ".hongseong.cneo365.kr": ["홍성고등학교", "Hongseong High School"],
    ".cnu.kr": ["Chungnam National University", "충남대학교"],
    ".mz.co.kr": ["Megazone IT Lifelong Education Center"],
    ".uos.co.kr": ["서울시립대학교"],
    ".dgu.kr": ["동국대학교", "dgu"],
    ".ddsciencehs.dje365.kr": [
        "대전동신과학고등학교",
        "Daejeon Dongsin Science High School",
    ],
    ".djgces.dje365.kr": [
        "대전갑천초등학교",
        "Daejeon Gabcheon Elementry School",
    ],
    ".gpms.dje365.kr": ["대전관평중학교", "Daejeong Gwanpyeong Middle School"],
    ".namseonms.dje365.kr": [
        "대전남선중학교",
        "Daejeon Namseon Middle School",
    ],
    ".dyshs.djsch.kr": ["대전용산고등학교", "Daejeon Yongsan High School"],
    ".jeonminhs.djsch.kr": ["대전전민고등학교", "Daejeon Jeonmin High School"],
    ".dshs.kr": ["대전대신고등학교", "Daejeon Daeshin High School"],
    ".dsu.kr": ["dongshin university"],
    ".dulwich-seoul.kr": ["Dulwich College Seoul"],
    ".gjue.kr": ["공주교육대학교", "Kongju National University of Education"],
    ".gnu.kr": ["경상국립대학교"],
    ".cbs-h.cbe.go.kr": ["충북과학고등학교", "chungbuk science high school"],
    ".chungil-m.cbe.go.kr": ["충일중학교", "Chungil Middle School"],
    ".daewon-h.cbe.go.kr": ["충주대원고등학교", "Chungju Daewon High School"],
    ".sangdang-h.cbe.go.kr": ["상당고등학교", "Sangdang High School"],
    ".cberi.go.kr": [
        "충청북도교육연구정보원",
        "Chungcheongbuk-do Education Research and Information Institute",
    ],
    ".dge.go.kr": [
        "대구광역시교육청",
        "Daegu Metropolitan Office of Education",
    ],
    ".gsuite.gen.go.kr": ["살레시오고등학교", "salesio high school"],
    ".haman-h.gne.go.kr": ["함안고등학교", "Haman High School"],
    ".aybuheungm.goe.go.kr": ["안양부흥중학교", "AnyangBuheung Middle School"],
    ".bojeongh.goe.go.kr": ["보정고등학교", "Bojeong High School"],
    ".changhyunh.goe.go.kr": ["창현고등학교", "Changhyun High School"],
    ".daepyonge.goe.go.kr": ["대평초등학교", "daepyung elementary school"],
    ".daepyongm.goe.go.kr": ["대평중학교", "daepyong middle school"],
    ".dshangangm.goe.go.kr": ["다산한강중학교", "Dasan Hangang Middle School"],
    ".ggh.goe.go.kr": [
        "경기도교육청",
        "Gyeonggi Province Office of Education",
        ".group",
    ],
    ".gghsm.goe.go.kr": ["광교호수중학교", "Gwanggyo Hosu Middle School"],
    ".ggm.goe.go.kr": [
        "경기도교육청",
        "Gyeonggi Province Office of Education",
        ".group",
    ],
    ".gokjeongh.goe.go.kr": ["곡정고등학교", "Gokjeong High School"],
    ".haesolm.goe.go.kr": ["해솔중학교", "Haesol Middle School"],
    ".hanambizh.goe.go.kr": [
        "하남경영고등학교",
        "Hanam Management High School",
    ],
    ".hanamh.goe.go.kr": ["하남고등학교", "hanam high school"],
    ".ilsanh.goe.go.kr": [
        "일산국제컨벤션고등학교",
        "Ilsan International Convention High School",
    ],
    ".jukgeonm.goe.go.kr": ["Jukgeon Middle School"],
    ".mae-wone.goe.go.kr": ["매원초등학교", "Maewon elementary School"],
    ".pjwadonge.goe.go.kr": [
        "파주와동초등학교",
        "Paju Wadong Elementary School",
    ],
    ".samil-th.goe.go.kr": ["삼일공업고등학교", "Samil Technical High School"],
    ".shinbongm.goe.go.kr": ["신봉중학교", "Shinbong Middle School"],
    ".shth.goe.go.kr": ["수원하이텍고등학교", "Suwon Hi-tech High School"],
    ".suwondasanm.goe.go.kr": ["수원다산중학교", "Suwon Dasan Middle School"],
    ".woosungh.goe.go.kr": ["우성고등학교", "WooSung High School"],
    ".yshinchonm.goe.go.kr": [
        "용인신촌중학교",
        "Yongin Shinchon Middle School",
    ],
    ".hifive.go.kr": ["선린인터넷고등학교", "Sunrin Internet High School"],
    ".gclass.ice.go.kr": [
        "인천광역시교육청",
        "Incheon Metropolitan Office of Education",
    ],
    ".ice.go.kr": ["인천기계공업고등학교"],
    ".onedu.jje.go.kr": ["남주고등학교", "Namju High School"],
    ".o365.pen.go.kr": ["부산광역시교육청"],
    ".sen.go.kr": ["SUNGSU TECHNICAL HIGH SCHOOL"],
    ".vision-m.goept.kr": ["비전중학교", "Vision Middle School"],
    ".bdj-h.goesn.kr": ["대진고등학교"],
    ".seohyeon-m.goesn.kr": ["서현중학교", "seohyeon middle school"],
    ".hanma.kr": ["\ufeff경남대학교", "Kyungnam University"],
    ".hnu.kr": ["한남대학교", "Hannam University"],
    ".dimigo.hs.kr": [
        "Korea Digital Media High School",
        "한국디지털미디어고등학교",
    ],
    ".dolma.hs.kr": ["Dolma High School", "돌마고등학교"],
    ".dsm.hs.kr": [
        "Daedeok Software Meister Highschool",
        "대덕소프트웨어마이스터고등학교",
    ],
    ".e-mirim.hs.kr": ["Mirim Meister Highschool"],
    ".hana.hs.kr": ["Hana Academy Seoul", "하나고등학교"],
    ".hansei.hs.kr": ["Hansei Cyber Security High School"],
    ".has.hs.kr": ["하나고등학교", "Hana Academy Seoul"],
    ".jeonghyeon.hs.kr": ["정현고등학교 ", "Jeonghyeon High School"],
    ".ksa.hs.kr": [
        "Korea Science Academy of KAIST",
        "한국과학기술원 부설 한국과학영재학교",
    ],
    ".one.hs.kr": ["Hana Academy Seoul", "하나고등학교"],
    ".gyeongseong.sen.hs.kr": ["Gyeongseong High School", "경성고등학교"],
    ".shinsung.hs.kr": ["ShinSung High School", "-신성고등학교"],
    ".sshs.hs.kr": [
        "Seoul Science High School",
        "서울과학고등학교",
        "official website(Korean): https://sshs.sen.hs.kr/",
        "official website(English): http://en.sshs.hs.kr/html/index.php",
        'curriculum: download "2022교육계획서_서울과학고(0421).pdf" at https://sshs.sen.hs.kr/120316/subMenu.do. Then, look at the page 26.',
        "proof of official domain(screenshot): https://drive.google.com/file/d/18r7TRVlMpuGLb7Dgfif3kFZ9FZurm0Jp/view?usp=sharing",
    ],
    ".hufs.kr": [
        "한국외국어대학교",
        "Hankuk University of Foreign Studies (HUFS)",
    ],
    ".iasa.icehs.kr": [
        "인천과학예술영재학교",
        "Incheon Academy of Science and Arts",
    ],
    ".ikw.kr": ["경운대학교", "KYUNGWOON UNIVERSITY"],
    ".innoaca.kr": ["이노베이션아카데미", "INNOVATIONACADEMY"],
    ".innovationacademy.kr": ["이노베이션아카데미", "INNOVATIONACADEMY"],
    ".itc.kr": ["인하공업전문대학", "Inha Technical College"],
    ".muan.hs.jne.kr": ["무안고등학교", "Muan Highschool"],
    ".shinbuket.hs.jne.kr": [
        "전남에너지고등학교",
        "Jeonnam energy high school",
    ],
    ".jnu.kr": ["Chonnam National University"],
    ".kau.kr": ["Korea Aerospace University"],
    ".kiu.kr": ["Kyungill University"],
    ".kmu.kr": ["계명대학교", "Keimyung University"],
    ".knu.kr": ["경북대학교"],
    ".kwus.kr": ["광주여자대학교"],
    ".kyungpook.kr": ["경북대학교"],
    ".liveuou.kr": ["Ulsan University"],
    ".bakhyun.ms.kr": ["백현중학교", "Bakhyun Middle School"],
    ".mtu.kr": ["감리신학대학교-메인"],
    ".cmcnu.or.kr": [
        "가톨릭대학교 가톨릭중앙의료원",
        "CATHOLIC UNIVERSITY OF KOREA, CATHOLIC MEDICAL CENTER",
    ],
    ".ksdream.or.kr": ["광성드림학교", "KWANGSUNG"],
    ".socialwork.or.kr": ["Korea Nazarene University"],
    ".ymgh.or.kr": ["양명여자고등학교", "Yangmyung Girls' High School"],
    ".pnu.kr": ["부산대학교", "Pusan National University"],
    ".kist.re.kr": ["Korea Institute of Science and Technology"],
    ".ncc.re.kr": [
        "국립암센터 국제암대학원대학교",
        "National Cancer Center Korea Graudate School of Cancer Science and Policy",
    ],
    ".sangmyung.kr": ["Sang Myung University"],
    ".ahyeon.sen.sc.kr": ["Ahyeon Polytechnic School", "아현산업정보학교"],
    ".xavier.sc.kr": ["LYCEE INTERNATIONAL XAVIER"],
    ".seoultech.kr": [
        "서울과학기술대학교",
        "Seoul National University of Science and Technology",
    ],
    ".boram.sjedums.kr": ["보람중학교"],
    ".skhu.kr": ["SungKongHoe University"],
    ".smit.kr": [
        "서울미디어대학원대학교",
        "Seoul Media Institute of Technology",
    ],
    ".sungil-i.kr": ["성일정보고등학교", "Sungil Information High School"],
    ".sunmoon.kr": ["선문대학교", "sunmoon university"],
    ".ynu.kr": ["영남대학교", "Yeungnam University"],
    ".britishuniversity.krd": ["British International University"],
    ".auis.edu.krd": ["American University of Iraq, Sulaimani"],
    ".dpu.edu.krd": ["Duhok Polytechnic University"],
    ".duhokcihan.edu.krd": [
        "Cihan University - Duhok",
        "Cihan University - Duhok",
    ],
    ".hmu.edu.krd": ["Hawler Medical University"],
    ".hsti.edu.krd": [
        "په\u200c\u200cيمانگاى ته\u200cكنيكى هه\u200cيبه\u200cت سوڵتان",
        "Haibat Sultan Technical Institute",
    ],
    ".kissr.edu.krd": [
        "Kurdistan Institution for strategic studies and scientific research"
    ],
    ".kti.edu.krd": ["Kurdistan Technical Institute"],
    ".nawroz.edu.krd": ["Nawroz University"],
    ".pti.edu.krd": ["Paitaxt Technical institute"],
    ".su.edu.krd": ["Salahaddin University"],
    ".sulicihan.edu.krd": [
        "Cihan University of Sulaimaniya",
        "Cihan University of Sulaimaniya",
    ],
    ".ue.edu.krd": ["International University of Erbil"],
    ".ukh.edu.krd": ["University of Kurdistan Hawler"],
    ".uor.edu.krd": ["University of Raparin"],
    ".uoz.edu.krd": ["University of Zakho"],
    ".aasu.edu.kw": ["Abdullah Al Salam University"],
    ".aou.edu.kw": ["Arab Open University, Kuwait Branch"],
    ".auk.edu.kw": ["American University of Kuwait "],
    ".aum.edu.kw": [
        "American University of the middle east",
        "American University of the middle east",
    ],
    ".dbs.edu.kw": ["Dasman Bilingual School"],
    ".gust.edu.kw": ["Gulf University for Science and Technology"],
    ".iuk.edu.kw": ["International University of Kuwait"],
    ".ku.edu.kw": ["Kuwait University", "Kuwait University"],
    ".kuniv.edu.kw": ["Kuwait University"],
    ".smartmind.edu.kw": ["SmartMind Institute"],
    ".apsb.edu.ky": [
        "The Asia Pacific School of Business (Private) Education Group",
        "APSB",
    ],
    ".cayprep.edu.ky": ["Cayman Islands Prep High School"],
    ".icci.edu.ky": ["International College of the Cayman Islands"],
    ".ucci.edu.ky": ["University College of the Cayman Islands"],
    ".60edu.kz": ["School #60 Nur Sultan"],
    ".adilet.kz": ["Adilet Higher Law School"],
    ".almaty.kz": ["Kazak State University of Agriculture"],
    ".amu.kz": [
        "Astana Medical University",
        "Астана медицина университеті",
        "Медицинский университет Астана",
    ],
    ".apa.kz": [
        "Academy of Public Administration under the President of the Republic of Kazakhstan"
    ],
    ".apk-edu.kz": [
        "Актюбинский Высший политехнический колледж",
        "Aktobe High polytechnical college",
    ],
    ".aues.kz": [
        "Almaty University of Power Engineering and Telecommunications"
    ],
    ".catec.kz": [
        "ЦЕНТРАЛЬНОАЗИАТСКИЙ ТЕХНИКО-ЭКОНОМИЧЕСКИЙ КОЛЛЕДЖ",
        "CENTRAL ASIAN TECHNICAL ECONOMIC COLLEGE",
    ],
    ".dku.kz": [
        "Казахстанско-Немецкий Университет",
        "Deutsch-Kasachische Universität",
    ],
    ".dulaty.kz": [
        "Taraz Regional University named after M.Kh.Dulaty",
        "М.Х. Дулати атындағы Тараз өңірлік университеті",
        "Dulaty University",
    ],
    ".amu.edu.kz": [
        "Astana Medical University",
        "Астана медицина университеті",
        "Медицинский университет Астана",
    ],
    ".astanait.edu.kz": ["Astana IT University"],
    ".kkat.edu.kz": ["Kostanay College of Automobile Transport"],
    ".mok.edu.kz": [
        "Международная Образовательная Корпорация",
        "International Educational Corporation",
        "Legal successor to the Kazakh leading architecture and civil engineering academy and the Kazakh-American University",
    ],
    ".nu.edu.kz": ["Назарбаев Университеті", "Nazarbayev University"],
    ".rii.edu.kz": ["rii.edu.kz"],
    ".sdu.edu.kz": ["Suleyman Demirel University"],
    ".shokan.edu.kz": [
        "Ш. Уәлиханов атындағы Көкшетау университеті",
        "Ualikhanov University",
    ],
    ".ektu.kz": ["East Kazakstan State Technical University"],
    ".enu.kz": ["Eurasia National University"],
    ".etonhouse.kz": ["EtonHouse Kazakhstan International School"],
    ".eurazir.kz": ["Eurasian Institute of market"],
    ".fizmat.kz": [
        "Республиканская физико математическая школа",
        "Republican Physics and Mathematics School",
    ],
    ".hexly.kz": [
        'ТОО "Колледж Хекслет" / Hexlet College Limited Liability Company'
    ],
    ".iitu.kz": [
        "International IT University Kazakhstan",
        "International IT University",
    ],
    ".intc.kz": [
        "ИННОВАЦИОННЫЙ ТЕХНИЧЕСКИЙ КОЛЛЕДЖ",
        "Innovative Technical College",
    ],
    ".itstep.kz": ["IT Step"],
    ".jihc.kz": [
        " Жамбылский инновационный высший колледж ",
        "Zhambyl Innovation College",
    ],
    ".kau.kz": ["Kazak American University"],
    ".kazatu.kz": [
        "Казахский агротехнический университет имени С.Сейфуллина",
        "S.Seifullin Kazakh Agro Technical University",
    ],
    ".kazguu.kz": [
        "Казахский государственный юридический университет имени М.С. Нарикбаева ",
        "M. Narikbayev KAZGUU University",
    ],
    ".kaznmu.kz": ["Kazakh National Medical university"],
    ".kazntu.kz": ["Kazakh National Technical University"],
    ".kaznu.kz": ["Al-Farabi Kazakh National University"],
    ".kbtu.kz": [],
    ".keu.kz": ["Karaganda Economic University"],
    ".kgmu.kz": [
        "Karaganda Medical University",
        "Медицинский университет Караганды",
        "Қарағанды медицина университеті",
    ],
    ".kgu.kz": [
        "Кокшетауский университет им. Ш.Уалиханова",
        "Ualikhanov University",
    ],
    ".kimep.kz": [
        "Kazakhstan Institute of Management, Economics, and Strategic Research"
    ],
    ".kst.kz": ["Kostanai State University"],
    ".kstu.kz": ["Karaganda State Technical University"],
    ".ksu.kz": ["Karaganda State Buketov University"],
    ".kuef.kz": [
        "Kazakh University of Economics, Finance and International Trade"
    ],
    ".mok.kz": [
        "Международная Образовательная Корпорация",
        "International Educational Corporation",
        "Legal successor to the Kazakh leading architecture and civil engineering academy and the Kazakh-American University",
    ],
    ".narxoz.kz": ["Narxoz University"],
    ".nkzu.kz": ["North Kazakhstan State University"],
    ".okmpu.kz": [
        "Южно-Казахстанский государственный педагогический институт",
        "South Kazakhstan State Pedagogical Institute",
    ],
    ".polytech.kz": [
        "ASTANA POLYTECHNIC COLLEGE",
        "ASTANA POLYTECHNIC COLLEGE",
    ],
    ".psu.kz": ["Pavlodar State University"],
    ".qmu.kz": [
        "Медицинский Университет Караганды",
        "Medical University of Karaganda",
    ],
    ".sci.kz": [
        "Almaty Abai State University",
        "Kazak National Technical University",
    ],
    ".semgu.kz": ["Shakarim University"],
    ".sfek.kz": [
        "RSBE Semey financial-economic college named after Rymbek Baiseitov"
    ],
    ".tarsu.kz": ["Taraz State University", "Тараз Мемлекеттік Университеті"],
    ".tau-edu.kz": ["Туран-Астана", "Turan-Astana University"],
    ".turan-edu.kz": ["Turan University"],
    ".uib.kz": ["University of international business"],
    ".vkgu.kz": ["East Kazakhstan State University"],
    ".wjfs.kz": ["West Kazakhstan Juridical Fintech School"],
    ".wkau.kz": ["Western Kazakhstan Agricultural University"],
    ".zhez.kz": ["Zhezkazgan Baikonurov University"],
    ".zti.kz": [
        "Институт интеллектуальных технологий",
        "Institute of Intelligent Technologies",
    ],
    ".fe-nuol.edu.la": ["National University of Laos"],
    ".nuol.edu.la": ["National University of Laos"],
    ".aku.edu.lb": ["Al Kaffaat University", "Al Kaffaat University"],
    ".aou.edu.lb": ["Arab Open University"],
    ".arabou-lb.edu.lb": ["Arab Open University"],
    ".aub.edu.lb": ["American University of Beirut"],
    ".aul.edu.lb": ["Arts, Sciences and Technology University"],
    ".students.b-iu.edu.lb": ["The International University of Beirut"],
    ".balamand.edu.lb": ["University of Balamand"],
    ".cut.edu.lb": ["Centre Universitaire de Technologie"],
    ".gu.edu.lb": ["Global University"],
    ".haigazian.edu.lb": ["Haigazian University"],
    ".ic.edu.lb": ["International College Beirut, Lebanon"],
    ".isae.edu.lb": ["Conservatoire national des arts et métiers (CNAM)"],
    ".iul.edu.lb": [
        "Islamic University Of Lebanon",
        "Islamic University Of Lebanon",
    ],
    ".jinan.edu.lb": ["Jinan University"],
    ".lau.edu.lb": ["Lebanese American University"],
    ".le-lycee-national.edu.lb": ["Le Lycee National"],
    ".liu.edu.lb": ["Lebanese International University"],
    ".matnu.edu.lb": ["Matn University"],
    ".mu.edu.lb": ["al maaref university"],
    ".mubs.edu.lb": [
        "Modern University for Business and Science",
        "Modern University for Business and Science",
    ],
    ".muc.edu.lb": ["Matn University College"],
    ".mut.edu.lb": ["Al-Manar University"],
    ".ndu.edu.lb": ["Notre Dame University"],
    ".pu.edu.lb": [" Phoenicia University"],
    ".rhu.edu.lb": ["Rafik Hariri University", "جامعة رفيق الحريري"],
    ".theonest.edu.lb": ["Near East School of Theology"],
    ".ua.edu.lb": ["UA Université Antonine"],
    ".student.uls.edu.lb": ["Université La Sagesse", "Sagesse University"],
    ".usal.edu.lb": ["University of Sciences and Arts in Lebanon"],
    ".usek.edu.lb": ["Holy Spirit University of Kaslik"],
    ".usj.edu.lb": ["St. Joseph University Beirut"],
    ".apps.salcc.edu.lc": ["Sir Arthur Lewis Community College"],
    ".iap.li": ["Internationle Akademie für Philosophie"],
    ".schulen.li": ["BMS Liechtenstein"],
    ".uni.li": ["Universität Liechtenstein"],
    ".accimt.ac.lk": ["Arthur C Clarke Institute of Modern Technologies"],
    ".bpu.ac.lk": ["Buddhist and Pali University of Sri Lanka"],
    ".busl.ac.lk": ["Buddhasravaka Bhiksu University"],
    ".cmb.ac.lk": ["University of Colombo"],
    ".esn.ac.lk": ["Eastern University, Sri Lanka"],
    ".iit.ac.lk": ["Informatics Institute of Technology, Sri Lanka"],
    ".kln.ac.lk": ["University of Kelaniya"],
    ".mrt.ac.lk": ["University of Moratuwa"],
    ".ou.ac.lk": ["Open University of Sri Lanka"],
    ".pdn.ac.lk": ["University of Peradeniya"],
    ".pgia.ac.lk": ["Postgraduate Institute of Agriculture (PGIA)"],
    ".rjt.ac.lk": ["Rajarata University of Sri Lanka"],
    ".ruh.ac.lk": ["University of Ruhuna"],
    ".sab.ac.lk": ["Sabaragamuwa University of Sri Lanka"],
    ".saegis.ac.lk": ["Saegis Campus"],
    ".seu.ac.lk": ["South Eastern University of Sri Lanka"],
    ".sjp.ac.lk": ["University of Sri Jayewardenepura"],
    ".slgti.ac.lk": ["Sri Lanka-German Training Institute"],
    ".sliate.ac.lk": [
        "Sri Lanka Institute of Advanced Technological Education"
    ],
    ".sltc.ac.lk": ["Sri Lanka Technological Campus"],
    ".uovt.ac.lk": ["University of Vocational Technology"],
    ".uwu.ac.lk": ["Uva Wellassa University"],
    ".vau.ac.lk": ["Univerisity of Vavuniya, Sri Lanka"],
    ".vpa.ac.lk": ["University of the Visual and Performing Arts"],
    ".wyb.ac.lk": [
        "Wayamba Univarsity of Sri Lanka",
        "Wayamba Univarsity of Sri Lanka",
    ],
    ".acbt.lk": ["Australian college of business and technology"],
    ".apiit.lk": ["Asia Pacific Institute of Information Technology (APIIT)"],
    ".bcas.lk": ["BCAS CITY CAMPUS", "BCAS CITY CAMPUS"],
    ".bci.lk": ["Benedict XVI Catholic institute of Higher Education"],
    ".cclacademy.lk": ["CCL Academy"],
    ".csacolombo.edu.lk": ["City School of Architecture, Colombo Sri Lanka"],
    ".hardyati.edu.lk": ["Hardy Advanced Technological Institute"],
    ".horizoncampus.edu.lk": ["Horizon Campus "],
    ".student.icbtcampus.edu.lk": ["ICBT Kandy Campus "],
    ".icbtcampus.edu.lk": ["ICBT Campus"],
    ".javainstitute.edu.lk": ["Java Institute For Advanced Technology"],
    ".sack.edu.lk": ["St. Anthony's College Kandy"],
    ".saegis.edu.lk": ["Saegis Campus ", "Saegis Campus "],
    ".sltc.edu.lk": ["SLTC", "Sri Lanka Technological Campus"],
    ".esoft.lk": ["ESOFT Metro Campus"],
    ".gatewaycollege.lk": ["Gateway College"],
    ".dtet.gov.lk": [
        "Department of Technical Education & Training, Sri Lanka"
    ],
    ".vtasl.gov.lk": ["Vocational Training Authority of Sri Lanka"],
    ".ijse.lk": [
        "Institute of Software Engineering (IJSE)",
        "Institute of Java and Software Engineering",
    ],
    ".kingscollege.lk": ["\ufeffKing’s College Colombo"],
    ".lnbti.lk": ["Lanka Nipon BizTech Institute"],
    ".lyceum.lk": ["Lyceum International Schools"],
    ".nexuscampus.lk": ["Nexus Campus"],
    ".nibm.lk": ["National Institute of Business Management"],
    ".nsbm.lk": ["NSBM Green University of Sri Lanka"],
    ".ousl.lk": ["Open University of Sri Lanka"],
    ".ric.lk": ["Royal Institute of Colombo "],
    ".sitc.lk": ["SITC Campus"],
    ".sliit.lk": ["Sri Lanka Institute of Information Technology (SLIT)"],
    ".ucl.lk": ["Universal College Lanka", "UCL"],
    ".stu.ucsc.lk": [
        "University of Colombo School of Computing",
        "University of Colombo School of Computing",
    ],
    ".uom.lk": ["University of Moratuwa"],
    ".wesleycollege.lk": ["Wesley College, Sri Lanka"],
    ".saintcecilias.london": ["Saint Cecilia's Church of England School"],
    ".sthelens.london": ["St Helen's School"],
    ".woodmansterne.london": [
        "Woodmansterne School & Sixth Form",
        "Woodmansterne School & Sixth Form",
    ],
    ".limkokwing.ac.ls": ["Limkokwing University of Creative Technology"],
    ".nule.ls": ["National University of Lesotho"],
    ".akulvietis.lt": ["Vilniaus Abraomo Kulviečio klasikinė gimnazija"],
    ".asu.lt": ["Aleksandro Stulginskio university"],
    ".azuolo.lt": ['Panevežio "Ąžuolo" progimnazija'],
    ".azuolynogimnazija.lt": ["Klaipėdos Ąžuolyno gimnazija"],
    ".student.ehu.lt": [
        "Europos humanitarinis universitetas",
        "European Humanities University",
    ],
    ".ehu.lt": [
        "Europos humanitarinis universitetas",
        "European Humanities University",
    ],
    ".erudito.lt": [
        "Erudito Licejus",
        "Erudito High School",
        "Erudito licejus is an IB world school",
    ],
    ".esdc.lt": [
        'Viešosios įstaigos "Europos Humanitarinis Universitetas" filialas EPAM skaitmeninės inžinerijos mokykla',
        "EHU Skaitmeninių kompetencijų mokykla",
        "EHU School of Digital Competencies",
    ],
    ".ftmc.lt": [
        "Center for Physical Sciences and Technology ",
        "Center for Physical Sciences and Technology ",
    ],
    ".ism.lt": ["International School of Management"],
    ".jp2gimnazija.lt": [
        "Kauno Jono Pauliaus 2 Gimnazija",
        "Kaunas John Paul The Second Gymnasium",
    ],
    ".kauko.lt": ["Kauno Kolegija Univrsity of Applied Sciences"],
    ".kitm.lt": ["Kaunas information technology school"],
    ".klpvm.lt": ["Klaipeda service and business school"],
    ".kma.lt": ["Kaunas Medical Academy"],
    ".kmmokykla.lt": ["Karalienės Mortos mokykla"],
    ".ktmc.lt": [
        "Klaipėdos technologijų mokymo centras",
        "Klaipeda Technology Training Centre",
    ],
    ".ktu.lt": ["Kaunas University of Technology"],
    ".ku.lt": ["Klaipeda University"],
    ".kvk.lt": ["Klaipėda State College"],
    ".kvkedu.lt": [
        "Klaipėdos valstybinė kolegija",
        "Klaipeda State University of Applied Sciences",
    ],
    ".lcc.lt": ["Lithuania Christian College"],
    ".leu.lt": ["Lithuanian University Of Educational Sciences"],
    ".licejus.lt": ["Vilniaus Licejus"],
    ".lka.lt": ["Military academy of Lithuania"],
    ".lkka.lt": ["Lithunian Institute of Physical Education"],
    ".lmta.lt": ["Lithunian Academy of Music and Theatre"],
    ".lsmuni.lt": [
        "Lietuvos sveikatos mokslų universitetas",
        "Lithuanian University of Health Sciences",
    ],
    ".ltvk.lt": ["VšĮ Lietuvos verslo kolegija", "Lithuania Business College"],
    ".lva.lt": ["Lithunian Veterinary Academy"],
    ".lzua.lt": ["Lithunian University of Agriculture"],
    ".mii.lt": ["Vilnius Academy of Arts"],
    ".mmgimnazija.lt": [
        "Marijampolės marijonų gimnazija",
        "Marijampolė marian gymnasium",
    ],
    ".panko.lt": ["Panevezys college"],
    ".pliaterytes.lt": ["Vilniaus Emilijos Pliaterytės progimnazija"],
    ".rackauskas.lt": ["Mažeikių Merkelio Račkausko gimnazija"],
    ".smarttech.lt": ["Smart tech academy", "Smart tech academy"],
    ".smk.lt": ["University of Applied Social Sciences"],
    ".spindulioprogimnazija.lt": ["Spndulio Progimnazija"],
    ".su.lt": ["Siauliai University"],
    ".svako.lt": ["Šiauliai State College"],
    ".techin.lt": [
        "Vilnius technology and engineering training center (TECHIN)"
    ],
    ".stud.vda.lt": ["Vilniaus Dailės Akademija", "Vilnius Academy of Arts"],
    ".vdu.lt": ["Vytautas Magnus University"],
    ".vgtu.lt": ["Vilnius Gediminas Technical University"],
    ".viko.lt": ["Vilniaus kolegija/University of Applied Sciences "],
    ".stud.vilniustech.lt": ["Vilnius Tech", "Vilnius Tech"],
    ".vilniustech.lt": [
        "Vilniaus Gedimino technikos universitetas",
        "Vilnius Tech",
    ],
    ".vischool.lt": [
        "Vilniaus Tarptautine mokykla",
        "Vilnius International School",
    ],
    ".vpu.lt": ["Vilnius Pedagogical University"],
    ".vtdko.lt": [
        "Vilniaus Technologiju ir dizaino kolegija",
        "Vilnius college of technologies and design",
    ],
    ".vu.lt": ["Vilnius University"],
    ".vvk.lt": ["Vilniaus Verslo Kolegija ", "Vilnius Business College"],
    ".vydmantugimnazija.lt": ["Vydmantų gimnazija", "Vydmantai High School"],
    ".42luxembourg.lu": ["42 Luxembourg"],
    ".btsgp.lu": ["Lycee des Arts et Metiers"],
    ".btsi.lu": ["Lycee des Arts et Metiers"],
    ".education.lu": ["Education Luxembourg"],
    ".iuil.lu": ["International University Institute of Luxembourg"],
    ".luxsb.lu": ["Luxembourg School of Business "],
    ".school.lu": ["Students Emails Education Luxembourg"],
    ".uni.lu": ["University of Luxemburg"],
    ".alberta-koledza.lv": ["Alberta Koldedža", "Albert College"],
    ".aml.lv": ["Medical Academy of Latvia"],
    ".citadaskola.lv": [
        "Liepājas Raiņa 6. vidusskola",
        "Liepaja Rainis Secondary School No. 6",
    ],
    ".du.lv": ["Daugavpils University"],
    ".bsa.edu.lv": ["Baltic International Academy"],
    ".eka.edu.lv": [
        "Ekonomikas un kultūras augstskola",
        "EKA University of Applied Sciences",
    ],
    ".liepa6vsk.edu.lv": [
        "Liepājas Raiņa 6. vidusskola",
        "Liepāja Rainis Secondary School No. 6",
    ],
    ".liepu.edu.lv": ["Liepaja University"],
    ".lka.edu.lv": ["Latvian Academy of Culture"],
    ".polak.edu.lv": ["Police Academy of Latvia"],
    ".sseriga.edu.lv": ["Stockholm School of Economics in Riga"],
    ".vtdt.edu.lv": [
        "Vidzemes Tehnologiju un Dizaina tehnikums",
        "Vidzemes Technology and Design vocational school",
    ],
    ".isma.lv": [
        "Informacijas Sistemu Menedžmenta Augstskola",
        "Information Systems Management University",
    ],
    ".isriga.lv": ["International School of Riga"],
    ".kcrtk.lv": ["Rīgas Tehniskā koledža", "Riga Tehnical college"],
    ".lama.lv": ["Latvian Maritime Academy"],
    ".lanet.lv": ["Latvian Academy of Sports Education"],
    ".lbtu.lv": [
        "Latvijas Biozinātņu un tehnoloģiju universitāte",
        "Latvia University of Life Sciences and Technologies",
    ],
    ".liepu.lv": ["Liepaja University"],
    ".llu.lv": ["Latvia University of Life Sciences and Technologies"],
    ".lma.lv": ["Latvian Academy of Arts"],
    ".lmuza.lv": ["Latvian Academy of Music"],
    ".lpu.lv": ["Liepaja Pedagogical Higher School"],
    ".lu.lv": ["University of Latvia"],
    ".lumii.lv": [
        "University of Latvia, Institute of Mathematics and Computer Science"
    ],
    ".www.mil.lv": ["National Defence Academy of Latvia"],
    ".ozolniekuvsk.lv": ["Ozolnieku vidusskola"],
    ".psy.lv": ["Higher School of Psychology"],
    ".rau.lv": ["Riga Aviation University"],
    ".rezeknestehnikums.lv": ["Rezekne Polytechnic"],
    ".edu.riga.lv": ["Riga Schools"],
    ".riseba.lv": ["Riseba school"],
    ".rpg.lv": ["Rīgas Purvciema vidusskola"],
    ".rpiva.lv": ["Riga Teacher Training and Educational Management Academy"],
    ".rta.lv": [
        "Rēzeknes Tehnoloģiju akadēmija",
        "Rezekne Academy of Technologies",
    ],
    ".rtu.lv": ["Riga Technical University"],
    ".ru.lv": ["Rezekne Higher School"],
    ".rvt.lv": ["\ufeffRīgas Valsts tehnikums"],
    ".s1vsk.lv": ["Salaspils 1. vidusskola"],
    ".tsi.lv": ["Transport and Telecommunication Institute"],
    ".turiba.lv": ["Turiba University"],
    ".va.lv": ["Vidzeme University College"],
    ".valmierastehnikums.lv": ["Valmieras tehnikums"],
    ".venta.lv": ["Ventspils University College"],
    ".academy.edu.ly": ["Academy of Graduate Studies"],
    ".alacademia.edu.ly": ["Academy of Graduate Studies"],
    ".asmarya.edu.ly": ["Asmarya University for Islamic Studies"],
    ".elmergib.edu.ly": ["Elmergib University"],
    ".jgu.edu.ly": ["Al-Jabal Al-Gharbi University"],
    ".limu.edu.ly": ["Libyan International Medical University (LIMU)"],
    ".omu.edu.ly": ["Omar Al-Mukhtar University"],
    ".sebhau.edu.ly": ["Sebha University"],
    ".student.1337.ma": ["1337 School"],
    ".archi.ac.ma": ["Ecole Nationale d'Architecture"],
    ".efet.ac.ma": ["EFET", "French Technical Education Schools"],
    ".ehtp.ac.ma": [
        "Ecole Hassania des travaux publics, Casablanca",
        "Hassania School for Public Works, Casablanca",
    ],
    ".emi.ac.ma": ["Ecole Mohammadia d'Ingénieurs"],
    ".enameknes.ac.ma": ["Ecole National d'Agriculture de Meknes"],
    ".enim.ac.ma": [
        "Ecole Nationale Supérieur des Mines, Rabat",
        "National School of Mines, Rabat",
    ],
    ".ensaf.ac.ma": [
        "École nationale des sciences appliquées (Fès)",
        "National school of applied sciences (Fez)",
    ],
    ".ensat.ac.ma": ["École nationale des sciences appliquées de Tanger"],
    ".ensem.ac.ma": ["École nationale supérieure d'électricité et mécanique "],
    ".etu.enset-media.ac.ma": [
        "Ecole Normale Supérieure de l’Enseignement Technique de Mohammedia",
        "ENSET Mohammedia",
    ],
    ".enset-media.ac.ma": [
        "Ecole Normale Supérieure de l'Enseignement Technique Mohammedia"
    ],
    ".esi.ac.ma": ["Ecole des sciences de l'information Rabat"],
    ".esisa.ac.ma": [
        "Ecole Supérieure d'Ingénierie En Sciences Appliquées",
        "Higher School of Engineering and Applied Sciences",
        "ESISA",
    ],
    ".esta.ac.ma": ["Université Ibn Zohr Agadir"],
    ".fsr.ac.ma": [
        "Faculté des Sciences de Rabat",
        "Faculty of Sciences of Rabat",
    ],
    ".fstm.ac.ma": ["Faculté des Sciences et Techniques de Mohammedia"],
    ".hec.ac.ma": ["Ecole des Hautes Etudes Commerciales MAROC"],
    ".hem.ac.ma": ["Institut des Hautes Etudes de Management"],
    ".etud.iga.ac.ma": ["L’école supérieure d’Ingénierie et de Management."],
    ".iihem.ac.ma": ["International Institute for Higher Education"],
    ".ilcs.ac.ma": [
        "Institute for Leadership and Communication Studies",
        "Institute for Leadership and Communication Studies",
    ],
    ".inpt.ac.ma": ["Institut National des Postes et Télécommunications"],
    ".isfort.ac.ma": [
        "ISFORT - Institut de Formation en Technologie Alimentaire"
    ],
    ".les4temps.ac.ma": [
        "GROUPE SCOLAIRE LES QUATRE TEMPS",
        "GROUPE SCOLAIRE LES QUATRE TEMPS",
    ],
    ".matci.ac.ma": [
        "Institut Supérieur de Management et de Technologie (MATCI)"
    ],
    ".supmti.ac.ma": [
        "Ecole supérieure de management, d'informatique et de télécommunication",
        "SUP Mti",
    ],
    ".supmtimeknes.ac.ma": ["SupMTI Meknes"],
    ".uae.ac.ma": ["Université Abdelmalek Essadi"],
    ".ucam.ac.ma": ["Université Cadi Ayyad"],
    ".ucd.ac.ma": ["Université Chouaib Doukkali"],
    ".uhp.ac.ma": ["UNIVERSITE HASSAN 1", "university Hassan first", "UH1"],
    ".uir.ac.ma": ["Université Internationale de Rabat"],
    ".uit.ac.ma": ["University of Ibn Tofail"],
    ".edu.uiz.ac.ma": ["Université Ibn Zohr"],
    ".uiz.ac.ma": ["Université Ibn Zohr"],
    ".um5a.ac.ma": ["Université Mohammed V - Agdal"],
    ".um5r.ac.ma": [
        "Université Mohammed-V de Rabat",
        "MOHAMMED V UNIVERSITY IN RABAT",
    ],
    ".um5s.ac.ma": ["Université Mohammed V - Souissi"],
    ".umi.ac.ma": ["Université Moulay Ismaïl", "Moulay Ismail University"],
    ".ump.ac.ma": ["University Mohammed First"],
    ".univ-ibntofail.ac.ma": ["Université Ibn Toufail"],
    ".univ-oujda.ac.ma": ["Université Mohammed Ier"],
    ".upf.ac.ma": ["Université Privée de Fès"],
    ".vinci.ac.ma": ["Institut Supérieur Vinci"],
    ".aiac.ma": [
        "ACADEMIE INTERNATIONAL D'AVIATION CIVILE",
        "INTERNATIONAL ACADEMY OF CIVILE AVIATION",
    ],
    ".aiacingenieur.ma": [
        "ACADEMIE INTERNATIONAL D'AVIATION CIVILE",
        "INTERNATIONAL ACADEMY OF CIVILE AVIATION",
    ],
    ".aui.ma": ["Al Akhawayn University"],
    ".centrale-casablanca.ma": [
        "Ecole Centrale Casablanca",
        "Ecole Centrale Casablanca",
    ],
    ".cesa.ma": [
        "Centre d'Enseignement des Sciences Appliquuées(CESA SUP)",
        "Center for the Teaching of Applied Sciences (CESA SUP)",
    ],
    ".e-polytechnique.ma": ["Ecole Polytechnqiue Universiapolis Agdir "],
    ".eigsica.ma": ["EIGSI Casablanca"],
    ".emsi-edu.ma": [
        "École Marocaine des Sciences de l'Ingénieur",
        "Moroccan School of Engineering Sciences",
        "Marokkanische Hochschule der Ingenieurwissenschaften",
        "EMSI",
    ],
    ".emsi.ma": [
        "École Marocaine des Sciences de l'Ingénieur",
        "Moroccan School of Engineering Sciences",
        "Marokkanische Hochschule der Ingenieurwissenschaften",
        "EMSI",
    ],
    ".ensam-casa.ma": [
        "Ecole nationale supérieur des arts et métiers",
        "National school of arts and crafts",
    ],
    ".ensi.ma": [
        "École des Nouvelles Sciences et Ingénierie",
        "School of New Sciences and Engineering",
        "ENSI",
    ],
    ".enstetouan.ma": [
        "École Normale Supérieure de Tétouan",
        "ENS Tétouan",
        "contact@enstetouan.ma",
    ],
    ".hestim.ma": ["HESTIM"],
    ".imbt.ma": ["Institute of Management and Business Technology"],
    ".ine.inpt.ma": [
        "inpt -institut national des postes et télécommunications-",
        "National Institute of Posts and Telecommunications",
    ],
    ".edu.isga.ma": ["Groupe ISGA"],
    ".isiam.ma": [
        "Université Internationale d'Agadir",
        "International University of Agadir",
    ],
    ".lm6e.ma": [
        "Lycée Mohamed 6 d'Excellence",
        "Highschool of Excellence Mohamed 6",
    ],
    ".lycee-descartes.ma": ["Lycée Descartes"],
    ".mundiapolis.ma": ["Mundiapolis University"],
    ".um5s.net.ma": ["Université Mohammed 5 - Rabat"],
    ".ofppt.ma": [
        "L'Office de la formation professionnelle et de la promotion du travail (OFPPT), Morocco"
    ],
    ".ordiciel.ma": ["Ordiciel Institute"],
    ".ras.ma": ["Rabat American School"],
    ".uca.ma": ["Université Cadi Ayyad"],
    ".ucd.ma": ["Université Chouaib Doukkali", "Chouaib Doukkali University"],
    ".uiass.ma": [
        "UIASS",
        "Abulcasis International University of Health Science",
    ],
    ".emines.um6p.ma": [
        "EMINES-Mohammed VI Polytechnic University",
        "Université Mohammed VI Polytechnique (UM6P)",
    ],
    ".um6p.ma": ["Mohamed 6 Polytechnic University"],
    ".ensao.ump.ma": ["National School of Applied Sciences Oujda"],
    ".ump.ma": ["University Mohammed First"],
    ".univcasa.ma": ["UNIVERSITE HASSAN II DE CASABLANCA"],
    ".univh2c.ma": ["UNIVERSITE HASSAN II DE CASABLANCA"],
    ".usms.ma": [
        "Université Sultan Moulay Slimane",
        "sultan moulay slimane university",
    ],
    ".student.youcode.ma": ["YouCode"],
    ".ase.md": ["Academy of Economic Studies of Moldova"],
    ".ceef.md": [
        "Centrul de Excelență în Economie și Finanțe",
        "Center of Excellence in Economics and Finance",
    ],
    ".ceiti.md": [
        "Centrul de Excelență în Informatică și Tehnologii Informaționale",
        "Center of Excellence in Informatics and Information Technologies",
    ],
    ".student.itstep.md": ["STEP IT Academy"],
    ".kdu.md": ["Comrat State University"],
    ".liceuldavinci.md": [
        'Instituția Privată Liceul "Da Vinci"',
        'Private Institution "Da Vinci" Lyceum',
    ],
    ".ltpetrestefanuca.md": ['L.T. "Petre Stefanuca"'],
    ".moldnet.md": ["Pedagogical State University Ion Creanga"],
    ".orizont.md": [
        "Liceul Teoretic Orizont",
        "Orizont Theoretical High School",
    ],
    ".prometeu.md": [
        'LICEUL DE CREATIVITATE ȘI INVENTICA  "PROMETEU–PRIM"',
        "Prometeu-Prim Lyceum (High School)",
    ],
    ".uasm.md": ["Moldova State Agricultural University"],
    ".uccm.md": ["Moldova Cooperative Trade University"],
    ".ulim.md": ["Free International University of Moldova"],
    ".upsc.md": ["Pedagogical State University Ion Creanga from Chisinau"],
    ".usarb.md": ["Balti State University Alecu Russo"],
    ".usm.md": ["Moldova State University"],
    ".usmf.md": [
        "Moldova State University of Medicine and Pharmacy N. Testemitsanu"
    ],
    ".ust.md": ["Tiraspol State University"],
    ".ia.utm.md": [
        "Universitatea Tehnica din Republica Moldova",
        "Technical University from Republic of Moldova",
    ],
    ".utm.md": ["Moldova Technical University"],
    ".ees-bp.edu.me": ["JU Srednja Elektro-ekonomska škola Bijelo Polje"],
    ".ets-pg.edu.me": ['Elektrotehnička Škola "Vaso Aligrudić"'],
    ".gim-bp.edu.me": ['JU Gimnazija "Miloje Dobrašinović"'],
    ".gim-pg.edu.me": [
        "Gimnazija Slobodan Škerović",
        "Gimnazija Slobodan Škerović",
    ],
    ".os-spejanovic.edu.me": [
        "Osnovna škola Savo Pejanović",
        "Primary School - Savo Pejanović Podgorica",
    ],
    ".udg.edu.me": ["Univerzitet Donja Gorica", "University of Donja Gorica"],
    ".mediaschool.me": [
        "L’IRIS, L’ECOLE SUPÉRIEURE D’INFORMATIQUE",
        "IRIS, THE HIGHER SCHOOL OF COMPUTING",
        "IRIS Mediaschool",
    ],
    ".q3academy.me": ["Q3 Academy Great Barr"],
    ".emit.mg": [
        "Ecole de Management et d'Innovation Technologique (EMIT), Université de Fianarantsoa",
        "School of Management and Technological Innovation (EMIT), University of Fianarantsoa",
    ],
    ".eni.mg": [
        "Ecole Nationale d'Informatique (ENI)",
        "National School of Computer science (ENI)",
    ],
    ".esti.mg": [
        "ESTI Madagascar",
        "Graduate School of Information Technology",
    ],
    ".insi.mg": ["INSI", "INSI"],
    ".isinfo.mg": ["Institut Supérieur d'Informatique (IS-INFO)"],
    ".univ-antananarivo.mg": ["Université d'Antananarivo"],
    ".univ-fianar.mg": ["Université de Fianarantsoa"],
    ".univ-mahajanga.mg": ["Université de Mahajanga"],
    ".univ-toamasina.mg": ["Université de Toamasina"],
    ".univ-toliara.mg": ["Université de Toliary"],
    ".af.mil": [
        "United States Air Force Academy",
        "Air Force Institute of Technology",
    ],
    ".navy.mil": ["Naval Postgraduate School"],
    ".usuhs.mil": ["Uniformed Services Universty of the Health Sciences"],
    ".bas.edu.mk": [
        "Бизнис Академија Смилевски - БАС",
        "Business Academy Smilevski - BAS",
    ],
    ".eccfp.edu.mk": [
        "Универзитет Св. Климент Охридски - Битола, Економски Факултет - Прилеп"
    ],
    ".eust.edu.mk": [
        "International University of Struga",
        "International University of Struga",
    ],
    ".fon.edu.mk": ["FON University"],
    ".ibu.edu.mk": ["International Balkan University"],
    ".next.edu.mk": ["Brainster Next College"],
    ".seeu.edu.mk": ["See University at Tetovo"],
    ".uacs.edu.mk": ["University of American College", "UACS"],
    ".ugd.edu.mk": ["University Goce Delcev"],
    ".uist.edu.mk": [
        "University for Information Science and Technology  St. Paul The Apostle "
    ],
    ".ukim.edu.mk": ["St.Cyril and Methodius University"],
    ".uklo.edu.mk": ["St.Kliment Ohridski University"],
    ".unite.edu.mk": ["State University of Tetova"],
    ".unt.edu.mk": ["Mother Teresa University"],
    ".vision.edu.mk": ["International Vision University"],
    ".fon.mk": ["FON University"],
    ".ukim.mk": ["St.Cyril and Methodius University"],
    ".auston.edu.mm": ["Auston University"],
    ".cumandalay.edu.mm": ["The University of Computer Studies (Mandalay)"],
    ".hbtu.edu.mm": ["Technological Univerity of Hmawbi"],
    ".ilbc.edu.mm": ["International Language Business Center (ILBC)"],
    ".kyauksetu.edu.mm": ["Technological University of Kyaukse"],
    ".maeu.edu.mm": ["Myanmar Aerospace Engineering University"],
    ".miit.edu.mm": [
        "မြန်မာသတင်းအချက်အလက်နည်းပညာတက္ကသိုလ်",
        "Myanmar Institute of Information Technology",
    ],
    ".mtu.edu.mm": ["Mandalay Technological University"],
    ".mu.edu.mm": ["Mandalay University"],
    ".parami.edu.mm": ["Parami University"],
    ".strategyfirst.edu.mm": ["Strategy First University"],
    ".tukalay.edu.mm": ["Technological University of Kalay"],
    ".tumeiktila.edu.mm": [
        "Technological University (meiktila)",
        "Technological University (meiktila)",
    ],
    ".tumlm.edu.mm": ["\ufeffTechnological University of Mawlamyine"],
    ".tumonywa.edu.mm": ["Technological University (MONYWA)"],
    ".tupku.edu.mm": ["Technological University Pakokku"],
    ".tutoungoo.edu.mm": [
        "Technological University (Toungoo)",
        "Technological University (Toungoo)",
    ],
    ".ucsh.edu.mm": ["University of Computer Studies, Hinthada"],
    ".ucshpaan.edu.mm": [
        "ကွန်ပျူတာတက္ကသိုလ် ဘားအံ",
        "University of Computer Studies, Hpa-an",
    ],
    ".ucskalay.edu.mm": ["University of Computer Studies, Kalay"],
    ".ucsm.edu.mm": [
        "မန္တလေးကွန်ပျူတာတက္ကသိုလ်",
        "University of Computer Studies, Mandalay, Myanmar",
    ],
    ".ucsmgy.edu.mm": [
        "University of Computer Studies (Magway),Myanmar",
        "University of Computer Studies (Magway),Myanmar",
    ],
    ".ucsmtla.edu.mm": ["University of Computer Studies, Meiktila"],
    ".ucsmub.edu.mm": ["University Of Computer Studies (Maubin)"],
    ".ucspkku.edu.mm": ["University of Computer Studies ( Pakokku )"],
    ".ucstaungoo.edu.mm": [
        "University of Computer Studies, Taungoo",
        "University of Computer Studies, Taungoo",
    ],
    ".ucstt.edu.mm": ["University of Computer Studies (Thaton)"],
    ".um1ygn.edu.mm": ["University of Medicine 1, Yangon"],
    ".ummg.edu.mm": ["University of Medicine Magway"],
    ".utycc.edu.mm": [
        "University of Technology ( Yatanarpon Cyber City )",
        "UTYCC",
    ],
    ".ytu.edu.mm": ["Yangon Technological University"],
    ".most.gov.mm": [
        "Dawei Technological University",
        "Hinthada Technological University",
        "Hpaan Technological University",
        "Kalay Technological University",
        "Kyaukse Technological University",
        "Loikaw Technological University",
        "Magway Technological University",
        "Mandalay Technological University",
        "Maubin Technological University",
        "Mawlamyaing Technological University",
        "Meikhtila Technological University",
        "Monywa Technological University",
        "Myeik Technological University",
        "Myitkyina Technological University",
        "Pakokku Technological University",
        "Pathein Technological University",
        "Pyay Technological University",
        "Sittwe Technological University",
        "Taunggyi Technological University",
        "Taungoo Technological University",
        "Yangon Technological University",
    ],
    ".itbmu.org.mm": [
        "International Theravada Buddhist Missionary University"
    ],
    ".csms.edu.mn": [
        "Компьютерийн техник, менежментийн сургууль",
        "School of Computer Science and Management",
    ],
    ".dornod.edu.mn": ["Dornod Univercity"],
    ".gmit.edu.mn": ["German-Mongolian Institute for Resource and Technology"],
    ".icb.edu.mn": ["Institute of Commerce and Business"],
    ".empasoft.ider.edu.mn": [
        "EMPASOFT INSTITUTE OF TECHNOLOGY",
        "Ider University",
    ],
    ".management.edu.mn": ["Цэцээ гүн", "Tsetsee gun"],
    ".mandakh.edu.mn": ["Мандах их сургууль", "Mandakh University"],
    ".miu.edu.mn": [
        "Монголын Олон Улсын Дээд Сургууль",
        "Mongolia International University",
    ],
    ".mnums.edu.mn": [
        "Анагаахын Шинжлэх Ухааны Үндэсний Их Сургууль",
        "Mongolian National University of Medical Sciences",
    ],
    ".mnun.edu.mn": [
        "Монгол Үндэсний Их Сургууль",
        "Mongolian National University",
    ],
    ".msue.edu.mn": ["Mongolian State University of Education"],
    ".must.edu.mn": ["Mongolian University of Science and Technology"],
    ".nmct.edu.mn": [
        "Шинэ Монгол Технологийн Коллеж",
        "New Mongolia College of Technology",
    ],
    ".nmit.edu.mn": [
        "Шинэ монгол технологийн дээд сургууль",
        "New mongol institude of technology",
    ],
    ".num.edu.mn": ["Mongolian National University"],
    ".orkhon.edu.mn": ["Orkhon University"],
    ".orkhonschool.edu.mn": [
        "Орхон Хасу Олон Улсын Дунд Сургууль",
        "Orkhon Khasu International School",
    ],
    ".shinemongol3.edu.mn": ["Шинэ Монгол 3", "Shine Mongol 3"],
    ".shineue.edu.mn": ["Шинэ Үе", "Shine ue"],
    ".tomyo.edu.mn": [
        "ТомЁ Улаанбаатар сургууль",
        "Tomyo school of Ulaanbaatar",
    ],
    ".ufe.edu.mn": [
        "University of Finance and Economic",
        "University of Finance and Economic",
    ],
    ".ufenu.edu.mn": [
        "Санхүү Эдийн Засгийн Их Сургууль",
        "University of Finance and Economicss",
    ],
    ".ulaanbaatar.edu.mn": ["Ulaanbaatar University"],
    ".humanities.mn": ["University of the Humanities"],
    ".khan-uul.mn": ["Khan-Uul Institute"],
    ".cityu.mo": ["澳門城市大學", "City University of Macau"],
    ".cityu.edu.mo": ["澳門城市大學", "City University of Macau"],
    ".ipm.edu.mo": ["Macau Polytechnic Institute"],
    ".mpu.edu.mo": [
        "Macau Polytechnic University",
        "Macau Polytechnic University",
    ],
    ".student.must.edu.mo": [
        "澳门科技大学",
        "Macau University of Science and Technology",
    ],
    ".must.edu.mo": [
        "澳門科技大學",
        "Macau University of Science and Technology",
    ],
    ".g.puiching.edu.mo": ["澳門培正中學", "Macau Pui Ching Middle School"],
    ".puiva.edu.mo": ["澳門培華中學", "Pui va Middle School"],
    ".um.edu.mo": ["University of Macau", "University of Macau"],
    ".usj.edu.mo": ["University of Saint Joseph"],
    ".umac.mo": ["University of Macau"],
    ".clrchs.mobi": ["Cardinal Langley RC High School & Sixth Form College"],
    ".jamsa.mobi": ["Jämsän sivistyspalvelukeskus"],
    ".mcag.moscow": [
        'Государственное бюджетное профессиональное образовательное учреждение города Москвы "Московский колледж архитектуры и градостроительства"',
        "Gosudarstvennoe byudzhetnoe professional'noe obrazovatel'noe uchrezhdenie goroda Moskvy \"Moskovskij kolledzh arhitektury i gradostroitel'stva\"",
    ],
    ".iup.e-una.mr": ["Institut Universitaire Professionnel"],
    ".edge.mr": ["EDGE Business School", "Edge"],
    ".esp.mr": [
        "Ecole Supérieure Polytechnique de Nouakchott",
        " Higher Polytechnic School of Nouakchott",
    ],
    ".iscae.mr": [
        "Institut Supérieur de Comptabilité et d'administration des Entreprises"
    ],
    ".supnum.mr": ["institut supérieur du numérique"],
    ".univ-nkc.mr": ["University of Nouakchott"],
    ".aum.edu.mt": ["American University of Malta"],
    ".ilearn.edu.mt": [
        "Giovanni Curmi Higher Secondary",
        "Giovanni Curmi Higher Secondary",
    ],
    ".stedwards.edu.mt": ["St Edward's College"],
    ".um.edu.mt": ["University of Malta"],
    ".student.mccibs.ac.mu": [
        "MCCI Business School",
        "Mauritius Chamber of Commerce and Industry",
    ],
    ".mccibs.ac.mu": ["MCCI Business School"],
    ".mdx.ac.mu": ["Middlesex University Mauritius"],
    ".open.ac.mu": ["Open University of Mauritius"],
    ".poly.ac.mu": ["Polytechnics Mauritius"],
    ".student.udm.ac.mu": ["University of Mascareignes"],
    ".uom.ac.mu": ["University of Mauritius"],
    ".utm.ac.mu": ["University of Technology"],
    ".cyryxcollege.edu.mv": ["Cyryx College", "Cyryx College"],
    ".hulhudhuffaaruschool.edu.mv": [
        "Hulhudhuffaaru School",
        "Hulhudhuffaaru School",
    ],
    ".ium.edu.mv": ["Islamic University of Maldives"],
    ".micollege.edu.mv": ["MI College"],
    ".mnu.edu.mv": [
        "Maldives National University ",
        "Maldives National University",
    ],
    ".villacollege.edu.mv": ["Villa College", "Villa College"],
    ".mca.ac.mw": ["Malawi College of Accountancy"],
    ".mubas.ac.mw": ["Malawi University of Business and Applied Sciences"],
    ".must.ac.mw": ["Malawi university of science and technology"],
    ".mzuni.ac.mw": ["Mzuzu University"],
    ".unima.ac.mw": ["University Of Malawi"],
    ".icam.mw": [
        "Institute of Chartered Accountants in Malawi",
        "Institute of Chartered Accountants in Malawi",
    ],
    ".stud.medcol.mw": ["Kamuzu University of Health Sciences"],
    ".unima.mw": ["University of Malawi"],
    ".Inecol.mx": [
        "Instituto de Ecología, AC",
        "Institute of Ecology, (non-profit civil association)",
    ],
    ".anahuacmayab.mx": ["Universidad Anáhuac Mayab"],
    ".buap.mx": [
        "Benemerita Universidad Autónoma de Puebla",
        "Benemerita Universidad Autónoma de Puebla",
    ],
    ".ceti.mx": [
        "Centro de Enseñanza Técnica Industrial",
        "Centro de Enseñanza Técnica Industrial",
    ],
    ".cetys.mx": ["CETYS Universidad", "CETYS Universidad"],
    ".ceux.mx": [
        "Centro de Estudios Universitarios Xochicalco",
        "Centro de Estudios Universitarios Xochicalco",
    ],
    ".chapingo.mx": [
        "Universidad Autónoma de Chapingo",
        "Universidad Autónoma de Chapingo",
    ],
    ".cicese.mx": ["CICESE"],
    ".cimat.mx": ["Centro de Investigación en Matemáticas"],
    ".cinvestav.mx": [
        "Centro de Investigación y de Estudios Avanzados del Instituto Politécnico Nacional"
    ],
    ".cio.mx": ["Centro de Investigaciones en Óptica"],
    ".ciqa.mx": ["Centro de Investigación en Química Aplicada"],
    ".cncivirtual.mx": ["Universidad CNCI"],
    ".colmex.mx": ["El Colegio de México", "El Colegio de México"],
    ".colpos.mx": ["Colegio de Postgraduados", "Postgraduate College"],
    ".ateneo.com.mx": ["Ateneo de Mérida", "Ateneo de Mérida"],
    ".ceunix.com.mx": [
        "Centro Universitario Ixtlahuaca",
        "Centro Universitario Ixtlahuaca",
    ],
    ".motolinia.com.mx": [
        "Universidad Motolinía del Pedregal",
        "Universidad Motolinía del Pedregal",
    ],
    ".prepacusac.com.mx": ["Colegio Universitario de Saltillo"],
    ".ujsierra.com.mx": ["Justo Sierra"],
    ".umamexico.com.mx": [
        "Universidad del Medio Ambiente",
        "University of the Enviroment",
    ],
    ".umma.com.mx": [
        "Universidad Mundo Maya",
        "Universidad Mundo Maya, México",
    ],
    ".ebc.mx": [
        "Escuela Bancaria y Comercial",
        "Escuela Bancaria y Comercial",
    ],
    ".amerike.edu.mx": [
        "Amerike Instituto de Estudios Universitarios Campus Ciudad de México",
        "Amerike Instituto de Estudios Universitarios Campus Guadalajara",
    ],
    ".bab.edu.mx": ["Bchillerato Alexander Bain"],
    ".cbtis013.edu.mx": [
        'Centros de Bachillerato Tecnológico Industrial y de Servicios No. 13 "Dr. José María Cos y Pérez"'
    ],
    ".cbtis156.edu.mx": [
        "Centro de Bachillerato Tecnologico Industrial y de Servicios Num. 156",
        "CBTis #156 LA JOYA",
    ],
    ".cbtis217.edu.mx": [
        "Centro de Bachillerato Tecnológico Industrial y de Servicios 217"
    ],
    ".cbtis278.edu.mx": [
        "Centros de Bachillerato Tecnologico Industrial y de Servicios 278, Tijuana, Mexico"
    ],
    ".cbtis71.edu.mx": [
        "Centro de Bachillerato Tecnológico, Industrial y de Servicios 71"
    ],
    ".cecati19.edu.mx": [
        "Centros de Formación para el Trabajo Número 19",
        "Work Training Centers Number 19",
    ],
    ".cecyt02.edu.mx": [
        "Colegio de Estudios Científicos y Tecnológicos del Estado de Baja California Sur, Plantel 02"
    ],
    ".cecyte.edu.mx": [
        "Colegio de Estudios Científicos y Tecnologícos del Estado de Campeche"
    ],
    ".cecytebc.edu.mx": [
        "Colegio de Estudios Científicos y Tecnológicos del Estado de Baja California"
    ],
    ".cecytec.edu.mx": [
        "Colegio de Estudios Cientificos y Tecnologicos del Estado de Coahuila",
        "Colegio de Estudios Cientificos y Tecnologicos del Estado de Coahuila",
    ],
    ".cecytechihuahua.edu.mx": [
        "Colegio de Estudios Científicos y Tecnológicos del Estado de Chihuahua"
    ],
    ".cecytem.edu.mx": [
        "Colegio de Estudios Científicos y Tecnológicos del Estado de Michoacán"
    ],
    ".cecytezac.edu.mx": [
        "COLEGIO DE ESTUDIOS CIENTÍFICOS Y TECNOLÓGICOS DEL ESTADO DE ZACATECAS",
        "https://cecytezac.edu.mx/",
        "https://cecytezac.edu.mx/carrera.php?cual=7",
    ],
    ".cedi.edu.mx": ["Centro de Desarrollo Integral Arboledas"],
    ".ceesanet.edu.mx": ["Centro de Estudios Superiores Allende"],
    ".cemsa.edu.mx": [
        "COLEGIO DE EDUCACIÓN MEDIA SUPERIOR ABIERTA",
        "COLEGIO DE EDUCACIÓN MEDIA SUPERIOR ABIERTA",
    ],
    ".cenaucalpan.edu.mx": ["Centro de Estudios Naucalpan"],
    ".cenidet.edu.mx": [
        "Centro Nacional de Investigación y Desarrollo Tecnológico \\ Tecnológico Nacional de México",
        "National Center for Research and Technological Development \\ National Technological Center of Mexico",
    ],
    ".centrogeo.edu.mx": [
        "Centro de Investigación en Ciencias de Información Geoespacial",
        "Geospatial Information Science Research Center",
    ],
    ".cenyca.edu.mx": [
        "Centro de Enseñanza y Capacitación de Estudios Superiores de Baja California"
    ],
    ".cesun.edu.mx": ["Cesun universidad"],
    ".cesunbc.edu.mx": ["CESUN"],
    ".cetis108.edu.mx": [
        "Centro de Estudios Tecnológicos Industrial y de Servicios No. 108"
    ],
    ".cetis17.edu.mx": [
        "CENTRO DE ESTUDIOS TECNOLÓGICOS DE LA INDUSTRIS Y SERVICIOS N 17"
    ],
    ".cetis47.edu.mx": ["CETIS 47"],
    ".cetys.edu.mx": [
        "Centro de Enseñanza Técnica Y Superior",
        "CETYS Universidad",
        "https://www.cetys.mx/oferta-educativa/profesional/ingenieria-en-ciencias-computacionales/",
    ],
    ".ceu.edu.mx": [
        "Centro de Estudios Universitarios Monterrey",
        "Centro de Estudios Universitarios Monterrey",
    ],
    ".cgcarmen.edu.mx": ["Computación del Golfo"],
    ".champagnat.edu.mx": ["Universidad Champagnat", "Universidad Champagnat"],
    ".cicese.edu.mx": [
        "Centro de Investigación Científica y Educación Superior de Ensenada",
        "Center for Scientific Research and Higher Education at Ensenada",
    ],
    ".cidesi.edu.mx": ["Centro de Ingeniería y Desarrollo Industrial"],
    ".cimav.edu.mx": [
        "Centro de Investigación en Materiales Avanzados (Mexico)",
        "Center for Research in Advanced Materials",
    ],
    ".math.cinvestav.edu.mx": [
        "Centro de Investigación y de Estudios Avanzados del Instituto Politécnico Nacional",
        "Center for Research and Advanced Studies of the National Polytechnic Institute",
        "https://www.cinvestav.mx/",
        "https://www.cinvestav.mx/Departamentos/Matematicas/Programas-de-posgrado",
        "Maestría en matemáticas computacionales/Master degree on mathematics for computer science",
        "https://www.cinvestav.mx/Departamentos/Matematicas/Lineas-de-investigacion",
        "Teoría del cómputo/Theory of computer sciences",
    ],
    ".alumno.clavijero.edu.mx": ["Instituto Consorcio Clavijero"],
    ".icc.clavijero.edu.mx": [
        "Instituto Consorcio Clavijero",
        "Instituto Consorcio Clavijero",
    ],
    ".cobachbc.edu.mx": [
        "Colegio de Bachilleres del Estado de Baja California"
    ],
    ".cobachih.edu.mx": ["Colegio de Bachilleres del Estado de Chihuahua"],
    ".cobaej.edu.mx": [
        "Colegio de Bachilleres del Estado de Jalisco Plantel 15"
    ],
    ".cobaes.edu.mx": [
        "Colegio de Bachilleres del Estado de Sinaloa (COBAES)"
    ],
    ".cobat.edu.mx": ["Colegio de Bachilleres del Estado de Tamaulipas"],
    ".colegiodelmayab.edu.mx": ["Colegio del Mayab"],
    ".colegioespanoldemorelos.edu.mx": ["Colegio Español de Morelos"],
    ".colegiomodernohumanista.edu.mx": ["COLEGIO MODERNO HUMANISTA"],
    ".df.conalep.edu.mx": ["CONALEP PLANTEL SANTA FE"],
    ".cpds.edu.mx": [
        "Colegio de Posgrado en Desarrollo de Software",
        "Software Development Postgraduate College",
    ],
    ".cuauhtemoc.edu.mx": ["Universidad Cuauhtémoc", "Universidad Cuauhtémoc"],
    ".cumbrestoluca.edu.mx": ["CUMBRES INTERNATIONAL SCHOOL TOLUCA"],
    ".dasc.edu.mx": ["DASC Instituto Tecnológico Universitario"],
    ".delasalle.edu.mx": ["Universidad De La Salle Bajío"],
    ".e-itesca.edu.mx": ["Instituto Tecnológico Superior de Cajeme"],
    ".escihupuebla.edu.mx": [
        "Escuela Superior de Ciencias y Humanidades (ESCIHU)"
    ],
    ".est177.edu.mx": ["Escuela Secundaria Técnica 177"],
    ".f-idiomas.edu.mx": ["UABJO", "Facultad de idiomas sede Burgoa"],
    ".formacioninternacional.edu.mx": ["Instituto de Formación Internacional"],
    ".frayluca.edu.mx": [
        "Universidad Fray Luca Paccioli",
        "Universidad Fray Luca Paccioli",
    ],
    ".i.edu.mx": ["Universidad Itaca", "Universidad Itaca"],
    ".iberoleon.edu.mx": ["Universidad Iberoamericana León"],
    ".alumnos.icel.edu.mx": ["Universidad ICEL"],
    ".iclasalle.edu.mx": ["Instituto Cancun La Salle"],
    ".ict.edu.mx": ["Instituto Cultural Tampico A.C."],
    ".idec.edu.mx": ["Instituto de Ciencias"],
    ".iebem.edu.mx": [
        "Instituto de la Educación Basica del Estado de Morelos"
    ],
    ".iedep.edu.mx": ["Instituto de Educación Digital del Estado de Puebla"],
    ".ieso.edu.mx": [
        "Instituto de Estudios Superiores de Oaxaca",
        "Higher Institute of Studies of Oaxaca",
    ],
    ".iest.edu.mx": ["Instituto de Estudios Superiores de Tamaulipas"],
    ".alumno.ieu.edu.mx": [
        "Universidad IEU,  Instituto de Estudios Universitarios, Puebla, México"
    ],
    ".ijm.edu.mx": ["Instituto Jefferson de Morelia"],
    ".ilb.edu.mx": ["Instituto Leonardo bravo", "Leonardo Bravo Institute"],
    ".ilce.edu.mx": [
        "Instituto Latinoamericano de la Comunicación Educativa",
        "Latin American Institute of Educational Communication",
    ],
    ".instcamp.edu.mx": ["instituto campechano"],
    ".institutooviedo.edu.mx": ["Instituto Oviedo, A.C."],
    ".ipefh.edu.mx": [
        "INSTITUTO PROFESIONAL EN LA ENSEÑANZA Y FORMACIÓN HUMANA",
        "PROFESSIONAL INSTITUTE IN HUMAN EDUCATION AND TRAINING",
        "https://ipefh.edu.mx/",
    ],
    ".ipn.edu.mx": [
        "Instituto Politécnico Nacional",
        "Instituto Politécnico Nacional",
    ],
    ".ircumbres.edu.mx": [
        "Instituto Regiomontano Cumbres",
        "Regiomontano Cumbres Institute",
    ],
    ".irsl.edu.mx": ["Instituto Real de San Luis", "http://z.irsl.edu.mx"],
    ".itcampeche.edu.mx": [
        "Instituto Tecnologico de Campeche",
        "Technological Institute of Campeche",
    ],
    ".itcancun.edu.mx": ["Instituto Tecnologico de Cancún"],
    ".itcelaya.edu.mx": ["Instituto Tecnológico de Celaya"],
    ".itcj.edu.mx": ["Técnologico Nacional de México Campus Cd. Juárez"],
    ".itdurango.edu.mx": [
        "Instituto Tecnologico de Durango",
        "Durango Institute of Technology ",
    ],
    ".ite.edu.mx": [
        "Instituto Tecnológico de Ensenada",
        "Ensenada Institute of Technology",
    ],
    ".itesa.edu.mx": [
        "Instituto Tecnológico Superior del Oriente del Estado de Hidalgo"
    ],
    ".itescam.edu.mx": [
        "Instituto Tecnológico Superior de Calkiní en el Estado de Campeche"
    ],
    ".iteshu.edu.mx": [
        "Instituto Tecnológico Superior de Huichapan",
        "ITESHU",
    ],
    ".itiguala.edu.mx": ["Instituto Tecnológico de Iguala"],
    ".correo.itlalaguna.edu.mx": ["Instituto Tecnologtico de la Laguna"],
    ".itlp.edu.mx": ["Instituto Tecnológico de la Paz"],
    ".itmatamoros.edu.mx": ["Instituto Tecnologico De Matamoros"],
    ".itmerida.edu.mx": ["Tecnologico Nacional de Merida"],
    ".itmexicali.edu.mx": ["Instituto Tecnológico de Mexicali"],
    ".itmina.edu.mx": [
        "Instituto Tecnologico de Minatitlan",
        "Instituto Tecnologico de Minatitlan",
    ],
    ".itmorelia.edu.mx": [
        "Instituto Tecnológico de Morelia",
        "Instituto Tecnológico de Morelia",
    ],
    ".ito-depi.edu.mx": ["Tecnológico Nacional de México, Campus Orizaba"],
    ".itoaxaca.edu.mx": [
        "Instituto Tecnológico de Oaxaca",
        "Instituto Tecnológico de Oaxaca",
    ],
    ".itparral.edu.mx": ["Instituto Tecnológico de Parral"],
    ".itq.edu.mx": [
        "Instituto Tecnológico de Querétaro",
        "Instituto Tecnológico de Querétaro",
    ],
    ".itsa.edu.mx": ["Instituto Tecnológico Superior de Apatzingán"],
    ".itsanjuan.edu.mx": [
        "Tecnologico nacional de Mexico",
        "Instituto Tecnológico de San Juan del Río",
    ],
    ".itscarrillopuerto.edu.mx": [
        "Tecnológico Nacional de México Campus Felipe Carrillo Puerto"
    ],
    ".itses.edu.mx": [
        "INSTITUTO TECNOLOGICO SANMIGUELENSE DE ESTUDIOS SUPERIORES",
        "INSTITUTO SANMIGUELENSE",
    ],
    ".itslp.edu.mx": [
        "Instituto Tecnológico de San Luis Potosí",
        "Instituto Tecnológico de San Luis Potosí",
    ],
    ".itsmante.edu.mx": ["Instituto Tecnológico Superior de El Mante"],
    ".itsmotul.edu.mx": ["Instituto Tecnologico Superior de motul"],
    ".itsn.edu.mx": ["Instituto Tecnológico Superior de Nochistlán"],
    ".itsncg.edu.mx": [
        "Instituto Tecnológico Superior de Nuevo Casas Grandes"
    ],
    ".itson.edu.mx": ["Instituto Tecnológico de Sonora"],
    ".itsperote.edu.mx": ["Instituto Tecnológico Superior de Perote"],
    ".itsta.edu.mx": [
        "Instituto Tecnologico Superior de Tantoyuca",
        "Instituto Tecnologico Superior de Tantoyuca",
    ],
    ".itsur.edu.mx": [
        "Instituto Tecnológico Superior del Sur de Guanajuato (TecNM Campus Sur de Guanajuato)"
    ],
    ".itsuruapan.edu.mx": ["Instituto Tecnológico Superior de Uruapan"],
    ".itsva.edu.mx": ["Instituto Tecnológico Superior de Valladolid"],
    ".itsx.edu.mx": ["Instituto Tecnológico Superior de Xalapa"],
    ".ittepic.edu.mx": [
        "Instituto Tecnológico de Tepic",
        "Instituto Tecnológico de Tepic",
    ],
    ".itvy.edu.mx": [
        "Instituto Tecnologico del Valle del Yaqui",
        "Yaqui Valley Institute of Technology",
    ],
    ".itzacatepec.edu.mx": ["Instituto Nacional de Mexico Campus Zacapetec"],
    ".iunis.edu.mx": [
        "Instituto Universitario del Sureste",
        "Instituto Universitario del Sureste",
    ],
    ".iuv.edu.mx": ["IUV Universidad"],
    ".ives.edu.mx": [
        "Instituto Veracruzano de Educación Superior (IVES)",
        "Instituto Veracruzano de Educación Superior (IVES)",
    ],
    ".lamar.edu.mx": ["Universidad Lamar", "Lamar University"],
    ".lania.edu.mx": ["Laboratorio nacional de informatica avanzada"],
    ".lasallebajio.edu.mx": ["Universidad La Salle Bajio"],
    ".lasallecancun.edu.mx": ["La salle cancun"],
    ".lasallenoroeste.edu.mx": [
        "Universidad La Salle Noroeste",
        "La Salle University Northwest",
    ],
    ".laselva.edu.mx": ["Universidad Tecnológica de la Selva"],
    ".liceoloscabos.edu.mx": ["Liceo Los Cabos"],
    ".lucerna.edu.mx": ["Universidad Lucerna"],
    ".umq.maristas.edu.mx": ["Universidad Marista de Querétaro"],
    ".mis.edu.mx": ["Madison International School Campus Country Merida"],
    ".miutt.edu.mx": [
        "Universidad Tecnologica de Tijuana",
        "Technological University of Tijuana",
    ],
    ".mondragonmexico.edu.mx": ["Universidad Mondragon Mexico"],
    ".novauniversitas.edu.mx": ["NovaUniversitas", "NovaUniversitas"],
    ".olmeca.edu.mx": ["Universidad Olmeca", "Universidad Olmeca"],
    ".oxfordacambaro.edu.mx": ["Colegio Oxford Acambaro"],
    ".prepaenlinea-sep.edu.mx": [
        "PREPA EN LINEA SEP",
        "HIGH SCHOOL SEP MEXICO",
    ],
    ".s-anahuac.edu.mx": [
        "Colegios Salesianos de Guadalajara",
        "Salesian Schools of Guadalajara",
        ".group",
    ],
    ".seiem.edu.mx": ["Servicios Educativos Integrados al Estado de México"],
    ".teccan.edu.mx": [
        "Tecnológico Nacional de Mexico Campus Cananea",
        "National Technological Institute of Mexico, Cananea Campus",
    ],
    ".tecdecintalapa.edu.mx": [
        "Instituto Tecnológico Superior de Cintalapa",
        "Instituto Tecnológico Superior de Cintalapa",
    ],
    ".tecdesoftware.edu.mx": [
        "Instituto Tecnológico de Software",
        "Tecnológico de Software",
    ],
    ".tecmartinez.edu.mx": [
        "Instituto Superior del Tecnológico de Martínez de la Torre"
    ],
    ".chapala.tecmm.edu.mx": ["Tecnologico Superior de Jalisco Chapala"],
    ".tequila.tecmm.edu.mx": [
        "Tecnológico Superior de Jalisco Tequila",
        "Higher Technological Institute of Jalisco Tequila",
    ],
    ".vallarta.tecmm.edu.mx": [
        "Tecnológico Superior de Jalisco Puerto Vallarta"
    ],
    ".zapotlanejo.tecmm.edu.mx": [
        "Tecnologico Superior de Jalisco UA Zapotlanejo"
    ],
    ".tecmuzquiz.edu.mx": ["Instituto Tecnológico Superior de Muzquiz"],
    ".tecsanpedro.edu.mx": [
        "Instituto Tecnológico Superior de San Pedro de las Colonias ",
        "Tec San Pedro",
    ],
    ".tectijuana.edu.mx": ["Instituto Tecnolgico de Tijuana"],
    ".tepeyac.edu.mx": ["Universidad del Tepeyac", "Universidad del Tepeyac"],
    ".tesch.edu.mx": [
        "Tecnológico de Estudios Superiores de Chalco",
        "Technological of Higher Studies of Chalco",
    ],
    ".teschi.edu.mx": ["Tecnologico de Estudios Superiores de Chimalhuacan"],
    ".tesco.edu.mx": [
        "Tecnológico de Estudios Superiores de Coacalco",
        "TESCo",
    ],
    ".tesoem.edu.mx": [
        "Tecnológico de Estudios Superiores del Oriente del Estado de México"
    ],
    ".tnuniversity.edu.mx": ["TN University"],
    ".tua.edu.mx": ["Tecnológico Universitario Aguascalientes"],
    ".uabc.edu.mx": ["Universidad Autonoma de Baja California"],
    ".uacm.edu.mx": [
        "Universidad Autónoma de la Ciudad de México",
        "Universidad Autónoma de la Ciudad de México",
    ],
    ".uad.edu.mx": [
        "Universidad Autonoma  de Durango",
        "Universidad Autonoma  de Durango",
    ],
    ".uadec.edu.mx": ["Universidad autónoma de coahuila"],
    ".uaed.edu.mx": [
        "Universidad Autonoma España de Durango",
        "Universidad Autonoma España de Durango",
    ],
    ".uaeh.edu.mx": ["Universidad Autónoma Del Estado de Hidalgo"],
    ".uais.edu.mx": ["Universidad Autonoma Indigena de Mexico"],
    ".ual.edu.mx": ["Universidad America Latina", "https://www.ual.edu.mx"],
    ".uan.edu.mx": ["Universidad Autonoma de Nayarit"],
    ".uane.edu.mx": [
        "Universidad Autónoma del Noreste",
        "Universidad Autónoma del Noreste",
    ],
    ".uanmexico.edu.mx": [
        "UAN universidad america del norte",
        "IAN instituto america del norte",
    ],
    ".uartesdigitales.edu.mx": [
        "UAD - Universidad de Artes Digitales",
        "UAD - Universidad de Artes Digitales",
    ],
    ".uas.edu.mx": [
        "Universidad Autonoma de Sinaloa",
        "Autonomous University of Sinaloa",
    ],
    ".uat.edu.mx": [
        "Universidad Autónoma de Tamaulipas",
        "Autonomous University of Tamaulipas",
    ],
    ".uaz.edu.mx": [
        "Universidad Autónoma de Zacatecas",
        "Universidad Autonoma de Zacatecas",
    ],
    ".ubac.edu.mx": ["Universidad del Bajío", "Universidad del Bajío"],
    ".ucad.edu.mx": ["UNIVERSIDAD UCAD"],
    ".ucaribe.edu.mx": ["Universidad del Caribe"],
    ".ucarolina.edu.mx": ["Universidad Carolina"],
    ".ucem.edu.mx": [
        "Universidad del Centro de México",
        "Universidad del Centro de México",
    ],
    ".ucienega.edu.mx": ["Universidad De La Ciénega"],
    ".uclah.edu.mx": [
        "Universidad Cientifica Latinoamericana de Hidalgo",
        "Universidad Cientifica Latinoamericana de Hidalgo",
    ],
    ".ucma.edu.mx": ["UCMA Universidad", "UCMA University"],
    ".ucq.edu.mx": ["Universidad Cuauhtémoc Querétaro"],
    ".uda.edu.mx": ["Universidad del Atlantico", "Atlantic University"],
    ".udavinci.edu.mx": ["Universidad Da Vinci", "Davinci University"],
    ".udec.edu.mx": ["Universidad de Celaya", "Universidad de Celaya"],
    ".udeh.edu.mx": ["Universidad de Hermosillo", "Universidad de Hermosillo"],
    ".udelp.edu.mx": [
        "Universidad del Pedregal",
        "https://www.universidaddelpedregal.edu.mx",
        "https://www.universidaddelpedregal.edu.mx/Ingenieria_Sistemas.php",
    ],
    ".udem.edu.mx": ["Universidad de Monterrey", "Universidad de Monterrey"],
    ".udemex.edu.mx": ["Universidad Digital del Estado de México"],
    ".udv.edu.mx": ["Universidad Don Vasco", "Universidad Don Vasco"],
    ".uflp.edu.mx": [
        "Universidad Fray Luca Paccioli",
        "Universidad Fray Luca Paccioli",
    ],
    ".ufram.edu.mx": [
        "Universidad Franco-Mexicana",
        "Universidad Franco-Mexicana",
    ],
    ".uhipocrates.edu.mx": [
        "Universidad Hipócrates",
        "Universidad Hipocrates",
    ],
    ".uic.edu.mx": [
        "Universidad Intercontinental",
        "Universidad Intercontinental",
    ],
    ".uicui.edu.mx": ["Universidad de Ixtlahuaca CUI"],
    ".uimqroo.edu.mx": [
        "Universidad Intercultural Maya de Quintana Roo",
        "University Intercultural Maya of Quintana Roo",
    ],
    ".ula.edu.mx": ["Universidad Latinoamericana (ULA)"],
    ".ulsa-noroeste.edu.mx": ["Universidad La Salle Noroeste"],
    ".ulsa.edu.mx": ["Universidad La Salle", "Universidad La Salle"],
    ".ulsab.edu.mx": [
        "Universidad Lasallista Benavente",
        "Universidad Lasallista Benavente",
    ],
    ".ulsac.edu.mx": [
        "Universidad La Salle Cuernavaca",
        "Universidad La Salle Cuernavaca",
    ],
    ".ulsachihuahua.edu.mx": ["Universidad La Salle Chihuahua"],
    ".ulsaoaxaca.edu.mx": [
        "Universidad La Salle Oaxaca",
        "La Salle University of Oaxaca",
    ],
    ".ulsavictoria.edu.mx": ["Universidad La Salle Victoria"],
    ".ulv.edu.mx": [
        "Universidad Linda Vista",
        "ULV, Universidad Linda Vista Plantel Tuxtla",
    ],
    ".um.edu.mx": ["Universidad de Montemorelos", "Montemorelos University"],
    ".umad.edu.mx": ["Universidad Madero", "Universidad Madero"],
    ".umg.edu.mx": ["Universidad Marista de Guadalajara"],
    ".umi.edu.mx": [
        "Universidad México Internacional",
        "Universidad México Internacional",
    ],
    ".umla.edu.mx": [
        "Universidad Metropolitana Latin Campus",
        "Universidad Metropolitana Latin Campus",
    ],
    ".umontemorelos.edu.mx": [
        "Universidad de Montemorelos",
        "Universidad de Montemorelos",
    ],
    ".umsa.edu.mx": [
        "Universidad Mesoamericana de San Agustín",
        "Universidad Mesoamericana de San Agustín",
    ],
    ".un.edu.mx": ["Universidad del Norte", "Universidad del Norte"],
    ".unade.edu.mx": ["Universidad Americana de Europa", "UNADE"],
    ".unav.edu.mx": ["Universidad de Navojoa"],
    ".une.edu.mx": ["Universidad del Noreste", "Universidad del Noreste"],
    ".unes.edu.mx": [
        "Universidad España de Durango",
        "Universidad España de Durango",
    ],
    ".uniat.edu.mx": ["UNIAT - University of Advance Technology"],
    ".unica.edu.mx": [
        "Universidad de Comunicación Avanzada",
        "Universidad de Comunicación Avanzada",
    ],
    ".unicla.edu.mx": ["Universidad Contemporánea de las Américas"],
    ".unideh.edu.mx": [
        "Solicitud de licencia a Universidad Digital del Estado de Hidalgo https://unideh.edu.mx/"
    ],
    ".unidem.edu.mx": [
        "Universidad de Morelia (UDEM)",
        "Morelia University (UDEM)",
    ],
    ".mte.unidep.edu.mx": ["Universidad del Desarrollo Profesional"],
    ".tij.unidep.edu.mx": ["Universidad del Desarrollo Profesional (UNIDEP)"],
    ".unikino.edu.mx": ["Universidad Kino"],
    ".unimayab.edu.mx": ["Universidad del Mayab", "Universidad del Mayab"],
    ".unimex.edu.mx": ["Universidad Mexicana", "Universidad Mexicana"],
    ".unipolidgo.edu.mx": ["Universidad Politecnica de Durango"],
    ".unisant.edu.mx": ["Universidad Santander"],
    ".unisierra.edu.mx": ["Universidad de la Sierra"],
    ".bianni.unistmo.edu.mx": ["Universidad del Istmo", "University of Istmo"],
    ".sandunga.unistmo.edu.mx": ["Universidad del Istmo campus Tehuantepec"],
    ".unitec.edu.mx": ["Universidad Tecnológica de México"],
    ".univas.edu.mx": [
        "Universidad Jóse Vasconcelos",
        "Universidad Jóse Vasconcelos",
    ],
    ".alumnos.univer-gdl.edu.mx": ["Univer University, Mexico"],
    ".univermilenium.edu.mx": [
        "Universidad UniverMilenium",
        "UniverMilenium University",
    ],
    ".universidaddeleon.edu.mx": [
        "Universidad de León",
        "Universidad de León",
    ],
    ".universidadlaconcordia.edu.mx": [
        "Universidad la Concordia",
        "Universidad la Concordia",
    ],
    ".alumno.universidadlatino.edu.mx": ["Universidad Latino"],
    ".universidadlux.edu.mx": ["Universidad Lux", "Lux University"],
    ".universidadmotolinia.edu.mx": [
        "Universidad Motolinía del Pedegral",
        "Universidad Motolinía del Pedegral",
    ],
    ".universidadmundomaya.edu.mx": [
        "Universidad Mundo Maya",
        "Universidad Mundo Maya",
    ],
    ".universidadsalesiana.edu.mx": [
        "Universidad Salesiana",
        "Universidad Salesiana",
    ],
    ".universidadupp.edu.mx": ["Universidad Privada de la Península (UPP)"],
    ".univo-gdl.edu.mx": [
        "Universidad del Valle de Orizaba, Guadalajara, México"
    ],
    ".univo.edu.mx": ["Universidad del Valle de Orizaba, Veracrúz, México"],
    ".unla.edu.mx": ["Universidad Latina", "Universidad Latina"],
    ".unpa.edu.mx": ["Universidad del Papaloapan"],
    ".unsij.edu.mx": ["Universidad de la Sierra Juárez"],
    ".unsis.edu.mx": [
        "Universidad de la Sierra Sur (UNSIS)",
        "University of the Sierra Sur",
    ],
    ".uom.edu.mx": [
        "Universidad Obrera de Mexico",
        "Universidad Obrera de Mexico",
    ],
    ".up.edu.mx": ["Universidad Panamericana", "Panamerican University"],
    ".upa.edu.mx": ["La Universidad Politécnica de Aguascalientes"],
    ".upaep.edu.mx": [
        "Universidad Popular Autónoma del Estado de Puebla (UPAEP)"
    ],
    ".upalt.edu.mx": ["Universidad Politécnica de Altamira"],
    ".upam.edu.mx": ["Universidad Politécnica de Amozoc"],
    ".upbicentenario.edu.mx": ["Universidad Politécnica del Bicentenario"],
    ".upchiapas.edu.mx": ["Universidad Politecnica de Chiapas"],
    ".upemor.edu.mx": [
        "UPEMOR",
        "Universidad Politecnica del estado de morelos",
    ],
    ".upfim.edu.mx": ["Universidad Politécnica de Francisco I. Madero"],
    ".upgto.edu.mx": ["Universidad Politécnica de Guanajuato"],
    ".upjr.edu.mx": ["Universidad Politecnica de Juventino Rosas"],
    ".upmf.edu.mx": ["Universidad Politecnica de Monclova Frontera"],
    ".upmh.edu.mx": ["Universidad Politecnica Metropolitana de Hidalgo"],
    ".upnay.edu.mx": [
        "Universidad Politécnica del Estado de Nayarit",
        "Polytechnic University of the State of Nayarit",
    ],
    ".upp.edu.mx": ["Universidad Politécnica de Pachuca"],
    ".uppuebla.edu.mx": ["Universidad Politécnica de Puebla"],
    ".upq.edu.mx": ["Universidad Politecnica de Queretaro"],
    ".upqroo.edu.mx": ["Universidad Politécnica de Quintana Roo"],
    ".upsin.edu.mx": ["Universidad Politécnica de Sinaloa"],
    ".upslp.edu.mx": ["Universidad Politécnica de San Luis Potosí"],
    ".upsrj.edu.mx": [
        "Universidad Politécnica de Santa Rosa Jáuregui",
        "Polytechnic University of Santa Rosa Jauregui",
    ],
    ".upt.edu.mx": ["Universidad Politécnica de Tulancingo"],
    ".siga.uptapachula.edu.mx": [
        "Universidad Politécnica De Tapachula (UPTAP)",
        "Polytechnic University of Tapachula",
    ],
    ".uptapachula.edu.mx": [
        "Universidad Politécnica De Tapachula (UPTAP)",
        "Polytechnic University of Tapachula",
    ],
    ".uptlax.edu.mx": ["Universidad Politécnica de Tlaxcala"],
    ".sise.uptlaxponiente.edu.mx": [
        "Universidad Politécnica de Tlaxcala Región Poniente"
    ],
    ".upv.edu.mx": ["Universidad Politecnica de Victoria"],
    ".upvm.edu.mx": ["Universidad Politécnica del Valle de México"],
    ".upy.edu.mx": ["Universidad Politecnica de Yucatan"],
    ".upz.edu.mx": ["Universidad Politecnica de Zacatecas"],
    ".upzmg.edu.mx": [
        "Universidad Politécnica de la Zona Metropolitana de Guadalajara"
    ],
    ".urmh.edu.mx": [
        "Universidad Regional Miguel Hidalgo",
        "Universidad Regional Miguel Hidalgo",
    ],
    ".urse.edu.mx": [
        "Universidad Regional del Sureste",
        "Universidad Regional del Sureste",
    ],
    ".usac.edu.mx": [
        "Universidad de la Sierra A.C.",
        "Universidad de la Sierra A.C.",
    ],
    ".usb.edu.mx": ["Universidad Simón Bolivar", "Universidad Simón Bolivar"],
    ".usebeq.edu.mx": ["Secundaria General 32 José Clemente Orozco"],
    ".ut-morelia.edu.mx": ["Universidad Tecnológica de Morelia"],
    ".ut-tijuana.edu.mx": [
        "Universidad Tecnológica de Tijuana",
        "Technological University of Tijuana",
    ],
    ".utags.edu.mx": [
        "Universidad Tecnológica de Aguascalientes",
        "Aguascalientes' Tecnological University",
    ],
    ".utcgg.edu.mx": [
        "Universidad Tecnologica de la Costa Grande de Guerrero (UTCGG)",
        "https://utcgg.edu.mx/",
    ],
    ".utch.edu.mx": [
        "Universidad Tecnológica de Chihuahua",
        "Technological University of Chihuahua",
    ],
    ".utcj.edu.mx": ["Universidad Tecnologica de Ciudad Juarez "],
    ".utculiacan.edu.mx": ["Universidad Tecnologica De Culiacan"],
    ".utcv.edu.mx": ["Universidad Tecnológica del Centro de Veracruz"],
    ".utd.edu.mx": [
        "Universidad Tecnológica de Durango",
        "The Technological University of Durango",
    ],
    ".utdelacosta.edu.mx": ["Universidad Tecnologica de la Costa"],
    ".utectulancingo.edu.mx": ["Universidad Tecnológica de Tulancingo"],
    ".uteg.edu.mx": ["Universidad Tecnologica De Guadalajara"],
    ".utel.edu.mx": [" Universidad Tecnológica Latinoamericana"],
    ".utem.edu.mx": ["Universidad Tecnológica de Manzanillo"],
    ".uteq.edu.mx": [
        "Universidad Tecnológica de Querétaro",
        "Technological University of Querétaro",
    ],
    ".utez.edu.mx": [
        "Universidad Tecnológica Emiliano Zapata del Estado de Morelos"
    ],
    ".utgz.edu.mx": ["Universidad Tecnologica de Gutierrez Zamora"],
    ".uth.edu.mx": ["Universidad Tecnologica de Huejotzingo"],
    ".uthermosillo.edu.mx": [
        "UNIVERSIDAD TECNOLÓGICA DE HERMOSILLO, SONORA",
        "TECH UNIVERSITY OF HERMOSILLO, SONORA",
    ],
    ".utj.edu.mx": ["Universidad Tecnologica de Jalisco"],
    ".utlaguna.edu.mx": ["UNIVERSIDAD TECNOLOGICA DE LA LAGUNA DE DURANGO"],
    ".utleon.edu.mx": ["Universidad Tecnológica de León"],
    ".utmatamoros.edu.mx": ["Universidad Tecnológica de Matamoros"],
    ".alumno.utmetropolitana.edu.mx": [
        "Universidad Tecnológica Metropolitana"
    ],
    ".utmir.edu.mx": ["Universidad Tecnológica del Mineral de la Reforma"],
    ".alumnos.utn.edu.mx": ["Universidad Tecnológica de Nezahualcóyotl"],
    ".utna.edu.mx": [
        "Universidad Tecnológica del Norte de Aguascalientes",
        "Technological University of Northern Aguascalientes",
    ],
    ".utnay.edu.mx": ["Universidad Tecnológica de Nayarit"],
    ".utneza.edu.mx": [
        "Universidad Tecnologica de Nezahualcoyotl",
        "Universidad Tecnologica de Nezahualcoyotl",
    ],
    ".utng.edu.mx": [
        "UNIVERSIDAD TECNOLÓGICA DEL NORTE DE GUANAJUATO",
        "TECHNOLOGICAL UNIVERSITY OF THE NORTH OF GUANAJUATO",
    ],
    ".utnuevolaredo.edu.mx": ["UNIVERSIDAD TECNOLOGICA DE NUEVO LAREDO"],
    ".alumno.utpuebla.edu.mx": [
        "Universidad Tecnológica de Puebla (UTP)",
        "Technologic University of Puebla",
    ],
    ".utrivieramaya.edu.mx": ["Universidad Tecnológica de la Riviera Maya"],
    ".utrng.edu.mx": [
        "Universidad Tecnologica de la Región Norte de Guerrero"
    ],
    ".utsalamanca.edu.mx": ["Universidad Tecnológica de Salamanca"],
    ".utsc.edu.mx": ["Universidad Tecnologica de Santa Catarina"],
    ".utselva.edu.mx": [
        "Universidad Tecnológica de la Selva",
        "Universidad Tecnológica de la Selva",
    ],
    ".utsem-morelos.edu.mx": [
        "Universidad Tecnológica del Sur del Estado de México"
    ],
    ".utsem.edu.mx": ["Universidad Tecnologica del Sur del Estado de Mexico"],
    ".utsh.edu.mx": ["Universidad Tecnologica de la Sierra Hidalguense"],
    ".utsjr.edu.mx": ["Instituto Tecnológico de San Juan del Río"],
    ".utt.edu.mx": [
        "Universidad Tecnologica de Torreón",
        "Universidad Tecnologica de Torreón",
    ],
    ".uttc.edu.mx": ["Universidad Tecnológica de la Tierra Caliente"],
    ".uttcampus.edu.mx": ["Universidad Tecnológica de Torreón"],
    ".uttecamac.edu.mx": ["Univerdad Tecnologica de Tecamac"],
    ".uttehuacan.edu.mx": ["Universidad Tecnológica de Tehuacán"],
    ".uttt.edu.mx": [
        "Universidad Tecnológica de Tula-Tepeji",
        "Technological University of Tula-Tepeji",
    ],
    ".utvco.edu.mx": [
        "Universidad Tecnológica de los Valles Centrales de Oaxaca"
    ],
    ".utvtol.edu.mx": ["Universidad Tecnológica del Valle de Toluca"],
    ".utxicotepec.edu.mx": [
        "Universidad Tecnológica de Xicotepec de Juárez",
        "Technological University of Xicotepec de Juárez",
    ],
    ".alumnos.utzac.edu.mx": [
        "Universidad Tecnológica del Estado de Zacatecas",
        "Technological University of the State of Zacatecas",
    ],
    ".utzmg.edu.mx": [
        "Universidad Tecnologica de la Zona metropolitana de Guadalajara"
    ],
    ".uvaq.edu.mx": ["UNIVERSIDAD VASCO DE QUIROGA"],
    ".uvb.edu.mx": [
        "Universidad del Valle del Bravo",
        "Universidad del Valle del Bravo",
    ],
    ".es.uveg.edu.mx": ["Universidad Virtual del Estado de Guanajuato"],
    ".uveg.edu.mx": [
        "Universidad Virtual del Estado de Guanajuato",
        "Universidad Virtual del Estado de Guanajuato",
    ],
    ".uvm.edu.mx": [
        "Universidad del Valle de México",
        "University of the Valley of Mexico",
    ],
    ".uvp.edu.mx": [
        "Universidad del Valle de Puebla",
        "University of the Valley of Puebla",
        "UVP",
    ],
    ".uvt.edu.mx": [
        "Universidad del Valle de Toluca",
        "Universidad del Valle de Toluca",
    ],
    ".ux.edu.mx": ["Universidad de Xalapa", "Xalapa University"],
    ".uxac.edu.mx": ["Universidad Xicotepetl", "Universidad Xicotepetl"],
    ".westhill.edu.mx": ["Westhill University", "Westhill University"],
    ".yavne.edu.mx": ["Escuela Yavne"],
    ".educem.mx": ["EDUCEM | Instituto Universitario del Centro de México"],
    ".esimez.mx": [
        "Escuela Superior de Ingeniería Mecánica y Eléctrica Unidad Zacatenco",
        "School of Mechanical and Electrical Engineering, Zacatenco",
    ],
    ".ibero.mx": ["UNIVERSIDAD IBEROAMERICANA", "IBEROAMERICAN UNIVERSITY"],
    ".iberopuebla.mx": [
        "Universidad Iberoamericana Puebla",
        "Universidad Iberoamericana Puebla",
        "IBERO Puebla",
    ],
    ".ifp.mx": [
        "Instituto Francisco Possenti",
        "Instituto Francisco Possenti",
    ],
    ".inaoep.mx": ["Instituto Nacional de Astrofísica, Óptica y Electrónica"],
    ".infotec.mx": [
        "Dirección General de Institutos Tecnológicos",
        "Dirección General de Institutos Tecnológicos",
    ],
    ".ipn.mx": ["National Polytechnic Institute"],
    ".ita.mx": [
        "Instituto Tecnológico de Aguascalientes",
        "Instituto Tecnológico de Aguascalientes",
    ],
    ".itam.mx": [
        "Instituto Tecnológico Autonómo de México",
        "Instituto Tecnológico Autonómo de México",
    ],
    ".itc.mx": [
        "Instituto Tecnológico de Celaya",
        "Instituto Tecnológico de Celaya",
    ],
    ".iteso.mx": [
        "Instituto Tecnológico y de Estudios Superiores de Occidente",
        "Instituto Tecnológico y de Estudios Superiores de Occidente",
    ],
    ".ith.mx": ["Instituto Tecnológico de Hermosillo"],
    ".itla.mx": [
        "Instituto Tecnólogico Latinoamericano",
        "Instituto Tecnólogico Latinoamericano",
    ],
    ".itson.mx": [
        "Instituto Tecnológico de Sonora",
        "Instituto Tecnológico de Sonora",
    ],
    ".lasallep.mx": [
        "Universidad La Salle Pachuca",
        "La Salle Pachuca University",
    ],
    ".lamar.org.mx": ["Universidad Lamar", "Lamar University"],
    ".lasallistas.org.mx": ["Universidad La Salle"],
    ".reduaeh.mx": [
        "Universidad Autónoma del Estado de Hidalgo",
        "Universidad Autónoma del Estado de Hidalgo",
    ],
    ".reduaz.mx": [
        "Universidad Autónoma de Zacatecas",
        "Universidad Autónoma de Zacatecas",
    ],
    ".saei.mx": ["SAE School of Audio Engineering México"],
    ".secuiep.mx": ["Sistema Educativo CUIEP"],
    ".soyunaq.mx": [
        "Universidad Aeronáutica en Queretaro",
        "Aeronautical University in Queretaro",
    ],
    ".tec.mx": [
        "Instituto Tecnológico y de Estudios Superiores de Monterrey (ITESM)",
        "Instituto Tecnológico y de Estudios Superiores de Monterrey (ITESM)",
    ],
    ".tecbc.mx": [
        "Tecnologico de Baja California, Universidad",
        "Tecnologico de Baja California, Universidad",
    ],
    ".tecmor.mx": ["Instituto tecnológico de morelia"],
    ".chetumal.tecnm.mx": ["Instituto Tecnlógico de Chetumal"],
    ".morelia.tecnm.mx": [
        "Instituto Tecnologico de Morelia",
        "Morelia Institute of Technology",
    ],
    ".nlaredo.tecnm.mx": ["Instituto Tecnlogico de Nuevo Laredo"],
    ".nogales.tecnm.mx": ["Instituto Tecnológico de Nogales"],
    ".piedad.tecnm.mx": ["Instituto Tecnologico de La Piedad"],
    ".surguanajuato.tecnm.mx": [
        "Instituto Tecnológico Superior del Sur de Guanajuato (TecNM Campus Sur de Guanajuato)"
    ],
    ".toluca.tecnm.mx": ["Instituto Tecnológico de Toluca"],
    ".tecvalles.mx": [
        "Tecnológico Nacional de México Campus Instituto Tecnológico de Ciudad Valles"
    ],
    ".teczamora.mx": [
        "Instituto Tecnologico de Estudios Superiores de Zamora",
        "Technological Institute of Superior Studies of Zamora",
    ],
    ".u-erre.mx": ["Universidad Regiomontana"],
    ".correo.uaa.mx": ["Universidad Autónoma de Aguascalientes"],
    ".edu.uaa.mx": ["Universidad Autónoma de Aguascalientes"],
    ".uaaan.mx": [
        "Universidad Autónoma Agraria Antonio Narro",
        "Universidad Autónoma Agraria Antonio Narro",
    ],
    ".uabc.mx": [
        "Universidad Autónoma de Baja California",
        "Universidad Autónoma de Baja California",
    ],
    ".uabcs.mx": [
        "Universidad Autónoma de Baja California Sur",
        "Universidad Autónoma de Baja California Sur",
    ],
    ".uabjo.mx": [
        "Universidad Autónoma Benito Juárez de Oaxaca",
        "Universidad Autónoma Benito Juárez de Oaxaca",
    ],
    ".uacam.mx": [
        "Universidad Autónoma de Campeche",
        "Universidad Autónoma de Campeche",
    ],
    ".uach.mx": [
        "Universidad Autónoma de Chihuahua",
        "Universidad Autónoma de Chihuahua",
    ],
    ".uadec.mx": [
        "Universidad Autónoma de Coahuila",
        "Universidad Autónoma de Coahuila",
    ],
    ".uadeo.mx": [
        "Universidad Autonoma de Occidente",
        "Autonomous University of Occident",
    ],
    ".uady.mx": [
        "Universidad Autónoma de Yucatán",
        "Universidad Autónoma de Yucatán",
    ],
    ".uaem.mx": [
        "Universidad Autónoma del Estado de Morelos",
        "Universidad Autónoma del Estado de Morelos",
    ],
    ".uaemex.mx": [
        "Universidad Autónoma del Estado de México",
        "Universidad Autónoma del Estado de México",
    ],
    ".uaf.mx": [
        "Universidad Autónoma de Fresnillo",
        "Universidad Autónoma de Fresnillo",
    ],
    ".uag.mx": [
        "Universidad Autónoma de Guadalajara",
        "Universidad Autónoma de Guadalajara",
    ],
    ".uagro.mx": [
        "Universidad Autónoma de Guerrero",
        "Universidad Autónoma de Guerrero",
    ],
    ".ual.mx": [
        "Universidad Autónoma de la Laguna",
        "Universidad Autónoma de la Laguna",
    ],
    ".uam.mx": [
        "Universidad Autónoma Metropolitana",
        "Universidad Autónoma Metropolitana - Azcapotzalco",
        "Universidad Autónoma Metropolitana - Iztapalapa",
        "Universidad Autónoma Metropolitana - Xochimilco",
        "Universidad Autónoma Metropolitana",
        "Universidad Autónoma Metropolitana - Azcapotzalco",
        "Universidad Autónoma Metropolitana - Iztapalapa",
        "Universidad Autónoma Metropolitana - Xochimilco",
    ],
    ".uanl.mx": [
        "Universidad Autónoma de Nuevo León",
        "Universidad Autónoma de Nuevo León",
    ],
    ".uaq.mx": [
        "Universidad Autónoma de Querétaro",
        "Universidad Autónoma de Querétaro",
    ],
    ".uas.mx": ["Universidad Anáhuac del Sur", "Universidad Anáhuac del Sur"],
    ".uaslp.mx": [
        "Universidad Autónoma de San Luis Potosí",
        "Universidad Autónoma de San Luis Potosí",
    ],
    ".uasnet.mx": [
        "Universidad Autónoma de Sinaloa",
        "Universidad Autónoma de Sinaloa",
    ],
    ".uat.mx": [
        "Universidad Autónoma de Tamaulipas",
        "Universidad Autónoma de Tamaulipas",
    ],
    ".uatx.mx": [
        "Universidad Autónoma de Tlaxcala",
        "Universidad Autónoma de Tlaxcala",
    ],
    ".ucc.mx": ["Universidad Cristóbal Colón", "Universidad Cristóbal Colón"],
    ".ucol.mx": ["Universidad de Colima", "Universidad de Colima"],
    ".udem.mx": ["Universidad de Monterrey"],
    ".udg.mx": ["Universidad de Guadalajara", "Universidad de Guadalajara"],
    ".udladf.mx": ["Universidad de las Américas"],
    ".udlap.mx": [
        "Universidad de las Américas - Puebla",
        "Universidad de las Américas - Puebla",
    ],
    ".udo.mx": ["Universidad de Occidente", "Universidad de Occidente"],
    ".ues.mx": [
        "Universidad Estatal de Sonora",
        "Universidad Estatal de Sonora",
    ],
    ".uia.mx": ["Universidad Iberoamericana", "Universidad Iberoamericana"],
    ".uinenlinea.mx": ["Universidad Insurgentes"],
    ".ujat.mx": [
        "Universidad Juárez Autónoma de Tabasco",
        "Universidad Juárez Autónoma de Tabasco",
    ],
    ".ujed.mx": [
        "Universidad Juárez del Estado de Durango",
        "Universidad Juárez del Estado de Durango",
    ],
    ".ujsierra.mx": ["Universidad Justo Sierra", "Universidad Justo Sierra"],
    ".umar.mx": ["Universidad del Mar", "Universidad del Mar"],
    ".umich.mx": [
        "Universidad Michoacana de San Nicolás de Hidalgo",
        "Universidad Michoacana de San Nicolás de Hidalgo",
    ],
    ".umov.mx": ["Universidad en Movimiento", "UMOV"],
    ".un.mx": ["Universidad de Norteamerica", "Universidad de Norteamerica"],
    ".unacar.mx": [
        "Universidad Autónoma del Carmen",
        "Universidad Autónoma del Carmen",
    ],
    ".unach.mx": [
        "Universidad Autónoma de Chiapas",
        "Universidad Autónoma de Chiapas",
    ],
    ".unadmexico.mx": ["Universidad Abierta y a Distancia de México"],
    ".unam.mx": [],
    ".unicaribe.mx": ["Universidad del Caribe"],
    ".unicuc.mx": ["Centro Universitario Celsus"],
    ".unikino.mx": ["Universidad Kino", "Universidad Kino"],
    ".unison.mx": ["Universidad de Sonora"],
    ".unitec.mx": [
        "Universidad Tecnológica de México",
        "Universidad Tecnológica de México",
    ],
    ".univa.mx": [
        "Universidad del Valle de Atemajac",
        "Universidad del Valle de Atemajac",
    ],
    ".univillarica.mx": [
        "Universidad Autónoma de Veracruz Villa Rica",
        "Universidad Autónoma de Veracruz Villa Rica",
    ],
    ".up.mx": ["Universidad Panamericana", "Universidad Panamericana"],
    ".upaep.mx": [
        "Universidad Popular Autonóma del Estado de Puebla",
        "Universidad Popular Autonóma del Estado de Puebla",
    ],
    ".upgch.mx": [
        "Universidad Pablo Guardado Chávez",
        "Pablo Guardado Chavez University",
    ],
    ".upn.mx": [
        "Universidad Pedagógica Nacional",
        "Universidad Pedagógica Nacional",
    ],
    ".upq.mx": ["Universidad Politecnica de Queretaro"],
    ".uqroo.mx": [
        "Universidad de Quintana Roo",
        "Universidad de Quintana Roo",
    ],
    ".ur.mx": ["Universidad Regiomontana", "Universidad Regiomontana"],
    ".uson.mx": ["Universidad de Sonora", "Universidad de Sonora"],
    ".doc.utc.mx": ["Universidad Tres Culturas"],
    ".edu.utc.mx": ["UNIVERSIDAD TRES CULTURAS", "THREE CULTURES UNIVERSITY"],
    ".utm.mx": [
        "Universidad Tecnologica de la Mixteca",
        "Universidad Tecnologica de la Mixteca",
    ],
    ".uttn.mx": ["Universidad Tecnologica de Tamaulipas Norte"],
    ".uv.mx": ["Universidad Veracruzana", "Universidad Veracruzana"],
    ".1utar.my": ["Universiti Tunku Abdul Rahman"],
    ".aeu.edu.my": ["Asia E University"],
    ".aiu.edu.my": ["Al-Bukhari International University"],
    ".apiit.edu.my": [
        "Asia Pacific Institute of Information Technology (APIIT)"
    ],
    ".apu.edu.my": [
        "Asia Pacific University of Technology & Innovation (APU)"
    ],
    ".asb.edu.my": ["Asia School of Business"],
    ".aswara.edu.my": [
        "Akademi Seni Budaya Dan Warisan Kebangsaan",
        "National Academy Of Art Culture And Heritage",
    ],
    ".atc2u.edu.my": ["Advance Tertiary College"],
    ".bac.edu.my": ["Brickfields Asia College"],
    ".binary.edu.my": [
        "Binary University College of Managemant &amp; Entrepreneurship"
    ],
    ".britishschool.edu.my": [
        "The British International School of Kuala Lumpur"
    ],
    ".cempaka.edu.my": ["Cempaka International School Damansara Heights"],
    ".chhsban.edu.my": ["芙蓉中华中学", "Chung Hua High School"],
    ".chonghwa-kuantan.edu.my": ["SEKOLAH MENENGAH CHONG HWA KUANTAN"],
    ".city.edu.my": ["City University College of Science and Technology"],
    ".cosmopointcollege.edu.my": [
        "Cosmopoint College Seremban",
        "Cosmopoint College Seremban",
    ],
    ".curtin.edu.my": ["Curtin University of Technology, Sarawak Campus"],
    ".st.cyberjaya.edu.my": [
        "Universiti Cyberjaya",
        "University of Cyberjaya (UOC)",
    ],
    ".cybermed.edu.my": ["Cyberjaya University College of Medical Science"],
    ".disted.edu.my": ["DISTED College", "DISTED College"],
    ".djzhlc.edu.my": [
        "New Era Institute of Vocational and Continuing Education"
    ],
    ".firstcity.edu.my": ["First City University College"],
    ".foonyew.edu.my": ["新山宽柔中学", "FOON YEW HIGH SCHOOL JOHOR BAHRU"],
    ".gardenschool.edu.my": ["Garden International School"],
    ".geomatika.edu.my": ["Universiti Geomatika Malaysia"],
    ".student.gmi.edu.my": [
        "German-Malaysian Institute",
        "German-Malaysian Institute",
    ],
    ".hanxing.edu.my": ["Oneworld Hanxin College"],
    ".help.edu.my": ["HELP University College", "HELP University "],
    ".hidayah.edu.my": ["Sekolah Islam Hidayah", "Hidayah Islamic School"],
    ".hikmah.edu.my": ["Darul Hikmah Islamic College"],
    ".hinhua.edu.my": ["Hin Hua High School"],
    ".iact.edu.my": ["Iact College"],
    ".iic.edu.my": ["International Islamic College"],
    ".iiu.edu.my": ["International Islamic University"],
    ".iium.edu.my": [
        "International Islamic University Malaysia",
        "International Islamic University Malaysia",
    ],
    ".imas.edu.my": ["International Modern Arabic School, Malaysia"],
    ".imu.edu.my": ["International Medical University"],
    ".inhouse.edu.my": ["IHM College", "IHM College"],
    ".instedt.edu.my": ["Darul Takzim Institute of Technology"],
    ".intec.edu.my": ["INTEC Education College"],
    ".ipb.edu.my": ["Baitulmal Management Institute (IPB)"],
    ".ipbl.edu.my": ["Institute of Teachers Education, Batu Lintang"],
    ".ipda.edu.my": ["Institute of Teachers Education, Darul Aman"],
    ".ipgkrajang.edu.my": ["Institute of Teachers Education, Rajang"],
    ".ipgkti.edu.my": ["Institute of Teachers Education, Temenggong Ibrahim"],
    ".ipgmksm.edu.my": ["Institute of Teachers Education, Sultan Mizan"],
    ".ipik.edu.my": ["Institute of Teachers Education, Ilmu Khas"],
    ".ipislam.edu.my": ["Institute of Teachers Education, Islamic Education"],
    ".ipkent.edu.my": ["Institute of Teachers Education, Kent"],
    ".ipsah.edu.my": ["Institute of Teachers Education, Sultan Abdul Halim"],
    ".iptho.edu.my": ["Institute of Teachers Education, Tun Hussein Onn"],
    ".iptips.edu.my": ["Perlis Islamic Higher Learning Institute"],
    ".isp.edu.my": ["The International School @ ParkCity (ISP)"],
    ".iuctt.edu.my": [
        "International University College of Technology Twintech (IUCTT)"
    ],
    ".s.iukl.edu.my": ["Infrastructure University"],
    ".iumw.edu.my": [
        "International University of Malaya-Wales",
        "International University of Malaya-Wales",
    ],
    ".kbu.edu.my": ["KBU International College"],
    ".kdu.edu.my": ["KDU College Sdn Bhd"],
    ".kias.edu.my": ["Sultan Ismail Petra International Islamic College"],
    ".kist.edu.my": ["Islamic College for Sciences and Technologies"],
    ".kitab.edu.my": ["International Islamic College of Penang"],
    ".mjii.kktm.edu.my": ["MARA Japan Industrial Institute"],
    ".klmu.edu.my": ["Kuala Lumpur Metropolitan University"],
    ".kolejypc.edu.my": ["YPC-iTWEB College"],
    ".kptm.edu.my": ["Mara Poly-Tech College"],
    ".ktd.edu.my": ["Darul Naim College of Technology"],
    ".kuim.edu.my": ["Melaka Islamic University College"],
    ".kuin.edu.my": ["Kolej Universiti Insaniah"],
    ".kuis.edu.my": ["Selangor Islamic University College"],
    ".kuptm.edu.my": ["Kolej Universiti Poly-Tech Mara Kuala Lumpur"],
    ".limkokwing.edu.my": [
        "Limkokwing University College of Creative Technology"
    ],
    ".lincoln.edu.my": ["Lincoln University College"],
    ".linton.edu.my": ["Linton University College"],
    ".mahsa.edu.my": [
        "Mahsa University College for Health and Medical Science"
    ],
    ".mahsastudent.edu.my": ["玛莎大学", "MAHSA University"],
    ".mazinternational.edu.my": ["MAZ International School, Petaling Jaya"],
    ".mckl.edu.my": ["Methodist College Kuala Lumpur"],
    ".mckl2.edu.my": ["Methodist College Kuala Lumpur"],
    ".mdis.edu.my": [
        "Kolej MDIS Malaysia",
        "Management Development Institute of Singapore",
    ],
    ".mediu.edu.my": ["Al Madinah International University"],
    ".mmu.edu.my": ["Multimedia University"],
    ".monash.edu.my": ["Monash University, Malaysia Campus"],
    ".msu.edu.my": ["Management and Science University"],
    ".murni.edu.my": ["Murni Nursing College"],
    ".must.edu.my": ["Malaysia University of Science and Technology (MUST)"],
    ".mykwanghua.edu.my": [
        "巴生光华独立中学",
        "Kwang Hua Private High School",
    ],
    ".neivce.edu.my": [
        "New Era Institute of Vocational and Continuing Education"
    ],
    ".newera.edu.my": ["New Era University College"],
    ".newinti.edu.my": ["INTI International University & Colleges"],
    ".nilai.edu.my": ["Nilai University College"],
    ".nottingham.edu.my": ["University of Nottingham, Malaysia Campus"],
    ".olympia.edu.my": ["Olympia College"],
    ".oum.edu.my": ["Open University Malaysia"],
    ".oxburgh.edu.my": ["Oxburgh International School"],
    ".pbu.edu.my": ["POLITEKNIK BALIK PULAU"],
    ".perdanauniversity.edu.my": [
        "Perdana University - School for Data Sciences"
    ],
    ".pidc.edu.my": ["Penang International Dental College"],
    ".pine.edu.my": ["Institut Prima Bestari - Pine Academy "],
    ".pkb.edu.my": ["Kota Bharu Polytechnic"],
    ".pmj.edu.my": ["Politeknik Mersing Johor"],
    ".pmm.edu.my": ["Merlimau Polytechnic"],
    ".pmu.edu.my": ["Politeknik Mukah Sarawak"],
    ".poliku.edu.my": ["Kuching Polytechnic"],
    ".polimas.edu.my": ["Sultan Abdul Halim Muadzam Shah Polytechnic"],
    ".polimelaka.edu.my": ["Melaka City Polytechnic"],
    ".polipd.edu.my": ["Port Dickson Polytechnic"],
    ".polisas.edu.my": ["Sultan Haji Ahmad Shah Polytechnic"],
    ".psa.edu.my": ["Sultan Salahuddin Abdul Aziz Shah Polytechnic"],
    ".psas.edu.my": ["Sultan Azlan Shah Polytechnic "],
    ".psis.edu.my": ["Sultan Idris Shah Polytechnic"],
    ".psp.edu.my": ["Seberang Perai Polytechnic"],
    ".ptpl.edu.my": ["PTPL College"],
    ".ptsb.edu.my": ["Sultanah Bahiyah Polytechnic"],
    ".ptss.edu.my": ["Tunku Syed Sirajuddin Polytechnic"],
    ".puo.edu.my": ["Ungku Omar Premier Polytechnic"],
    ".qiu.edu.my": ["Quest International University "],
    ".qiup.edu.my": [
        "Quest International University",
        "Quest International University",
    ],
    ".saito.edu.my": ["Saito College"],
    ".saitostudent.edu.my": ["Saito University College"],
    ".segi.edu.my": ["Segi University College"],
    ".sentral.edu.my": ["SENTRAL College Penang"],
    ".sunway.edu.my": ["Sunway University College"],
    ".swinburne.edu.my": [
        "Swinburne University of Technology, Sarawak Campus"
    ],
    ".taj.edu.my": ["Taj International College"],
    ".tarc.edu.my": ["Tunku Abdul Rahman Chinese College"],
    ".taylors.edu.my": ["Taylor's University College"],
    ".student.tenby.edu.my": ["Tenby Schools Setia Eco Park"],
    ".toa.edu.my": ["The One Academy of Communication Design"],
    ".tpmcollege.edu.my": ["TPM College"],
    ".ucsiuniversity.edu.my": ["UCSI University"],
    ".ucti.edu.my": [
        "University College of Technology &amp; Innovation (UCTI)"
    ],
    ".ucts.edu.my": ["University College of Technology Sarawak"],
    ".uitm.edu.my": ["Universiti Teknologi MARA (UiTM)"],
    ".ukm.edu.my": [
        "Universiti Kebangsaan Malaysia",
        "The National University of Malaysia",
    ],
    ".um.edu.my": ["Universiti Malaya"],
    ".umk.edu.my": ["Universiti Malaysia Kelantan"],
    ".student.umpsa.edu.my": ["Universiti Malaysia Pahang Al-Sultan Abdullah"],
    ".umpsa.edu.my": ["Universiti Malaysia Pahang Al-Sultan Abdullah"],
    ".ums.edu.my": ["Universiti Malaysia Sabah"],
    ".umt.edu.my": ["Universiti Malaysia Terengganu"],
    ".unikl.edu.my": [
        "Universiti Kuala Lumpur",
        "Universiti Kuala Lumpur Malaysian Institute of Information Technology (MIIT)",
    ],
    ".unimap.edu.my": ["Universiti Malaysia Perlis"],
    ".student.unimy.edu.my": [
        "University Malaysia of Computer Science & Engineering"
    ],
    ".unirazak.edu.my": ["University Tun Abdul Razak"],
    ".unisel.edu.my": ["Universiti Industri Selangor"],
    ".unishams.edu.my": [
        "Universiti Islam Antarabangsa Sultan Abdul Halim Mu'adzam Shah"
    ],
    ".putra.unisza.edu.my": ["Universiti Sultan Zainal Abidin"],
    ".uniten.edu.my": ["Universiti Tenaga Nasional"],
    ".student.uow.edu.my": ["University Of Wollongong Malaysia"],
    ".upsi.edu.my": ["Universiti Pendidikan Sultan Idris"],
    ".uptm.edu.my": [
        "Universiti Poly-Tech Malaysia (UPTM)",
        "https://www.uptm.edu.my/",
    ],
    ".utar.edu.my": [
        "Tunku Abdul Rahman University (Chinese University)",
        "Universiti Tunku Abdul Rahman",
    ],
    ".utem.edu.my": ["Universiti Teknikal Malaysia Melaka"],
    ".uthm.edu.my": ["Universiti Tun Hussein Onn Malaysia"],
    ".utmspace.edu.my": ["UTMSPACE"],
    ".utn.edu.my": ["Universiti Tenaga Nasional"],
    ".utp.edu.my": [
        "Petronas Technology University",
        "Universiti Teknologi Petronas",
    ],
    ".uts.edu.my": ["University of Technology Sarawak"],
    ".uum.edu.my": ["Universiti Utara Malaysia"],
    ".vitrox.edu.my": ["VITROX COLLEGE", "VITROX COLLEGE"],
    ".vucstudent.edu.my": ["Veritas University College (VUC), Malaysia"],
    ".westminster.edu.my": ["West Minster International College"],
    ".xmu.edu.my": [
        "Xiamen University Malaysia",
        "Universiti Xiamen Malaysia",
        "厦门大学马来西亚分校",
    ],
    ".ytl-ichm.edu.my": ["YTL International College of Hotel Management"],
    ".marlboroughcollege.my": ["Marlborough College Malaysia"],
    ".segi4u.my": ["SEGI University", "SEGI University"],
    ".uitm.my": ["Universiti Teknologi MARA"],
    ".ukm.my": ["Universiti Kebangsaan Malaysia"],
    ".unimas.my": ["Universiti Malaysia Sarawak"],
    ".unisza.my": ["universiti sultan zainal abidin"],
    ".unitar.my": ["UNITAR International University"],
    ".usm.my": ["Universiti Sains Malaysia"],
    ".utm.my": ["Universiti Teknologi Malaysia"],
    ".isctem.ac.mz": [
        "Instituto Superior de Ciências e Tecnologia de Moçambique"
    ],
    ".ismonitor.ac.mz": ["Instituto Superior Monitor"],
    ".isri.ac.mz": ["Instituto Superior de Relações Internacionais (ISRI) "],
    ".isutc.ac.mz": [
        "Instituto Superior de Transportes e Comunicações",
        "Higher Institute of Transport and Communications",
    ],
    ".uem.ac.mz": ["Universidade Eduardo Mondlane"],
    ".unilurio.ac.mz": ["Universidade Lúrio", "Lúrio University", "UniLúrio"],
    ".up.ac.mz": [
        "Universidade Pedagógica de Maputo",
        "Maputo Pedagogical University",
    ],
    ".ustm.ac.mz": [
        "Universidade São Tomás de Moçambique",
        "University of Saint Thomas of Mozambique",
    ],
    ".uzambeze.ac.mz": ["Universidade Zambeze", "Zambeze University"],
    ".isutc.transcom.co.mz": [
        "Instituto Superior de Transportes e Comunicações",
        " Higher Institute of Transport and Communications",
    ],
    ".unisced.edu.mz": ["Universidade Aberta ISCED", "ISCED Open University"],
    ".www.uem.mz": ["Universidade Eduardo Mondlane"],
    ".edu.na": [
        "Ilsa Independent College",
        "International University of Management",
    ],
    ".nust.na": ["Namibia University of Science and Technology"],
    ".unam.na": ["University of Namibia"],
    ".ftl.name": ["P. L. Kapitsa Phystech Lyceum"],
    ".unc.nc": ["University of New Caledonia"],
    ".refer.ne": ["Université Abdou Moumouni de Niamey"],
    ".C2KNI.net": ["C2KNI", "C2KEN", "Dromore High School"],
    ".aab-edu.net": ["AAB University"],
    ".accadis.net": [
        "accadis Hochschule",
        "accadis University of Applied Sciences",
    ],
    ".achievementtraining.net": [
        "Achievement Training Ltd",
        "Part of City College Plymouth",
    ],
    ".aearraiolos.net": [
        "Agrupamento de Escolas de Arraiolos - EB 2,3/S de Cunha Rivara"
    ],
    ".afftonschools.net": ["Affton High School"],
    ".aischool.net": ["Ahmedabad International School"],
    ".aisschool.net": ["American International School"],
    ".alighieripascoli.net": ["Alighieri Pascoli"],
    ".allhallows.net": ["All Hallows Catholic School"],
    ".students.alvinisd.net": ["Shadow Creek High School"],
    ".c.anabuki-college.net": [
        "穴吹コンピュータカレッジ",
        "Anabuki Computer College",
    ],
    ".ansford.net": ["Ansford Academy", "Ansford Academy"],
    ".antigua-luberri.net": ["Antigua Luberri BHI institutoa"],
    ".student.antiochschools.net": ["Antioch High School"],
    ".aptechsite.net": ["Aptech Computer Education"],
    ".aries-esi.net": ["Ecole Aries"],
    ".auamed.net": ["American University of Antigua"],
    ".students.ausd.net": ["Arcadia High School"],
    ".avccengg.net": ["A.V.C. College of Engineering"],
    ".backwellschool.net": ["Backwell School"],
    ".barnim-gymnasium.net": ["Barnim-Gymnasium Berlin"],
    ".baypath.net": ["Bay Path Regional Vocational Technical High School"],
    ".bbs2leer.net": ["Berufsbildende Schulen 2 Leer"],
    ".bcpsk12.net": ["Byron Center High School"],
    ".bcsdschools.net": ["Berkeley County School District"],
    ".bedfordnhk12.net": ["Bedford School District NH"],
    ".students.berkeley.net": ["Berkeley High School"],
    ".besd.net": ["Box Elder School District", ".group"],
    ".beverleyhigh.net": ["Beverley High School", "Beverley High School"],
    ".bhbl.net": ["Burnt Hills Ballston Lake"],
    ".bilgiedu.net": ["Istanbul Bilgi University"],
    ".birdvilleschools.net": ["Birdville Independent School District"],
    ".bisdmail.net": ["Game Development Design School"],
    ".bishanoi.net": [
        "British International School, Hanoi (Trường Quốc Tế Đa Cấp Anh - Hà Nội)"
    ],
    ".bisvietnam.net": [
        "British International School, Ho Chi Minh City (Trường Quốc Tế Đa Cấp Anh - Thành phố Hồ Chí Minh)"
    ],
    ".bjalearn.net": ["Bob Jones Academy"],
    ".bluevalleyk12.net": ["Blue Valley School District"],
    ".bmiet.net": ["B. M. Institute Of Engineering & Technology"],
    ".bmstu.net": [
        "Bauman Moscow State Technical University",
        "Bauman Moscow State Technical University",
    ],
    ".boiseschools.net": ["Boise School District"],
    ".bracuniversity.net": ["Brac University"],
    ".brightoncollege.net": ["Brighton College"],
    ".students.bsd-ri.net": ["Burrillville High School"],
    ".bsgg.net": ["Berufliche Schulen Groß-Gerau"],
    ".bssdstd.net": ["Blue Springs School District"],
    ".bts-malraux.net": ["Lycée Andre Malraux, Allonnes, France"],
    ".bumail.net": ["Bangkok University"],
    ".bvishanoi.net": [
        "British Vietnamese International School, Hanoi (Trường Quốc Tế Đa Cấp Anh Việt - Hà Nội)"
    ],
    ".bvisvietnam.net": [
        "British Vietnamese International School, Ho Chi Minh City (Trường Quốc Tế Đa Cấp Anh Việt - Thành phố Hồ Chí Minh)"
    ],
    ".c2ken.net": ["Slemish College"],
    ".carfax-pupils.net": ["Carfax Education"],
    ".carfax-tutors.net": ["Carfax Education"],
    ".carlsbadusd.net": ["Carlsbad Unified School District", ".group"],
    ".catholiccentral.net": ["Detroit Catholic Central High School"],
    ".student.ccboe.net": [
        "Columbia County school system of Georgia",
        "Columbia county",
        "Website:",
        "www.ccboe.net",
    ],
    ".ccisd.net": ["Clear Creek Independent School District", ".group"],
    ".ccsacademy.net": ["Chipping Campden School"],
    ".nv.ccsd.net": [
        "Charles Silvestri JHS",
        "Foothill High School",
        ".group",
    ],
    ".ccsd15.net": ["Thomas Jefferson Middle School"],
    ".cendrassos.net": [
        "Institut Cendrassos-Figueres",
        "Cendrassos-Figueres High School",
    ],
    ".cepnet.net": [
        "Centre d’Estudis Politècnics",
        "Polytechnic Study Center",
    ],
    ".cesde.net": ["Cesde, Colombia"],
    ".stu.cfisd.net": ["Cyfair Highschool"],
    ".cicracampus.net": [
        "CICRA Campus (Pvt) Ltd",
        "University main website: https://cicra.edu.lk",
        "Long term IT course URL: https://cicra.edu.lk/bachelor-of-cyber-security-pathway-program-deakin-university-australia/",
        "Parent business group URL: https://cicra.lk/",
    ],
    ".cipsa.net": ["CIPSA"],
    ".citchennai.net": [
        "Chennai Institute of Technology",
        "Chennai Institute of Technology",
    ],
    ".uczen.ckziu.net": [
        "Centrum Kształcenia Zawodowego i Ustawicznego w Jaworznie"
    ],
    ".claytonschools.net": ["Clayton High School"],
    ".codeinstitute.net": ["Code Institute"],
    ".colegiolasallepaterna.net": ["Colegio La Salle Paterna"],
    ".aluno.colegiomaanaim.net": ["Colégio Maanaim"],
    ".colegiovitoriaregia.net": ["Colégio Vitória Régia"],
    ".comunidadunir.net": [
        "International University of La Rioja",
        "Universidad Internacional de La Rioja",
    ],
    ".learn.conejousd.net": ["Westlake High School"],
    ".studentmail.conroeisd.net": ["The Woodlands High School "],
    ".conroeisd.net": ["Stockton Junior High School"],
    ".courtmoorschool.net": ["Court Moor School"],
    ".crcmail.net": ["Champlain Regional College"],
    ".csustudent.net": ["Charleston Southern University"],
    ".ct-college.net": ["Kharkiv computer and technology college"],
    ".ctide.net": ["Pottsville Area High School"],
    ".alumni.cuhk.net": ["The Chinese University of Hong Kong"],
    ".cvsd.net": [
        "Chartiers Valley School District",
        "Chartiers Valley School District",
    ],
    ".dallastownsd.net": ["Dallastown Area Middle School"],
    ".darzo.net": ["Istituto Superiore Silvio D'arzo"],
    ".deegfeld.net": ["Oberschule Deegfeld"],
    ".deerparkschool.net": ["Cirencester Deerpark School"],
    ".denbigh.net": ["Denbigh School"],
    ".depinfonancy.net": [
        "DepInfoNancy.net which translate to IT Department of Mines Nancy (France).",
        "Unofficial domain for IT department, for which IT Students have an email (gmail + domain). The official email is used for alumni stuff as well thus do not meet requirements.",
        "References : http://www.depinfonancy.net/, http://www.mines-nancy.univ-lorraine.fr/content/syllabus-20152016-0 (a link from this page to www.depinfonancy.net exist in Information & Systems part)",
    ],
    ".digital-campus.net": ["ESG - Ecole de commerce"],
    ".dpsk12.net": ["Denver Public Schools"],
    ".dpsrkp.net": ["Delhi Public School, R.K. Puram"],
    ".go.dsdmail.net": ["Davis County School District, Utah"],
    ".dublinusd.net": ["Dublin Unified School District"],
    ".dunlapcusd.net": ["Dunlap High School"],
    ".dunlapstudents.net": ["Dunlap High School"],
    ".dzrtvu.net": ["DAZHOU RADIO&TV UNIVERSITY"],
    ".e-artsup.net": ["École de la Passion Créative"],
    ".eada.net": ["Eada Business School"],
    ".eanesisd.net": ["Eanes Independent School District"],
    ".eartvic.net": [
        "Escola Superior de Disseny i d'Arts Plàstiques de Catalunya (ESDAP)",
        "Superior School of Design and Plastic Arts of Catalonia",
    ],
    ".eclisboa.net": ["Escola do comercio de lisboa"],
    ".ecole-ipssi.net": [
        "IPSSI - École d’Informatique, Web et Design Graphique"
    ],
    ".ecoles-epsi-wis.net": [
        "École professionnelle des sciences informatiques"
    ],
    ".ecoles-epsi.net": ["École professionnelle des sciences informatiques"],
    ".ecoles-wis.net": ["Web International School"],
    ".bbs1.edukl.net": [
        "Berufsbildende Schule I Technik - Kaiserslautern",
        "Vocational School I Technology Kaiserslautern",
    ],
    ".efrei.net": [
        "École d'ingénieur généraliste en informatique et technologies du numérique"
    ],
    ".eichendorffschule.net": ["Eichendorffschule Kelkheim"],
    ".elisava.net": ["Fundació Privada Elisava Escola Universitària"],
    ".live.emvs.net": ["Ecole des Métiers du Valais"],
    ".engimtorino.net": [
        "ENGIM Piemonte – Artigianelli Torino ",
        "URL website: http://www.engimtorino.net/",
        "CERTIFICATIONS",
        "ENGIM Piemonte - Artigianelli Torino is certified according to the UNI EN ISO 9001: 2015 standard for the sectors:",
        "EA 37 (Education)",
        "EA 35 (Professional Business Services)",
        "Courses: http://www.engimtorino.net/corsi/ some in IT. ",
        "Address",
        "c.so Palestro 14 – 10122 Torino",
        "ITALIAN CODE for School (Codice meccanografico): TOCF01600C",
    ],
    ".epita.net": ["École Pour l'Informatique et les Techniques Avancées"],
    ".epmistes.net": ["ECAM EPMI - école d'ingénieurs"],
    ".es-be.net": ["Saint Michel des Batignolles"],
    ".es-rm.net": [
        "Europäische Schule RheinMain",
        "European School RheinMain",
    ],
    ".esarc-evolution.net": ["ESG - Ecole de commerce"],
    ".alunos.escolasobidos.net": [
        "Escola Basica e Secundaria Josefa de Obidos",
        "Basic and Secondary School Josefa de Óbidos",
    ],
    ".esigetel.net": [
        "École supérieure d'ingénieurs en informatique et génie des télécommunications"
    ],
    ".esrp.net": ["Escola Superior de Relacions Públiques"],
    ".etna-alternance.net": [
        "École de la Nouvelle Alternance en Informatique"
    ],
    ".etsmtl.net": ["École de technologie supérieure, Université du Québec"],
    ".evhs.net": ["East Valley High School"],
    ".ewhain.net": ["Ewha Womans University"],
    ".fairfieldschools.net": ["Fairfield Ludlowe High School "],
    ".fapsnewdelhi.net": ["The Frank Anthony Public School"],
    ".fcpsschools.net": ["Fairfax County Schools"],
    ".ferrarispancaldo.net": [
        "IIS Ferraris - Pancaldo",
        "Technical School Ferraris - Pancaldo",
    ],
    ".fevaq.net": ['Facultad de Economia "Vasco de Quiroga"'],
    ".fisdk12.net": ["Friendswood High School"],
    ".flvsft912.flvs.net": ["Florida Virtual School"],
    ".learn.flvs.net": ["Florida Virtual School"],
    ".fosbos.net": [
        "Maximilian Kolbe (Fachober- & Berufsober-) Schule Neumarkt"
    ],
    ".franklinps.net": ["Franklin High School in Massachusetts"],
    ".fundacionloyola.net": ["Colegio Concertado San José, Málaga."],
    ".fusdk12.net": ["American High School"],
    ".garfieldre2.net": ["Rifle Middle School"],
    ".garlandisd.net": ["Garland Independent School District"],
    ".gcisdstudents.net": ["iUniversity Prep"],
    ".gdcvi.net": [
        "广东建设职业技术学院",
        "Guangdong Construction Vocational and Technical College",
    ],
    ".oxf.gdst.net": ["Oxford High School"],
    ".por.gdst.net": ["Portsmouth High School for Girls"],
    ".shr.gdst.net": [
        "Shrewsbury High School GDST",
        "Shrewsbury High School GDST",
    ],
    ".wim.gdst.net": ["Wimbledon High School"],
    ".gemsdaa.net": ["GEMS Dubai American Academy"],
    ".ggits.net": ["Gyan Ganga"],
    ".ggusd.net": ["Pacifica High School", "Pacifica High School"],
    ".gi-tec.net": ["Gratiot Isabella technical education center"],
    ".gitis.net": [
        "Russian Academy of Theatre Arts",
        "Russian Academy of Theatre Arts",
    ],
    ".golosal.net": ["Los Alamitos High School"],
    ".gomalle.net": ["Atheneum Malle"],
    ".gowcs.net": ["Williamston High School"],
    ".graphische.net": ["die Graphische"],
    ".grb-online.net": ["Gymnasium Riedberg"],
    ".guhsd.net": ["Grossmont Union High School "],
    ".guilderlandschools.net": ["Guilderland High School"],
    ".gulfuniversity.net": ["Gulf University College"],
    ".stu.gusd.net": ["Herbert Hoover High School"],
    ".gym-leoben.net": ["BG/BRG Leoben 1 (Altes Gymnasium Leoben)"],
    ".gymbay.net": ["Staedtisches Gymnasium Bayreuther Strasse - Wuppertal"],
    ".student.gymkatzelsdorf.net": ["Gymnasium Klemens Maria Hofbauer"],
    ".gymmar.net": ["Gymnasium Mariehthal", "High school Marienthal"],
    ".gymott.net": ["Gymnasium Otterndorf"],
    ".gyo6.net": ["경상북도교육청", "Gyeongbuk Education"],
    ".gzkjxy.net": ["广州科技职业技术大学"],
    ".hadleighhigh.net": ["Hadleigh High School"],
    ".g.hayscisd.net": [
        "Johnson High School",
        "Moe & Gene Johnson High School",
    ],
    ".hcps.net": [
        "Hillsborough County Public Schools",
        "Thomas Jefferson High School",
    ],
    ".helmholtzschule-ffm.net": ["Helmholtzschule Frankfurt"],
    ".hetic.net": ["HETIC, la grande école d'internet"],
    ".hetperspectief.net": ["Het Perspectief PCVO - Adult Education"],
    ".apps.hhdc.net": ["Nuestra Señora de los Dolores"],
    ".hilcoe.net": ["HiLCoE School of Computer Science and Technology"],
    ".hillsidek12.net": ["Hillside Public Schools"],
    ".hillsideschool.net": ["Hillside School"],
    ".hinchingbrookeschool.net": ["Hinchingbrooke School"],
    ".hindusthan.net": [
        "Hindusthan Educational Institutions, Coimbatore ",
        ".group",
    ],
    ".hneu.net": ["Simon Kuznets Kharkiv National University of Economics"],
    ".g.horrycountyschools.net": ["Myrtle Beach High School", ".group"],
    ".humbleisd.net": ["Kingwood Park Highschool"],
    ".hunau.net": ["湖南农业大学", "Hunan Agricultural University"],
    ".hvf-bs.net": ["Hoffmann-von-Fallersleben-Schule Gymnasium"],
    ".hwbcymru.net": ["Cardiff High School"],
    ".hwps.net": ["George W Hewlett High School"],
    ".hwschools.net": ["Hamilton Wenham Regional High School"],
    ".iaac.net": ["Institute for advanced architecture of Catalonia"],
    ".ichthuscollege.net": ["Ichthus college"],
    ".ict-campus.net": ["Eidgenössisches Fähigkeitszeugnis"],
    ".icuzambia.net": ["Information and Communications University"],
    ".ilb.idserve.net": ["Apple Developer Academy Infinite Learning"],
    ".iedib.net": [
        "IES INSTITUT D'ENSENYAMENTS A DISTÀNCIA DE LES ILLES BALEARS (07015719) (Palma)",
        "IES INSTITUTE OF DISTANCE EDUCATION OF THE BALEARIC ISLANDS (07015719) (Palma)",
    ],
    ".iedparis8.net": ["iedparis8 foad"],
    ".ies9023.net": ["CESIT INSTITUTO DE EDUCACIÓN SUPERIOR IES-9023"],
    ".iesdamiahuguet.net": ["IES Damià Huguet"],
    ".iese.net": ["IESE Business School"],
    ".iesjuandeherrera.net": [
        "INSTITUTO DE EDUCACIÓN SECUNDARIA JUAN DE HERRERA"
    ],
    ".iesportocristo.net": ["IES Porto Cristo"],
    ".iessanclemente.net": ["IES San Clemente"],
    ".iessarenal.net": ["IES s'Arenal de Llucmajor"],
    ".iesunamuno.net": ["Instituto de educación secundaria Miguel de Unamuno"],
    ".igs-rodenberg.net": ["IGS Rodenberg"],
    ".iiitb.net": [
        "International Institute of Information Technology Bangalore"
    ],
    ".iimtindia.net": ["IIMT Group of colleges in India"],
    ".impscet.net": ["IMPS College of Engineering and Technology, Malda"],
    ".imt-atlantique.net": ["Institut Mines-Télécom Atlantique"],
    ".indianatech.net": ["Indiana Tech"],
    ".infobosccoma.net": ["Institut Bosc de la Coma"],
    ".institutodh.net": [
        "Instituto de Educación Secundaria Delgado Hernandez in Bollullos Par del Condado, Huelva, Andalusia, Spain"
    ],
    ".ip-formation.net": [
        "IPSSI - École d’Informatique, Web et Design Graphique"
    ],
    ".ipilyon.net": ["IPI Lyon"],
    ".ipsas-ens.net": [
        "institut polytechnique des sciences avancées sfax-Tunisie"
    ],
    ".irakasle.net": [
        "Delegación de Educación del Gobierno Vasco / Eusko Jaurlaritza Hezkuntza Saila"
    ],
    ".iraquniversity.net": ["Iraq University College"],
    ".iscpalyon.net": ["ISCPA Lyon - Institut Supérieur des Médias"],
    ".isetsf.net": [
        "institut supérieur des études technologiques de sfax ",
        "Higher Institute of Technological Studies of Sfax",
    ],
    ".ism-sabis.net": [
        "The International School of Minnesota",
        "International School of Minnesota",
        "ISM",
    ],
    ".ismreves.net": ["Institut Sainte-Marie"],
    ".ispaj.net": ["Instituto Superior Politécnico Alvorecer da Juventude"],
    ".itiomar.net": ['Istituto Tecnico Industriale "Giuseppe Omar"'],
    ".itivoltativoliguidonia.net": [
        "ISTITUTO TECNICO TECNOLOGICO STATALE ALESSANDRO VOLTA",
        "official website https://itivolta.edu.it",
        "Long term (3 yrs) computer science course information: https://www.itivolta.edu.it/offerta-formativa-itts-volta/",
    ],
    ".jamesrumsey.net": ["James Rumsey Technical Institute"],
    ".jarrellisd.net": ["Jarrell High School"],
    ".jaumebalmes.net": ["Institut Jaume Balmes"],
    ".jcsds.net": ["Junction City High School"],
    ".jedlik.net": ["Jedlik Ányos Gimnázium"],
    ".jhs.net": ["Jesuit High School"],
    ".jirovcovka.net": [
        "Gymnázium, České Budějovice, Jírovcova 8, Czech Republic"
    ],
    ".jksmail.net": ["Jeddah Knowledge International School"],
    ".jlhs.net": ["金陵中学"],
    ".jls-hh.net": ["Julius-Leber-Schule"],
    ".johnabbottcollege.net": ["John Abbott College"],
    ".juanxxiii.net": ["Centro de Formación Profesional Juan XXIII"],
    ".kalamazoopublicschools.net": [
        "Hillside Middle school",
        "Kalamazoo Public Schools",
        ".group",
    ],
    ".kashmiruniversity.net": ["University of Kashmir, India"],
    ".kellerisd.net": ["Keller Center for Advanced Learning"],
    ".kes.net": ["King Edwards VI School, Stratford"],
    ".kingsmeadschool.net": ["Kingsmead School"],
    ".kingstirana.net": ["Kings Tirana"],
    ".kkos.net": ["Käthe-Kollwitz-Gymnasium Berlin"],
    ".students.kleinisd.net": ["Klein Forest High School"],
    ".zsp2.krotoszyn.net": [
        "Zespół Szkół Ponadgimnazjalnych nr 2 w Krotoszynie"
    ],
    ".ksrct.net": ["K.S.Rangasamy College of Technology"],
    ".kumsa.net": ["Khurasan University"],
    ".kvschools.net": [
        "Kankakee Valley High School",
        "KVHS",
        "Kankakee Valley Middle School",
        "KVMS",
    ],
    ".kwantlen.net": ["Kwantlen Polytechnic University"],
    ".ladueschools.net": [
        "Ladue Horton Watkins High School",
        "Ladue Horton Watkins High School",
    ],
    ".lammersvilleusd.net": ["Mountain House High School", ".group"],
    ".lasalleuniversities.net": [
        "La Salle Universities - International Programmes"
    ],
    ".laschools.net": ["Los Alamos High School"],
    ".lbschools.net": [
        "Long Beach Unified School District in Los Angeles, CA, USA",
        ".group",
    ],
    ".lcieducation.net": ["LaSalle College Institute - Vancouver"],
    ".lcisd.net": ["Lubbock-Cooper High School"],
    ".lecnam.net": ["Conservatoire national des Arts et Métiers"],
    ".leeschools.net": ["The School District of Lee County"],
    ".leobaeck.net": ["Leobaeck High School"],
    ".edu.leonschools.net": ["James S. Rickards Highschool"],
    ".eleve.leschartreux.net": ["Les Chartreux"],
    ".leyada.net": ["Hebrew University Secondary School"],
    ".lfschools.net": ["Lake Forest High School"],
    ".lgflmail.net": ["Southborough High School "],
    ".liceolapaz.net": ["CPR Plurilingüe Liceo La Paz"],
    ".lifesciencesutc.net": ["Liverpool Life sciences UTC"],
    ".lions.net": ["South Fayette High School"],
    ".lisd.net": ["Lewisville Independent School District"],
    ".liskeard.net": ["Liskeard School and Community College"],
    ".litech.net": [
        'Технічний фаховий коледж Національного університету "Львівська політехніка"'
    ],
    ".livenau.net": ["National Aviation University"],
    ".livingstonschools.net": ["Holden High"],
    ".lpsfrisco.net": ["Leadership Prep School Secondary Campus, Frisco, Tx"],
    ".lsr7.net": ["Lee's Summit R-7 School District"],
    ".lsrhs.net": ["Lincoln-Sudbury Regional High School"],
    ".d204.lths.net": ["Lyons Township High School"],
    ".lubbockisd.net": ["Lubbock High School", "Lubbock High School"],
    ".luhsd.net": ["Liberty High School Unified District"],
    ".lycee-bordebasse.net": ["Lycée Borde Basse"],
    ".etud.lycee-mermoz.net": ["lycee jean mermoz", "jean mermoz high school"],
    ".lyndhurstschools.net": ["Lyndhurst High School"],
    ".lz95.net": ["Lake Zurich Community District"],
    ".madisonk12.net": ["Madison High School", "https://www.madisonk12.net/"],
    ".mail-formateur.net": ["EPSI Ecole d'Ingénierie Informatique"],
    ".manavrachna.net": [
        "Manav Rachna International Institute of Research and Studies"
    ],
    ".marionstudents.net": ["Westport High school", "Westport High School"],
    ".matc.net": ["Manhattan Area Technical College"],
    ".max-emden.net": ["Max-Windmüller-Gymnasium"],
    ".mayfieldschool.net": ["Mayfield School"],
    ".mba-esg.net": ["MBA ESG"],
    ".mbs.net": ["Morristown-Beard School"],
    ".mchs.net": ["Minooka Community High School"],
    ".mckinneyisd.net": ["McKinney Independent School District"],
    ".mcmsnj.net": [
        "Woodbridge Academy - Middlesex County Magnet School of New Jersey"
    ],
    ".mcpsmd.net": ["Montgomery County Public Schools (Maryland)"],
    ".mdusd.net": [
        "Northgate High School",
        "Mt. Diablo Unified School District",
    ],
    ".mgschools.net": ["Monona Grove Highschool"],
    ".misdmail.net": ["Lake Ridge High School"],
    ".monlycee.net": ["Mon Lycee Ile-de-France"],
    ".monroeps.net": ["Monroe Public Schools"],
    ".msitprogram.net": [
        "Master of Science in Information Technology",
        "International Institute of Information Technology Hyderabad",
    ],
    ".msjnet.net": ["Mount Saint Joseph High School"],
    ".muehlbachschule.net": ["Mühlbachschule Schemmerhofen"],
    ".muwci.net": ["Mahindra United World College India"],
    ".mvla.net": ["Mountain View Los Altos High School District"],
    ".mvwsd.net": ["Isaac Newton Graham Middle School Mountain View"],
    ".myecran.net": ["ESG - Ecole de commerce"],
    ".myesg.net": ["ESG - Ecole de commerce"],
    ".myoneclay.net": ["Fleming Island High School"],
    ".mypisd.net": ["Plano Independent School District"],
    ".nashobatech.net": ["Nashoba Valley Technical High School"],
    ".ncvt.net": [
        "Nanning College For Vocational Technology",
        "http://www.ncvt.net",
    ],
    ".ndbellegarde.net": ["Notre-Dame de Bellegarde"],
    ".ndoverneuil.net": ["Notre Dame les Oiseaux Verneuil / NDO Verneuil"],
    ".netkentuni.net": [
        "Netkent Akdeniz Araştırma ve Bilim Üniversitesi",
        "Netkent Mediterranean Research and Science University",
    ],
    ".nhps.net": ["Barnard (B.E.S.T)"],
    ".nicevillehighschool.net": ["Niceville High School"],
    ".nisd.net": [
        "Harlan Highschool",
        "Northside Independent School District",
        ".group",
    ],
    ".nitsri.net": ["National Institue of Technology Srinagar", "nitsri.net"],
    ".northrise.net": ["Northrise University, Ndola, Zambia "],
    ".nsboroschools.net": [
        "Public Schools of Northborough and Southborough / Algonquin Regional High School",
        "Url: https://www.nsboro.k12.ma.us/arhs",
        "Mail: (name)@nsboroschools.net",
    ],
    ".nsd42.net": ["Nashua School District"],
    ".nspu.net": ["Novosibirsk State Pedagogical University"],
    ".ntai.net": ["\ufeffNetwork Technology Academy"],
    ".ntg-plovdiv.net": [
        "Национална Търговска Гимназия",
        "National High School of Trade and Commerce Plovdiv",
    ],
    ".student.nths.net": ["add new trier high school"],
    ".ntschools.net": ["Casuarina Senior College"],
    ".nycstudents.net": ["Mark Twain I.S. 239"],
    ".oak-hill.net": ["Oak Hill Academy"],
    ".ocps.net": ["Orange County Public Schools (Florida)"],
    ".ofcs.net": ["Olmsted Falls City Schools"],
    ".ogsd.net": ["Oak Grove School District, California, USA"],
    ".oisbd.net": ["Oxford International School"],
    ".ontariotechu.net": ["Ontario Tech University"],
    ".msd.oregonk-12.net": ["McMinnville High School"],
    ".oregonsd.net": ["Oregon High School"],
    ".student.osceolaschools.net": ["NeoCity Academy"],
    ".palisadessd.net": ["Palisades School District"],
    ".parklandsd.net": ["Parkland High School"],
    ".parkschool.net": ["The Park School of Baltimore"],
    ".parkwayschools.net": ["Parkway School District"],
    ".pdsb.net": ["Peel District School Board", ".group"],
    ".pennmanor.net": ["Penn Manor School District"],
    ".stu.pfisd.net": ["John B. Connally High School"],
    ".pghs.net": ["Pleasant Grove High School"],
    ".pimajted.net": ["Pima JTED"],
    ".pimunn.net": [
        'ФГБОУ ВО "Приволжский исследовательский медицинский университет" Минздрава России'
    ],
    ".pinescharter.net": ["Pembroke Pines Charter High School"],
    ".pittsgrove.net": ["Arthur P. Schalick High School"],
    ".plaiaundi.net": ["IES Plaiaundi BHI", "Plaiaundi Vocational Institute"],
    ".plainville270.net": ["Plainville USD 270"],
    ".pleasantonusd.net": ["Pleasanton Unified School District"],
    ".plus4u.net": ["Unicorn College"],
    ".polahs.net": [
        "Port of Los Angeles High School",
        "Port of Los Angeles High School",
    ],
    ".polytech-lille.net": ["Ecole polytechnique universitaire de Lille"],
    ".student.pps.net": ["Metropolitan Learning Center"],
    ".pps.net": ["Portland Public Schools"],
    ".ppsstudents.net": ["Pittsburgh Public Schools"],
    ".promsocatc.net": ['Collège Technique "Aumôniers du Travail"'],
    ".k12.prosper-isd.net": ["Prosper High School"],
    ".raabeschule.net": ["Gymnasium Raabeschule Braunschweig"],
    ".radyr.net": ["Radyr Comprehensive School", "Radyr Comprehensive School"],
    ".raisoni.net": ["Raisoni Group Of Institution"],
    ".rascol.net": [
        "Lycée public général et professionnel dans l'Occitanie ( 81 ) ",
        "URL : http://www.rascol.net/",
    ],
    ".student.rcschools.net": ["Rutherford County Schools", ".group"],
    ".redlandsschools.net": ["Citrus Valley High School"],
    ".regentghana.net": [
        "Regent University College",
        "Regent University College Of Science And Technology  ",
    ],
    ".rgsu.net": [
        "Российский государственный социальный университет",
        "Russian state social university",
    ],
    ".rgtu.net": ["Rajiv Gandhi Proudyogiki Vishwavidyalaya, Bhopal"],
    ".riinvest.net": ["Riinvest College"],
    ".ruppin365.net": ["Ruppin Academic Center"],
    ".rusoil.net": [
        "Ufa State Petroleum Technological University",
        "Ufa State Petroleum Technological University",
    ],
    ".sabauni.net": ["Saba University"],
    ".aisriyadh.sabis.net": ["Sabis", "Sabis"],
    ".saint-louis29.net": ["Lycée Saint-Louis - Châteaulin"],
    ".saintdominique.net": ["Institut Saint-Dominique de Neuilly"],
    ".saintolaves.net": ["St. Olave's Grammar School"],
    ".saisd.net": ["CAST Tech "],
    ".saltashcloud.net": ["saltash.net community school"],
    ".sandi.net": ["San Diego Unified School District"],
    ".sarasotacountyschools.net": ["Sarasota County Schools"],
    ".sau25.net": ["Bedford High School"],
    ".sccs-stu.net": ["Santa Cruz High School"],
    ".school4games.net": ["School for Games"],
    ".scusd.net": ["Santa Clara High School, Santa Clara, CA 95051"],
    ".sd27j.net": ["27J Online Academy", "27J Online Academy"],
    ".my.sduhsd.net": ["San Dieguito Union High School District"],
    ".stumail.shermanisd.net": [
        "Sherman Independent School District",
        "Sherman, Texas",
        "https://www.shermanisd.net/ (institution site)",
        "https://www.shermanisd.net/Domain/2740 (The high school course guide contains college-level computer science classes)",
        "https://www.shermanisd.net/domain/2060 (Could not find proof of stumail.shermanisd.net but you can see the use of shermanisd.net, which is also included in this PR)",
    ],
    ".shermanisd.net": [
        "Sherman Independent School District",
        "Sherman, Texas",
        "https://www.shermanisd.net/ (institution site)",
        "https://www.shermanisd.net/Domain/2740 (The high school course guide contains college-level computer science classes)",
        "https://www.shermanisd.net/domain/2060 (This is the setup guide for instructor emails. You can see shermanisd.net mentioned more than once)",
    ],
    ".shu-bg.net": ["Shoumen University Konstantin Preslavski"],
    ".sio-mermoz.net": ["lycée jean mermoz"],
    ".student.sisd.net": ["Americas High School"],
    ".solskicenter.net": [
        "Šola s slovenskim učnim jezikom Simon Gregorčič Primož Trubar",
        'official website: "https://www.solskicenter.net"',
    ],
    ".solvaypostgrad.net": ["Solvay"],
    ".somorrostro.net": ["Centro de formación Somorrostro"],
    ".spumail.net": ["มหาวิทยาลัยศรีปทุม", "Sripatum University"],
    ".srvusd.net": ["San Ramon Valley Unified School District", ".group"],
    ".student.st-chris.net": ["St Christopher's School of Bahrain"],
    ".stanislascollege.net": ["Stanislascollege"],
    ".starkstate.net": ["Stark State College"],
    ".stjameslc.net": [
        "St. James Lutheran College",
        "St. James Lutheran College",
    ],
    ".stmcougars.net": ["St. Thomas More Catholic High School"],
    ".student-jcboe.net": ["Jefferson County High School"],
    ".studentlaschools.net": ["Los Alamos High School"],
    ".suhsd.net": ["Shasta High School"],
    ".suumail.net": ["Southern Utah University"],
    ".swchs.net": [
        "Saffron Walden County High School",
        "Audley End Road",
        "Saffron Walden",
        "Essex",
        "CB11 4UH",
    ],
    ".swcta.net": ["Southwest Career and Technical Academy"],
    ".talaiabhi.net": ["Talaia "],
    ".tcskailua.net": ["Trinity Christian School"],
    ".telecomnancy.net": ["TELECOM NANCY"],
    ".tesdk12.net": ["Conestoga High School"],
    ".tfobz.net": ["Technologische Fachoberschule Bozen"],
    ".thammasat.net": ["Thammasat University", "Thammasat University"],
    ".theleys.net": ["The Leys", "The Leys"],
    ".thestudio-liverpool.net": ["The Studio Liverpool"],
    ".thomas-hardye.net": ["Thomas Hardye School"],
    ".tipsglobal.net": ["The Indian Public School"],
    ".sec.tomballschools.net": [
        "Tomball Memorial High School",
        "Tomball Memorial High School",
    ],
    ".tomballschools.net": ["Grand Lakes Junior High School"],
    ".trentcollege.net": ["Trent College in Nottingham, England"],
    ".tretherras.net": ["Newquay Tretherras Academy"],
    ".trinityhigh.net": ["Trinity High School and sixth form Centre"],
    ".tscstudents.net": ["William Henry Harrison High School West Lafayette"],
    ".tsmmechelen.net": ["Tsm mechelen"],
    ".student.tusd.net": ["John C. Kimball High School"],
    ".edu.tversu.net": [
        "Тверской Государственный Университет",
        "Tver State University",
    ],
    ".uamcr.net": ["Universidad Americana"],
    ".uantonine.net": ["UA Universite Antonine"],
    ".ubboemmius.net": [
        "Ubbo Emmius Scholengemeenschap, The Netherlands, Students Email Domain"
    ],
    ".ubt-uni.net": ["University for Business and Technology"],
    ".ubuea.net": ["University of Buéa"],
    ".ucasal.net": ["Universidad Católica de Salta"],
    ".ucfsd.net": ["Unionville High School"],
    ".ugtu.net": ["Ukhta State Technical University"],
    ".ulatina.net": ["Universidad Latina de Costa Rica"],
    ".ulpgl.net": [
        "Université Libre des Pays des Grands Lacs",
        "Free University of Great Lakes Countries",
    ],
    ".umasd.net": ["Upper Merion Area High School"],
    ".unadeca.net": ["Universidad Adventista de Centroamerica"],
    ".unesc.net": ["Universidade do Extremo Sul Catarinense"],
    ".uni-gjilan.net": ["University Kadri Zeka"],
    ".uni-plovdiv.net": ["University of Plovdiv"],
    ".unibave.net": ["Centro Universitário Barriga Verde"],
    ".unicornuniversity.net": ["Unicorn College"],
    ".unimediteran.net": ["Univerzitet Mediteran", "Mediterranean University"],
    ".uninettunouniversity.net": [
        "Universita Telematica Internazionale UniNettuno"
    ],
    ".unir.net": ["Universidad Internacional de La Rioja"],
    ".univ-mngb.net": ["University Marien Ngouabi Brazzaville"],
    ".universityofsomalia.net": ["University of Somalia"],
    ".uoit.net": ["University of Ontario Institute of Technology"],
    ".usd259.net": ["Wichita East High School"],
    ".vcpusd.net": ["Valley Center-Pauma Unified"],
    ".vidalibarraquer.net": [
        "Institut Francesc Vidal i Barraquer",
        "https://www.vidalibarraquer.net/",
    ],
    ".videndjurs.net": ["Viden Djurs"],
    ".vitoriaregia.net": ["Colégio Vitória Régia"],
    ".vizja.net": ["Wyższa Szkoła Technologii Informatycznych"],
    ".vntu.net": ["Vinnytsia National Technical University"],
    ".volgatech.net": ["Volga State University of Technology"],
    ".vossie.net": ["Eduvos"],
    ".vvit.net": ["Vasireddy Venkatadri Institute of Technology"],
    ".wakecoll.net": ["Wakefield College"],
    ".wcpss.net": ["Wake County Public School System"],
    ".westminster.net": ["The Westminster Schools"],
    ".westottawa.net": ["West Ottawa High School"],
    ".wilhelm-gym.net": ["Wilhelm-Gymnasium Braunschweig"],
    ".willitscharter.net": ["Willits Charter School"],
    ".woldgate.net": ["Woldgate School and Sixth Form College"],
    ".wra.net": ["Western Reserve Academy"],
    ".wsd.net": ["Weber School District"],
    ".wths.net": ["Warren Township Highschool"],
    ".wylieisd.net": [
        "Wylie High School",
        "Wylie High",
        "WylieISD",
        "Wylie ISD",
        "Wylie ISD School District",
    ],
    ".xbhs.net": ["Xaverian Brothers High School"],
    ".zeppelin-university.net": ["Zeppelin University"],
    ".zhxhs.net": ["广州市执信中学"],
    ".zsnr4.net": ["Zespół Szkół nr4 w Nowym Sączu"],
    ".zszwolsztyn.net": ["Zespół Szkół Zawodowych Wolsztyn, Poland"],
    ".zib.network": [
        "TU Ilmenau - Zentralinstitut für Bildung",
        "TU Ilmenau - Central Institute for Education",
    ],
    ".aapoly.edu.ng": ["Academies Australasia Polytechnic Pty Limited"],
    ".aaua.edu.ng": ["Adekunle Ajasin University, Akungba-Akoko"],
    ".aauekpoma.edu.ng": ["Ambrose Alli University"],
    ".achievers.edu.ng": ["Achievers University", "Achievers University"],
    ".acu.edu.ng": ["Ajayi Crowther University"],
    ".student.adelekeuniversity.edu.ng": ["Adeleke University"],
    ".afit.edu.ng": [
        "Air Force Institue of Technology, Kaduna",
        "https://afit.edu.ng/home/mechatronics-engineering/",
        "info@afit.edu.ng",
        "Note: In My School We do not have official domains for students we just use Gmail or other emailling platforms to register for anything",
    ],
    ".alhikmah.edu.ng": ["Alhikmah University Ilorin"],
    ".aquatechcollege.edu.ng": [
        "Aquatech College of Agriculture and Technology"
    ],
    ".atbu.edu.ng": [
        "Abubakar Tafawa Balewa University Bauchi  State Nigeria"
    ],
    ".auk.edu.ng": ["Al-Qalam University Katsina"],
    ".student.aul.edu.ng": [
        "Anchor University Lagos",
        "Anchor University Lagos",
        "AUL",
        "Anchor University Lagos Ayobo",
        "# As added by Okorie God'sfavour Chiemerie AUL/SCI/16/0042 - Department of Computer Science and Mathematics 2016",
    ],
    ".aul.edu.ng": ["Anchor university, Lagos, Nigeria"],
    ".aun.edu.ng": ["American University of Nigeria"],
    ".aust.edu.ng": [
        "African University of Science and Technology [AUST], Abuja"
    ],
    ".pg.babcock.edu.ng": ["Babcock University"],
    ".student.babcock.edu.ng": ["Babcock University"],
    ".basug.edu.ng": ["Bauchi State University Gadau"],
    ".bazeuniversity.edu.ng": ["Baze University Abuja"],
    ".bellsuniversity.edu.ng": ["Bells University of Technology"],
    ".binghamuni.edu.ng": ["Bingham University"],
    ".bouesti.edu.ng": [
        "Bamidele Olumilua University of Education, Science and Technology, Ikere-Ekiti"
    ],
    ".bowen.edu.ng": ["Bowen University"],
    ".bsum.edu.ng": [
        "Benue State University Makurdi",
        "BSUM",
        "BSU Makurdi",
        "BSU",
    ],
    ".buk.edu.ng": [
        "Bayero University, Kano",
        "BUK",
        "Official Website: https://www.buk.edu.ng/",
        "The student email is like   student_i@buk.edu.ng",
        "#Request made by Shamsuddeen Hassan Muhammad, Faculty of Computer Science and IT.",
    ],
    ".calebuniversity.edu.ng": ["Caleb University"],
    ".ccu.edu.ng": ["Coal City University, Nigeria"],
    ".coedarazo.edu.ng": ["College of Education Darazo"],
    ".covenantuniversity.edu.ng": ["Covenant University"],
    ".crs-coeakamkpa.edu.ng": [
        "Cross River State College of Education, Akamkpa, Cross River",
        "Cross River State College of Education, Akamkpa",
    ],
    ".crutech.edu.ng": ["Cross River University of Technology "],
    ".stu.cu.edu.ng": ["Covenant University"],
    ".cuab.edu.ng": ["Crescent University, Abeokuta"],
    ".dui.edu.ng": ["Dominican University Ibadan"],
    ".edouniversity.edu.ng": [
        "Edo State University",
        "Formerly Known as Edo University",
    ],
    ".eit.edu.ng": [
        "Elerinmosa Institute of Technology, Erin-Osun, Osun State, Nigeria.",
        "Elerinmosa Institute of Technology",
    ],
    ".eksu.edu.ng": ["Ekiti State University"],
    ".elizadeuniversity.edu.ng": ["Elizade University, Illara-Mokin"],
    ".fbiu.edu.ng": [
        "Franco-British International University",
        "Franco-British International University",
    ],
    ".fcahptib.edu.ng": [
        "Federal College Of Animal Health & Production Technology Ibadan"
    ],
    ".fcepankshin.edu.ng": [
        "Federal College of Education, Pankshin, Plateau State, Nigeria"
    ],
    ".fcepkn.edu.ng": ["Federal College of Education Pankshin"],
    ".federalpolyede.edu.ng": ["The Federal Polytechnic Ede, Osun State."],
    ".federalpolyilaro.edu.ng": ["The Federal Polytechnic, Ilaro"],
    ".fedpolyado.edu.ng": ["The Federal Polytechnic Ado-Ekiti"],
    ".fideipoly.edu.ng": ["Fidei Polytechnic Gboko, Benue state, Nigeria"],
    ".flyingdoveinstitute.edu.ng": ["Flying Dove Institute Nigeria"],
    ".fptb.edu.ng": ["The Federal Polytechnic Bauchi, Nigeria"],
    ".fubk.edu.ng": ["Federal University Birnin Kebbi"],
    ".fud.edu.ng": ["Federal University Dutse"],
    ".fudutsinma.edu.ng": [
        "federal University Dutsin-ma Katsina State Nigeria"
    ],
    ".fugusau.edu.ng": ["Federal University Gusau"],
    ".fukashere.edu.ng": ["Federal University of Kashere"],
    ".student.fulafia.edu.ng": [
        "Federal University Lafia,Nigeria",
        "http://www.fulafia.edu.ng",
    ],
    ".fulokoja.edu.ng": ["Federal University Lokoja"],
    ".pg.funaab.edu.ng": [
        "Federal University Of Agriculture Postgraduate school"
    ],
    ".student.funaab.edu.ng": ["Federal University of Agriculture, Abeokuta."],
    ".funaab.edu.ng": [
        "Federal University of Agriculture, Abeoukuta",
        "FUNAAB",
    ],
    ".funai.edu.ng": [
        "Alex Ekwueme Federal University Ndufu Alike Ikwo.",
        "Alex Ekwueme Federal University Ndufu Alike.",
    ],
    ".fuoye.edu.ng": ["The Federal University of Oye Ekiti"],
    ".fupre.edu.ng": ["Federal University of Petroleum Resources, Effurun"],
    ".futa.edu.ng": ["The Federal University of Technology Akure"],
    ".st.futminna.edu.ng": [
        "Federal university of Techonology, Minna",
        "http://futminna.edu.ng",
        "The student email is like -- student_id@st.futminna.edu.ng",
    ],
    ".futo.edu.ng": [
        "FEDERAL UNIVERSITY OF TECHNOLOGY OWERRI (FUTO), NIGERIA",
        "FEDERAL UNIVERSITY OF TECHNOLOGY OWERRI (FUTO), NIGERIA",
    ],
    ".fuwukari.edu.ng": ["Federal University Wukari"],
    ".gsu.edu.ng": ["Gombe State University"],
    ".imsu.edu.ng": ["Imo State University Owerri"],
    ".interlinkpolytechnic.edu.ng": [
        "Interlink Polytechnic, Ijebu-Jesa, Osun State"
    ],
    ".kadunapolytechnic.edu.ng": ["Kaduna Polytechnic"],
    ".kasu.edu.ng": ["Kaduna State University"],
    ".kingsuniversity.edu.ng": ["Kings University, Odeomu"],
    ".kum.edu.ng": ["Khadija University Majia", "Khadija University Majia"],
    ".kwarastatepolytechnic.edu.ng": [
        "Kwara State Polytechnic, Ilorin, Kwara State"
    ],
    ".kwasu.edu.ng": ["Kwara State University, Malete"],
    ".lasu.edu.ng": ["Lagos State University"],
    ".lautech.edu.ng": ["Ladoke Akintola University of Technology"],
    ".lmu.edu.ng": ["Landmark University, Omu-Aran"],
    ".mau.edu.ng": ["Modibbo Adama University, Yola"],
    ".mautech.edu.ng": [" Modibbo Adamawa University of Technology, Yola"],
    ".mcu.edu.ng": ["McPherson University, Seriki-Sotayo, Ogun State"],
    ".std.miu.edu.ng": ["Mewar International University (MIU)"],
    ".miva.edu.ng": ["Miva Open University"],
    ".mouau.edu.ng": ["micheal okpara university of agriculture "],
    ".mtu.edu.ng": ["Mountain Top University"],
    ".nacest.edu.ng": [
        "Nigerian army college of environmental science and technology (NACEST)"
    ],
    ".naub.edu.ng": ["Nigerian Army University Biu"],
    ".nda.edu.ng": ["Nigeria Defence Academy, Kaduna, Nigeria"],
    ".ndu.edu.ng": ["Niger Delta University, Nigeria"],
    ".nileuniversity.edu.ng": ["Nile University of Nigeria"],
    ".nocen.edu.ng": ["NWAFOR ORIZU COLLEGE OF EDUCATION NSUGBE"],
    ".nou.edu.ng": ["National Open University of Nigeria"],
    ".nsuk.edu.ng": ["Nasarawa State University, Keffi"],
    ".ntnu.edu.ng": ["Nigerian Turkish Nile"],
    ".nutm.edu.ng": ["Nigerian University of Technology and Management"],
    ".oauife.edu.ng": ["Obafemi Awolowo University"],
    ".oouagoiwoye.edu.ng": [
        "OLABISI ONABANJO UNIVERSITY",
        "OLABISI ONABANJO UNIVERSITY",
    ],
    ".osustech.edu.ng": [
        "OSUSTECH",
        "Ondo State university of science and Technology",
    ],
    ".pau.edu.ng": ["Pan-Atlantic University", "PAU"],
    ".plapoly.edu.ng": ["Plateau State Polytechnic, Barkin Ladi, Nigeria"],
    ".polac.edu.ng": ["Nigerian Police Academy"],
    ".run.edu.ng": ["Redeemer's University"],
    ".slu.edu.ng": [
        "Sule Lamido University, Kafin Hausa, Jigawa State Nigeria"
    ],
    ".tasued.edu.ng": [
        "Tai Solarin University of Education",
        "Tai Solarin University of Education",
    ],
    ".tech-u.edu.ng": ["First Technical University "],
    ".topfaith.edu.ng": ["Topfaith University"],
    ".tsuniversity.edu.ng": ["Taraba State University"],
    ".uat.edu.ng": [
        "University of Africa Toru-Orua",
        "University of Africa Toru-Orua",
    ],
    ".dlc.ui.edu.ng": ["University of Ibadan DLC"],
    ".stu.ui.edu.ng": ["University of Ibadan"],
    ".ui.edu.ng": ["University of Ibadan (UI)"],
    ".umyu.edu.ng": ["Umaru Musa Yar'adua University Katsina"],
    ".unical.edu.ng": ["University Of Calabar"],
    ".unicross.edu.ng": ["University of Cross River State"],
    ".unilag.edu.ng": ["University of Lagos."],
    ".unilorin.edu.ng": ["University of Ilorin"],
    ".unimaid.edu.ng": ["University of Maiduguri", "Unimaid"],
    ".uniosun.edu.ng": ["Osun State University"],
    ".uniport.edu.ng": ["Uniport Of Port Harcourt"],
    ".uniuyo.edu.ng": ["University of Uyo", "University of Uyo, Uyo"],
    ".unizik.edu.ng": ["Nnamdi Azikiwe University"],
    ".ust.edu.ng": ["Rivers State University of Science and Technology"],
    ".veritas.edu.ng": ["Veritas University Abuja"],
    ".yabatech.edu.ng": ["Yaba College of Technology"],
    ".yumsuk.edu.ng": ["Yusuf Maitama Sule University Kano"],
    ".lbs.net.ng": ["Lagos Business School, Pan-Atlantic University, Lagos"],
    ".uam.edu.ni": ["Universidad Americana"],
    ".uca.edu.ni": ["Universidad Centroamericana"],
    ".ucc.edu.ni": ["Universidad Ciencias Comerciales"],
    ".ucem.edu.ni": [
        "Universidad Centroamericana de Ciencias Empresariales (UCEM)"
    ],
    ".ucyt.edu.ni": ["Universidad Nicaragüense de Ciencia y Tecnológica"],
    ".udem.edu.ni": ["Universidad de Managua (U de M)"],
    ".uhispam.edu.ni": ["Universidad Hispanoamericana"],
    ".ulam.edu.ni": ["Universidad de las Américas (ULAM)"],
    ".una.edu.ni": ["Universidad Nacional Agraria"],
    ".unan.edu.ni": ["Universidad Nacional Autonoma de Nicaragua"],
    ".uni.edu.ni": ["Universidad Nacional de Ingenieria"],
    ".unica.edu.ni": [
        "Universidad Catolica Redemptoris Mater",
        "Universidad Catolica Redemptoris Mater",
        "Universidad Catolica Redemptoris Mater",
    ],
    ".unicit.edu.ni": ["Universidad Iberoamericana de Ciencia y Tecnologia"],
    ".upoli.edu.ni": ["Universidad Politecnica de Nicaragua"],
    ".uponic.edu.ni": ["Universidad Popular de Nicaragua (UPONIC)"],
    ".utc.edu.ni": ["Universidad Técnica de Comercio"],
    ".uam.net.ni": [
        "Universidad Americana (UAM)",
        "Universidad Americana (UAM)",
        "Universidad Americana (UAM)",
    ],
    ".st.roc.a12.nl": ["ROC A12"],
    ".a12.nl": ["ROC A12"],
    ".ad-academie.nl": ["AD Academie", "Associate degrees Academie"],
    ".ade-buas.nl": ["Breda University of Applied Sciences"],
    ".student.ahk.nl": ["Amsterdam University Of The Arts"],
    ".ahk.nl": ["Amsterdam University Of The Arts"],
    ".student.albeda.nl": ["Albeda College Rotterdam"],
    ".albeda.nl": ["Albeda College"],
    ".aletta.nl": ["dr. Aletta Jacobs College"],
    ".student.alfa-college.nl": [
        "Student subdomain for Alfa College in Hoogeveen and Groningen"
    ],
    ".alfa-college.nl": ["Alfa-college Hardenberg"],
    ".amadeuslyceum.nl": ["Amadeus Lyceum"],
    ".ambelt.nl": ["Het Ambelt in Zwolle"],
    ".amstelveencollege.nl": ["Amstelveen College"],
    ".amsterdamumc.nl": ["Amsterdam UMC", "Amsterdam UMC"],
    ".andreascollege.nl": ["Stichting Andreas College"],
    ".arcuscollege.nl": ["https://vistacollege.nl/"],
    ".arentheemcollege.nl": ["Arentheem College"],
    ".student.artez.nl": ["ArtEZ hogeschool voor de kunsten"],
    ".artez.nl": ["ArtEZ hogeschool voor de kunsten"],
    ".ash.nl": [
        "American School of the Hague",
        "American School of the Hague",
    ],
    ".edu.atchilversum.nl": ["Alberdingk Thijm College"],
    ".atlascollege.nl": [
        "Atlas College",
        "Copernicus SG",
        "OSG West-Friesland",
        "SG De Dijk",
        "SG De Triade",
        "SG Newton",
    ],
    ".auc.nl": ["Amsterdam University College"],
    ".avans.nl": ["Avans University of Applied Sciences"],
    ".aventus.nl": ["Aventus.nl"],
    ".barlaeus.nl": ["Barlaeus Gymnasium"],
    ".edu.bartimeus.nl": ["Bartimeus REA College"],
    ".bc-enschede.nl": ["Bonhoeffer College Enschede"],
    ".beekdallyceum.nl": ["Beekdal Lyceeum"],
    ".bernardinuscollege.nl": ["Bernardinuscollege"],
    ".student.bit-academy.nl": ["Bit Academy"],
    ".bit-academy.nl": ["Bit Academy"],
    ".bonhoeffer.nl": ["Bonhoeffercollege Castricum"],
    ".bsnstudent.nl": ["The British School in The Netherlands"],
    ".buas.nl": ["Breda University of Applied Sciences"],
    ".leerling.cals.nl": ["Cals College"],
    ".calvijn.nl": ["CSG Calvijn"],
    ".calvijncollege.nl": ["Calvijn College"],
    ".candea.nl": ["Candea College"],
    ".capellen.nl": ["Van der Capellen Scholengemeenschap Zwolle Lassuslaan"],
    ".carolus.nl": ["Carolus Borromeus College"],
    ".cartesius2.nl": ["Cartesius 2"],
    ".celeanum.nl": ["Gymnasium Celeanum Zwolle"],
    ".leerling.cgu.nl": ["Christelijk Gymnasium Utrecht"],
    ".cgu.nl": [
        "Christelijk Gymnasium Utrecht",
        "Christian Gymnasium Utrecht",
    ],
    ".che.nl": ["CHE Christian University of Applied Sciences"],
    ".chrlyceumdelft.nl": ["Christelijk Lyceum Delft Molenhuispad"],
    ".student.cibap.nl": ["Cibap Vakschool voor Verbeelding"],
    ".clv.nl": ["christelijk lyceum veenendaal"],
    ".clz.nl": ["Christelijk Lyceum Zeist"],
    ".student.codam.nl": ["Codam Coding College"],
    ".corderius.nl": ["corderius college"],
    ".corlaercollege.nl": ["Corlaer College"],
    ".csg-comenius.nl": ["comenius"],
    ".csgaugustinus.nl": ["CSG Augustinus"],
    ".csgdgw.nl": ["csg de goudse waarden", "https://www.degoudsewaarden.nl/"],
    ".curio.nl": ["Curio"],
    ".davinci-leiden.nl": ["SG Leonardo Da Vinci"],
    ".davinci.nl": ["ROC Da Vinci College"],
    ".student.dcterra.nl": ["DC terra"],
    ".ddu.nl": ["Dutch Delta University"],
    ".degoudsewaarden.nl": [
        "https://www.degoudsewaarden.nl/",
        "csg de goudse waarden",
    ],
    ".deltion.nl": ["Deltion College"],
    ".denassau.nl": ["De nassau", "The Nassau"],
    ".depassiescholen.nl": ["De Passie"],
    ".develsteincollege.nl": ["DevelsteinCollege"],
    ".dewillem.nl": ["CSG Willem van Oranje"],
    ".dominicuscollege.nl": ["Dominicus College"],
    ".drenthecollege.nl": ["Drenthe College"],
    ".driestarcollege.nl": ["Driestar College (docenten)"],
    ".driestarleerling.nl": ["Driestar College"],
    ".edu-kw1c.nl": ["Koning Willem 1 College"],
    ".elu.nl": ["European Leadership University"],
    ".emelwerda.nl": ["Emelwerda"],
    ".erasmuscollege.nl": ["Erasmus College"],
    ".erasmusmc.nl": ["\ufeffErasmus University Medical Center Rotterdam"],
    ".eshthehague.nl": ["Europese School Den Haag"],
    ".aics.espritscholen.nl": ["Amsterdam International Community School"],
    ".denise.espritscholen.nl": [
        "Denise Esprit School",
        "In the Netherlands, high school education is a lot similar to universities. ",
        "Here, the high school is for students that are more than 18 years old.",
        "Secondary school lasts until 18 years of age. ",
        "So, in fact, what Denise proposes as secondary school is higher education.",
        "https://denise.espritscholen.nl/en/home",
        "https://denise.espritscholen.nl/fileadmin/user_upload/FAQ_about_IB_%40_DENISE.pdf",
        '* this version is outdated, Denise now offers Mathematics HL (High Level) that includes the subject "Analitics and Approaches" *',
        "-",
    ],
    ".fclive.nl": ["Friesland College Regionaal Opleidingencentrum"],
    ".fcroc.nl": ["Friesland College"],
    ".fioretti.nl": ["Fioretti College Lisse"],
    ".student.firda.nl": ["Firda"],
    ".firda.nl": ["Firda", "Website: www.firda.nl"],
    ".fonsvitae.nl": ["Fons Vitae Lyceum"],
    ".fontys.nl": ["Fontys University of Applied Sciences"],
    ".gentiaancollege.nl": ["Gentiaancollege Apeldoorn"],
    ".gerritrietveldcollege.nl": ["Gerrit Rietveld College"],
    ".ghc.nl": ["Graaf Huyn College"],
    ".student.gildeopleidingen.nl": [
        "Gilde Opleidingen, Roermond",
        "http://www.gildeopleidingen.nl/",
        "http://www.gildeopleidingen.nl/opleidingen/416091-applicatieontwikkelaar/studierichting=ict",
        "https://sts.gildeopleidingen.nl/adfs/ls/?client-request-id=8f0cbc03-4a9b-4bb5-b3ba-871c7fee255b&username=&wa=wsignin1.0&wtrealm=urn%3afederation%3aMicrosoftOnline&wctx=estsredirect%3d2%26estsrequest%3drQIIAeNisFLJKCkpKLbS188vLcnJz8_Wy09Ly0xO1UvOz9XLL0rPTAGxopiBskVCXALMe3j6Z3tt9d68q12m_p1q9CxG6eKS0pTUvBK99MyclNT8gpzUzJTMvPTUPL28nFWM8rhN188vT9S_wMi4iYnd18kzPjjY5wTT5c_8t5gE_YvSPVPCi91SU1KLEksy8_MeMfGGFqcW-eflVIbkZ6fmTWLmy8lPz8yLLy5Ki0_LyS8HCgBNLEhMLokvyUzOTi3ZxaxiYJ5kYpqYZKSbmGKSomuSZmqka5FsYKlrapJilmyQlpqWZmB0gUXgBwvjIlagz06ZMc42tDPwnsNuMKN42emMU6z6iUllYR6FOempFU5Vxjk-ESYZnkk-3p6-Ud75Ya4GFtr6VT4p4cHeYf6-ybbmVoa7OH0I-Na-KDUxJ9cWT4iplaXYlqcm5SZm5gAA0",
    ],
    ".glr.nl": ["Grafisch Lyceum Rotterdam"],
    ".glu.nl": ["Grafisch Lyceum Utrecht"],
    ".gomaruscollege.nl": ["Gomarus College"],
    ".graafschapcollege.nl": ["Graafschap College"],
    ".greijdanus.nl": ["Greijdanus College"],
    ".gsr.nl": ["Gereformeerde Scholengemeenschap Randstad"],
    ".guido.nl": ["Guido"],
    ".gymnasiumarnhem.nl": ["Stedelijk Gymnasium Arnhem"],
    ".gymnasiumbeekvliet.nl": ["Gymnasium Beekvliet"],
    ".gymnasiumhilversum.nl": ["Gemeentelijk Gymnasium Hilversum", ".group"],
    ".gymnasiumleiden.nl": ["Stedelijk Gymnasium Leiden"],
    ".gymnasiumnovum.nl": ["Gymnasium Novum"],
    ".haarlemmermeerlyceum.nl": ["Haarlemmermeer Lyceum"],
    ".hageveld.nl": ["Atheneum College Hageveld"],
    ".han.nl": ["HAN University of Applied Sciences"],
    ".hanze.nl": ["Hanze University Groningen"],
    ".has.nl": ["HAS Hogeschool"],
    ".helicon.nl": ["Helicon Opleidingen"],
    ".hetbaarnschlyceum.nl": ["Het Baarnsch Lyceum"],
    ".student.hetbaken.nl": ["Het Baken Stad "],
    ".hethooghuis.nl": ["Het Hooghuis"],
    ".hetnieuwelyceum.nl": ["Het Nieuwe Lyceum"],
    ".hetstreek.nl": ["CGS Het Streek"],
    ".hetwesteraam.nl": ["Het Westeraam"],
    ".hhs.nl": ["The Hague University of Applied Sciences"],
    ".hku.nl": ["Hogeschool voor de Kunsten Utrecht (HKU)"],
    ".hlz.nl": ["hervormd lyceum zuid"],
    ".hoekschlyceum.nl": ["Hoeksch Lyceum"],
    ".hondsrugcollege.nl": ["Hondsrug College"],
    ".hoornbeeck.nl": ["Hoornbeeck College"],
    ".horizoncollege.nl": ["Horizon College"],
    ".hr.nl": ["Rotterdam University"],
    ".hro.nl": ["Hogeschool Rotterdam"],
    ".hsleiden.nl": ["University of Applied Sciences Leiden"],
    ".hsmarnix.nl": ["Marnix Academie"],
    ".hu.nl": ["Hogeschool Utrecht"],
    ".hva.nl": ["Hogeschool van Amsterdam"],
    ".hvhl.nl": ["Hogeschool van Hall Larenstein"],
    ".hyperionlyceum.nl": ["Hyperion Lyceum"],
    ".hz.nl": ["HZ University of Applied Sciences"],
    ".ichthuscollege.nl": ["Ichthus college"],
    ".leerling.ichthuskampen.nl": ["Ichthus College Kampen "],
    ".ichthuslyceum.nl": ["Ichtus Lyceum"],
    ".ictaa.nl": ["ICT Academie Apeldoorn"],
    ".ictmbo.nl": ["ROC Tilburg", "School voor ICT & Mediatechnologie"],
    ".idcollege.nl": ["ROC ID College"],
    ".ijburgcollege.nl": ["IJburg College"],
    ".inholland.nl": ["Hogeschool Inholland"],
    ".insulacollege.nl": ["Insula College"],
    ".edu.ishilversum.nl": [
        "International School Hilversum",
        "International School Hilversum",
    ],
    ".islamicuniversity.nl": ["Islamic University of Rotterdam"],
    ".iss.nl": ["Institute of Social Studies"],
    ".itc.nl": [
        "International Institute for Geo - Information Science and Earth Observation"
    ],
    ".jtc-roosendaal.nl": ["Jan Tinbergen College"],
    ".jvo.nl": ["Johan van Oldenbarnevelt"],
    ".student.kabk.nl": [
        "Koninklijke Academie van Beeldende Kunsten, Den Haag"
    ],
    ".kabk.nl": ["Koninklijke Academie van Beeldende Kunsten, Den Haag"],
    ".leerling.kajmunk.nl": ["Kaj Munk College"],
    ".kalsbeek.nl": [
        "Kalsbeek College, Woerden",
        "https://www.kalsbeek.nl/",
        "Slideshow containing contents of computer science/informatica program: http://slideplayer.nl/slide/2213402/",
    ],
    ".leerling.kandinskycollege.nl": ["Kandinsky College"],
    ".kennemerlyceum.nl": ["Kennemer Lyceum"],
    ".koncon.nl": [
        "Koninklijk Conservatorium Den Haag",
        "Royal Conservatoire The Hague",
    ],
    ".kw1c.nl": ["Koning Willem 1 College"],
    ".kwcollege.nl": ["Krimpenerwaard College"],
    ".landstede.nl": ["Regional Community College Landstede"],
    ".laurenslyceum.nl": ["Laurens Lyceum"],
    ".leeuwenborgh.nl": ["Leeuwenborgh"],
    ".leidenuniv.nl": ["University of Leiden"],
    ".leijgraaf.nl": ["ROC de Leijgraaf"],
    ".lekenlinge.nl": ["ORS Lek en Linge"],
    ".liacs.nl": ["Leiden Institute of Advanced Computer Science"],
    ".liemerscollege.nl": ["Liemers College"],
    ".lindecollege.nl": ["Linde College"],
    ".student.lmc-vo.nl": [
        "Stichting LMC Voortgezet Onderwijs",
        "Experience College",
        "Havo/vwo voor muziek en dans",
        "Het Lyceum Rotterdam  ",
        "Het Praktijkcollege Centrum",
        "Het Praktijkcollege Charlois",
        "Het Praktijkcollege Zuidwijk",
        "Horeca Vakschool Rotterdam ",
        "Lyceum Kralingen ",
        "MT010 - De Mavo voor Theater",
        "Mavo Centraal",
        "Montessori Mavo Rotterdam",
        "Montfort College",
        "PT010 - Theater en Dans",
        "Roncalli Mavo",
        "Rotterdam Designcollege",
        "Theaterhavo/vwo",
        "TooropMavo",
        "Vak College Hillegersberg",
        "Vak College Zuidrand",
        "Veenoord ",
        "Young Business School Rotterdam en afdeling Vrijeschool de Kaap",
        "Zuiderpark College ",
        ".group",
    ],
    ".loi.nl": ["Leidse onderwijsinstellingen"],
    ".lorentzlyceum.nl": ["Lorentz Lyceeum"],
    ".lumc.nl": ["Leiden University Medical Center"],
    ".luzac.nl": ["Luzac College en Luzac Lyceum"],
    ".lyceumelst.nl": ["Lyceeum Elst"],
    ".ma-web.nl": ["Mediacollege Amsterdam"],
    ".maartenvanrossem.nl": ["Maarten van Rossum"],
    ".maaslandcollege.nl": ["Maaslandcollege"],
    ".maastrichtuniversity.nl": ["Maastricht University"],
    ".markland.nl": ["Markland College"],
    ".martinuscollege.nl": ["Martinuscollege"],
    ".mboamersfoort.nl": ["MBO Amersfoort"],
    ".mborijnland.nl": ["Mborijnland"],
    ".mboutrecht.nl": ["Regional college of Utrecht"],
    ".mendelcollege.nl": ["Mendelcollege"],
    ".mijncarmelhengelo.nl": ["Scholengroep Carmel Hengelo"],
    ".mondia.nl": ["Nehalennia SSG"],
    ".mondriaanict.nl": ["ROC mondriaan School voor ICT"],
    ".montessoriarnhem.nl": ["Montessori Arnhem"],
    ".msa.nl": ["Montessori Lyceum Amsterdam"],
    ".mydavinci.nl": ["Da Vinci College"],
    ".myloketzwijndrecht.nl": ["Loket Zwijndrechtse Waard"],
    ".dr.nassaucollege.nl": ["Dr. Nassau College"],
    ".newman.nl": ["newmancollege", "newmancollege"],
    ".nhl.nl": ["NHL University"],
    ".nijenrode.nl": ["University of Nijenrode"],
    ".nikhef.nl": ["National Institute for Subatomic Physics"],
    ".nki.nl": ["Netherlands Cancer Institute"],
    ".noorderpoort.nl": ["ROC Noorderpoort"],
    ".noordgouw.nl": ["Christelijk College de Noordgouw"],
    ".novacollege.nl": ["Nova College"],
    ".novi-education.nl": [
        "Hogeschool NOVI b.v.",
        "University of Applied Science NOVI",
    ],
    ".novi-youngcapital.nl": [
        "Hogeschool NOVI b.v.",
        "University of Applied Science NOVI",
    ],
    ".nyenrode.nl": ["Nyenrode Business Universiteit"],
    ".ogvo.nl": [
        "Onderwijsgemeenschap Venlo en Omstreken",
        "* Valuascollege",
        "* College Den Hulster",
        "* Blariacumcollege",
    ],
    ".olympuscollege.nl": ["Olympus College"],
    ".olz.nl": ["Openbaar Lyceum Zeist", "Nuovo Scholengroep"],
    ".omosghelmond.nl": ["Carolus Borromeus College"],
    ".ooz.nl": ["Openbaar Onderwijs Zwolle", ".group"],
    ".os3.nl": [
        "University of Amsterdam ",
        "- Security and Network engineering",
    ],
    ".osgh.nl": ["Openbare Scholengemeenschap Hengelo"],
    ".osvs.nl": ["Openbare Scholengroep Vlaardingen Schiedam", ".group"],
    ".ou.nl": ["Open University of the Netherlands"],
    ".leerling.over-y.nl": ["Over-Y College"],
    ".ovofn.nl": [
        "Stichting openbaar voortgezet onderwijs Fryslân-Noord",
        ".group",
    ],
    ".pallasathenecollege.nl": ["Pallas Athene College"],
    ".live.pantarijn.nl": ["RSG Pantarijn"],
    ".leerling.parmantscholen.nl": ["Parmant Scholen"],
    ".leerling.pieterzandt.nl": ["Pieterzandt Scholengemeenschap"],
    ".piusx-college.nl": ["PiusX-College Bladel"],
    ".pleysier.nl": ["Pleysier College"],
    ".politieacademie.nl": ["Politieacademie"],
    ".pontes.nl": ["Pontes Scholengroep"],
    ".leerling.portamosana.nl": ["Porta Mosana College"],
    ".ll.porteum.nl": ["Porteum"],
    ".praedinius.nl": ["Praedinius Gymnasium"],
    ".produsarnhem.nl": ["Produs Arnhem"],
    ".psg.nl": ["Purmerendse Scholen Gemeenschap"],
    ".leerling.pvanhorne.nl": ["Philips van Horne Weert"],
    ".quadraam.nl": ["Stichting Quadraam"],
    ".radboudumc.nl": ["Radboud University Medical Center"],
    ".reggesteyn.nl": ["CSG Reggesteyn"],
    ".regiocollege.nl": ["Regio College Zaandam"],
    ".reviusdoorn.nl": ["Revius Lyceum"],
    ".rhedens.nl": ["Atheneum Het Rhedens Rozendaal"],
    ".rijnijssel.nl": ["ROC Rijn IJssel"],
    ".rijnlandslyceum-rlo.nl": ["Rijnlands Lyceum Oegstgeest"],
    ".roac.nl": ["Roosevelt Academy University College"],
    ".student.roc-nijmegen.nl": [
        "Students subdomain domain for Regional Community College of Nijmegen."
    ],
    ".roc-nijmegen.nl": ["Regional Community College of Nijmegen"],
    ".roc-teraa.nl": [
        "Roc Ter AA",
        "Teacher domain",
        "http://www.roc-teraa.nl/opleiding/applicatie-en-mediaontwikkelaar/",
    ],
    ".roca12.nl": ["ROC A12"],
    ".rocdeleijgraaf.nl": ["ROC De Leijgraaf", "Leijgraaf"],
    ".roceindhoven.nl": ["Regional Community College of Eindhoven"],
    ".edu.rocfriesepoort.nl": ["ROC Friese Poort"],
    ".rocfriesepoort.nl": ["ROC Friese Poort"],
    ".rocgilde.nl": ["Gildeopleidingen"],
    ".rockopnh.nl": ["ROC Kop van Noord Holland"],
    ".rocleiden.nl": ["Regional Community College of Leiden"],
    ".edu.rocmn.nl": ["Roc Midden Nederland"],
    ".rocmn.nl": ["Roc Midden Nederland"],
    ".rocmondriaan.nl": ["Regional Community College Mondriaan of The Hague"],
    ".rocnijmegen.nl": ["Regional Community College of Nijmegen"],
    ".edu.rocrivor.nl": ["ROC RIVOR"],
    ".rocteraa-student.nl": [
        "Roc Ter AA",
        "Student domain",
        "http://www.roc-teraa.nl/opleiding/applicatie-en-mediaontwikkelaar/",
    ],
    ".roctilburg.nl": ["ROC Tilburg", "School for ICT & Mediatechnology"],
    ".rocva.nl": ["ROC van Amsterdam"],
    ".rocvantwente.nl": ["Regional Community College of Twente"],
    ".rocvf.nl": ["ROC van Flevoland"],
    ".rocwb.nl": ["ROC West-Brabant"],
    ".rsg-sneek.nl": ["RSG Magister Alvinus"],
    ".rsgedu.nl": ["RSG Enkhuizen", "https://rsg-enkhuizen.nl/"],
    ".edu.rsgrijks.nl": ["rsgrijks"],
    ".rsm.nl": [
        "Rotterdam School of Management, Erasmus University Rotterdam"
    ],
    ".ru.nl": ["Radboud University of Nijmegen"],
    ".rug.nl": ["University of Groningen"],
    ".rythovius.nl": ["Rythovius College"],
    ".sandberg.nl": ["Sandberg Instituut"],
    ".student.saxion.nl": ["Saxion University of Applied Sciences"],
    ".saxion.nl": ["Saxion University of Applied Sciences"],
    ".scalda.nl": ["Scalda Netherlands"],
    ".ll.scholenaanzee.nl": ["Scholen aan Zee"],
    ".student.segbroek.nl": ["Segbroek College"],
    ".sgtedu.nl": ["SG Tongerlo"],
    ".simonvestdijk.nl": ["RSG Simon Vestdijk"],
    ".sintlucas.nl": ["SintLucas"],
    ".sintlucasedu.nl": ["SintLucas"],
    ".sondervick.nl": ["Sondervick College"],
    ".spinozalyceum.nl": ["Spinoza Lyceum"],
    ".leerling.stadenesch.nl": ["Stad & Esch"],
    ".stedelijkgymnijmegen.nl": ["Stedelijk Gymnasium Nijmegen"],
    ".stenden.nl": [
        "NHL Stenden Hogeschool, Leeuwarden",
        "NHL Stenden University of Applied Sciences",
    ],
    ".stgs.nl": ["Stedelijk Gymnasium Schiedam"],
    ".summacollege.nl": ["Regional Community College of Eindhoven"],
    ".ut.svpo.nl": ["School voor Persoonlijk Onderwijs in Utrecht"],
    ".symbion-vo.nl": ["Symbion VO"],
    ".talland.nl": ["Talland College"],
    ".talnet.nl": ["MBO Hilversum"],
    ".tcrmbo.nl": ["Techniek College Rotterdam"],
    ".teylingen-college.nl": [
        "Teylingen College Noordwijkerhout/Voorhout/Rijnsburg"
    ],
    ".student.theresialyceum.nl": ["Theresialyceum"],
    ".tilburguniversity.nl": ["Tilburg University"],
    ".tio.nl": ["TIO University"],
    ".leerling.trevianum.nl": ["Trevianum Scholengroep"],
    ".tsgzwolle.nl": [
        "Thorbecke Scholengemeenschap",
        "http://heesweg.thorbecke-zwolle.nl/ (School website)",
        "http://liters.nl/dev/webfundament/tsgheesweg/wp-content/uploads/sites/5/2015/12/Nieuwe-keuzevakken-in-de-Tweede-Fase-feb-12I.pdf (IT-related page: Page 4)",
        "https://gyazo.com/020bc662241ab9c9c0e1b2abfdeda82c (Screenshot proving the used email is correct: on the bottom of http://heesweg.thorbecke-zwolle.nl/)",
    ],
    ".tudelft.nl": ["Delft University of Technology"],
    ".tue.nl": ["Eindhoven University of Technology"],
    ".tukampen.nl": ["TU Kampen"],
    ".umcutrecht.nl": ["University Medical Center Utrecht"],
    ".unimaas.nl": ["University of Maastricht"],
    ".usgym.nl": [
        "Utrechts Stedelijk Gymnasium",
        "Utrecht Municipal Gymnasium",
    ],
    ".utwente.nl": ["University of Twente"],
    ".uu.nl": ["Utrecht University"],
    ".uva.nl": ["University of Amsterdam"],
    ".uvh.nl": ["University for Humanistics (UH)"],
    ".uvt.nl": ["Tilburg University"],
    ".uwcmaastricht.nl": ["United World College Maastricht"],
    ".vathorstcollege.nl": ["Vathorst College"],
    ".leerling.veluwscollege.nl": [
        "Veluws College Walterbosch",
        "Veluws College Walterbosch",
    ],
    ".vestdijk.nl": ["RSG Simon Vestdijk"],
    ".vistacollege.nl": ["VISTA College"],
    ".vituscollege.nl": ["Vituscollege"],
    ".vmbo-venster.nl": ["VMBO Het Venster"],
    ".student.vonknh.nl": ["Vonk"],
    ".leerling.vova.nl": ["Voortgezet Onderwijs van Amsterdam"],
    ".vozaanstad.nl": ["OVO Zaanstad"],
    ".vu.nl": ["Free University Amsterdam"],
    ".vumc.nl": ["VU University Medical Center Amsterdam"],
    ".waerdenborch.nl": ["De Waerdenborch Holten"],
    ".wageningenuniversity.nl": ["Wageningen University"],
    ".wartburg.nl": ["Wartburg College"],
    ".windesheim.nl": ["Christelijke Hogeschool Windesheim"],
    ".windesheimflevoland.nl": ["Windesheim Flevoland"],
    ".wlg.nl": ["Willem Lodewijk Gymnasium"],
    ".wolfert.nl": ["Wolfert van Borselen Scholengroep"],
    ".wur.nl": ["Wageningen University"],
    ".youscope.nl": ["CSG Groene Hart"],
    ".zadkine.nl": ["Zadkine College"],
    ".zuyd.nl": ["Zuyd University"],
    ".zwijsencollege.nl": ["Zwijsen College Veghel"],
    ".afk.no": [
        "Akershus Fylkeskommune schools https://afk.no/tjenester/skole-og-opplaring/"
    ],
    ".agderskolen.agderskolen.no": ["Agderskolen", "Agder School"],
    ".elev.agderskolen.no": ["Aust Agder Fylkeskommune"],
    ".agderskolen.no": ["Agder Fylkeskommune"],
    ".aho.no": ["Oslo School of Architecture"],
    ".akademiet.no": ["Akademiet"],
    ".akershus-fk.no": ["Akershus' schools"],
    ".arendalsskolen.no": ["Arendal skole"],
    ".askerskolen.no": ["Asker Kommune"],
    ".asvg.no": ["Amalie skram vgs", "asvg.no"],
    ".bergensskolen.no": ["Åstveit skole", "Bergen kommune"],
    ".vgs.bfk.no": ["Buskerud Fylkeskommune"],
    ".bfk.no": ["Kongsberg Videregående Skole"],
    ".bi.no": ["Norwegian School of Management BI"],
    ".voss.fhs.no": ["Voss Folkehøgskule"],
    ".fs-innlandet.no": ["Fagskolen Innlandet"],
    ".getacademy.no": ["Get Academy"],
    ".gokstadakademiet.no": ["Gokstadakademiet"],
    ".hbv.no": ["Buskerud and Vestfold University College"],
    ".hia.no": ["Agder University College"],
    ".hials.no": ["Aalesund University College"],
    ".hib.no": ["Bergen University College"],
    ".hibo.no": ["Bodo Regional University"],
    ".hifm.no": ["Finnmark University College"],
    ".hig.no": ["Gjøvik University College"],
    ".hihm.no": [
        "Inland Norway University of Applied Sciences",
        "Høgskolen i Innlandet",
        "https://www.inn.no/",
    ],
    ".hil.no": [
        "Inland Norway University of Applied Sciences",
        "Høgskolen i Innlandet",
        "https://www.inn.no/",
    ],
    ".himolde.no": ["Molde University College"],
    ".hin.no": ["Narvik University College"],
    ".hint.no": ["Nord-Trøndelag University College"],
    ".stud.hioa.no": [
        "Oslo and Akershus University College of Applied Sciences"
    ],
    ".hioa.no": ["Høgskolen i Oslo og Akershus"],
    ".hiof.no": ["Østfold University College"],
    ".hist.no": ["Sør-Trøndelag University College"],
    ".hit.no": ["Telemark University College"],
    ".hive.no": ["Vestfold University College"],
    ".hivolda.no": ["Volda University College"],
    ".hvl.no": ["Western Norway University of Applied Sciences"],
    ".ikrs.no": [
        "Public schools in Kristiansand County, including: ",
        "Holte skole",
        "Tangen Videregående skole",
        "Kristiansand Katedralskole Gimle (KKG)",
        "Oddemarka skole",
        "Lovisenlund skole",
    ],
    ".inn.no": [
        "Inland Norway University of Applied Sciences",
        "Høgskolen i Innlandet",
        "https://www.inn.no/",
    ],
    ".innlandetfylke.no": ["Hamar Katedralskole", "Hamar Cathedral School"],
    ".iskule.no": ["Sogndal VGS"],
    ".karmoyskolen.no": ["Karmøy Kommune Skoledomene"],
    ".khio.no": [
        "National Academy of Fine Arts",
        "National College of Art and Design",
    ],
    ".skole.trondheim.kommune.no": ["Trondheim Kommune - Skole"],
    ".kristiania.no": [
        "Kristiania University College, the department of technology"
    ],
    ".larvikskolen.no": ["Langestrand Skole"],
    ".sksk.mil.no": ["Royal Norwegian Naval Academy", "Sjøkrigsskolen"],
    ".mrfylke.no": ["Romsdal videregående skole", "Romsdal high school"],
    ".vgs.nfk.no": ["Nordland Fylkeskommune"],
    ".nhh.no": ["Norwegian School of Economics and Business Administration"],
    ".nih.no": ["Norwegian University of Sport and Physical Education"],
    ".nith.no": ["Norway's Information Technology University College"],
    ".nittedalsskolen.no": ["Li Skole"],
    ".nla.no": [
        "Norwegian Teacher Academy for Studies in Religion and Education"
    ],
    ".nlh.no": ["Agricultural University of Norway"],
    ".nmbu.no": ["Norwegian University of Life Sciences"],
    ".nmh.no": ["Norwegian State Academy of Music"],
    ".nord.no": ["Nord University"],
    ".noroff.no": ["Noroff AS", "Noroff AS"],
    ".elev.ntfk.no": ["Verdal Videregående Skole"],
    ".ntnu.no": ["Norwegian University of Science and Technology"],
    ".oslomet.no": ["OsloMet – Oslo Metropolitan University"],
    ".osloskolen.no": ["Osloskolen"],
    ".ostfoldfk.no": [
        "Østfold Fylkeskommune schools. https://utdanning.ostfoldfk.no/ikbViewer/page/open/forsiden"
    ],
    ".ous-hf.no": ["Oslo universitetssykehus", "Oslo University Hospital"],
    ".oygardenskule.no": ["Fjell Ungdomskule"],
    ".elev.rogfk.no": [
        "Rogaland Fylkeskommune",
        "Rogaland County Municipality",
    ],
    ".skole.rogfk.no": [
        "Rogaland Fylkeskommune",
        "Rogaland County Municipality",
    ],
    ".skule.sfj.no": ["sogn og fjordane"],
    ".simula.no": ["Simula School of Research and Innovation"],
    ".skapfhs.no": ["\ufeffSKAP Kreativ Folkehøyskole"],
    ".sunnfolk.no": ["Sunnhordland Folkehøgskule"],
    ".elev.tffk.no": [
        "Nord-Troms Videregående Skole",
        "Nord-Troms High School",
        "\ufeffAlta Videregående Skole",
    ],
    ".tffk.no": [
        "Stangnes videregående skole, school district of Troms og Finnmark"
    ],
    ".tisipfagskole.no": ["TISIP fagskole"],
    ".tromsfylke.no": [
        "Nord-Troms Videregående Skole",
        "Nord-Troms High School",
    ],
    ".elev.trondelagfylke.no": ["Trondelag Fylkeskommune"],
    ".trondelagfylke.no": ["\ufeffTrøndelag Fylkeskommune"],
    ".tysverelev.no": [
        "Frakkagjerd Ungdomsskole",
        "Frakkagjerd Secondary School",
    ],
    ".uia.no": ["University of Agder"],
    ".uib.no": ["University of Bergen"],
    ".uin.no": ["University of Nordland"],
    ".uio.no": ["University of Oslo"],
    ".uis.no": ["University of Stavanger"],
    ".uit.no": ["University of Tromsø"],
    ".usn.no": [
        "Høgskolen i Sørøst-Norge / University College of Southeast Norway"
    ],
    ".vaf.no": ["Vest-Agder fylkeskommune "],
    ".veths.no": ["Norwegian College of Veterinary Medicine"],
    ".skole.vfk.no": ["Vestfold Fylkeskommune"],
    ".Asker.vgs.no": ["Asker Videregående Skole"],
    ".Verdal.vgs.no": ["Verdal Videregående Skole"],
    ".eid.vgs.no": ["Eid Videregående Skule"],
    ".krokeide.vgs.no": ["Krokeide videregående skole"],
    ".kvadraturen.vgs.no": [
        "Kvadraturen vgs",
        "Kvadraturen technical college",
    ],
    ".sameyde.vgs.no": ["Sam Eyde Vidregående Skole"],
    ".tangen.vgs.no": ["Tangen Videregående Skole"],
    ".viken.no": [
        "Viken Fylkeskommune schools. https://viken.no/tjenester/skole-og-opplaring/"
    ],
    ".vtfk.no": ["Vestfold og Telemark Fylkeskommune"],
    ".student.westerdals.no": [
        "Westerdals Oslo School of Arts, Communication and Technology"
    ],
    ".westerdals.no": [
        "Westerdals Høyskole - Oslo School of Arts, Communication and Technology AS"
    ],
    ".aadimcollege.edu.np": [
        "Aadim National College",
        "Aadim National College",
    ],
    ".aasthacollege.edu.np": [
        "Aastha College Of Business Studies,Damak-4, Jhapa, Nepal",
        "https://www.aasthacollege.edu.np",
    ],
    ".academiacollege.edu.np": [
        "Academia International College",
        "Academia International College, Nepal",
        "https://academiacollege.edu.np/",
    ],
    ".acem.edu.np": [
        "Advanced College of Engineering and Management",
        "Advanced College of Engineering and Management",
    ],
    ".achsnepal.edu.np": ["Asian College of Higher Studies"],
    ".acme.edu.np": ["Acme Engineering College"],
    ".acmecollege.edu.np": ["Acme College of Engineering"],
    ".adhyayan.edu.np": ["Adhyayan School"],
    ".ambition.edu.np": ["Ambition College", "Ambition College"],
    ".ankuram.edu.np": [
        "Ankuram Academy",
        "Bharatpur 7 Chitwan , Terashal Chowk , Nepal",
    ],
    ".apexcollege.edu.np": ["Apex College"],
    ".arniko.edu.np": ["Arniko International College"],
    ".asm.edu.np": ["Asian School of Management and Technology"],
    ".asmt.edu.np": ["Asian School of Management and Technology, Nepal"],
    ".axisschool.edu.np": ["Axis Vidyashram", "https://axisschool.edu.np"],
    ".balbikas.edu.np": ["Bal Bikas School of Science and Management"],
    ".balkumaricollege.edu.np": ["Balkumari College, Chitwan, Nepal"],
    ".baneshworcampus.edu.np": ["Baneshwor Campus"],
    ".banshagopal.edu.np": ["Banshagopal Secondary School (Technical School)"],
    ".bhagawatischool.edu.np": ["Shree Bhagawati Secondary School"],
    ".bicnepal.edu.np": ["Biratnagar International College, Nepal"],
    ".bkvm.edu.np": [
        "Bal Kalyan Vidhya Mandir School",
        "Bal Kalyan Vidhya Mandir School",
    ],
    ".bmcdharan.edu.np": ["Birendra Memorial College"],
    ".cab.edu.np": ["College of Applied Business and Technology"],
    ".cdcsit.edu.np": [
        "Central Department of Computer Science and Information Technology"
    ],
    ".cdmathtu.edu.np": [
        "Central Department of Mathematics Institute of Science & Technology Tribhuvan University",
        "CDMATHTU",
    ],
    ".chitwancollege.edu.np": ["Chitwan College of Technology"],
    ".cit.edu.np": [
        "College of Information Technology and Engineering",
        "Subidhanagar, Tinkune, Kathmandu, Nepal",
    ],
    ".cosmoscollege.edu.np": [
        "Cosmos College Of Management & Technology",
        "Cosmos College Of Management & Technology",
    ],
    ".deerwalk.edu.np": [
        "Deerwalk Institute of Technology",
        "P87V+22R, Jaya Bageshwori Road, Kathmandu 44600, Nepal",
        "https://deerwalk.edu.np/",
    ],
    ".divyagyan.edu.np": [
        "Divya Gyan College",
        "https://www.divyagyan.edu.np",
    ],
    ".eastpoleschool.edu.np": ["East-Pole School"],
    ".eemc.edu.np": [
        "Everest Engineering College",
        "Everest Engineering College",
        "(formerly recognized as Everest Engineering and Management College, EEMC)",
        "(https://www.eemc.edu.np)",
        "(https://www.eemc.edu.np/be-it-information-technology)",
        "(contact url: https://www.eemc.edu.np/contact)",
    ],
    ".emileacademy.edu.np": [
        "Emile Academy International",
        "Emile Academy International",
    ],
    ".excelsior.edu.np": ["Excelsior School", "Excelsior School"],
    ".gaushalamultiplecampus.edu.np": ["Gaushala Multiple Campus"],
    ".gces.edu.np": [
        "Gandaki College of Engineering and Science, Nepal",
        "GCES, Pokhara, Nepal",
    ],
    ".gci.edu.np": ["Global collage international"],
    ".gems.edu.np": ["Gems School"],
    ".gihe.edu.np": ["Gems School, Nepal"],
    ".globalacademy.edu.np": [
        "Global Academy Secondary School",
        "Global Academy Secondary School",
    ],
    ".gmmc.edu.np": ["Gupteshwor Mahadev Multiple Campus"],
    ".goldengate.edu.np": ["Goldengate Int'l College"],
    ".gomendracollege.edu.np": ["Gomendra Multiple College"],
    ".gpkmc.edu.np": [
        "G. P. Koirala Memorial (Community) College",
        "G. P. Koirala Memorial (Community) College",
    ],
    ".hcoe.edu.np": ["Himalaya College of Engineering"],
    ".heraldcollege.edu.np": [
        "HERALD COLLEGE KATHMANDU, UNIVERSITY OF WOLVERHAMPTON",
        "HERALD COLLEGE KATHMANDU, UNIVERSITY OF WOLVERHAMPTON",
    ],
    ".heraldintlcollege.edu.np": [
        "Herald International College",
        "contact@heraldintlcollege.edu.np",
    ],
    ".hetaudacitycollege.edu.np": ["Hetauda City College"],
    ".himalayacollege.edu.np": [
        "Himalaya Darshan College, Nepal",
        "Tribhuvan University",
        "https://himalayacollege.edu.np/",
    ],
    ".hist.edu.np": ["Himalayan Institute of Science and Technology"],
    ".hsm.edu.np": ["Hetauda School of Management and Social Sciences"],
    ".s.ica.edu.np": [
        "International Center for Academics",
        "International Center for Academics",
    ],
    ".icp.edu.np": [
        "Informatics College Pokhara, Nepal",
        "Informatics College Pokhara, Nepal",
    ],
    ".iic.edu.np": ["Itahari International College"],
    ".iimscollege.edu.np": ["Institute OF International Management Science"],
    ".ims.edu.np": ["IMS COLLEGE,Thapathali,Kathmandu"],
    ".indrenicollege.edu.np": ["Indreni College"],
    ".infomaxcollege.edu.np": ["Infomax College of IT & Management"],
    ".ioe.edu.np": ["IOE Pulchowk Campus", "Institute of Engineering, Nepal"],
    ".ioepc.edu.np": [
        "Purwanchal Campus, Institute of Engineering, Tribhuvan University",
        "Eastern Region Campus, Institute of Engineering, Tribhuvan University",
    ],
    ".islingtoncollege.edu.np": [
        "Islington College, Kamal Marg, Kamal Pokhari, Kathmandu, Nepal"
    ],
    ".ismt.edu.np": [
        "International School of Management and Technology (ISMT)"
    ],
    ".ith.edu.np": ["Impact Tech School"],
    ".jamc.edu.np": ["Jana Adarsha Multiple Campus"],
    ".janamaitri.edu.np": [
        "Janamaitri Multiple Campus",
        "Janamaitri Multiple Campus",
    ],
    ".janapriya.edu.np": ["Janapriya Multiple Campus"],
    ".kaasthamandap.edu.np": ["Kaasthamandap Vidhyalaya"],
    ".kamalamultiplecampus.edu.np": [
        "kamala multiple campus",
        "kamala multiple campus",
    ],
    ".kathford.edu.np": [
        "Kathford International College of Engineering and Management"
    ],
    ".kathmandumodelschool.edu.np": ["Kathmandu Model School"],
    ".kbc.edu.np": ["Kathmandu Bernhardt College"],
    ".kcc.edu.np": ["Kantipur City College"],
    ".kcm.edu.np": ["Kathmandu College of Management"],
    ".kcmit.edu.np": [
        "Kantipur College of Management and Information Technology"
    ],
    ".kct.edu.np": [
        "Kathmandu college of technology",
        "Kathmandu college of technology",
    ],
    ".kdbc.edu.np": ["Kathmandu Don Bosco College"],
    ".kec.edu.np": ["Kantipur Engineering College"],
    ".keckist.edu.np": ["Kathmandu Engineering College"],
    ".kecktm.edu.np": ["Kathmandu Engineering College, Kalimati Kathmandu"],
    ".khec.edu.np": ["Khwopa Engineering College"],
    ".khwopa.edu.np": [
        "Khwopa College of Engineering",
        "Khwopa College of Engineering",
    ],
    ".kisc.edu.np": ["Kathmandu International Study Centre"],
    ".kiscstudents.edu.np": ["Kathmandu International Study Centre"],
    ".kist.edu.np": ["KIST College & SS"],
    ".kistcollege.edu.np": ["Kist College"],
    ".kmcen.edu.np": ["Kathmandu Model College"],
    ".ku.edu.np": ["Kathmandu University"],
    ".kusoed.edu.np": ["Kathmandu University School of Education"],
    ".kusom.edu.np": ["KUSOM"],
    ".lagrandee.edu.np": ["LA GRANDEE International College"],
    ".lbc.edu.np": ["Lumbini Banijya Campus", "Lumbini Banijya Campus"],
    ".study.lbef.edu.np": ["Lord Buddha Education Foundation", "LBEF"],
    ".lcc.edu.np": ["Lumbini City College", "Lumbini City College"],
    ".lfes.edu.np": ["LITTLE FLOWERS' ENGLISH SCHOOL"],
    ".licnepal.edu.np": ["Lincoln International College"],
    ".lict.edu.np": ["Lumbini ICT Campus"],
    ".littleangelsrapti.edu.np": ["Little Angels School Rapti"],
    ".lumbini.edu.np": [
        "Lumbini engineering college",
        "Lumbini Engineering college",
    ],
    ".macpokhara.edu.np": ["Mount Annapurna Campus"],
    ".mahakavi.edu.np": ["Mahakavi Devkota Memorial Secondary School"],
    ".mbman.edu.np": [
        "Madan Bhandari Memorial Academy Nepal",
        "Madan Bhandari Memorial Academy Nepal",
    ],
    ".mbmc.edu.np": ["Madan Bhandari Memorial College"],
    ".mbmcsit.edu.np": ["Madan Bhandari Memorial College CSIT Department"],
    ".medhavicollege.edu.np": ["Medhavi College"],
    ".merocodingclass.edu.np": [
        "mero coding class",
        "https://merocodingclass.edu.np/",
    ],
    ".mkw.edu.np": ["Kathmandu University"],
    ".mmp.edu.np": ["Manmohan Memorial Polytechnic"],
    ".nagarjunacollege.edu.np": [
        "Nagarjuna college of Information Technology",
        "Shankhamul",
        "https://nagarjunacollege.edu.np/",
    ],
    ".nami.edu.np": ["Naaya Aayam Multi-Disciplinary Institute"],
    ".namunacollege.edu.np": ["Itahari Namuna College"],
    ".nast.edu.np": [
        "National Academy of Science and Technology",
        "Nast College",
    ],
    ".nationalinfotechcollege.edu.np": [
        "National Infotech College",
        "National Infotech College, Birgunj Nepal",
        "https://nationalinfotechcollege.edu.np/",
    ],
    ".nce.edu.np": ["NATIONAL COLLEGE OF ENGINEERING"],
    ".ncit.edu.np": [
        "Nepal College of Information Technology",
        "Nepal College of Information Technology",
    ],
    ".ncmt.edu.np": ["National College of Management and Technical Science"],
    ".nec.edu.np": ["Nepal engineering college"],
    ".nepalaya.edu.np": ["Nepalaya College", "Nepalaya College"],
    ".nepathyacollege.edu.np": ["Nepathya college"],
    ".newsummit.edu.np": ["NEW SUMMIT College"],
    ".nihareekacollege.edu.np": [
        "Nihareeka College of Science and technolgy",
        "Biratnagar, Morang 56613, Nepal",
        "http://nihareekacollege.edu.np/",
    ],
    ".nistbanepa.edu.np": [
        "Nist Banepa Secondary School",
        "https://nistbanepa.edu.np/",
    ],
    ".nistcollege.edu.np": [
        "Nist College, Tribhuban University",
        "https://nistcollege.edu.np/",
    ],
    ".nsu.edu.np": ["Nepal Sanskrit University"],
    ".oic.edu.np": ["Orchid International College, Kathmandu, Nepal"],
    ".padmashreecollege.edu.np": ["Padmashree College"],
    ".paramountpublicschool.edu.np": [
        "Paramount Public School",
        "Paramount Public School",
    ],
    ".pascalcollege.edu.np": ["Pascal National College"],
    ".patancollege.edu.np": ["Patan College for Professional Studies"],
    ".pcampus.edu.np": [
        "Tribhuvan University, Institute of Engineering, Pulchowk Campus"
    ],
    ".pcmgmt.edu.np": [
        "फिनिक्स कलेज अफ म्यानेजमेन्ट",
        "Phoenix College of Management",
    ],
    ".pec.edu.np": ["Pokhara engineering college"],
    ".peoplescampus.edu.np": ["Peoples Campus", "Peoples Campus"],
    ".pmc.edu.np": [
        "Tribhuvan University, Institute of Science and Technology, Patan Multiple Campus"
    ],
    ".premier.edu.np": ["Premier International IB Continuum School"],
    ".prime.edu.np": [
        "Prime College, Affiliated to Tribhuvan University, Khusibun, Nayabazar, Kathmandu, Nepal"
    ],
    ".pu.edu.np": ["Pokhara University"],
    ".pufost.edu.np": [
        "Purbanchal University Faculty of Science and Technology"
    ],
    ".purbuniv.edu.np": ["Purbanchal University"],
    ".pusat.edu.np": [
        "पूर्वाञ्चल युनिभर्सिटी स्कूल अफ साइन्स एन्ड टेक्नोलोजी",
        "Purbanchal University School of Science and Technology",
    ],
    ".pushas.edu.np": [
        "School of Health and Allied Sciences",
        "School of Health and Allied Sciences",
    ],
    ".pusob.edu.np": ["Pokhara University , School of Business"],
    ".radiantcollege.edu.np": ["रेडियन्ट कलेज", "Radiant College"],
    ".sagarmatha.edu.np": ["Sagarmatha Engineering College"],
    ".saipal.edu.np": ["Saipal Academy"],
    ".samriddhicollege.edu.np": ["Samriddhi college"],
    ".scst.edu.np": [
        "Sagarmatha College of Science and Technology",
        "Sagarmatha College of Science and Technology",
    ],
    ".shahidcampus.edu.np": ["Shahid Multiple Campus"],
    ".shivajanschool.edu.np": [
        "शिबजन उच्च माध्यामिक विध्यालय, नेपाल",
        "Shivajan Higher Secondary School, Nepal",
    ],
    ".sitarameshcampus.edu.np": [
        "Sita Ramesh Multiple Campus",
        "Sita Ramesh Multiple Campus",
    ],
    ".sochcollege.edu.np": ["Soch College of IT", "Soch College of IT"],
    ".softwarica.edu.np": [
        "Softwarica College of IT and E-Commerce, Maitri Marg, Dillibazar, Kathmandu"
    ],
    ".sos.edu.np": ["School of Scholars"],
    ".southwestern.edu.np": [
        "Southwestern State College",
        "Southwestern State College",
    ],
    ".spa.edu.np": ["Sudur Paschimanchal Campus"],
    ".sparkcollege.edu.np": [
        "Spark College Of Bussiness and Technology, Nepal"
    ],
    ".spictevt.edu.np": ["Shankharapur Polytechnic Institute"],
    ".ssha.edu.np": [
        "Smile Small Heaven Academy",
        "Smile Small Heaven Academy",
    ],
    ".standardinstitute.edu.np": ["Standard Institute of Technology"],
    ".stlawrence.edu.np": ["St. Lawrence College"],
    ".stunning.edu.np": [
        "Stunning Higher Secondary English Boarding School And It College",
        "https://stunning.edu.np",
    ],
    ".sungavacollege.edu.np": ["Sungava College"],
    ".sunway.edu.np": [
        "Sunway International Business School, Kathmandu",
        "Sunway College, Kathmandu",
    ],
    ".swastikcollege.edu.np": ["Swastik College"],
    ".swetasadanschool.edu.np": ["Sweta Sadan English Boarding School"],
    ".sxc.edu.np": ["St. Xavier's College"],
    ".tbc.edu.np": [
        "The British College",
        "The British College, Trade Tower, Thapathali Road, Kathmandu ",
    ],
    ".tcioe.edu.np": ["Institute of Engineering, Thapathali Campus"],
    ".tcmit.edu.np": ["Texas College of Management and IT", "tcmit"],
    ".texascollege.edu.np": ["Texas College of Management & IT"],
    ".texasintl.edu.np": ["Texas International College"],
    ".thamescollege.edu.np": ["Thames International College Pvt. Ltd."],
    ".thearyanschool.edu.np": [
        "Aryan school of engineering and management",
        "Devkota Sadak,Mid Baneshwor, Kathmandu, Nepal",
    ],
    ".tribhuvan-university.edu.np": ["Tribhuvan University Kathmandu"],
    ".trinity.edu.np": [
        "Trinity International College",
        "Trinity Internation College",
    ],
    ".triton.edu.np": ["Triton International College"],
    ".ac.tu.edu.np": ["Amrit Campus", "Amrit Science Campus (ASCOL), Nepal"],
    ".bimc.tu.edu.np": ["Birendra Multiple Campus"],
    ".bumc.tu.edu.np": ["Butwal Multiple Campus"],
    ".cct.tu.edu.np": [
        "central campus of technology (Tribhuvan university)",
        "central campus of technology (constituent college of Tribhuvan university)",
    ],
    ".cdcsit.tu.edu.np": [
        "CDCSIT",
        "Central Department of Computer Science & Information Technology",
    ],
    ".mahemc.tu.edu.np": ["Mahendra Multiple Campus Nepalgunj"],
    ".memc.tu.edu.np": ["Mechi Multiple Campus TU Nepal"],
    ".mmamc.tu.edu.np": ["Mahendra Morang Adarsh Multiple Campus, Nepal"],
    ".ncc.tu.edu.np": ["Nepal Commerce Campus"],
    ".pkmc.tu.edu.np": ["Padma Kanya Multiple Campus, Bagbazaar"],
    ".pmc.tu.edu.np": ["पाटन संयुक्त क्याम्पस", "Patan Multiple Campus, Lalitpur"],
    ".prnc.tu.edu.np": ["Prithivi narayan campus"],
    ".sdc.tu.edu.np": [
        "Shanker Dev Campus, Putalisadak Kathmandu",
        "Tribhuvan University",
        "https://www.shankerdevcampus.edu.np/",
    ],
    ".som.tu.edu.np": ["School Of Management"],
    ".trc.tu.edu.np": ["Tri-Chandra Multiple Campus"],
    ".tu.edu.np": [
        "Tribhuvan University",
        "Tribhuvan University and colleges affiliated with it.",
    ],
    ".tuicms.edu.np": ["Institute of Crisis Management Studies"],
    ".uesc.edu.np": ["Universal Engineering And Science College"],
    ".unitedtechnicalcollege.edu.np": [
        "United Technical College, Pokhara University, Nepal"
    ],
    ".vac.edu.np": ["Vishwa Adarsha Academy", "Vishwa Adarsha Academy"],
    ".valmiki.edu.np": ["Valmiki Shiksha Sadan"],
    ".vedascollege.edu.np": ["Vedas College"],
    ".virinchicollege.edu.np": ["Virinchi College"],
    ".wrc.edu.np": [
        "Tribhuvan University, Institute of Engineering, Pashchimanchal Campus",
        "Tribhuvan University, Institute of Engineering, Western Regional Campus (WRC)",
    ],
    ".xavier.edu.np": [
        "Xavier International College, Kalopul, Kathmandu, Nepal",
        "Xavier International College, Kalopul, Kathmandu, Nepal",
    ],
    ".rbg.nrw": ["Rudolph-Brandes-Gymnasium"],
    ".schueler.tsst.nrw": [
        "Technische Schule Steinfurt (tsst)",
        "Technical Schools Steinfurt (tsst)",
    ],
    ".adelfors.nu": ["Ädelfors Folkhögskola"],
    ".aug.nu": ["Augustinianum"],
    ".edu.nu": ["St Clements University - Higher Education School"],
    ".folkuniversitetet.nu": ["Folkuniversitetet"],
    ".futuregames.nu": ["Futuregames"],
    ".lme.nu": ["LM Engströms Gymnasium"],
    ".reggesteyn.nu": ["CSG Reggesteyn"],
    ".edu.tibble.nu": ["Tibble Gymnasium, students emails"],
    ".tibble.nu": ["Tibble Gymnasium"],
    ".valla.nu": ["Valla Folkhögskola"],
    ".adultliteracy.ac.nz": ["Rural Youth and Adult Literacy Trust"],
    ".agi.ac.nz": ["AGI", "AGI Auckland"],
    ".ais.ac.nz": [
        "Auckland Institute of Studies",
        "Auckland Institute of Studies",
    ],
    ".ames.ac.nz": ["AMES "],
    ".amesstudent.ac.nz": ["AMES  - The Institute of IT"],
    ".ara.ac.nz": ["Ara Institute of Canterbury"],
    ".arastudent.ac.nz": ["Ara Institute of Canterbury"],
    ".aspire2student.ac.nz": ["Aspire"],
    ".ec.auckland.ac.nz": ["University of Auckland - Electronic Campus"],
    ".auckland.ac.nz": ["University of Auckland"],
    ".aucklanduni.ac.nz": ["University of Auckland"],
    ".aut.ac.nz": ["Auckland University of Technology"],
    ".autuni.ac.nz": ["Auckland University of Technology"],
    ".canterbury.ac.nz": ["University of Canterbury"],
    ".mail.computerpower.ac.nz": ["Whitecliffe Technology And Innovation"],
    ".developers.ac.nz": ["Developers Institute"],
    ".developersinstitute.ac.nz": ["Developers Institute"],
    ".eit.ac.nz": ["Eastern Institute of Technology"],
    ".garincollege.ac.nz": ["Garin College"],
    ".kiwi.ac.nz": ["Kiwi College of New Zealand"],
    ".lincoln.ac.nz": ["Lincoln University"],
    ".lincolnuni.ac.nz": ["Lincoln University"],
    ".massey.ac.nz": ["Massey University"],
    ".mds.ac.nz": ["Media Design School"],
    ".myop.ac.nz": ["Open Polytechnic"],
    ".myopenpolytechnic.ac.nz": ["Open Polytechnic of New Zealand"],
    ".myunitec.ac.nz": ["Unitec Institute of Technology"],
    ".myvuw.ac.nz": ["Victoria University of Wellington"],
    ".live.nmit.ac.nz": ["Nelson Marlborough Institute of Technology"],
    ".nmit.ac.nz": ["Nelson Marlborough Institute of Technology"],
    ".student.op.ac.nz": ["Otago Polytechnic "],
    ".op.ac.nz": ["Otago Polytechnic"],
    ".openpolytechnic.ac.nz": ["Open Polytechnic "],
    ".otago.ac.nz": ["University of Otago"],
    ".sit.ac.nz": ["Southern Institute of Technology, New Zealand"],
    ".techtorium.ac.nz": ["Techtorium NZIT"],
    ".tnt.ac.nz": ["Taupo nui a tia"],
    ".toiohomai.ac.nz": ["Toi Ohomai Institute of Technology"],
    ".akonga.twoa.ac.nz": ["Te Wananga o Aotearoa"],
    ".uclive.ac.nz": ["University of Canterbury"],
    ".ucol.ac.nz": ["Universal College of Learning"],
    ".unitec.ac.nz": ["Unitec Institute of Technology"],
    ".visioncollege.ac.nz": ["Vision College"],
    ".vuw.ac.nz": ["Victoria University of Wellington"],
    ".waikato.ac.nz": ["University of Waikato"],
    ".student.weltec.ac.nz": ["WelTec", "Wellington Institute Of Technology"],
    ".whitecliffe.ac.nz": [
        "Whitecliffe College",
        "over 1 year programe URL:https://www.whitecliffe.ac.nz/technology",
    ],
    ".whitireianz.ac.nz": ["Whitireia and WelTec "],
    ".student.wintec.ac.nz": ["Waikato Institute of Technology"],
    ".wintec.ac.nz": ["Waikato Institute of Technology"],
    ".yoobeestudent.ac.nz": ["Yoobee College of Design"],
    ".animationcollege.co.nz": ["Animation College"],
    ".aucklanduni.co.nz": ["University of Auckland"],
    ".autuni.co.nz": ["Auckland University of technology"],
    ".students.whs.co.nz": ["Whakatane High School"],
    ".karamu.nz": ["Karamu High School"],
    ".grammar.net.nz": ["Auckland Grammar School"],
    ".onelearn.nz": ["Onehunga High School"],
    ".tekura.org.nz": ["Te Aho o Te Kura Pounamu"],
    ".rollestoncollege.nz": ["Rolleston College"],
    ".aotawhiti.school.nz": ["Ao Tawhiti Unlimited Discovery"],
    ".bdsc.school.nz": ["Botany Downs Secondary College"],
    ".burnside.school.nz": ["Burnside High School"],
    ".cashmere.school.nz": ["Cashmere High School"],
    ".chilton.school.nz": ["Chilton Saint James School"],
    ".students.farmcove.school.nz": ["Farmcove Intermediate "],
    ".hillcrest-high.school.nz": ["Hillcrest High School"],
    ".icl.school.nz": ["ICL Graduate Business School"],
    ".jameshargest.school.nz": [
        "James Hargest College",
        "James Hargest College",
    ],
    ".kc.school.nz": ["Kapiti College"],
    ".kingshigh.school.nz": ["Kings High School"],
    ".kristin.school.nz": ["Kristin school, New Zealand"],
    ".lbc.school.nz": ["Long Bay College"],
    ".lincoln.school.nz": ["Lincoln High School"],
    ".liston.school.nz": ["Liston College, Auckland, New Zealand"],
    ".lynfield.school.nz": ["Lynfield College"],
    ".mairehau.school.nz": ["Mairehau High School", "Mairehau High School"],
    ".maristcollege.school.nz": ["Marist College, New Zealand"],
    ".marsden.school.nz": ["Samuel Marsden College"],
    ".mcglashan.school.nz": ["John McGlashan College"],
    ".mtaspiring.school.nz": ["Mount Aspiring College"],
    ".mytekura.school.nz": ["Te Aho O Te Kura Pounamu"],
    ".naenaeint.school.nz": ["Naenae Intermediate School"],
    ".ohs.school.nz": ["Onehunga High School"],
    ".ormiston.school.nz": ["Ormiston Senior College"],
    ".otahuhucollege.school.nz": ["Otahuhu College"],
    ".otc.school.nz": ["Otumoetai College"],
    ".student.pakuranga.school.nz": ["Pakuranga College"],
    ".rhs.school.nz": ["Rototuna Junior High School "],
    ".students.sacredheart.school.nz": [
        "SacredHeart College",
        "SacredHeart College",
    ],
    ".scotscollege.school.nz": ["Scots College"],
    ".selwyn.school.nz": ["Selwyn College"],
    ".spotswoodcollege.school.nz": ["Spotswood College"],
    ".st-peters.school.nz": ["St Peter's College"],
    ".stcuthberts.school.nz": ["St Cuthbert's College"],
    ".storans.school.nz": ["St Oran's College for Girls"],
    ".stpeterspn.school.nz": ["St Peter's College, Palmerston North"],
    ".taieri.school.nz": ["Taieri College"],
    ".ths.school.nz": ["Taradale High School"],
    ".waimea.school.nz": ["Waimea College"],
    ".wakatipu.school.nz": ["waktipu high school"],
    ".wc.school.nz": ["Wellington College"],
    ".westlandhigh.school.nz": ["Westland High School"],
    ".wgc.school.nz": ["Wellington Girls' College"],
    ".wgpcollege.school.nz": ["Whangaparaoa College"],
    ".whangamata.school.nz": ["Whangamata Area School"],
    ".whs.school.nz": ["Wellington High School"],
    ".wsc.school.nz": ["Western Springs College"],
    ".act.edu.om": ["Al Musanna  College of Technology"],
    ".buc.edu.om": ["Al-Buraimi University College"],
    ".du.edu.om": ["Dhofar University"],
    ".student.gutech.edu.om": [
        "German University of Technology in Oman (GUtech)"
    ],
    ".ibrict.edu.om": ["Ibri College of Technology"],
    ".ict.edu.om": ["Ibra College of Technology"],
    ".majancollege.edu.om": ["Majan University College"],
    ".mcbs.edu.om": [
        "الكلية الحديثة للتجارة والعلوم",
        "Modern College of Business and Science",
    ],
    ".mec.edu.om": ["Middle East College"],
    ".moderngps.edu.om": ["Modern Generation Private School, Oman"],
    ".mtc.edu.om": ["Military Technological College"],
    ".muscatcollege.edu.om": ["Muscat College"],
    ".nct.edu.om": [
        "university of Technology and Applied Sciences-Nizwa, Oman"
    ],
    ".nu.edu.om": ["National University, Oman"],
    ".ocmt.edu.om": ["Oman College of Management & Technology"],
    ".omancollege.edu.om": ["Oman College Of Management &amp; Technology"],
    ".shct.edu.om": [
        "University of Technology and Applied Sciences-Shinas, formerly Shinas College of Technology (ShCT)"
    ],
    ".soharuni.edu.om": ["Sohar University"],
    ".squ.edu.om": ["Sultan Qaboos University"],
    ".students.su.edu.om": ["جامعة صحار", "sohar university"],
    ".suc.edu.om": ["Sur University College"],
    ".unizwa.edu.om": ["University of Nizwa"],
    ".uob.edu.om": ["University of Buraimi", "University of Buraimi"],
    ".utas.edu.om": ["University of Technology and Applied Sciences"],
    ".vibrantprivateschool.edu.om": ["Vibrant Private School"],
    ".moe.om": [
        "Ministry of Education - Oman",
        "Ministry of Education - Oman",
    ],
    ".nmu.one": ["National Mining University", "NMU"],
    ".hgs-singen.online": ["Hohentwiel Gewerbeschule Singen"],
    ".linkiafp.online": ["Linkia FP"],
    ".scholastica.online": ["Scholastica"],
    ".21cccs.org": ["21st Century Cyber Charter School"],
    ".2isa.org": [
        "Institut Informatique Sud Aveyron",
        "Website: http://www.2isa.com/",
        "student emails at @2isa.org for example sergey.epifanov@2isa.org",
    ],
    ".42network.org": ["Ecole 42", "42 School"],
    ".DerbyAcademy.org": ["Derby Academy"],
    ".NeighborhoodMusicSchool.org": ["Neighborhood Music School"],
    ".OFY.org": ["Options For Youth"],
    ".aabfs.org": ["Arab Academy for Banking and Financial Sciences"],
    ".aacps.org": ["Anne Arundel County Public Schools", ".group"],
    ".aas-sofia.org": ["Anglo-American School of Sofia"],
    ".abschools.org": ["Acton Boxborough Regional High School"],
    ".acarcs.org": [
        "Arrowhead Christian Academy",
        "Redlands Christian Schools",
    ],
    ".acccai.org": ["ACCCAI"],
    ".acitech.org": ["Atlantic County Vocational School District"],
    ".acsbg.org": ["American College of Sofia", "Американски колеж в София"],
    ".acwhcc.org": ["Ashland County-West Holmes Career Center", "ACWHCC"],
    ".adams-central.org": ["Adams Central Jr/Sr High School"],
    ".adams12.org": ["Adams 12 Five Star Schools"],
    ".aejics.org": [
        "Agrupamento de Escolas Joaquim Inácio da Cruz Sobral",
        "Joaquim Inácio da Cruz Sobral School Group",
    ],
    ".africanleadershipacademy.org": ["African Leadership Academy"],
    ".fpcoruna.afundacion.org": ["CPR Afundación A Coruña"],
    ".agora.org": ["Agora Cyber Charter School"],
    ".aguafria.org": ["Canyon View High School"],
    ".aims-senegal.org": [
        "AIMS Senegal",
        "African institute for mathematical sciences",
    ],
    ".aimsammi.org": ["African Institute for Mathematical Sciences"],
    ".aischool.org": ["Atlanta International School"],
    ".aissmsioit.org": ["AISSMS Institute of Information Technology"],
    ".akfauniversity.org": ["Akfa University"],
    ".akiva.org": ["Akiva Hebrew Day School"],
    ".alamedaunified.org": [
        "Encinal JR/SR High School",
        "Alameda High School",
    ],
    ".alastudents.org": ["African Leadership Academy"],
    ".alleneastschools.org": ["Allen East Local School District"],
    ".allenisd.org": ["Allen High School"],
    ".allsaintshigh.org": [
        "All Saints Episcopal School - Lubbock",
        "All Saints Episcopal School - Lubbock",
    ],
    ".allsaintsschool.org": [
        "All Saints Episcopal School - Lubbock",
        "All Saints Episcopal School - Lubbock",
    ],
    ".alpinesd.org": ["Timpanogos High", "Lone Peak High School", ".group"],
    ".alsalamprivateschool.org": ["Al Salam Community School"],
    ".alsionschool.org": ["Alsion Montessori Middle/High School"],
    ".altamontschool.org": ["The Altamont School"],
    ".amalnet.org": [
        "הרב תחומי עמל ב' - פתח תקווה",
        "Amal Bet  - Petah Tikva",
        ".group",
    ],
    ".amccollege.org": ["AMC College"],
    ".amityregion5.org": ["Amity Regional High School"],
    ".amouduniversity.org": ["Amoud University"],
    ".anjaconline.org": ["Ayya Nadar Janaki Ammal College"],
    ".students.annaisd.org": ["Anna High School"],
    ".aoiths.org": ["Academy of Innovative Technology"],
    ".apollocc.org": ["Apollo Career Center"],
    ".apschools.org": ["Alliance Public Schools"],
    ".apsk12.org": ["Midtown High School"],
    ".aquinas.org": ["St. Thomas Aquinas Regional Secondary School"],
    ".archwood.org": ["Archbishop Wood High School"],
    ".ardsleyschools.org": ["Ardsley High School "],
    ".argenta-oreana.org": ["Argenta Oreana Middle School"],
    ".arkboulton.org": ["Ark Boulton Academy"],
    ".arnoldcentralschool.org": [
        "St. Arnold Central School",
        "St. Arnold Central School",
    ],
    ".arps.org": ["Amherst Regional High School"],
    ".asbindia.org": ["American School of Bombay", "asb"],
    ".ascensionacademy.org": ["Ascension Academy"],
    ".ascte.org": ["Alabama School of Cyber Technology and Engineering"],
    ".asd20.org": ["Academy School District 20, Colorado Springs, CO 8920"],
    ".asdk12.org": ["Anchorage School District", "ASD", "ASDschool"],
    ".asdlopes.org": ["Avonworth School District"],
    ".asdnh.org": ["Academy for Science and Design"],
    ".ashevilleschool.org": ["Asheville School"],
    ".asl.org": ["The American School in London"],
    ".asmadrid.org": ["American School of Madrid"],
    ".asmsa.org": [
        "Arkansas School for Mathematics, Sciences, and the Arts",
        "Arkansas School for Math, Sciences, and the Arts",
        "Arkansas School for Math, Sciences, and Arts",
        "ASMSA",
    ],
    ".aspatriots.org": [
        "All Saints Episcopal School - Lubbock",
        "All Saints Episcopal School - Lubbock",
    ],
    ".association-esi.org": ["Ecole Supérieure d'Informatique Internationale"],
    ".astu.org": [
        "Astrahan State Technical University",
        "Astrahan State Technical University",
    ],
    ".asvalencia.org": ["American School Of Valencia"],
    ".aswarsaw.org": ["American School of Warsaw"],
    ".athenian.org": ["Athenian School"],
    ".atlanticcollege.org": ["United World College of Atlantic"],
    ".atljewishacademy.org": ["Atlanta Jewish Academy"],
    ".auamed.org": ["American University of Antigua"],
    ".augustachristian.org": ["Augusta Christian Schools"],
    ".auhsdschools.org": ["Acalanes Union High School District", ".group"],
    ".auk.org": ["RIT Kosovo (AUK) - Rochester Institute of Technology"],
    ".aurorak12.org": ["Aurora Public Schools", "APS", ".group"],
    ".ausdk12.org": ["Albany Unified School District"],
    ".austinisd.org": ["LBJ Early College High School"],
    ".avcoe.org": ["Amrutvahini College of Engineering"],
    ".avenues.org": ["Avenues: The World School"],
    ".avhsd.org": ["Eastside High School", "Eastside High School", ".group"],
    ".students.avon-schools.org": ["Avon Highschool"],
    ".avondaleschools.org": ["Avondale School District"],
    ".avu.org": ["African Virtual University"],
    ".axiscolleges.org": ["Axis institute of technology and management "],
    ".baisedu.org": ["Bandung Alliance Intercultural School"],
    ".gr.balbharati.org": ["Bal Bharati Public School"],
    ".bangorschools.org": ["Bangor Township Schools"],
    ".barnsley-academy.org": ["Barnsley Academy"],
    ".barstowschool.org": ["The Barstow School"],
    ".basdschools.org": ["liberty high school"],
    ".bathwildcats.org": ["Bath Local Schools"],
    ".battlegroundps.org": ["Prairie High School"],
    ".bayschoolsohio.org": ["Bay Village Schools"],
    ".bbs-me.org": ["BBS-ME – Otto-Brenner-Schule"],
    ".bcp.org": ["Bellarmine College Preparatory"],
    ".bcps.org": [],
    ".bearzi.org": ['Istituto Tecnico Industriale "G. Bearzi", Udine'],
    ".bebs.org": ["Barcelona Executive Business School"],
    ".beckfoot.org": ["Beckfoot"],
    ".beckfootoakbank.org": [
        "Beckfoot Oakbank Academy",
        "Oakbank School",
        "Beckfoot Oakbank School",
    ],
    ".bedfordps.org": ["John Glenn Middle School"],
    ".student.beehiveacademy.org": ["Beehive Academy"],
    ".belenwolverines.org": ["Belen Jesuit Preparatory School"],
    ".bellinghamschools.org": ["Squalicum High School"],
    ".belmonthill.org": ["Belmont Hill School"],
    ".bentonvillek12.org": ["Bentonville Public Schools"],
    ".bergen.org": ["Bergen County Technical Schools"],
    ".berwickacademy.org": ["Berwick Academy", "Berwick Academy"],
    ".bethanyschoolsheffield.org": ["Bethany School, Sheffield"],
    ".bethlehemschools.org": ["Bethlehem Central High School"],
    ".bfhsla.org": ["Benjamin Franklin High School"],
    ".bfw-hamm.org": [
        "Berufsförderungswerk Hamm GmbH",
        "Berufsförderungswerk Hamm",
        "BFW Hamm",
    ],
    ".bhischina.org": ["Beijing Horizon International School"],
    ".bhpsnj.org": ["Governor Livingston High School"],
    ".bhrsd.org": ["Berkshire Hills Regional School District"],
    ".bhrsdonline.org": ["Berkshire Hills Regional School District"],
    ".bhsconnect.org": ["Beverly High School", "Beverly High School"],
    ".bihe.org": [
        "Baha'i Institute for Higher Education",
        "The Bahá'í Institute For Higher Education (BIHE)",
    ],
    ".binusian.org": ["Binus University"],
    ".bischicagosl.org": [
        "British International School of Chicago, South Loop"
    ],
    ".bishopireton.org": ["Bishop Ireton High School"],
    ".bkwschools.org": ["BERNE-KNOX-WESTERLO CENTRAL SCHOOL DISTRICT"],
    ".blakeschool.org": ["The Blake School"],
    ".blindbrook.org": ["Blind Brook High School"],
    ".bloomfield.org": ["Bloomfield Hills Schools"],
    ".students.blountk12.org": ["Heritage High School"],
    ".bluedemons.org": [
        "Kennett High School",
        "Kennett Consolidated School District",
        "300 East South Street",
        "Kennett Square, PA 19348",
    ],
    ".bluevalleyk12.org": ["Blue Valley School District"],
    ".blufftonschools.org": ["Bluffton Exempted Village School District"],
    ".bmsastem.org": ["Bio-Med Science Academy"],
    ".boiseschools.org": ["Boise School District"],
    ".bolashak.org": ["Caspian College Bolashak"],
    ".bolles.org": ["The Bolles School"],
    ".bostonpublicschools.org": ["Boston Public Schools (Teachers)"],
    ".bostontrinity.org": ["Boston Trinity Academy"],
    ".student.bournemouth-school.org": ["Bournemouth School, Dorset"],
    ".bhs.bownet.org": ["Bow High School", "Bow High School"],
    ".bms.bownet.org": ["Bow Memorial School", "Bow Memorial School"],
    ".bphawks.org": ["Bethel Park High School"],
    ".bpmcemadhepura.org": ["B. P. Mandal College of Engineering, Madhepura"],
    ".bps121.org": ["Burlington Public Schools"],
    ".branson.org": ["The Branson School"],
    ".brebeuf.org": ["Brebeuf Jesuit Preparatory School"],
    ".student.breckschool.org": ["Breck", "Breck"],
    ".brevardschools.org": [
        "Brevard Schools",
        "Andersen Elementary School",
        "Apollo Elementary",
        "Atlantis Elementary",
        "Audubon Elementary",
        "Cambridge Elementary",
        "Cape View Elementary",
        "Challenger 7 Elementary",
        "Columbia Elementary",
        "Coquina Elementary",
        "Croton Elementary",
        "Discovery Elementary",
        "Dr. W.J. Creel Elementary",
        "Endeavour Elementary",
        "Enterprise Elementary",
        "Fairglen Elementary",
        "Freedom 7 Elementary",
        "Gemini Elementary",
        "Golfview Elementary Magnet",
        "Harbor City Elementary",
        "Holland Elementary",
        "Imperial Estates Elementary",
        "Indialantic Elementary",
        "Jupiter Elementary",
        "Lewis Carroll Elementary",
        "Lockmar Elementary",
        "Longleaf Elementary",
        "Manatee Elementary",
        "McAuliffe Elementary",
        "Meadowlane Intermediate Elementary",
        "Meadowlane Primary Elementary",
        "MILA Elementary",
        "Mims Elementary",
        "Oak Park Elementary",
        "Ocean Breeze Elementary",
        "Palm Bay Elementary",
        "Pinewood Elementary",
        "Port Malabar Elementary",
        "Quest Elementary",
        "Riviera Elementary",
        "Roosevelt Elementary",
        "Roy Allen Elementary",
        "Sabal Elementary",
        "Saturn Elementary",
        "Sea Park Elementary",
        "Sherwood Elementary",
        "South Lake Elementary",
        "Stevenson Elementary",
        "Sunrise Elementary",
        "Suntree Elementary",
        "Surfside Elementary",
        "Tropical Elementary",
        "Turner Elementary",
        "University Park Elementary Magnet",
        "Viera Elementary",
        "West Melbourne School for Science",
        "Westside Elementary",
        "Williams Elementary",
        "Central Middle",
        "DeLaura Middle",
        "Hoover Middle",
        "Jackson Middle",
        "Jefferson Middle",
        "Johnson Middle",
        "Kennedy Middle",
        "Madison Middle",
        "McNair Magnet Middle",
        "Southwest Middle",
        "Stone Magnet Middle",
        "Viera Middle",
        "Astronaut High",
        "Bayside High",
        "Cocoa Beach Jr/Sr High",
        "Cocoa High",
        "Eau Gallie High",
        "Edgewood Jr/Sr High",
        "Heritage High",
        "Melbourne High",
        "Merritt Island High",
        "Palm Bay Magnet High",
        "Rockledge High",
        "Satellite High",
        "Space Coast Jr/Sr",
        "Titusville High",
        "Viera High",
        "West Shore Jr/Sr High",
        "Adult Education",
        "Brevard Virtual",
        "Educational Horizons",
        "Emma Jewel",
        "Gardendale Separate Day School",
        "Imagine Schools",
        "North Central Alternative Learning",
        "Odyssey Charter Elementary Campus",
        "Odyssey Charter - Jr/Sr Campus",
        "Odyssey Preparatory Charter",
        "Palm Bay Academy Middle",
        "Pineapple Cove Classical Academy",
        "Pineapple Cove Classical Academy-Lockmar",
        "Pineapple Cove Classical Academy - West Melb.",
        "Pinecrest Academy Space Coast",
        "Riverside Charter High School",
        "Royal Palm Charter",
        "Sculptor Charter",
        "South Alternative Learning",
        "Viera Charter",
        ".group",
    ],
    ".brewsteracademy.org": ["Brewster Academy"],
    ".brickschools.org": ["Brick Township Public Schools"],
    ".bridgeacademy.org": ["Bridge Academy"],
    ".bridgtonacademy.org": ["Bridgton Academy"],
    ".brightstarschools.org": ["Bright Star Schools (Staff)"],
    ".brightstarstudents.org": ["Bright Star Schools (Students)"],
    ".britishschoolmanila.org": ["The British School of Manila"],
    ".bronxvilleschool.org": ["Bronxville School"],
    ".brookeweston.org": ["Brooke Weston Academy"],
    ".student.brookfieldps.org": ["Brookfield High School"],
    ".brooklinek12.org": ["Brookline High School", "Brookline High School"],
    ".brophybroncos.org": ["Brophy College Preparatory"],
    ".brunswickschool.org": ["Brunswick High School"],
    ".brunswicksd.org": ["Brunswick High School"],
    ".bruntsacademy.org": ["The Brunts Academy"],
    ".brynmawrschool.org": ["Bryn Mawr School"],
    ".bsacet.org": [
        "B.S.A. College of Engineering & Technology ",
        "BSACET ",
        "The email we use is xyz@bsacet.org",
        "Official College Website: (https://www.bsacet.org/)",
        "URL of a page on the official website where a long-term (>1 year) IT related course is offered by the university: (https://www.bsacet.org/course/computer-science-engineering/)",
        "URL of a page or some other proof (.pdf or a screenshot are OK) showing that the university recognizes the domain which you are submitting as an official email domain for the enrolled students: ",
        "1. {[Faculity Emails](https://www.bsacet.org/faculty)} (Please Check for Emails of Faculty)",
        "2.",
        "[Please Check for Email of the College in contatct us](https://www.bsacet.org/contact/)    ",
    ],
    ".bsd220.org": ["Barrington School District 220"],
    ".bsd405.org": ["Bellevue School District"],
    ".bsd48.org": ["Beaverton School District"],
    ".bsdi-bd.org": ["Bangladesh Skill Development Institute"],
    ".bsdvt.org": ["Burlington High School"],
    ".bsu-edu.org": ["Baku Slavic University"],
    ".btfiloh.org": ["Beth Tfiloh"],
    ".budapestschool.org": ["Budapest School"],
    ".stu.burbankusd.org": ["Burbank Unified School District"],
    ".burlcoschools.org": ["Burlington County Insitute of Technology"],
    ".burltwpsch.org": ["Burlington Township High School"],
    ".bvhs.org": ["Bishop Verot Catholic High School"],
    ".bvsd.org": ["Boulder Vally School District"],
    ".byerach.org": ["בית ירח", "Beit Yerach"],
    ".c-dh.org": ["Cretin-Derham Hall"],
    ".my.caddoschools.org": ["C.E. Byrd"],
    ".students.cal-mum.org": [" Caledonia-Mumford Central School District"],
    ".calallen.org": ["Calallen High School (Grades 9-12)"],
    ".calbrightcollege.org": [
        "Calbright College",
        "University official website URL: https://www.calbright.org",
        "URL of IT related course > 1 year: https://www.calbright.org/programs/it-support/",
        "Student email: firstname.lastname@calbrightcollege.org",
    ],
    ".caliva.org": ["California Virtual Academies"],
    ".cambournevc.org": [
        "Cambourne Village College, UK",
        "Cambourne Village College, UK",
    ],
    ".camelotacademy.org": ["Camelot Academy"],
    ".campbellhall.org": [
        "Campbell Hall - an independent coeducational day school for grades K-12"
    ],
    ".campus-la-chataigneraie.org": ["Campus la Châtaigneraie"],
    ".campusfonderiedelimage.org": ["Campus Fonderie de l'Image"],
    ".canisiushigh.org": ["Canisius High School"],
    ".cannonschool.org": ["Cannon School", "Cannon School"],
    ".ctec.canyonsdistrict.org": ["Canyons Technical Education Center (CTEC)"],
    ".capitalcityacademy.org": ["Capital City Academy"],
    ".capousd.org": ["Capistrano Unified School District"],
    ".caravel.org": ["Caravel Academy"],
    ".students.carmelschools.org": ["Carmel High School"],
    ".carmelschools.org": ["Carmel High School"],
    ".cavendishza.org": ["Cavendish University"],
    ".cbaalbany.org": ["Christian Brothers Academy"],
    ".cbchs.org": ["Christian Brothers College High School"],
    ".student.cbsd.org": ["Lenape Middle School"],
    ".ccaschools.org": ["Clear Creek Amana High School"],
    ".ccchs.org": [
        "Clearwater Central Catholic High School",
        "Clearwater Central Catholic",
        "CCC",
    ],
    ".stu.ccsdut.org": ["Cache County School District"],
    ".ccsdut.org": ["Cache County School District"],
    ".ccusd.org": ["Culver City High School"],
    ".students.cdaschools.org": ["Venture High School", "Venture High School"],
    ".ce-kgr.org": ["College of Engineering Kidangoor"],
    ".ceaprc.org": ["Centro de Estudios Avanzados de Puerto Rico y el Caribe"],
    ".cedarpark.org": ["Cedar Park Christian School"],
    ".centraliens-lille.org": ["Ecole Centrale de Lille"],
    ".centraluniversity.org": ["Central University College"],
    ".cesjds.org": ["Charles E. Smith Jewish Day School"],
    ".cfsd16.org": ["Catalina Foothills High School"],
    ".cgps.org": ["columbia grammar and preparatory school"],
    ".chadwickschool.org": ["Chadwick School"],
    ".challoners.org": ["Dr Challoner's Grammar School"],
    ".chaminade.org": ["Chaminade College Preparatory"],
    ".chaminet.org": ["Chaminade College Preparatory"],
    ".charlottelatin.org": ["Charlotte Latin School"],
    ".charlottesvilleschools.org": ["Charlottesville City Public Schools"],
    ".charmouniversity.org": ["Charmo University"],
    ".student.charterarts.org": [
        "Lehigh Valley Charter High School for the Arts"
    ],
    ".charterschool.org": ["The Charter School of Wilmington"],
    ".chatham-nj.org": ["Chatham High School"],
    ".chclc.org": ["Cherry Hill Public Schools"],
    ".chelsea-academy.org": ["Chelsea Academy"],
    ".cheltenhamcollege.org": ["Cheltenham College"],
    ".cheneyschool.org": ["Cheney School"],
    ".cherrycreekschools.org": ["Cherry Creek School District #5"],
    ".cheshamgrammar.org": ["Chesham Grammar School"],
    ".cheshireacademy.org": ["Cheshire Academy"],
    ".chettinadvidyashram.org": ["chettinad vidyashram"],
    ".chewonki.org": ["Chewonki Foundation Semester School"],
    ".chigwell-school.org": ["Chigwell School"],
    ".silverdale.chorustrust.org": ["Silverdale School", "Silverdale School"],
    ".christchurchschool.org": ["Christchurch School"],
    ".chsd117.org": ["Community High School District 117"],
    ".cifpperedesongall.org": ["CIFP Pere de Son Gall"],
    ".citedesentreprises.org": [
        "Pôle Formation CFAI AFPI Loire-Drôme-Ardèche"
    ],
    ".cittumkur.org": [
        "Channabasaveshwara Institute of Technology, Tumkur",
        "CIT",
    ],
    ".cjits.org": ["Christu Jyothi Institute Of Technology and Science"],
    ".clearlakeschools.org": [
        "Clear Lake Schools",
        ".group",
        "School district, Clear Lake, Iowa 50428",
    ],
    ".clevelandmetroschools.org": ["Cleveland Metro School District"],
    ".cmasas.org": ["Christa McAuliffe Academy School of Arts and Sciences"],
    ".cmsdk12.org": ["Cleveland Metro School District"],
    ".cmseducation.org": ["City Montessori School, Lucknow, India"],
    ".cmselearning.org": ["City Montessori School, Lucknow, India"],
    ".cns-school.org": ["City of Norwich School, An Ormiston Academy"],
    ".cobbk12.org": [
        "Wheeler High School",
        ".group",
        "http://www.cobbk12.org/",
    ],
    ".students.coderva.org": ["CodeRVA Regional High School"],
    ".coldwatercavs.org": ["Coldwater Exempted Village Schools"],
    ".coleacademy.org": ["Cole Academy"],
    ".doral.colegia.org": ["Doral Academy Charter High School"],
    ".college-prep.org": ["The College Preparatory School"],
    ".collegiateacademies.org": [
        "Livingston Collegiate Academy",
        "Livingston Collegiate Academy",
    ],
    ".collegiateschool.org": ["Collegiate School"],
    ".colonialsd.org": ["Colonial School District"],
    ".columbusacademy.org": [
        "Columbus Academy",
        "website: http://www.columbusacademy.org/",
    ],
    ".g.comalisd.org": ["Canyon High School"],
    ".combertonvc.org": ["Comberton Village College"],
    ".commschool.org": ["Commonwealth School"],
    ".communityschoolnaples.org": ["Community School Of Naples"],
    ".scholars.compasscharters.org": [
        "Compass Charter Schools of Yolo",
        ".group",
    ],
    ".concordcarlisle.org": [
        "Concord-Carlisle Regional High School",
        "Concord-Carlisle Regional High School",
    ],
    ".concordiashanghai.org": ["Concordia International School Shanghai"],
    ".conejousd.org": ["Conejo Valley Unified School District (CVUSD)"],
    ".cornwallhill.org": ["Cornwall Hill College"],
    ".corsigaldus.org": ["Galdus", "Galdus"],
    ".cossali.org": ['I.I.S."G. Cossali"'],
    ".cottonwoodclassical.org": ["Cottonwood Classical Preparatory School"],
    ".countyupper.org": [
        "County Upper School",
        "County Upper",
        "https://www.countyupper.org/",
    ],
    ".cowesec.org": ["Cowes Enterprise College"],
    ".cpgoenka.org": [
        "CP Goenka international school",
        "https://www.cpgoenkainternationalschool.com/",
        "https://www.cpgoenkainternationalschool.com/boards/ibdp",
        "https://www.cpgoenkainternationalschool.com/contact-us",
    ],
    ".cpsk12.org": ["Columbia Public Schools"],
    ".cranleigh.org": ["Cranleigh School", "Cranleigh School"],
    ".cravenk12.org": ["West Craven High School"],
    ".creanlutheran.org": [
        "Crean Lutheran High School",
        "School Website: https://creanlutheran.org",
        "Staff Email Domain: creanlutheran.org",
        "Student Email Domain stu.creanlutheran.org",
        "Question: Our student email domain restricts emails outside of our domain. What email(s) from jetbrains do we need to whitelist so that they can access pycharm?",
    ],
    ".creightonprep.org": ["Creighton Preparatory School"],
    ".crescentschool.org": ["Crescent School"],
    ".cresthavenacademy.org": ["Cresthaven Academy Charter School"],
    ".cri-paris.org": [
        "Centre de recherches interdisciplinaire de paris ( descartes + diderot )"
    ],
    ".cromptonhouse.org": ["Crompton House"],
    ".crosspointacademy.org": ["California Crosspoint Academy"],
    ".csd117.org": ["Discovery High School", "Camas High School", ".group"],
    ".csd99.org": ["Downers Grove North Highschool"],
    ".csddocs.org": ["Canyons School District"],
    ".csj-rpi.org": ["Colegio San Jose"],
    ".csusaflstudent.org": ["Don Soffer Aventura High School"],
    ".students.ctasd.org": ["Conemaugh Township High School"],
    ".ctechigh.org": ["Fresno County Schools"],
    ".cttech.org": ["Ella T. Grasso Technical Highschool"],
    ".cuhsd.org": ["Campbell Union High School District", ".group"],
    ".cummingtamilschool.org": ["Cumming Tamil School"],
    ".cusd200.org": ["Community Unit School District 200 (Wheaton, IL, USA)"],
    ".cusdk8.org": ["Hyde Middle School"],
    ".cushingisd.org": ["Cushing Independent School District", "Cushing ISD"],
    ".cvcolonials.org": ["Conewago Valley School District"],
    ".cvoantwerpen.org": ["CVO Antwerpen"],
    ".cvsd356.org": ["Central Valley School District"],
    ".cvsdstudents.org": ["Cumberland Valley High School"],
    ".cvsdvt.org": [
        "Champlain Valley School District",
        "Hinesburg Community School",
        "Champlain Valley Union High School",
        ".group",
    ],
    ".cymcass.org": ["中華基督教青年會中學", "Chinese YMCA Secondary School"],
    ".d-e.org": ["Dwight-Englewood School"],
    ".d125.org": ["Adlai E. Stevenson High School"],
    ".d155.org": ["Prairie Ridge High School"],
    ".students.d211.org": ["Township High School District 211"],
    ".d211.org": ["Township High School District 211"],
    ".stu.d214.org": ["Township High School District 214", ".group"],
    ".d219.org": ["Niles West High School"],
    ".d230.org": ["Amos Alonzo Stagg High School"],
    ".students.d303.org": ["Saint Charles East High School", ".group"],
    ".da.org": [
        "Durham Academy",
        "link to Upper School Technology Curriculum: http://www.da.org/page.cfm?p=704",
    ],
    ".dallasisd.org": [
        "Dallas Independent School District",
        "School of Science and Engineering",
        "Science and Engineering Magnet",
        "School of the Talented and Gifted",
        "Talented and Gifted Magnet",
        ".group",
    ],
    ".dalton.org": ["The Dalton School"],
    ".danielcastelao.org": [
        'Centro de Formacion Profesional "Daniel Castelao"'
    ],
    ".darienps.org": ["Darien High School", "Middlesex Middle School"],
    ".darlingtonschool.org": ["Darlington School"],
    ".student.dasd.org": ["Downingtown S.T.E.M. Academy"],
    ".davenportschools.org": ["West High School"],
    ".davietjal.org": ["DAV Institute of Engineering & Technology"],
    ".davincischools.org": ["Da Vinci Schools"],
    ".davisonschools.org": ["Davison High School"],
    ".daystarus.org": ["Daystar University"],
    ".dc-tech.org": ["Dauphin County Technical School"],
    ".dci-student.org": ["DCI Digital Career Institute"],
    ".dcp.org": ["Downtown College Preparatory"],
    ".dcrustm.org": [
        "Deenbandhu Chhotu Ram University of Science and Technology"
    ],
    ".s.dcsdk12.org": ["Douglas County School District", ".group"],
    ".dcsdk12.org": ["Douglas County School District", ".group"],
    ".student.dcsok.org": ["Deer Creek School District 6"],
    ".ddecnc.org": [
        "Lycée Privé Générale et Technologique Blaise Pascal (DDEC)"
    ],
    ".deensacademy.org": ["Deens Academy", "Deens Academy"],
    ".delphian.org": ["The Delphian School"],
    ".delphoscityschools.org": ["Delphos City Schools"],
    ".delphosstjohns.org": ["Delphos St. John's School"],
    ".denmarkroad.org": ["Denmark Road High School"],
    ".derryfield.org": ["The Derryfield School"],
    ".desmet.org": [
        "De Smet Jesuit High School",
        "De Smet Jesuit",
        "DeSmet Jesuit",
        "DeSmet Jesuit High School",
    ],
    ".devrijeruimte.org": ["De Vrije Ruimte", "The Free Space"],
    ".dhsb.org": ["Devonport high school for boys"],
    ".diderot.org": ["Lycée Polyvalent Diderot"],
    ".dietms.org": [
        "Deogiri Institute of Engineering and Management Studies Aurangabad "
    ],
    ".diiage.org": ["Centre Universitaire Catholique de Bourgogne"],
    ".student.dimanregional.org": [
        "Diman Regional Vocational Technical High School"
    ],
    ".dimanregional.org": ["Diman Regional Vocational Technical High School"],
    ".dist113.org": ["Deerfield High School"],
    ".district112.org": ["Independent School District 112"],
    ".district196.org": [
        "Independent School District 196 Rosemount-Apple Valley-Eagan"
    ],
    ".apps.district833.org": [
        "South Washington County School District (sowashco.org) "
    ],
    ".divini.org": ["ITIS Eustachio Divini"],
    ".dld.org": ["DLD College London"],
    ".dlshs.org": ["De La Salle High School"],
    ".student.dmschools.org": ["Des Moines Public Schools"],
    ".dncoe.org": ["Del Norte County Office of Education"],
    ".dnusd.org": ["Del Norte Unified School District"],
    ".donboscocairo.org": [
        "Istituto Tecnico Industriale Salesiano - Don Bosco Cairo"
    ],
    ".donntu.org": ["Donetsk National Technical University"],
    ".doversherborn.org": ["Dover-Sherborn High School"],
    ".educ.dpcdsb.org": ["St. Roch Catholic Secondary School"],
    ".dpengineering.org": ["Dos Pueblos Engineering Academy"],
    ".dpisd.org": ["Deer Park Independent School District"],
    ".dpsgandhidham.org": ["Delhi Public School, Gandhidham"],
    ".student.dpsindore.org": ["Delhi Public School Indore"],
    ".dragonschool.org": ["Dragon School", "Dragon School"],
    ".dsatulsa.org": ["Dove Science Academy Tulsa"],
    ".dtechhs.org": ["Design Tech High School"],
    ".dubaicollege.org": ["Dubai College"],
    ".dulwich.org": ["Dulwich College Beijing", "Dulwich College Beijing"],
    ".dupage88.org": ["DuPage High School District 88"],
    ".duvalschools.org": ["Duval County Public Schools"],
    ".dwightlondon.org": ["Dwight School London"],
    ".dyker201.org": ["Dyker Heights Intermediate School 201"],
    ".eaportal.org": [
        "Colégio Adventista de Viamão",
        "Viamao Adventist Academy",
    ],
    ".eastbrookschool.org": ["Eastbrook School"],
    ".eastsidecatholic.org": ["Eastside Catholic School"],
    ".eastsidecatholicschool.org": ["Eastside Catholic School"],
    ".ebnet.org": ["East Brunswick High School"],
    ".ebrschools.org": ["Baton Rouge Magnet High School"],
    ".ecfs.org": ["Ethical Culture Fieldston School"],
    ".ecrchs.org": ["El Camino Real Charter High School"],
    ".ecscollege.org": [
        "ecscollege.org",
        "Evangel Christian Seminary & College",
    ],
    ".student.edgemont.org": ["Edgemont Jr/Sr High School"],
    ".edmonds15.org": ["Edmonds School District"],
    ".edubridgeschool.org": ["Edubridge International School"],
    ".edubuzz.org": [
        "Musselburgh Grammar School",
        ".group",
        "http://www.edubuzz.org/musselburghgrammar/",
    ],
    ".educastur.org": ["Educational centers in Asturias, Spain"],
    ".kfaryarok.eduil.org": ["בית הספר הכפר הירוק", "Green Village School"],
    ".modiin.eduil.org": ["Ironi Alef Modiin High School"],
    ".raanana.eduil.org": ["Ostrovsky High School", ".group"],
    ".shoham.eduil.org": ["Yahalom Shoham High School", ".group"],
    ".rabinks.edumschool.org": ["רבין", "Rabin"],
    ".info-spsepn.edupage.org": [
        "Stredná Priemyselná Škola Elektrotechnická Piešťany",
        "High School of Electrical Engineering in Piešťany",
        "SPŠE PN",
    ],
    ".eduservices.org": ["Eduservices", ".group"],
    ".egcsd.org": ["Columbia High School"],
    ".egibide.org": [
        "Fundación Diocesanas - Jesús Obrero Fundazioa",
        "Egibide",
    ],
    ".egsd.org": [
        "Middle Park High School",
        "East Grand Middle School",
        ".group",
    ],
    ".einsteinmed.org": ["Albert Einstein College of Medicine"],
    ".elcachargers.org": ["Eagles Landing Christian Academy"],
    ".elcampico.org": ["E.F.A. El Campico"],
    ".elevate208.org": ["Elevate Academy Nampa"],
    ".elis.org": ["ELIS"],
    ".elmbrookstudents.org": [
        "Brookfield East High School",
        "Brookfield Cental High School",
        "https://www.elmbrookschools.org/brookfield-east-high-school",
        "Brookfield, Wisonsin",
        ".group",
    ],
    ".elsys-bg.org": [
        "Technological school Electronic Systems",
        "Associated with Technical University Sofia, Bulgaria",
    ],
    ".em-is.org": ["Eastern Mediterranean International School"],
    ".enfieldgrammar.org": ["Enfield Grammar School"],
    ".ens2m.org": [
        "École Nationale Supérieure de Mécanique et des Microtechniques"
    ],
    ".ensta-bretagne.org": [
        "Ecole Nationale Supérieure de Techniques Avancées Bretagne"
    ],
    ".ep-student.org": ["Eden Prairie School District - Student Emails"],
    ".epatt.org": ["East Palo Alto Tutoring and Tennis"],
    ".epcarvalhais.org": ["Escola profissional de carvalhais"],
    ".epiccharterschools.org": ["Epic Charter Schools"],
    ".er9.org": ["Joel Barlow High School"],
    ".eriesd.org": ["Erie School District"],
    ".erpsk12.org": ["Eaton Rapids Public Schools"],
    ".esaip.org": ["École supérieure angevine en informatique et productique"],
    ".escacilhastejo.org": ["Escola Secundária Cacilhas-Tejo"],
    ".escolapiasvalencia.org": ["Colegio Escolapias Valencia"],
    ".esdallas.org": ["The Episcopal School of Dallas"],
    ".esgis.org": ["Ecole Supérieure de Gestion Informatque et des Sciences"],
    ".esicad.org": ["ESICAD école de commerce sur Montpellier et Toulouse "],
    ".esisalama.org": [
        "Ecole superieure d'informatique Salama",
        "Salama School of Computer Science",
    ],
    ".esj.org": ["Episcopal School of Jacksonville"],
    ".student.esmonline.org": [
        "Eastport South-Manor Junior Senior High School"
    ],
    ".esmonline.org": ["Eastport South-Manor Junior Senior High School"],
    ".esmschools.org": [
        "East Syracuse Minoa High School",
        "East Syracuse Minoa High School",
    ],
    ".esmt.org": [
        "European School of Management and Technology (ESMT), Berlin"
    ],
    ".esuhsd.org": ["East Side Union High School District", ".group"],
    ".eteo.org": ["Escola Técnica Empresarial Do Oeste"],
    ".etsc.org": [
        "Evanglical Theological Seminary in Cairo",
        "Evanglical Theological Seminary in Cairo",
    ],
    ".eufsdk12.org": ["Eastchester High School", ".group"],
    ".campus.euss.org": ["Escola Universitaria Salesiana Sarria (EUSS)"],
    ".apps.everettsd.org": ["Henry M. Jackson High School"],
    ".student.evergreenps.org": ["Evergreen Public Schools"],
    ".brunts.evolvetrust.org": ["The Brunts Academy"],
    ".exploris.org": ["The Exploris School"],
    ".fa.org": ["Friends Academy"],
    ".fabiuspompey.org": ["Fabius-Pompey Middle School High School"],
    ".fairlawnsds.org": ["Memorial Middle School Fair Lawn NJ"],
    ".fallriverschools.org": ["Fall River Public Schools"],
    ".farberhds.org": ["Farber Hebrew Day School"],
    ".farnborough-hill.org": ["Farnborough Hill"],
    ".fayacademy.org": ["Fayetteville Academy"],
    ".fayerweather.org": ["Fayerweather Street School "],
    ".fcboe.org": ["Fayette County Public Schools"],
    ".fccps.org": ["Falls Church County Public Schools"],
    ".research.fchampalimaud.org": [
        "Champalimaud Research",
        "Champalimaud Foundation",
    ],
    ".fcoe.org": ["Fresno County Schools"],
    ".fcstu.org": ["Fulton County Schools"],
    ".student.fcusd.org": ["Sutter Middle School"],
    ".felsted.org": ["Felsted School, Essex"],
    ".fergflor.org": [
        "Ferguson-Florissant School District",
        "Ferguson-Florissant R-II",
    ],
    ".ferraris.org": ["ITI Galileo Ferraris"],
    ".ffc8.org": ["Fountain-Fort Carson Highschool"],
    ".fhsdschools.org": ["Francis Howell School District"],
    ".fisdk12.org": ["Friendswood High School"],
    ".fjuhsd.org": ["Troy High School"],
    ".flaglercps.org": [
        "Flagler Palm Coast High School",
        "Flagler Palm Coast High School",
    ],
    ".flatbush.org": ["Yeshivah of Flatbush"],
    ".florencek12.org": [
        "Florence High School",
        "Florence City Schools",
        ".group",
    ],
    ".flpoly.org": ["Florida Polytechnic University"],
    ".students.fmcsd.org": ["Fort Madison High School"],
    ".stu.fondazionejobsacademy.org": ["FondazioneJAC JobsAcademy"],
    ".forestgatecst.org": ["forest gate community school"],
    ".foresthillshs.org": ["Forest Hills High School"],
    ".forestinstitute.org": ["Forest Institute of Professional Psychology"],
    ".forpro-creteil.org": ["GRETA MTE 77"],
    ".forsythk12.org": ["Lambert High School"],
    ".foxc6.org": ["Fox C-6 School District"],
    ".fpsct.org": ["Farmington High School"],
    ".fpsed.org": ["Framingham Public Schools"],
    ".fracademy.org": ["Fowey River Academy"],
    ".francisparker.org": ["Francis W. Parker School"],
    ".franklinsabers.org": ["Franklin High School", "Franklin High School"],
    ".freemens.org": ["City of London Freemen's School"],
    ".fresnoccs.org": ["Fresno County Schools"],
    ".fresnou.org": ["Edison High School"],
    ".fresnounified.org": ["Edison High School"],
    ".friendsbalt.org": ["Friends School of Baltimore"],
    ".friendscentral.org": ["Friends' Central School"],
    ".friendsseminary.org": ["Friends Seminary"],
    ".frisch.org": ["The Frisch School", "Yeshivat Frisch", "Frisch"],
    ".friscoisd.org": ["Centennial High School"],
    ".fromecollege.org": ["Frome College"],
    ".fryeburgacademy.org": ["Fryeburg Academy"],
    ".fsbwit.org": [
        "Fachschule der Bundeswehr für Elektrotechnik und Informatiktechnik",
        "German Armed Forces Vocational School for Electronics and Information Technology",
    ],
    ".ftcsc.org": ["Franklin Central High School"],
    ".ftstudent.org": ["Franklin Central High School"],
    ".g.fuchsmizrachi.org": ["Fuchs Mizrachi"],
    ".student.fuhsd.org": [
        "Cupertino High School, Cupertino, California",
        "Fremont High School, Sunnyvale, California",
        "Homestead High School, Cupertino, California",
        "Lynbrook High School, San Jose, California",
        "Monta Vista High School, Cupertino, California",
        ".group",
    ],
    ".fuhsd.org": ["Fremont Union High School District", ".group"],
    ".fulton58.org": ["Fulton Public Schools"],
    ".fultonschools.org": ["Fulton County Schools"],
    ".fultonscienceacademy.org": [
        "Fulton Science Academy",
        "fultonscienceacademy.org",
        "https://www.fultonscienceacademy.org/academics/high-school-curriculum",
        "on the website at line 3, go to Course catalog page 30 for the CS course",
    ],
    ".fuma.org": ["Fork Union Military Academy"],
    ".fundacion-jala.org": ["Fundación Jala", "Jala Foundation"],
    ".fwastudents.org": ["Faith West Academy"],
    ".students.fwisd.org": ["Fort Worth Independent School District"],
    ".fwisd.org": ["Fort Worth Independent School District"],
    ".fwparker.org": ["Francis W. Parker School of Chicago"],
    ".gannacademy.org": [
        "Gann Academy",
        "New Jewish High School of Greater Boston",
    ],
    ".garnetvalley.org": ["Garnet Valley School District"],
    ".gbwl.org": ["The Birch Wathen Lenox School"],
    ".gcccharters.org": ["Gateway Community Charters"],
    ".gcelabschool.org": ["GCE Lab School"],
    ".gcpsk12.org": ["Gwinnett County Public Schools"],
    ".gdgu.org": [
        "gdgoenka university",
        "university url: http://www.gdgoenkauniversity.com/",
        "Course url : http://www.gdgoenkauniversity.com/schoolofengineering/,http://www.gdgoenkauniversity.com/schoolofengineering/programmes-eligibility/",
        "university url: http://www.gdgoenkauniversity.com/",
        "Course url : http://www.gdgoenkauniversity.com/schoolofengineering/,http://www.gdgoenkauniversity.com/schoolofengineering/programmes-eligibility/",
        "domain Proof : http://www.gdgoenkauniversity.com/iclass2018/conference-venue/",
    ],
    ".gds.org": ["Georgetown Day School"],
    ".gems-auenland.org": ["Gemeinschaftsschule Auenland"],
    ".geneva304.org": ["Geneva Community High School", ".group"],
    ".georgiacyber.org": ["Georgia Cyber Academy", "Georgia Cyber Academy"],
    ".germantownfriends.org": ["Germantown Friends School"],
    ".ges-coengg.org": [
        "Gokhale Education Society's R.H. Sapat College of Engineering, Management Studies & Research"
    ],
    ".gfacademy.org": ["Greens Farms Academy"],
    ".ggpi.org": [
        "Glazov pedagogical Institute",
        "ГЛАЗОВСКИЙ ГОСУДАРСТВЕННЫЙ ПЕДАГОГИЧЕСКИЙ ИНСТИТУТ ИМЕНИ В.Г.КОРОЛЕНКО",
        "http://www.ggpi.org/news.php",
    ],
    ".gh-is.org": ["YOUNITED - Givat Haviva International School"],
    ".dijaki.gimb.org": [
        "Gimnazija Bežigrad",
        "Bežigrad High School",
        "http://www.gimb.org/",
    ],
    ".gimvic.org": ["Gimnazija vič, Ljubljana, Slovenija"],
    ".gipplab.org": [
        "Scientific Information Analytics Group at University Göttingen"
    ],
    ".gissv.org": ["German International School of Silicon Valley"],
    ".gjust.org": ["GURU JAMBHESHWAR UNIVERSITY OF SCIENCE AND TECHNOLOGY"],
    ".glbajajgroup.org": ["GL Bajaj Group of Institutions, Mathura"],
    ".glenbard.org": ["Glenbard South High School"],
    ".glenbrook225.org": ["Glenbrook North High School "],
    ".glenrocknj.org": ["Glen Rock High School"],
    ".gltech.org": ["Greater Lowell Technical High School"],
    ".glynschool.org": ["Glyn School"],
    ".students.gmsdk12.org": [
        "Germantown Municipal School District",
        ".group",
    ],
    ".gncasc.org": [
        "Guru Nanak College of Arts, Science and Commerce",
        "Guru Nanak College of Arts, Science and Commerce",
        "Official Website: https://www.gncasc.org",
        "Long Term Course/Program offered by the college: ",
        "1. B.Sc. Information Technology - https://www.gncasc.org/programs/b-sc-information-technology",
        "2. M.Sc. Information Technology - https://www.gncasc.org/programs/m-sc-i-t",
    ],
    ".gniindia.org": ["Guru Nanak Institutions"],
    ".gocommodores.org": ["Lafayette Middle School"],
    ".goierrieskola.org": ["Goierri Eskola"],
    ".golapolytechnic.org": ["Gola Polytechnic School"],
    ".gosfordhillschool.org": ["Gosford hill school"],
    ".gouldacademy.org": ["Gould Academy"],
    ".gpranchi.org": ["Government Polytechnic Ranchi"],
    ".gpsne.org": ["Gretna Public Schools"],
    ".graniteschools.org": ["Granite School District"],
    ".granitesd.org": ["Granite School District (students)"],
    ".greenhill.org": ["Greenhill School"],
    ".greenhillsschool.org": ["Greenhills School"],
    ".greenwichacademy.org": ["Greenwich Academy"],
    ".greenwichschools.org": ["Greenwich High School"],
    ".grenoble-inp.org": ["Grenoble University of Technology"],
    ".mail.gretnadragons.org": ["Gretna Public Schools"],
    ".groupe-esigelec.org": [
        "École supérieure d'ingénieurs en génie électrique",
        "Graduate School of Engineering",
    ],
    ".students.grps.org": ["Grand Rapids Public Schools"],
    ".gsastl.org": ["Gateway Science Academy of St Louis"],
    ".gsdwi.org": ["Germantown High School"],
    ".gtzfonet.org": [
        "המקיף הדרוזי אחווה ירכא",
        "The Druze friendship high school",
    ],
    ".student.guhsdaz.org": [
        "Thunderbird High School",
        "Glendale Union High School District",
        ".group",
    ],
    ".guhsdaz.org": ["Glendale Union High School District"],
    ".gujaratvidyapith.org": ["GUJARAT VIDYAPITH AHEMDABAD"],
    ".gunston.org": ["The Gunston School"],
    ".student.gvsd.org": ["Great Valley Middle School"],
    ".gvvit.org": [
        "GRANDHI VARALAKSHMI VENKATA RAO INSTITUTE OF TECHNOLOGY",
        "GRANDHI VARALAKSHMI VENKATA RAO INSTITUTE OF TECHNOLOGY",
    ],
    ".gw-hs.org": ["Great Wyrley High School"],
    ".gymkro.org": ["Gymnasium Kronshangen"],
    ".gymnasium-melle.org": ["Gymnasium Melle"],
    ".haashall.org": ["Haas Hall Academy"],
    ".hacollege.org": ["Haridas Achratlal College of Commerce"],
    ".haklaiph.org": [
        "בית ספר חקלאי פרדס חנה",
        "Pardes Hanna Agricultural High School",
    ],
    ".hanovernorwichschools.org": ["Dresden School District"],
    ".harker.org": ["The Harker School"],
    ".student.harmonytx.org": ["Harmony School of Advancement"],
    ".students.harrisonschools.org": ["Harrison High School"],
    ".my.hartdistrict.org": [
        "William S. Hart Union High School District",
        "Hart District",
        "William S. Hart District",
        ".group",
    ],
    ".hartselletigers.org": [
        "Hartselle High School",
        "Hartselle Junior High School",
        ".group",
    ],
    ".hatboro-horsham.org": ["Hatboro-Horsham School District"],
    ".haverford.org": ["The Haverford School for Boys"],
    ".hawbridgeschool.org": ["Hawbridge School - Teacher Email"],
    ".hawbridgeschoolstudent.org": ["Hawbridge School - Student Emails"],
    ".hawlermu.org": ["Hawler Medical University"],
    ".hazelwick.org": ["Hazelwick School"],
    ".hazlet.org": ["Raritan High School"],
    ".student.hccts.org": [
        "Highlands Community Charter and Technical Schools",
        "Highlands Community Charter and Technical Schools",
    ],
    ".hcdsb.org": ["Halton Catholic School Board"],
    ".hcesonepat.org": [
        "Hindu college of engineering ",
        "Hindu college of engineering",
    ],
    ".hcisd.org": ["Harlingen High School South"],
    ".student.hcps.org": ["Harford County Public Schools"],
    ".inst.hcpss.org": ["Howard County Public School System", ".group"],
    ".hcpss.org": ["Howard County Public School System", ".group"],
    ".hcrhs.org": ["Hunterdon Central Regional High School"],
    ".hdch.org": [
        "Hamilton District Christian High",
        "Hamilton District Christian High",
    ],
    ".hdschools.org": ["HD Shanghai Bilingual School "],
    ".hdsd.org": [
        "Hillsboro - Deering High School",
        "We are a small 9-12 school in western NH, US.  We offer AP/ college CS courses as well as a developing FRC Robotics team. ",
        "Our school website is...",
        "http://hdhs.hdsd.org/pages/Hillsboro-Deering_High_School",
        "Most of our CS classrooms communicate through Google Classroom.",
        "Our frc website (it is in its infancy) is...",
        "https://sites.google.com/hdsd.org/oscats/home ",
    ],
    ".headroyce.org": ["Head Royce School"],
    ".hedmark.org": ["Hamar Katedralskole"],
    ".heilwig-gymnasium.org": ["Heilwig-Gymnasium"],
    ".henricostudents.org": ["Henrico County Public Schools, Virginia"],
    ".hermits.org": ["St. Augustine Preparatory School"],
    ".hertie-school.org": ["Hertie School of Governance"],
    ".heschel.org": ["Abraham Joshua Heschel School"],
    ".hg47.org": ["Харьковская гімназія № 47", " Kharkiv gymnasium № 47"],
    ".hgce.org": ["Hasmukh Goswami College of Engineering"],
    ".hhschools.org": ["Hasbrouck Heights HS/MS"],
    ".hickmank12.org": ["East Hickman High School"],
    ".highlandsschool.org": ["Highlands School"],
    ".hillers.org": ["Hopkinton high school"],
    ".hillsidek12.org": ["Hillside Public Schools"],
    ".hitam.org": ["Hyderabad Institute of Technology And Management"],
    ".hmhn.org": ["Hackensack-Meridian School of Medicine", "HMSOM"],
    ".hmstudents.org": ["Hill Murray"],
    ".hockaday.org": ["The Hockaday School", "The Hockaay School for Girls"],
    ".learn.hohschools.org": [
        "Hastings-on-Hudson Union Free School District",
        ".group",
    ],
    ".holahoboken.org": ["holahoboken.org"],
    ".holychild.org": ["Connelly School of the Holy Child"],
    ".holyghostprep.org": ["Holy Ghost Preparatory School"],
    ".holynames-sea.org": ["Holy Names Academy "],
    ".holyredeemerhs.org": ["Holy Redeemer High School"],
    ".hopeccs.org": ["Hope Chinese Charter School"],
    ".hopedaleschools.org": ["Hopedale Jr. Sr. High School"],
    ".horacemann.org": ["Horace Mann High School"],
    ".horizonclc.org": ["Horizon Community Learning Center"],
    ".horizoncolumbus.org": ["Horizon Science Academy Columbus High School"],
    ".houstonisd.org": ["Houston Independent School District", ".group"],
    ".stu.hpisd.org": ["Highland Park ISD"],
    ".hpisd.org": ["Highland Park High School"],
    ".hprmail.org": ["High Point Regional High School"],
    ".hspu.org": [
        "Российский государственный педагогический университет им. А. И. Герцена",
        "The Herzen State Pedagogical University of Russia",
    ],
    ".hsrw.org": ["Hochschule Rhein-Waal"],
    ".hunschool.org": ["The Hun School of Princeton"],
    ".hunterschools.org": ["Hunter College Campus School"],
    ".huttoisd.org": ["Hutto Middle School"],
    ".hvs.org": [
        "Huron Valley Schools",
        "Harbor High School",
        "International Academy",
        "Lakeland High School",
        "Milford High School",
        ".group",
    ],
    ".iaisiege.org": [
        "Institut Africain d'Informatique (IAI-SIEGE), Libreville, Gabon"
    ],
    ".sw.iatseg.org": [
        "ElSewedy International Applied Technology and Software School",
        "ElSewedy International Applied Technology and Software School",
    ],
    ".ibsindia.org": ["ICFAI Business School, India"],
    ".ichsstudent.org": ["InTech Collegiate High School"],
    ".icstudents.org": ["Iowa City West High School"],
    ".ictuniversity.org": ["ICT UNIVERSITY", "ICT UNIVERSITY"],
    ".ideaventionsacademy.org": ["Ideaventions Academy"],
    ".ies1xabia.org": ["IES Número 1 – Xàbia"],
    ".iesabastos.org": [
        "Institut d'Educació Secundaria i FP Abastos",
        "iesabastos",
    ],
    ".iesalandalus.org": ["IES Al-Andalus", "IES Al-Andalus Almería, Spain"],
    ".iescelia.org": ["IES Celia Viñas"],
    ".iesch.org": ["ies segundo de chomon"],
    ".ieschabas.org": ["IES Historiador Chabas "],
    ".iesdonana.org": ["IES Doñana (Sanlúcar de Barrameda, Cádiz, Spain)"],
    ".ieselcaminas.org": ["Spanish graduate institute of IES El Caminas"],
    ".ieselescorial.org": ["IES El Escorial", "El Escorial High School"],
    ".iesevalorpego.org": ["IES Enric Valor - Pego"],
    ".iesfbmoll.org": ["IES Francesc de Borja Moll"],
    ".iesgrancapitan.org": [
        "IES Gran Capitán (Córdoba, Spain)",
        "https://www.iesgrancapitan.org/",
        "https://informatica.iesgrancapitan.org/",
    ],
    ".ieshnosmachado.org": ["IES Hermanos Machado"],
    ".iesitacaalcorcon.org": ["I.E.S Ítaca, Alcorcón, Madrid."],
    ".iesjoandaustria.org": [
        "Institut Joan d'Austria",
        "Institut Joan d'Austria",
    ],
    ".iesjoanramis.org": ["IES Joan Ramis i Ramis"],
    ".iesllucmajor.org": ["IES Llucmajor"],
    ".ieslluissimarro.org": [
        "IES Dr. Lluis Simarro",
        "High School Dr. Lluis Simarro",
        "ieslluissimarro.org",
    ],
    ".iesmarquesdecomares.org": ["ies marques de comares "],
    ".iesmiralcamp.org": ["IES MIRALCAMP"],
    ".iesmontsia.org": ["institut montsia"],
    ".iespoblenou.org": ["Institut Poblenou"],
    ".iespoligonosur.org": ["IES Polígono Sur", "Polígono Sur College"],
    ".iesportada.org": ["IES Portada Alta", "IES Portada Alta Málaga, Spain"],
    ".iessampedro.org": ["I.E.S. José Luis Sampedro"],
    ".ieszaidinvergeles.org": ["I.E.S Zaidín-Vergeles"],
    ".ifheindia.org": ["Icfai Foundation For Higher Education(IFHE)"],
    ".ifnti.org": [
        "Institut de Formation Aux Normes et Technologies de l'Informatique (IFNTI)"
    ],
    ".students.ignatius.org": ["Saint Ignatius College Prep"],
    ".ihmc.org": ["Institute for Human & Machine Cognition"],
    ".ihsdubai.org": [
        "The Indian High School, Dubai",
        "The Indian High School, Dubai",
    ],
    ".iiitb.org": [
        "International Institute of Information Technology, Bangalore"
    ],
    ".iisbianchi.org": ["IIS Mosè Bianchi - Monza"],
    ".iitbombay.org": ["Indian Institute of Technology Bombay"],
    ".imdea.org": ["Instituto IMDEA", "IMDEA Institute"],
    ".imitsuriname.org": [
        "IMIT SURINAME",
        "IMIT SURINAME",
        "Institute of Management and Information Technology",
        "https://imitsuriname.org",
        "https://imitsuriname.org/wp-content/uploads/2025/06/FACTSHEET-BIM-2025-1.6.25-NLF.pdf",
    ],
    ".imsp-uac.org": [
        "Institut de Mathématiques et de Sciences Physique",
        "Institute of Mathematics and Physical Sciences",
    ],
    ".imt-atlantique.org": [
        "IMT Atlantique Bretagne-Pays de la Loire École Mines-Télécom"
    ],
    ".imt-nord-europe.org": [
        "IMT Nord Europe",
        "Institut Mines-Télécom Nord Europe",
    ],
    ".incoslapaz.org": ["INCOS La Paz"],
    ".infai.org": [
        "Institut für Angewandte Informatik e.V. an der Universität Leipzig"
    ],
    ".students.inghamisd.org": ["Ingham Intermediate School District"],
    ".inghamisd.org": ["Ingham Intermediate School District"],
    ".iniad.org": ["Toyo University INIAD"],
    ".innovationcharter.org": ["Innovation Acadamy Charter School"],
    ".insa-lyon.org": ["Institut National des Sciences Appliquées de Lyon"],
    ".insideranken.org": ["Ranken Technical College"],
    ".institutoserpis.org": ["Instituto de Educación Secundaria Serpis"],
    ".institutsaintjean.org": ["Institut Saint Jean"],
    ".intechchs.org": ["InTech Collegiate High School"],
    ".interlakes.org": ["Interlakes High School"],
    ".interlochen.org": ["Interlochen Arts Academy"],
    ".internationaluniversity-schoolofmedicine.org": [
        "International University School of Medicine (IUSOM)"
    ],
    ".invenio.org": ["Universidad Invenio"],
    ".invertis.org": [
        "Invertis University, Bareilly",
        "Website: https://www.invertisuniversity.ac.in/",
        "https://www.invertisuniversity.ac.in/courses/btech-computer-science-engineering-/9/",
    ],
    ".invictushigh.org": ["Invictus High School"],
    ".ipeindia.org": [
        "Institute Of Public Enterprise",
        "Website: http://www.ipeindia.org",
        "student emails at @ipeindia.org for example 1301007@ipeindia.org",
    ],
    ".ipiaget.org": ["Instituto Piaget"],
    ".ipsacademy.org": ["IPS Academy, Indore"],
    ".ipsd.org": ["Indian Prarie School District 204", "ipsd.org"],
    ".iqraeducation.org": ["IQRA ENGLISH MEDIUM HIGH SCHOOL"],
    ".irvingtonschools.org": [
        "Irvington Union-Free School District",
        "Irvington Union-Free School District",
    ],
    ".iscom.org": ["ISCOM Lyon"],
    ".isd110.org": ["Waconia Public Schools"],
    ".isd112.org": ["Independent School District 112"],
    ".isd181.org": ["Independent School District 181"],
    ".isd194.org": [
        "Independent School District 194",
        "Lakeville North High School",
        "Lakeville South High School",
        "Kenwood Trail Middle School",
        "Miguire Middle School",
        "Century Middle School",
    ],
    ".isd273.org": ["Edina Schools"],
    ".isd361.org": ["Falls High School"],
    ".isd535.org": ["Century High School"],
    ".isefac.org": [
        "Ecole ISEFAC de Bac à Bac+5",
        "website : http://isefac.org",
    ],
    ".isfce.org": ["Institut Supérieur de Formation Continue d'Etterbeek"],
    ".ishahomeschool.org": ["Isha Home School"],
    ".isismattei.org": ["ISIS E MATTEI"],
    ".islahonline.org": ["Al-Islah University"],
    ".islqatar.org": ["islqatar", "International School of London Qatar"],
    ".ismanila.org": ["International School Manila", "ISM"],
    ".isneu.org": [
        "Trường Đại học Kinh tế Quốc dân",
        "National Economics University",
    ],
    ".iss-lubumbashi.org": ["Institut Supérieur de Statistique de Lubumbashi"],
    ".istemghs.org": ["iSTEM Early College High School"],
    ".isticbc.org": [
        "Institut Supérieur des Technologies de l'Information et de la Communication",
        "The Higher Institute of Information Technologies and Communication",
    ],
    ".istitutodionigiscano.org": ['IIS "Dionigi Scano - Ottone Bacaredda"'],
    ".istitutomarangoni.org": ["Istituto Marangoni", "Marangoni Institute"],
    ".isyedu.org": ["International School Yangon"],
    ".itiangioy.org": [
        "ITI G.M. Angioy sassari",
        "industrial Technical Institute G.M. Angioy of Sassari",
    ],
    ".itlearning-campus.org": ["IT LEARNING ACADEMY, AKA ENSIT Tanger"],
    ".itlearning-settat.org": [
        "IT Learning Campus Pole Ingénierie Systèmes, Réseaux, Sécurité et Management"
    ],
    ".itstep.org": ["IT Academy Step"],
    ".ittterni.org": ['Istituto Tecnico Tecnologico "Allievi-Sangallo"'],
    ".iu-study.org": ["Internationale Hochschule Bad Honnef Bonn GmbH"],
    ".iu.org": [
        "IU Internationale Hochschule",
        "IU International University of Applied Science",
    ],
    ".iuget.org": ["INSTITUT UNIVERSITAIRE DES GRANDES ECOLES DES TROPIQUES "],
    ".iusd.org": ["Irvine Unified School District", "IUSD"],
    ".ivesheadschool.org": ["Iveshead School"],
    ".jamesirwin.org": ["James Irwin Charter Schools"],
    ".jankollar.org": [
        "Gymnázium Jána Kollára so žiackym domovom v Báčskom Petrovci",
        "Jan Kollar Gymnasium with a student dormitory in Bački Petrovac",
    ],
    ".jarrellisd.org": ["Jarrell High School"],
    ".jburroughs.org": ["John Burroughs School"],
    ".jcpsnj.org": ["McNair Academic High School"],
    ".jec-jabalpur.org": ["Jabalpur Engineering College"],
    ".jeffcopublicschools.org": ["Jefferson County Public Schools"],
    ".jefftwp.org": [
        "Jefferson Township Public Schools",
        "Jefferson Township Public Schools",
    ],
    ".jenaplangymnasium.org": ["Jenaplan Gymnasium Nürnberg"],
    ".jeppiaarcollege.org": ["Jeppiar Engineering College"],
    ".jeppiaarinstitute.org": ["Jeppiaar Institute of Technology"],
    ".jerichoapps.org": ["Jericho High School"],
    ".jesuitmail.org": [
        "Jesuit High School",
        "Url:  https://www.jesuitportland.org/",
        "IT course: https://www.jesuitportland.org/academics/academics-new-2019-clone/academics-new-2019-mathdepartment",
    ],
    ".jgvaldemora.org": ["IES Juan García Valdemora"],
    ".jhncc.org": ["John Henry Newman Catholic College"],
    ".jimsgn.org": ["JIMSEMTC"],
    ".jimsindia.org": ["Jagan Institute of Management Studies"],
    ".jisiasr.org": ["JIS INSTITUTE OF ADVANCED STUDIES AND RESEARCH"],
    ".jmieti.org": [
        "Jai Parkash Mukand Lal Innovative Institue of Engineering",
        "Radur, INDIA",
    ],
    ".jmlschool.org": ["Jasudben M L school, Mumbai, India"],
    ".johnadamsacademy.org": ["John Adams Academy Roseville"],
    ".jordandistrict.org": ["Jordan School District, UT, the U.S."],
    ".jpgacademy.org": ["John Paul the Great Academy"],
    ".jpsstudents.org": ["Jenison Public Senior High"],
    ".jrischools.org": ["The Victor School"],
    ".js-student.org": [
        "Justin-Siena High School",
        "Justin-Siena High School",
    ],
    ".jsd117.org": [
        "Jacksonville School District 117 (Website: https://jsd117.org/)"
    ],
    ".k12albemarle.org": ["Albemarle High School"],
    ".k12louisa.org": ["Louisa County Public Schools"],
    ".students.katyisd.org": [
        "Katy ISD School Board",
        "Katy Independent School District",
    ],
    ".kauffmanschool.org": ["Ewing Marion Kauffman School"],
    ".kbtcoe.org": [
        "MVP Karmaveer Adv. Baburao Ganpatrao Thakare College of Engineering KBTCOE, Nashik, Maharashtra",
        "MVP Karmaveer Adv. Baburao Ganpatrao Thakare College of Engineering KBTCOE, Nashik, Maharashtra",
    ],
    ".kcd.org": ["Kentucky Country Day School"],
    ".kcpupils.org": [
        "King's College Schools",
        "kingscollegeschools.org",
        ".group",
    ],
    ".kearsarge.org": ["Kearsarge Regional High School"],
    ".kentdenver.org": ["Kent Denver School"],
    ".kernhigh.org": ["Kern High School District"],
    ".kesw.org": ["King Edward's School Witley"],
    ".chb.kevibham.org": ["King Edward VI Camp Hill School for Boys"],
    ".kew.org": ["Kew Royal Botanic Gardens", "Kew Royal Botanic Gardens"],
    ".khazar.org": ["Khazar University"],
    ".kingsolomonschool.org": ["King Solomon School"],
    ".kinkaid.org": ["The Kinkaid School"],
    ".kirtlandhornet.org": ["Kirtland High School"],
    ".kjit.org": [
        "K.J. Institute of Engineering and Technology- savli, vadodara"
    ],
    ".klschools.org": ["Katonah Lewisboro School District"],
    ".knoxschools.org": ["Knox County Schools"],
    ".koyauniversity.org": ["Koya University"],
    ".ksd.org": ["Kennewick High School"],
    ".kua.org": ["Kimball Union Academy"],
    ".kuosat.org": ["Kyrgyzstan University of Science and Technology"],
    ".eleve.la-favorite.org": ["La Favorite"],
    ".la-pmn.org": [
        "La passerelle des métiers du numérique ",
        "The gateway to digital professions",
    ],
    ".laconiachristian.org": ["Laconia Christian Academy"],
    ".lakeflyers.org": ["Lake Local Schools"],
    ".lakeridgeacademy.org": ["Lake Ridge Academy"],
    ".lakesideschool.org": ["Lakeside School"],
    ".lamache.org": ["Sup'La Mache"],
    ".lancastercountryday.org": ["Lancaster Country Day School"],
    ".lancastermennonite.org": ["Lancaster Mennonite School"],
    ".landmarkschool.org": ["Landmark School"],
    ".laredoisd.org": ["Joseph W. Nixon High School"],
    ".lasalle-douala.org": [
        "Ecole Supérieure Technique La Salle - Douala",
        "Higher Technical Institute La Salle - Douala",
    ],
    ".lasalle84.org": ["La Salle Avignon"],
    ".student.lavelleprep.org": ["Lavelle Preparatory Charter School"],
    ".lavelleprep.org": ["John W. Lavelle Preparatory Charter School"],
    ".lawnmanor.org": ["Lawn Manor Academy"],
    ".lawrenceville.org": ["The Lawrenceville School"],
    ".lc-ps.org": [
        "Frederick V. Pankow Center",
        "L'Anse Creuse High School",
        "L'Anse Creuse High School North",
    ],
    ".lcamn.org": ["Legacy Christian Academy"],
    ".lccsnj.org": [
        "Learning Community Charter School",
        "Learning Community Charter School",
    ],
    ".students.lcisd.org": ["George Ranch High School"],
    ".lcucauquenes.org": ["Liceo Claudina Urrutia de Lavín"],
    ".leanderisd.org": ["Leander Independent School District"],
    ".learnatwren.org": ["Wren Academy"],
    ".learningplanetinstitute.org": [
        "Learning planet institute",
        "Learning planet institute",
    ],
    ".student.leffellschool.org": ["The Leffell School"],
    ".lemanmanhattan.org": ["Leman Manhattan Preparatory School"],
    ".lendi.org": ["Lendi Institute of Engineering and Technology"],
    ".leominsterschools.org": ["Leominster Public Schools"],
    ".lerebours.org": ["Lycée Le Rebours"],
    ".lewiscentral.org": ["Lewis Central"],
    ".365.lexca.org": ["Lexington Christian Academy"],
    ".lexingtonma.org": ["Lexington Public Schools"],
    ".students.lfanet.org": ["Lake Forest Academy"],
    ".lgsstudent.org": ["Saratoga High School"],
    ".lhprep.org": ["Lake Highland Preparatory School"],
    ".lhps.org": ["Lake Highland Preparatory School"],
    ".libertyunion.org": ["Liberty Union-Thurston High School"],
    ".libopenuniv-edu.org": ["Libya Open University"],
    ".liebenzell.org": ["Internationale Hochschule Bad Liebenzell"],
    ".lighthousecoolbridge.org": ["Lighthouse Cool Bridge Academy"],
    ".lilburntamilschool.org": [
        "Lilburn Tamil School",
        "Lilburn Tamil School",
    ],
    ".limacityschools.org": ["Lima City Schools"],
    ".lincolncharter.org": ["Lincoln Charter"],
    ".lincolnps.org": ["Lincoln Public Schools"],
    ".lincolnschool.org": ["Lincoln School"],
    ".students.lindenps.org": [
        "Linden High School",
        "Linden Public Schools, NJ, US",
    ],
    ".student.linnmar.org": ["Linnmar High School"],
    ".lios.org": ["The Leadership Institute of Seattle"],
    ".lippe-berufskolleg.org": ["Lippe Berufskolleg "],
    ".lisd.org": ["Leander Independant School District"],
    ".littletonps.org": ["Littleton High School", "Littleton High School"],
    ".ljcds.org": ["La Jolla Country Day School"],
    ".llanoisd.org": ["Llano Independent School District", ".group"],
    ".llwarriors.org": ["Lincoln Lutheran High School"],
    ".lmghs.org": ["Leon M. Goldstein H.S."],
    ".lmsd.org": ["Lower Merion School Discrict"],
    ".lmusd.org": ["Arroyo Grande High School"],
    ".locustvalleyschools.org": ["Locust Valley High school/Middle school"],
    ".loganschools.org": ["Logan High School"],
    ".stu.lok12.org": ["Lake Orion High School"],
    ".longtrailschool.org": ["Long Trail School"],
    ".loomis.org": ["Loomis Chaffee"],
    ".lordwandsworth.org": ["Lord Wandsworth College"],
    ".lposd.org": ["Sandpoint Middle School"],
    ".lpsk12.org": ["Arapahoe High School", "Arapahoe High School"],
    ".lrei.org": ["Elizabeth Irwin High School"],
    ".students.lrsd.org": ["Little Rock School District"],
    ".lrsd.org": ["Little Rock School District"],
    ".lrstudents.org": ["Lenape Regional High School District"],
    ".lschs.org": ["La Salle College High School"],
    ".lsf.org": [
        "Loughborough Schools Foundation, Loughborough, UK",
        "Loughborough Grammar School, Loughborough, UK",
        "Loughborough High School, Loughborough, UK",
        "Loughborough Amherst School, Loughborough, UK",
        "Fairfield Preparatory Schoo, Loughborough UK",
        ".group",
    ],
    ".lshigh.org": ["La Salle Catholic College Prepratory"],
    ".lslancers.org": ["Lutheran High School South"],
    ".lsrhs.org": ["Lincoln-Sudbury Regional High School"],
    ".lubbockisd.org": ["Lubbock High School", "Lubbock High School"],
    ".lusherschool.org": ["Lusher Charter School"],
    ".lvjusd.org": ["Livermore Highschool"],
    ".student.lvusd.org": ["Las Virgenes Unified School District"],
    ".lw210.org": ["Lincoln Way Community High School District 210"],
    ".tesla.lwsd.org": ["Tesla Stem High School, Washington, USA"],
    ".lwsd.org": ["Lake Washington School District"],
    ".lwshanghai.org": ["上海闵行区美高教育培训学校", "Living Word Shanghai"],
    ".lyceelyautey.org": ["Lycée Lyautey de Casablanca"],
    ".lyceemermozdakar.org": [
        "Lycée Français Jean Mermoz Dakar",
        "URL : https://www.lyceemermozdakar.org/",
    ],
    ".lyceenoaillesevian.org": ["Lycée Anna De Noailles"],
    ".lyceexavierseoul.org": [
        "Xavier International School in Seoul, South KOREA"
    ],
    ".lynnschools.org": ["Lynn Classical High School"],
    ".lz95.org": ["Lake Zurich Community District"],
    ".macintyreacademies.org": ["MacIntyre Academies"],
    ".madeira.org": ["The Madeira School"],
    ".madeiracityschools.org": ["Madeira City Schools"],
    ".educa.madrid.org": [
        "Consejería de Educación, Juventud y Deporte de la Comunidad de Madrid",
        "Counsel of Education, Youth and Sports of the Community of Madrid",
        "Portal: https://correoweb.educa.madrid.org/login.php",
    ],
    ".maldenps.org": ["Malden High School"],
    ".maltingsacademy.org": ["Maltings Academy"],
    ".maltonschool.org": ["Malton Secondary School"],
    ".marchwoodseniorschool.org": [
        "Marchwood Senior School",
        "Marchwood Senior School",
    ],
    ".mariancollege.org": [" Marian College Kuttikkanam (Autonomous)"],
    ".marista-carcavelos.org": [
        "Colegio Marista de Carcavelos",
        "Marist School of Carcavelos",
    ],
    ".marlboroughcollege.org": ["Marlborough College"],
    ".marsd.org": ["Matawan Regional High School"],
    ".marsk12.org": ["Mars Area School District, Mars, PA, U.S."],
    ".maruapula.org": ["Maru-a-Pula School, Gaborone"],
    ".marymathacollege.org": [
        "Mary Matha Arts & Science College, Mananthavady"
    ],
    ".mathfineco.org": [
        "Institut Universitaire MathFinEco",
        "MathFinEco University Institute",
    ],
    ".student.mauryk12.org": ["Spring Hill High School"],
    ".mayatanfoundation.org": ["Mayatan Bilingual School"],
    ".mbway.org": ["École MBway", "MBway"],
    ".mccallie.org": ["McCallie School"],
    ".mcdonogh.org": ["McDonogh School", "McDonogh "],
    ".mcps.org": [
        "Blacksburg Middle School (Montgomery County Public Schools)"
    ],
    ".mcqstudent.org": ["McQuaid Jesuit"],
    ".mcquaid.org": ["McQuaid Jesuit"],
    ".mcsoxford.org": ["Magdalen College School, Oxford"],
    ".mcusd709.org": ["Morton Unit School District 709"],
    ".mcvts.org": [
        "Morris County Vocational School of Technology",
        "MCST",
        "MCVTS",
        "MCVSD",
        "Morris County School of Technology",
        "Morris County Vocational School District",
    ],
    ".mdanderson.org": ["University of Texas MD Anderson Cancer Center"],
    ".mdusd.org": ["Northgate High School"],
    ".medinabees.org": ["Medina High School"],
    ".meltwater.org": [
        "Meltwater Entrepreneurial School of Technology (MEST)"
    ],
    ".memphisk12.org": ["Memphis Junior/Senior High School"],
    ".menloschool.org": ["Menlo School"],
    ".mesaschool.org": ["Mesa Union School"],
    ".metuchenschools.org": [
        "Metuchen High School",
        "https://metuchenschools.org/",
    ],
    ".mfriends.org": ["Moorestown Friends School"],
    ".students.mggs.org": ["Maidstone Grammar School for Girls", "MGGS"],
    ".mgs.org": ["The Manchester Grammar School"],
    ".mhrd.org": [
        "The Academy for Mathematics Science and Engineering at Morris Hills High School"
    ],
    ".mhusd.org": ["Morgan Hill Unified School District", ".group"],
    ".mibdu.org": [
        "MBA - International Business Delhi University",
        "MBA - International Business Delhi University",
    ],
    ".michaelhouse.org": ["Michaelhouse school, South Africa"],
    ".middletownusd.org": ["Middletown High School"],
    ".midlandps.org": ["H.H Dow High School"],
    ".milkenschool.org": ["Milken Community Schools"],
    ".millardps.org": ["Millard North Middle School"],
    ".millaschool.org": ["Pacific Crest Innovation Academy"],
    ".millasd.org": ["Pacific Crest Innovation Academy"],
    ".millburn.org": ["Millburn High School"],
    ".miltonps.org": ["Milton High School, Massachusetts "],
    ".mines-ales.org": ["Ecole des Mines d'Ales"],
    ".mines-douai.org": ["Ecole des Mines de Douai"],
    ".mines-nancy.org": ["École Nationale Supérieure des Mines de Nancy"],
    ".mines-saint-etienne.org": ["Ecole des Mines de Saint-Etienne"],
    ".misd400.org": ["Mercer Island School District"],
    ".missionacademy.org": ["Mission Academy Mesilla Valley"],
    ".mitmuzaffarpur.org": [
        "Muzaffarpur Institute of Technology, Muzaffarpur"
    ],
    ".miu.org": [
        "Maharishi International University",
        "Maharishi International University",
    ],
    ".mjbha.org": ["Berman Hebrew Academy"],
    ".mka.org": ["Montclair Kimberley Academy"],
    ".mkuniversity.org": ["Madurai Kamaraj University"],
    ".mlschools.org": ["Mountain Lakes High School"],
    ".mmumullana.org": ["Maharishi Markandeshwar (Deemed to be University)"],
    ".mmuusd.org": ["Mount Mansfield Union High School"],
    ".moberlyspartans.org": ["Moberly High School"],
    ".monroeps.org": ["Monroe Public Schools"],
    ".moorheadschools.org": ["Moorhead High School"],
    ".moreland.org": ["Moreland School District"],
    ".morgank12.org": ["Danville High School"],
    ".morganparkacademy.org": ["Morgan Park Academy"],
    ".morrishs.org": [
        "Morris Community High School",
        "Morris Community High School",
    ],
    ".motsd.org": ["Mount Olive High School"],
    ".motthallcs.org": ["Mott Hall Charter School"],
    ".moundsviewschools.org": ["Irondale High School"],
    ".mountainheightsacademy.org": ["Mountain Heights Academy"],
    ".mountvernonschool.org": ["The Mount Vernon School"],
    ".mpi-sws.org": ["Max Planck Institute for Software Systems (MPI-SWS)"],
    ".students.mpsaz.org": ["Mesa Public Schools District"],
    ".mpspride.org": ["Manchester CT, Public Schools"],
    ".mrc-academy.org": ["Midhurst Rother College", "Midhurst Rother College"],
    ".mrsdmail.org": ["Masconomet Regional High School"],
    ".ms447.org": [
        "The Math and Science Exploratory School ",
        "345 Dean St, Brooklyn, NY, NY, US 11217",
    ],
    ".msad11.org": [
        "Maine School Administrative District 11",
        "Serving the communities of Gardiner, Pittston, Randolph and West Gardiner Maine,USA",
        "http://www.msad11.org/",
        "All schools in our district share the same offical email domain. Elementry, middle and high school",
    ],
    ".msad49.org": ["Maine School Administrative District # 49"],
    ".msi-ggsip.org": ["Maharaja Surajmal Institute"],
    ".mskcc.org": [
        "Sloan Kettering Institute of Memorial Sloan Kettering Cancer Center"
    ],
    ".mssm.org": [
        "Maine School of Science and Mathematics",
        "The Maine School of Science and Mathematics",
    ],
    ".mtka.org": ["Minnetonka High School"],
    ".mtsm.org": ["Athenaeum of Ohio"],
    ".mtvidyapeeth.org": [
        "Mother Teresa Vidyapeeth",
        "Mother Teresa Vidyapeeth, Muzaffarpur",
    ],
    ".mursd.org": ["Nipmuc Regional High School"],
    ".students.mvcs.org": ["Monte Vista Christian School"],
    ".mvsd21.org": ["Marsh Valley High School"],
    ".mwschool.org": ["Meridian School"],
    ".my-digital-school.org": ["MyDigitalSchool"],
    ".mycommodores.org": ["Perry Local School District"],
    ".mycva.org": ["Columbia Virtual Academy"],
    ".mycw.org": ["Collingwood School, Morven Campus"],
    ".mydnschools.org": [
        "Del Norte County Unified School District - Student Accounts",
        "Del Norte Unified School District - Student Accounts",
    ],
    ".mydusd.org": ["Dublin High School"],
    ".myimmaculatehs.org": ["Immaculate High School"],
    ".mykolbe.org": ["Kolbe Academy"],
    ".mynbps.org": ["North Broward Prepatory School"],
    ".mysandstorm.org": ["Sandringham School"],
    ".mysbisd.org": ["Spring Branch ISD", ".group"],
    ".mysummitps.org": ["Summit Public Schools"],
    ".mytusd.org": ["Foothill High School"],
    ".myunit5.org": ["Normal Community High School"],
    ".nandhaengg.org": ["Nandha Engineering College Erode"],
    ".stu.naperville203.org": ["Naperville Central High School"],
    ".nasdstudents.org": [
        "Nazareth Area High School",
        "Nazareth Area High School",
    ],
    ".students.natickps.org": ["Natick High School"],
    ".stu.nbexcellence.org": [
        "New Berlin Eisenhower Middle/High School",
        "New Berlin Eisenhower High School",
        "New Berlin Eisenhower Middle School",
        "New Berlin Eisenhower",
        "Eisenhower",
        ".group",
    ],
    ".nbexcellence.org": [
        "New Berlin Eisenhower Middle/High School",
        "New Berlin Eisenhower High School",
        "New Berlin Eisenhower Middle School",
        "New Berlin Eisenhower",
        "Eisenhower",
        ".group",
    ],
    ".nbkrist.org": ["N.B.K.R. Institute Of Science & Technology"],
    ".nbnet.org": ['СУ"НЕШО БОНЧЕВ"'],
    ".nbps.org": ["North Broward Prepatory School"],
    ".ncclschool.org": ["Newark Center for Creative Learning", "NCCL School"],
    ".nccsk12.org": ["Shaker Middle/High School"],
    ".ncps-k12.org": ["New Canaan Public Schools"],
    ".ndfrance.org": ["Lycee Notre Dame de France"],
    ".ndpma.org": ["Notre Dame Preparatory School and Marist Academy"],
    ".ndsj.org": ["Notre Dame High School San Jose"],
    ".neevacademy.org": ["Neev Academy"],
    ".nehrucolleges.org": [
        "Nehru institute of engineering and technology",
        "Nehru institute of engineering and technology",
    ],
    ".nerinxhs.org": ["Nerinx Hall High School"],
    ".neskt.org": ["New English School "],
    ".netherhall.org": ["The Netherhall School"],
    ".newarkcityschools.org": ["Newark City Schools", "Newark City Schools"],
    ".newforestacademy.org": ["New Forest Academy"],
    ".newmanboston.org": ["The Newman School"],
    ".newmanstudents.org": ["The Newman School"],
    ".newtonsh.org": ["Newton Country Day School of the Sacred Heart"],
    ".nfsg-sofia.org": [
        "Национална финансово-стопанска гимназия",
        "National High School in Finance and Business",
    ],
    ".nhnnext.org": ["NHN NEXT"],
    ".nimsuniversity.org": [
        "NIMS UNIVERSITY, JAIPUR",
        "NIMS UNIVERSITY, JAIPUR",
    ],
    ".student.nisdtx.org": ["Northwest High School"],
    ".nkcschools.org": ["North Kansas City Schools"],
    ".nlpanthers.org": ["New Lexington High School"],
    ".nonsuchschool.org": ["Nonsuch High School For Girls"],
    ".nordakademie.org": [
        "NORDAKADEMIE Hochschule der Wirtschaft",
        "NORDAKADEMIE University of Applied Sciences",
    ],
    ".norfolkacademy.org": ["Norfolk Academy"],
    ".northcross.org": ["North Cross School"],
    ".northeastacademy.org": [
        "Northeast Academy for Aerospace and Advanced Technology"
    ],
    ".northoxfordshire-academy.org": [
        "North Oxfordshire Academy",
        "https://www.northoxfordshire-academy.org",
    ],
    ".northstarva.org": ["Northstar"],
    ".novaandradina.org": [
        "Federal Institute of Education, Science and Technology of South Mato Grosso - Nova Andradina Campus",
        "Instituto Federal de Educação, Ciência e Tecnologia de Mato Grosso do Sul - Câmpus Nova Andradina",
    ],
    ".stu.novik12.org": ["Novi High School"],
    ".npenn.org": ["North Penn School District"],
    ".npmg.org": ["National High School of Mathematics and Science"],
    ".nredlearn.org": ["New Rochelle High School"],
    ".nsbindia.org": ["National School of Business"],
    ".nscsd.org": ["North Syracuse Central Schools"],
    ".nsd.org": ["Northshore School District"],
    ".nsd131.org": ["Columbia High School", ".group"],
    ".nuast.org": [
        "Nottingham University Academy of Science and Technology",
        "NUAST",
    ],
    ".nuevaschool.org": ["The Nueva School"],
    ".students.nusd.org": ["San Marin High School"],
    ".nusdk12.org": ["Inderkum High School"],
    ".nutleyschools.org": ["Nutley Public School District"],
    ".nsp.nutmng.org": [
        "Nigerian University of Technology and Management (NUTM)"
    ],
    ".nycischool.org": ["NYC iSchool"],
    ".nyulangone.org": ["NYU Grossman School of Medicine"],
    ".students.oakwoodschool.org": ["Oakwood School, CA, US"],
    ".oasisarena.org": ["Oasis Academy Arena"],
    ".obps.org": ["Old Bridge Public Schools"],
    ".fp.oceanoatlantico.org": ["Océano Atlántico"],
    ".ocsi.org": ["Okinawa Christian School International"],
    ".ohva.org": ["Ohio Virtual Academy"],
    ".olatheschools.org": ["Olathe Public Schools USD 233"],
    ".oldrochester.org": ["Old Rochester Regional High School"],
    ".olgchs.org": ["Our Lady of Good Counsel High School"],
    ".omgau.org": ["Omsk State Agrarian University"],
    ".opgs.org": ["Oakwood Park Grammar School"],
    ".student.oprfhs.org": ["Oak Park and River Forest High School"],
    ".ops.org": ["Omaha Public Schools"],
    ".optima-osvita.org": ["Educational center Optima, Kiev, Ukraine"],
    ".orangecsd.org": ["Orange High School"],
    ".orangeusd.org": ["Orange Unified School District"],
    ".students.orchardview.org": ["Orchard View HighSchool"],
    ".oregoncs.org": ["Oregon City Schools", "  Located in Oregon, OH"],
    ".ousd.org": ["Oakland Unified School District (Oakland, California)"],
    ".overlake.org": ["The Overlake School"],
    ".ovidunivconstanta-edu.org": ["University of Constanta Medical School"],
    ".owis.org": ["One World International School"],
    ".apps.oxfordpublicschools.org": [
        "Oxford High School",
        "Oxford High School",
    ],
    ".oxfordspiresacademy.org": ["Oxford Spires Academy"],
    ".oxnardunion.org": ["Oxnard Union High School District", ".group"],
    ".paadultschool.org": ["Palo Alto Adult School", "Palo Alto Adult School"],
    ".pacificcoastacademy.org": ["Pacific Coast Academy"],
    ".pafa.org": ["Pennsylvania Academy of the Fine Arts"],
    ".paideiaschool.org": ["Paideia School"],
    ".paisd.org": ["Port Arthur Independent School District", ".group"],
    ".stu.palcsmail.org": ["Pennsylvania Leadership Charter School"],
    ".pchs.palihigh.org": ["Palisades Charter Highschool"],
    ".palisadessd.org": ["Palisades School District"],
    ".stu.palmbeachschools.org": ["Palm Beach Country School District"],
    ".palmbeachschools.org": ["Palm Beach School District"],
    ".parish.org": ["Parish Episcopal School"],
    ".parishepiscopal.org": ["Parish Episcopal School"],
    ".park6.org": ["Park County School District #6 (K-12)"],
    ".parmacityschools.org": ["Parma City School District"],
    ".pasadenaisd.org": ["Dobie High School"],
    ".pascack.org": [
        "Pascack Hills High School, Montvale NJ",
        "Pascack Valley High School, Hillsdale NJ",
        ".group",
    ],
    ".student.passerellesnumeriques.org": [
        "Passerelles Numeriques Vietnam",
        "Passerelles Numeriques Vietnam",
    ],
    ".patelhs.org": ["patel high school "],
    ".pathfinderstudents.org": ["Pathfinder Tech"],
    ".pathfindertech.org": [
        "Pathfinder Regional Vocational Technicial High School"
    ],
    ".pathwaysschools.org": [
        "Pathways in Education",
        "Nonprofit Public Schools",
        "Louisiana, United States",
        ".group",
    ],
    ".pausd.org": ["Palo Alto Adult school"],
    ".pawneeschools.org": ["Pawnee High School, Illinois"],
    ".pcastudentemail.org": ["Plymouth Christian Academy"],
    ".pccoepune.org": ["Pimpri Chinchwad College Of Engineering, Pune"],
    ".pcia.org": ["Pacific Crest Innovation Academy"],
    ".cat.pcsb.org": [
        "Center for Advanced Technologies at Lakewood High School"
    ],
    ".pcsb.org": ["Pinellas County School Board", ".group"],
    ".pcscharter.org": ["Pacific Collegiate School"],
    ".pdsb.org": ["Peel District School Board", ".group"],
    ".pearlandisd.org": ["Glenda Dawson High School"],
    ".peddie.org": ["Peddie School"],
    ".pennington.org": ["The Pennington School"],
    ".peponischool.org": ["Peponi School"],
    ".student.perryschools.org": ["Perry Meridian High School"],
    ".pgcps.org": ["Charles Herbert Flowers High School"],
    ".philasd.org": [
        "The School District of Philadelphia",
        "S.D.P.",
        "SDP",
        "Philadelphia School District",
        ".group",
    ],
    ".student.phoenixunion.org": ["Phoenix Union High School District"],
    ".piedmontschools.org": [
        "Piedmont Independent School District #22",
        "Piedmont Public Schools",
    ],
    ".piggottschool.org": ["The Piggott C of E School"],
    ".pinebushschools.org": ["Pine Bush HS"],
    ".pingree.org": ["Pingree School"],
    ".pingry.org": ["The Pingry School"],
    ".pionir.org": ["Слободна школа Пионир", "Pionir free school"],
    ".pisgahpats.org": ["Mount Pisgah Christian School"],
    ".plps-k12.org": [
        "Pompton Lakes High School",
        "Pompton Lakes High School",
    ],
    ".plsas.org": ["Prior Lake High School"],
    ".pmlrru.org": ["PML University"],
    ".students.pmsd.org": ["Pocono Mountain School District"],
    ".student.polandschools.org": [
        "Poland Seminary Junior/Senior High School, Poland, Ohio"
    ],
    ".polesworthstudents.org": ["The Polesworth School"],
    ".polyprep.org": ["Poly Prep Country Day School"],
    ".polytechnic-kabul.org": ["Polytechnical University of Kabul"],
    ".polytechnique.org": ["École polytechnique"],
    ".poornima.org": ["poornima"],
    ".popeprep.org": ["Pope John Paul II Preparatory School"],
    ".portnet.org": ["Paul D. Schreiber High School"],
    ".potomacschool.org": ["The Potomac School"],
    ".pottsboroisd.org": [
        "Pottsboro Independent School District",
        "Pottsboro Independent School District",
    ],
    ".prcak12.org": ["Pusch Ridge Christian academy"],
    ".priorysouthsea.org": ["Priory Southsea"],
    ".prospectschools.org": ["Brooklyn Prospect High School"],
    ".providenceday.org": [
        "Providence Day School",
        "Providence Day School, Charlotte NC",
        "Providence Day",
        "PDS",
    ],
    ".providencehighschool.org": ["Providence High School", "CA, USA"],
    ".prsd.org": [
        "Pentucket Regional High School",
        "Pentucket Regional High School",
    ],
    ".prsdnj.org": ["Pinelands Regional High School"],
    ".student.psdr3.org": ["Pattonville Highschool"],
    ".psdr3.org": ["Pattonville High School"],
    ".pt-sd.org": ["Peters Township School District"],
    ".pusdk12.org": ["Paradise High School", "Paradise High School"],
    ".puskino.org": ["Vilniaus Aleksandro Puškino gimnazija"],
    ".puyallupsd.org": ["Puyallup School District"],
    ".pvsd.org": ["Perkiomen Valley School District"],
    ".pwcs-edu.org": [
        "Patriot High School - Prince William County, VA USA",
        "https://patrioths.pwcs.edu/",
    ],
    ".qe.org": ["Queen Ethelburga's Collegiate"],
    ".qibaodwight.org": ["Shanghai Qibao Dwight High School"],
    ".malta.qsi.org": ["QSI Malta"],
    ".questar.org": [
        "Questar III BOCES",
        "Questar III",
        "Robert H Gibson Technical School",
        ".group",
    ],
    ".ransomeverglades.org": ["Ransom Everglades School"],
    ".student.rasg.org": ["Hebrew Academy Of Miami Beach"],
    ".rawsonsaunders.org": ["Rawson Saunders School"],
    ".rdale.org": ["Robbinsdale Area Schools"],
    ".redcad.org": [
        "Research Laboratory on Development and Control of Distributed Application",
        "teacher and student emails @redcad.org",
        "www.redcad.org",
    ],
    ".redlandschristian.org": [
        "Arrowhead Christian Academy",
        "Redlands Christian Schools",
    ],
    ".redmondschools.org": ["Ridgeview High School"],
    ".region16ct.org": [
        "Woodland Regional High School in Beacon Falls CT under the Regional School District # 16"
    ],
    ".regis.org": ["Regis High School", "Regis High School"],
    ".renaissanceschool.org": ["Renaissance School"],
    ".rhsfultonschools.org": ["Roswell High School"],
    ".riceindia.org": ["Adamas University"],
    ".richland2.org": ["Richland School District 2"],
    ".ridgelineacademy.org": ["Ridgeline Academy"],
    ".rightchoice.org": ["Community College of Denver"],
    ".risd.org": ["Richardson Independent School District"],
    ".riverdell.org": ["River Dell Regional School District"],
    ".riversideunified.org": ["Riverside Unified School District", ".group"],
    ".student.riverspringscharter.org": [
        "River Springs Charter School in Riverside - Pathfinder"
    ],
    ".rjit.org": [
        "Rustamji Institute of Technology",
        "Rustamji Institute of Technology",
    ],
    ".rkmshome.org": ["Ramakrishna Mission Polytechnic College"],
    ".rochester-college.org": ["Rochester Indepedent College, Rochester"],
    ".rochesterschools.org": [
        "Rochester Public Schools (teacher email)",
        ".group",
    ],
    ".stu.rockwallisd.org": ["Rockwall Heath High School"],
    ".roeper.org": ["The Roeper School"],
    ".roslynschools.org": ["Roslyn High School"],
    ".roundrockisd.org": ["Round Rock Indpenedent School District"],
    ".roxburylatin.org": ["The Roxbury Latin School"],
    ".rozascs.org": ["Colegio y Seminario de Rozas"],
    ".rpufsd.org": ["Rocky Point High School"],
    ".rr300.org": ["Rockridge High School"],
    ".rrce.org": ["Rajarajeswari College of Engineering"],
    ".rrcs.org": ["Rocky River High School"],
    ".rtnj.org": ["Randolph Middle School"],
    ".rumseyhall.org": ["Rumsey Hall School", "Rumsey Hall School"],
    ".rungta.org": ["Rungta College of Engineering and Technology"],
    ".rutgersprep.org": ["Rutgers Preparatory School"],
    ".rvcschools.org": ["South Side High School"],
    ".rvilleschools.org": ["Robbinsville High School", ".group"],
    ".ryecountryday.org": ["Rye Country Day School"],
    ".ryeschools.org": ["Rye High School"],
    ".rzjhs.org": ["Rochelle Zelle Jewish High School"],
    ".saddleriverday.org": ["Saddle River Day School"],
    ".sageintl.org": ["Sage International School of Boise"],
    ".sageschool.org": ["Sage School"],
    ".saintgits.org": [
        "Saintgits College of Engineering",
        "saintgits.org",
        "URL: http://saintgits.org/engineering-college",
    ],
    ".saintjo.org": ["Lycée Saint Joseph - Bressuire"],
    ".saintjosephregional.org": ["Saint Joseph Regional School"],
    ".saintpaulsrajkot.org": [
        "Saint Paul's School Rajkot",
        "Saint Paul's School Rajkot",
    ],
    ".saintstephens.org": ["Saint Stephen's Episcopal School"],
    ".saitm.org": ["St. Andrews Institute of Technology & Management"],
    ".salemkeizer.org": ["Salem Keizer School District"],
    ".sandbachschool.org": ["Sandbach School"],
    ".sandippolytechnic.org": ["Sandip polytechnic"],
    ".sanskrititheschool.org": ["Sanskriti The School"],
    ".sany.org": ["Science Academies of New York Charter Schools"],
    ".saratogausd.org": ["Redwood Middle School"],
    ".sasaustin.org": ["St. Andrew's Episcopal School - Austin, Texas"],
    ".saschina.org": ["Shanghai American School"],
    ".sau11.org": ["Dover High School"],
    ".sau16.org": ["Seacoast School of Technology"],
    ".sau26.org": ["Merrimack Highschool"],
    ".sau41.org": [
        "Hollis Brookline High School",
        "Program of Studies: https://resources.finalsite.net/images/v1676391125/sau41org/k7hzolkxforegdgnueqt/pos-24rev2-6-23.pdf",
        "Website: https://myhbhs.org",
    ],
    ".sau52.org": ["Portsmouth High School"],
    ".sau57.org": ["Salem High School"],
    ".saviochs.org": ["St. Dominic Savio High School"],
    ".sawstonvc.org": ["Sawston Village College"],
    ".sbcfamily.org": ["Roanoke Valley Christian Schools"],
    ".sboajc.org": [
        "SBOA School & Junior College",
        "SBOA School & Junior College",
    ],
    ".sbs.org": ["The Stony Brook School"],
    ".sbstudents.org": ["South Brunswick High School"],
    ".scarsdaleschools.org": [
        "Scarsdale High School",
        "Scarsdale High School",
    ],
    ".scattergood.org": ["Scattergood"],
    ".sccstudents.org": ["Juan Diego Catholic High School"],
    ".sch.org": ["Springside Chestnut Hill Academy"],
    ".student.schs.org": ["Grand Rapids South Christian High School"],
    ".scicu.org": ["Allen University", "Claflin College", "Morris College"],
    ".sciencescom.org": ["SciencesCom"],
    ".student.scit.org": ["Scituate High School, Scituate MA, USA"],
    ".scls-sh.org": ["上海宋庆龄学校", "Shanghai Soong Ching Ling School"],
    ".scmsgroup.org": ["SCMS School Of Technology and Management"],
    ".scsdb.org": ["South Carolina School for the Deaf and the Blind"],
    ".student.scsk12.org": ["Shelby County Schools, TN, US"],
    ".scuolacampostrini.org": ["Istituto Campostrini"],
    ".sd62learns.org": ["École John Stubbs", "John Stubbs "],
    ".sdjic.org": ["SDJ International College"],
    ".seafordhead.org": ["Seaford Head School"],
    ".seaprep.org": ["Seattle Preparatory School"],
    ".seattlegirlsschool.org": ["Seattle Girls' School"],
    ".seattleschools.org": [
        "Washington Middle School",
        "Garfield High School",
    ],
    ".sebrsd.org": ["David Prouty High School"],
    ".secuso.org": ["Technische Universität Darmstadt"],
    ".sedalia200.org": ["Smith-Cotton High School"],
    ".seps-auh.org": ["Sunrise English Private School"],
    ".seq.org": ["Menlo-Atherton High School"],
    ".servitehs.org": ["Servite", "Servite"],
    ".sesd.org": ["Sunnyvale Middle School District, CA"],
    ".westleigh.set.org": ["The Westleigh School (Shaw Education Trust)"],
    ".sevenoaksschool.org": ["Sevenoaks School"],
    ".sevier.org": ["Sevier County High School"],
    ".sfstoledo.org": ["St. Francis De Sales"],
    ".sfuhs.org": ["San Francisco University High School"],
    ".sgei.org": ["Anand Engineering College"],
    ".sgs-wa.org": ["Seattle Girls' School: Google Apps for Education Domain"],
    ".sgtuniversity.org": [
        "SGT University, Gurugram",
        "Shree Guru Gobind Singh Tricentenary University",
    ],
    ".sh44.org": [
        "Комунальний заклад “Середня загальноосвітня школа № 44” Кам’янської міської ради"
    ],
    ".stu.shaker.org": ["Shaker Heights High School"],
    ".shenschools.org": ["Shenendehowa High School"],
    ".shipleyschool.org": ["The Shipley School"],
    ".shriswaminarayanmission.org": [
        "SHRI SWAMINARAYAN MISSION SCHOOL, INDIA"
    ],
    ".shschools.org": ["Sacred Heart Schools"],
    ".student.shsd.org": ["Bernards High School"],
    ".siai.org": [
        "Swiss Institute of Artificial Intelligence",
        "Swiss Institute of Artificial Intelligence",
    ],
    ".siasindia.org": ["Safi Institute of Advanced Study"],
    ".sibadi.org": [
        "СИБИРСКИЙ ГОСУДАРСТВЕННЫЙ АВТОМОБИЛЬНО-ДОРОЖНЫЙ УНИВЕРСИТЕТ",
        "THE SIBERIAN STATE AUTOMOBILE AND HIGWAY UNIVERSITY",
    ],
    ".sineast.org": ["Sir Isaac Newton East Sixth Form"],
    ".sisschools.org": ["Singapore Intercultural School (SIS) Medan"],
    ".sjb-liege.org": ["Institut Saint-Jean Berchmans Liège"],
    ".sjnacademies.org": ["St. John's Northwestern Academies"],
    ".sjsm.org": ["St.James's School of Medicine, Bonaire"],
    ".sjusd.org": ["Leland High School"],
    ".sluh.org": ["St. Louis University High School"],
    ".smes.org": ["St. Margaret's Episcopal School"],
    ".smmacademy.org": [
        "St Mary Magdelene Academy",
        "St Mary Magdelene Academy",
    ],
    ".smmk12.org": ["Santa Monica High School"],
    ".smolny.org": ["Saint Petersburg State University"],
    ".smtexas.org": ["St. Mark's School of Texas"],
    ".smuedu.org": ["Saint Monica University"],
    ".smuhsd.org": ["San Mateo Union High School"],
    ".smwaldorf.org": ["Shining Mountain Waldorf School"],
    ".snsct.org": ["SNS College of Technology"],
    ".sonomaacademy.org": ["Sonoma Academy"],
    ".southasia-uni.org": ["University of South Asia"],
    ".southwestcoloradoeschool.org": ["Southwest Colorado eSchool"],
    ".spartandocs.org": ["Southern Lehigh High School"],
    ".spartanmed.org": ["Spartan University of Health Sciences"],
    ".spencerportschools.org": ["Spencerport Central School District"],
    ".spjimr.org": ["S. P. Jain Institute of Management And Research, Mumbai"],
    ".splendoraisd.org": ["Splendora High School"],
    ".sprucestreetnyc.org": ["Spruce Street School"],
    ".sps81.org": [
        "Spokane Public Schools (District 81)",
        "Spokane, Washington",
        "https://www.spokaneschools.org/ (institution site)",
        "https://www.spokaneschools.org/domain/1741 (Click on CTE. The school offers several computer sciences classes. These are college level.)",
        "https://www.spokaneschools.org/Page/2334 (Step 8 references email login)",
    ],
    ".spschools.org": [
        "St. Albert Public Schools",
        ".group",
        "http://www.spschools.org/",
    ],
    ".spsmail.org": ["Springfield Public School District"],
    ".spxabq.org": ["Saint Pius X High School"],
    ".srastudents.org": ["Santa Rosa Academy", "Santa Rosa Academy"],
    ".srcolleges.org": ["Sulaiman AlRajhi University"],
    ".srcs.org": ["San Rafael City Schools"],
    ".srit.org": ["SRI RAMAKRISHNA INSTITUTE OF TECHNOLOGY"],
    ".ssdmo.org": ["Special School District of St. Louis County"],
    ".ssrvm.org": ["Sri Sri Ravishankar Vidya Mandir"],
    ".sstx.org": [
        "Saint Stephen's Episcopal School",
        "Saint Stephens Episcopal School",
        "St. Stephen's Episcopal School",
        "St. Stephens Episcopal School",
        "Saint Stephen's Episcopal School of Austin",
        "Saint Stephens Episcopal School of Austin",
        "St. Stephen's Episcopal School of Austin",
        "St. Stephens Episcopal School of Austin",
        "Saint Stephen's Episcopal School, Austin",
        "Saint Stephens Episcopal School, Austin",
        "St. Stephen's Episcopal School, Austin",
        "St. Stephens Episcopal School, Austin",
        "Saint Stephen's Episcopal School, Austin TX",
        "Saint Stephens Episcopal School, Austin TX",
        "St. Stephen's Episcopal School, Austin TX",
        "St. Stephens Episcopal School, Austin TX",
    ],
    ".ssvotech.org": ["South Shore Vocational Technical High School"],
    ".students.st-andrews.org": ["Saint Andrew's Episcopal School"],
    ".st-christophers.org": ["St Christopher's CE High School"],
    ".st-columbas.org": ["St Columbas School"],
    ".ebpreston.staracademies.org": ["Eden Boys’ School, Preston"],
    ".stbernards.org": ["St. Bernard's School"],
    ".stcharles-stecroix.org": [
        "Saint Charles Sainte Croix Lycee general & technologique"
    ],
    ".stcolumbscollege.org": ["St Columbs College"],
    ".stcva.org": ["St. Christopher's School "],
    ".stedmundscollege.org": ["St Edmund's College"],
    ".stemhigh.org": ["STEM School and Academy"],
    ".stevensonschool.org": ["Stevenson School"],
    ".stfrancishouston.org": ["St. Francis Episcopal School"],
    ".stjacademy.org": ["St. Johnsbury Academy"],
    ".stjohnschs.org": ["St. John's College High School"],
    ".stjohnshigh.org": ["St. Johns High School", "St. Johns High School"],
    ".stjohnsprep.org": ["St. John's Preparatory High School"],
    ".stjschools.org": ["St. James R-1 School District"],
    ".stjude.org": ["St. Jude Children's Research Hospital"],
    ".stleonards-fife.org": ["St Leonards"],
    ".stluc-esa-bxl.org": [
        "ESA Saint-Luc Bruxelles",
        "École Superieure des Arts Saint-Luc Bruxelles",
        "Superior School of Arts Saint-Luc Brussels",
    ],
    ".stmarksschool.org": ["St.Mark's School, Massachusets, U.S."],
    ".stmaryscalne.org": ["St Mary's School Calne"],
    ".stmarysdelhi.org": ["St. Mary's School"],
    ".stmeduc.org": ["St. Michael Foundation"],
    ".stpaulseoul.org": ["Saint Paul Preparatory Seoul"],
    ".stpbb.org": ["Lycée St Paul Bourdon Blanc"],
    ".stpetershuntingdon.org": ["St Peters School", "St Peters School"],
    ".stringtheoryschools.org": ["String Theory Schools"],
    ".strosaire95.org": ["La Salle Saint Rosaire"],
    ".students.stsebs.org": ["St. Sebastian's School"],
    ".student158.org": ["Huntley High School"],
    ".studentasvalencia.org": ["American School Of Valencia"],
    ".stuttgartschools.org": ["Stuttgart Public Schools"],
    ".subharti.org": [
        "Swami Vivekanand Subharti University",
        "Swami Vivekanand Subharti University, Meerut",
        "Subharti University",
    ],
    ".successacademies.org": ["SuccessAcademies", "SuccessAcademies"],
    ".students.summitcds.org": ["The Summit Country Day School"],
    ".summitps.org": ["Summit Public High Schools"],
    ".stu.sumnersd.org": ["Bonney Lake High School"],
    ".sumnersd.org": [
        " Sumner-Bonney Lake School District",
        " Bonney Lake High School",
        " Sumner High School",
        " .group",
    ],
    ".sun-tech.org": ["SUN Area Technical Institute"],
    ".sunprairieschools.org": ["sun prairie high school"],
    ".susdgapps.org": ["Desert Mountain High School"],
    ".suttonmail.org": ["Cheam High School"],
    ".svak12.org": ["SkyView Academy", "SkyView Academy"],
    ".svaschool.org": ["Silicon Valley Academy"],
    ".svcschools.org": ["Saddleback Valley Christian School"],
    ".svisss.org": ["Sri Venkateshwara International Senior Secondary School"],
    ".students.svsd410.org": ["Mount Si High School"],
    ".svvsd.org": ["Niwot High School"],
    ".swceschool.org": ["Southwest Colorado eSchool"],
    ".sylvaniastudents.org": ["Sylvania Northview Highschool"],
    ".syossetschools.org": [
        "Syosset Senior High School",
        "Syosset Central School District",
    ],
    ".uczen.szkolawchmurze.org": ["Szkoła w Chmurze", "School in the Cloud"],
    ".taboracademy.org": ["Tabor Academy", "Tabor Academy"],
    ".student.tamdistrict.org": ["Redwood High School"],
    ".tampaprep.org": ["Tampa Preparatory School", "Tampa Preparatory School"],
    ".tanenbaumchat.org": [
        "The Anne & Max Tanenbaum Community Hebrew Academy of Toronto"
    ],
    ".tantasqua.org": ["Tantasqua Regional High School"],
    ".tavistockcollege.org": ["Tavistock College"],
    ".tbs-education.org": ["Toulouse Business School"],
    ".tbshs.org": ["the bishops stortford high school"],
    ".tcdsb.org": ["Toronto Catholic District School Board"],
    ".tcdupage.org": ["Technology Center of DuPage"],
    ".tcgcrest.org": ["TCG CREST"],
    ".tcsnc.org": ["Transylvania County Schools"],
    ".tcspioneers.org": ["Temple Christian School"],
    ".tcstudents.org": [
        "The Anne & Max Tanenbaum Community Hebrew Academy of Toronto"
    ],
    ".technonjr.org": ["Techno India NJR"],
    ".techvalleyhigh.org": ["Tech Valley High School"],
    ".tehcoll.org": [
        'ГАПОУ "Технический колледж им. В.Д.Поташова"',
        'GAPOU "Technical College named after V.D.Potashov"',
    ],
    ".teiacoltec.org": [
        "Colégio Técnico da UFMG - COLTEC",
        "UFMG Technical College - COLTEC",
        "Universidade Federal de Minas Gerais (UFMG) - MG - Brazil",
    ],
    ".stu.tempeunion.org": [
        "Tempe Union High School District",
        "Tempe Union High School District",
        ".group",
    ],
    ".teriinc.org": ["TERI Inc."],
    ".texasonlineprep.org": ["Texas Online Preparatory School"],
    ".tggs-bangkok.org": [
        "THE SIRINDHORN INTERNATIONAL THAI-GERMAN GRADUATE SCHOOL OF ENGINEERING"
    ],
    ".thakureducation.org": ["Thakur College of Engineering and Technology"],
    ".thayer.org": ["Thayer Academy"],
    ".stud.the-klu.org": [
        "Kühne Logistics University (KLU)",
        "Kuehne Logistics University",
    ],
    ".the-klu.org": [
        "Kühne Logistics University (KLU)",
        "Kuehne Logistics University",
    ],
    ".thecoleshillschool.org": ["The Coleshill School"],
    ".thedeantrustmoodle.org": ["Dean Trust Wigan, UK"],
    ".thedustonschool.org": ["Duston School"],
    ".theemcoe.org": ["Theem College of Engineering"],
    ".thegraysonschool.org": ["The Grayson School"],
    ".thehill.org": ["The Hill School"],
    ".thekaustschool.org": [
        "The Kaust School",
        "KAUST University High School",
    ],
    ".thekingstonacademy.org": ["The Kingston Academy"],
    ".themountbattenschool.org": ["The Mountbatten School"],
    ".theoakwoodschool.org": ["The Oakwood School"],
    ".thesummitprep.org": ["The summit preparatory school "],
    ".thiqaruni.org": ["Thi Qar University"],
    ".times2.org": ["Times2 STEM Academy"],
    ".students.tka.org": ["The King's Academy"],
    ".tms-hl.org": ["Thomas-Mann Schule"],
    ".tmsacademy.org": ["Triangle Math and Science Academy"],
    ".tmuni.org": ["Tashkent Metropolitan University"],
    ".tonbridge-school.org": ["Tonbridge School"],
    ".tooeleschools.org": ["Stansbury High School"],
    ".toulouse-bs.org": ["Toulouse Business School"],
    ".toutlesd.org": [
        "Toutle Lake Elementary",
        "Toutle Lake Junior High",
        "Toutle Lake High School",
        ".group",
    ],
    ".trainatfcoe.org": ["Fresno County Schools"],
    ".edu.tranemo.org": ["Tranemo gymnasieskola", "Tranemo gymnasium"],
    ".tremontschool.org": ["Tremont School"],
    ".trinityprep.org": ["Trinity Preparatory School"],
    ".trinityschoolnyc.org": ["Trinity School NYC"],
    ".student.trinityvalleyschool.org": ["Trinity Valley School"],
    ".trinityvalleyschool.org": ["Trinity Valley School"],
    ".triumemba.org": ["TRIUM GLOBAL EXECUTIVE MBA "],
    ".tsas.org": ["Tulsa School of Arts and Sciences "],
    ".tscng.org": [
        "Višja Strokovna Šola Nova Gorica",
        "Higher Vocational College Nova Gorica",
    ],
    ".tsinglan.org": ["清澜山学校", "Tsinglan Schol"],
    ".tsrs.org": ["The Shri Ram School Moulsari"],
    ".ttsdstudents.org": ["Tualatin High School"],
    ".tumo.org": ["Tumo Center For Creative Technologies"],
    ".tusol.org": ["University of Sierra Leone"],
    ".tusom.org": ["Trinity University School of Medicine"],
    ".twain239.org": ["Mark Twain is239, NY NY"],
    ".u-46.org": ["School District U-46", "School District U-46"],
    ".ubdtce.org": ["University BDT College of Engineering"],
    ".ucapanama.org": ["Universidad de Cartago"],
    ".ucentralasia.org": [
        "University of Central Asia",
        "https://ucentralasia.org/",
        "https://ucentralasia.org/Admissions/ComputerScience/EN",
        'As per the Email Use Policy: "Email accounts for all users are created upon information/authorization received from Human Resources or Student Affairs Department/Registrar/Head of SPCE respectively."',
    ],
    ".ucnh.org": ["Université Chrétienne du Nord d'Haiti"],
    ".udesmontagnes.org": ["Université des Montagnes"],
    ".stu.udsd.org": ["Upper Dublin High School"],
    ".eidia.ueuromed.org": ["L'Université Euromed de Fès (UEMF) "],
    ".insa.ueuromed.org": [
        "INSA Euro-méditérannée",
        "Euromed University of Fes",
    ],
    ".vac.ueuromed.org": ["L'Université Euromed de Fès (UEMF)"],
    ".ueuromed.org": [
        "Université Euro-Méditerranéenne de Fès",
        "Euro-Mediterranean University of Fez",
    ],
    ".ufa47.org": ["UFA47", "UFA47"],
    ".ugmit.org": [
        "UTKAL GOURAV MADHUSUDAN INSTITUTE OF TECHNOLOGY",
        "UTKAL GOURAV MADHUSUDAN INSTITUTE OF TECHNOLOGY",
    ],
    ".uha-ky.org": ["University Heights Academy"],
    ".umasd.org": ["Upper Merion Area High School"],
    ".un-ihe.org": ["IHE Delft Institute for Water Education"],
    ".unesco-ihe.org": ["UNESCO-IHE Institute for Water Education"],
    ".unibl.org": ["University of Banja Luka"],
    ".unicaf.org": ["Unicaf University"],
    ".unikam.org": ["Kamina University"],
    ".unis.org": ["United Nations International School"],
    ".unishanoi.org": ["United Nations International School of Hanoi"],
    ".univ-dschang.org": ["Université de Dschang"],
    ".univ-lyon.org": ["Université de Lyon"],
    ".universityliberia.org": ["University of Liberia"],
    ".universityprep.org": ["University Prep"],
    ".universum-ks.org": ["Universum college, Kosovo"],
    ".uofdjesuit.org": [
        "University of Detroit Jesuit High School and Academy"
    ],
    ".upeace.org": ["University for Peace"],
    ".students.uplifteducation.org": ["uplift North Hill Prep"],
    ".upou.org": ["University of the Philippines Open University"],
    ".upra.org": ["Athenaeum Pontificium Regina Apostolorum"],
    ".urbanschool.org": ["Urban School of San Francisco"],
    ".42.us.org": ["42 USA"],
    ".usd232.org": ["Mill Valley High School"],
    ".students.usd497.org": ["Lawrence High School"],
    ".usenghor-francophonie.org": ["Université Senghor d'Alexandrie"],
    ".student.ushschool.org": ["Upper Shirley High", "Upper Shirley High"],
    ".utahmilitaryacademy.org": ["Utah Military Academy"],
    ".utcncst.org": ["University Technical Collage Norfolk"],
    ".utcportsmouth.org": ["UTC Portsmouth"],
    ".utcwarrington.org": ["UTC Warrington"],
    ".uwcchina.org": ["United World College Changshu China"],
    ".vailstudents.org": ["Empire High School, AZ, US"],
    ".student.vansd.org": ["Vancouver School District"],
    ".vantagehall.org": ["Vantage Hall Girl's School, Dehradun"],
    ".vardhaman.org": ["Vardhaman College of Engineering"],
    ".vasvari.org": [
        "Szegedi SZC Vasvári Pál Gazdasági és Informatikai Technikum",
        "Szeged SZC Vasvári Pál School of Economics and Information Technology",
    ],
    ".vbisd.org": ["Van Buren Tech"],
    ".vcpusd.org": ["Valley Center-Pauma Unified"],
    ".vcuhealth.org": [
        "Virginia Commonwealth University",
        "vcu.edu, vcuhealth.org",
    ],
    ".vedam.org": [
        "Vedam School of Technology",
        "SET Education Technology Pvt. Ltd.",
        "Sunstone Education Technology Pvt. Ltd.",
    ],
    ".veltechmultitech.org": [
        "Vel Tech Multi Tech Dr. Rangarajan Dr. Sakunthala Engineering College"
    ],
    ".vidyavihar.org": ["Vidya Vihar Residential School"],
    ".student.vigoschools.org": ["Terre Haute South Vigo High School"],
    ".viitindia.org": [
        "Vidya Pratishthan's Institute of Information Technology, Baramati"
    ],
    ".edu.visio.org": ["Visio Onderwijs Grave"],
    ".visocloud.org": ["Vrij Instituut voor Secundair Onderwijs Mariakerke"],
    ".vistausd.org": ["Mission Vista High School"],
    ".viva-technology.org": ["VIVA Institute of Technology"],
    ".vjcet.org": ["Viswajyothi College of Engineering and Technology"],
    ".vpmthane.org": ["Bedekar College of Commerce"],
    ".vschsd.org": ["Valley Stream North High School"],
    ".vumc.org": ["Vanderbilt University Medical Center"],
    ".vvsaz.org": ["Verde Valley School"],
    ".wagonerps.org": ["Wagoner pubilc schools"],
    ".wakefieldschool.org": ["Wakefield School"],
    ".walkerschools.org": ["LaFayette High School", ".group"],
    ".walworthacademy.org": ["Walworth Academy"],
    ".waprep.org": ["Washington Preparatory School"],
    ".warnefordschool.org": ["Highworth Warneford School"],
    ".warwickschool.org": ["Warwick School"],
    ".warwicksd.org": ["Warwick High School - Lititz, PA, USA"],
    ".wasatchacademy.org": ["Wasatch Academy"],
    ".washk12.org": ["WASHINGTON COUNTY SCHOOL DISTRICT", ".group"],
    ".wataugaschools.org": ["Watauga Schools"],
    ".watershedschool.org": ["Watershed School"],
    ".students.watfordboys.org": ["Watford Grammar School for Boys"],
    ".waukeeschools.org": ["Waukee Community School District"],
    ".wawmsd.org": ["West Allis Central High School"],
    ".waylandps.org": ["Wayland High School"],
    ".waysideschools.org": ["Wayside Schools"],
    ".wbactc.org": [
        "Wilkes-Barre Area Career Technology Center",
        "Wilkes-Barre Area Career Technology Center",
    ],
    ".wbsd-schools.org": ["West Bend High School"],
    ".wcboe.org": ["Wicomico County Board of Education"],
    ".student.wchcs.org": ["Washington High School"],
    ".wcsd1.org": [
        "Newcastle High School",
        "Weston County School District",
        ".group",
    ],
    ".wctech.org": ["Warren County Technical School"],
    ".weldre4.org": ["Windsor High School"],
    ".welingkar.org": [
        "Prin. L. N. Welingkar Institute of Management Development & Research"
    ],
    ".westada.org": ["Sawtooth Middle School"],
    ".student.westboroughk12.org": [
        "Westborough Public Schools (Westborough, MA, US)"
    ],
    ".westerncenter.org": ["Western Montgomery Career and Technology Center"],
    ".westex.org": ["West Essex Regional High School"],
    ".weston.org": ["Weston High School"],
    ".westportps.org": ["Westport, CT Public Schools"],
    ".wgs.org": ["Withington Girls' School"],
    ".wheatleypark.org": ["Wheatley Park School"],
    ".wheelerschool.org": ["The Wheeler School"],
    ".student.whittiertech.org": [
        "Whittier Regional Vocational Technical High School"
    ],
    ".students.whpfederation.org": ["White Hills Park Federation"],
    ".whpfederation.org": ["White Hills Park Federation Teachers"],
    ".whps.org": ["West Hartford Public Schools", ".group"],
    ".whrhs-stu.org": ["Watchung Hills Regional High School"],
    ".wihi.org": ["Washtenaw International High School and Middle Academy"],
    ".williamsvillek12.org": ["Williamsville East High School"],
    ".winchendon.org": ["The Winchendon School"],
    ".winchesterps.org": [
        "Winchester High School Teacher Domains",
        "Email domain: @winchesterps.org",
    ],
    ".windhamsd.org": ["Windham High School"],
    ".wivcs.org": ["Wisconsin Virtual Academy"],
    ".wlsv.org": ["Wellsville Central School District"],
    ".wmrhsd.org": ["West Morris Regional High School District"],
    ".woodlandstarschool.org": ["Woodland Star Charter School"],
    ".woodstockacademy.org": ["The Woodstock Academy"],
    ".wpsstudent.org": [
        "Winchester High School Students",
        "Email domain: @wpsstudent.com",
        "Website: http://www.winchesterps.org",
    ],
    ".wpsstudents.org": ["Westwood Public Schools (Students)"],
    ".wscswarriors.org": ["West Side Christian School"],
    ".live.wsd1.org": ["Meadows West"],
    ".wsdr4.org": ["Wentzville School District, Wentzville, Missouri"],
    ".wsspartans.org": ["White Station High School "],
    ".wusd.org": ["Windsor Unified School District"],
    ".stu.wvusd.org": ["Suzanne Middle School"],
    ".wvwsd.org": ["Wyoming Valley West High School"],
    ".wwcsd.org": ["Wayne-Westland Community School District"],
    ".wwprsd.org": ["West Winsdsor Plainsboro High School South"],
    ".wychwoodschool.org": ["Wychwood School", "Wychwood School"],
    ".wymondhamcollege.org": ["Wymondham College"],
    ".x-camp.org": ["X-Camp Academy"],
    ".xrds.org": ["Crossroads School for Arts and Sciences"],
    ".y115.org": ["Yorkville High School"],
    ".yarmouthschools.org": ["Yarmouth Schools District"],
    ".yarmschool.org": ["Yarm School"],
    ".yellowwoodacademy.org": ["Yellow Wood Academy", "Yellow Wood Academy"],
    ".yhsmonsey.org": ["Yeshiva Ner Torah", "Yeshiva High School of Monsey"],
    ".yisseoul.org": ["Yongsan International School of Seoul"],
    ".ymtkfas.org": ["YAUMATI KFA SHOOL"],
    ".yorktown.org": ["Mildred E Strang Middle School"],
    ".yula.org": ["YULA High School"],
    ".yumingschool.org": ["Yu Ming Charter School"],
    ".zabalburu.org": ["Colegio Zabalburu"],
    ".zenithuniversitycollege.org": ["zenith university college"],
    ".zone01normandie.org": ["Zone01 Rouen Normandie"],
    ".oteima.ac.pa": ["Universidad Tecnológica Oteima"],
    ".udelas.ac.pa": ["Universidad Especializada de Las Americas"],
    ".ulat.ac.pa": ["Universidad Latina de Panamá"],
    ".unachi.ac.pa": ["Universidad Autonoma de Chiriqui"],
    ".unadp.ac.pa": ["Universidad Abierta y a Distancia de Panama"],
    ".usma.ac.pa": ["Universidad Católica Santa María La Antigua"],
    ".utp.ac.pa": ["Universidad Tecnológica de Panamá"],
    ".etu-digitalschool.paris": ["Digital School of Paris"],
    ".stu-psbedu.paris": ["Paris Business School"],
    ".cibertec.pe": ["INSTITUTO CIBERTEC"],
    ".adexperu.edu.pe": [
        "Instituto de Educación Superior Privado de Comercio Exterior",
        "Adex",
    ],
    ".autonoma.edu.pe": ["Universidad Autónoma del Perú"],
    ".carloscueto.edu.pe": [
        "Instituto de Educación Superior Tecnológico Público - Carlos Cueto Fernandini"
    ],
    ".certus.edu.pe": [
        "Instituto Certus",
        "Carreras Técnicas y Educación Continua",
    ],
    ".ceticoempresarios.edu.pe": ["Cetpro Cetico", "Cetico Empresarios"],
    ".champagnat.edu.pe": ["Universidad Marcelino Champagnat"],
    ".ci.edu.pe": ["Colegio de la Inmaculada Jesuitas Lima"],
    ".continental.edu.pe": ["Universidad Continental"],
    ".iestpmrap.drelm.edu.pe": [
        "IESTP María Rosario Araoz Pinto",
        "Instituto de Educación Superior Tecnológico Público - María Rosario Araoz Pinto",
    ],
    ".elp.edu.pe": ["Escuela Superior la Pontificia"],
    ".esan.edu.pe": ["Universidad ESAN"],
    ".fhpa.edu.pe": ["Institución Educativa Felipe Huaman Poma de Ayala"],
    ".idat.edu.pe": ["Instituto Superior Tecnológico Idat"],
    ".iestpantenororrego.edu.pe": [
        "Instituto Superior Tecnológico Público Antenor Orrego"
    ],
    ".iestpcab.edu.pe": [
        'Instituto de Educación Superior Público "Ciro Alegria Bazán"'
    ],
    ".iestpffaa.edu.pe": [
        " Instituto de Educación Superior Tecnológico Público de las Fuerzas Armadas ",
        "Public Technological Higher Education Institute of the Armed Forces",
    ],
    ".iestpgildaballivian.edu.pe": ["IESTP GILDA BALLIVIÁN ROSADO"],
    ".iestphuanta.edu.pe": ["IESTPub. Huanta"],
    ".iestpisa.edu.pe": ["I.E.S.T.P SANTA ANGELA", "I.E.S.T.P SANTA ANGELA"],
    ".iestplurin.edu.pe": [
        "Instituto de Educacion Superior Tecnologico Publico Lurin"
    ],
    ".iestpmotupe.edu.pe": [
        "Instituto de Educación Superior Tecnológico Público Motupe"
    ],
    ".istpargentina.edu.pe": [
        "Instituto de Educación Superior Tecnológico Público - Argentina"
    ],
    ".istrfa.edu.pe": [
        "I.E.S República Federal de Alemania",
        "I.E.S Federal Republic of Germany",
    ],
    ".isur.edu.pe": [
        "Instituto de Educación Superior Tecnológico Privado del Sur",
        "ISur",
    ],
    ".khipu.edu.pe": ["Instituto Superior Privado Khipu"],
    ".lamolina.edu.pe": ["Universidad Nacional Agraria La Molina"],
    ".lisoft.edu.pe": ["Lima International School of Tomorrow"],
    ".neumann.edu.pe": ["John Von Neumann - Instituto de Educación Superior"],
    ".newton.edu.pe": ["Newton college, Peru"],
    ".nsc.edu.pe": ["NUESTRA SEÑORA DEL CARMEN"],
    ".pucp.edu.pe": ["Pontificia Universidad Católica del Perú"],
    ".roncalli.edu.pe": ["Instituto Roncalli del Peru"],
    ".sacooliveros.edu.pe": ["Saco Oliveros"],
    ".salazarbondy.edu.pe": [
        "Instituto Educacion Superior Tecnologico Salazar Bondy",
        "Institute Technology Salazar Bondy",
    ],
    ".sam.edu.pe": [
        "Instituto de Educación Superior Tecnológica Público SANTIAGO ANTÚNEZ DE MAYOLO"
    ],
    ".senati.edu.pe": [
        "Servicio Nacional de Adiestramiento en Trabajo Industrial (SENATI)",
        "National Industrial Work Training Service (SENATI)",
    ],
    ".sil.edu.pe": ["Universidad San Ignacio de Loyola"],
    ".sistemasunica.edu.pe": ["Universidad Nacional San Luis Gonzaga de Ica"],
    ".tecsup.edu.pe": ["Tecsup", "Tecsup"],
    ".tls.edu.pe": ["Toulouse Lautrec"],
    ".trentino.edu.pe": [
        "IESTP TRENTINO JUAN PABLO II MANCHAY",
        "INSTITUTO DE EDUCACION SUPERIOR TECNOLOGICO PRIVADO TRENTINO JUAN PABLO II MANCHAY",
    ],
    ".uancv.edu.pe": ["Universidad Andina Nestor Caceares Velasquez"],
    ".uandina.edu.pe": ["Universidad Andina del Cusco"],
    ".uap.edu.pe": ["Universidad Alas Peruanas"],
    ".crear.ucal.edu.pe": [
        "Universidad de Ciencias y Artes de América Latina"
    ],
    ".ucl.edu.pe": [
        "Universidad Ciencia Lideres",
        "University of Leading Sciences",
    ],
    ".ucsp.edu.pe": ["Universidad Católica San Pablo"],
    ".ucsur.edu.pe": ["Universidad Cientifica del Sur"],
    ".uct.edu.pe": [
        "Universidad Católica de Trujillo",
        "Catholic University of Trujillo",
    ],
    ".ucv.edu.pe": ["Universidad César Vallejo"],
    ".ucvvirtual.edu.pe": [
        "Universidad Cesar Vallejo",
        "Universidad Cesar Vallejo",
    ],
    ".udch.edu.pe": ["Universidad Particular de Chiclayo"],
    ".udep.edu.pe": ["Universidad de Piura"],
    ".udh.edu.pe": ["Universidad de Huánuco"],
    ".ue.edu.pe": ["Universidad ESAN", "ESAN University"],
    ".uigv.edu.pe": ["Universidad Particular Inca Garcilaso de la Vega"],
    ".uladech.edu.pe": ["Universidad Los Angeles de Chimbote"],
    ".ulasalle.edu.pe": ["Universidad La Salle", "La Salle University"],
    ".ulasamericas.edu.pe": ["Universidad Peruana de las Américas"],
    ".ulima.edu.pe": ["Universidad de Lima"],
    ".umch.edu.pe": ["Universidad Marcelino Champagnat"],
    ".unab.edu.pe": [
        "Universidad Nacional de Barranca",
        "National University of Barranca",
    ],
    ".unac.edu.pe": ["Universidad Nacional del Callao"],
    ".unaj.edu.pe": ["Universidad Nacional de Juliaca"],
    ".unajma.edu.pe": ["UNIVERSIDAD NACIONAL JOSÉ MARÍA ARGUEDAS"],
    ".unam.edu.pe": ["UNIVERSIDAD NACIONAL DE MOQUEGUA"],
    ".unamad.edu.pe": ["UNIVERSIDAD NACIONAL AMAZONICA DE MADRE DE DIOS"],
    ".unamba.edu.pe": [
        "Universidad Nacional Micaela Bastidas de Apurímac",
        "Micaela Bastidas National University Apurímac",
        "UNAMBA",
        "Unamba Apurímac",
    ],
    ".unap.edu.pe": ["Universidad Nacional del Altiplano"],
    ".unapiquitos.edu.pe": [
        "Universidad Nacional De La Amazonia Peruana",
        "National University of the Peruvian Amazon",
    ],
    ".unas.edu.pe": ["Universidad Nacional Agraria La Selva"],
    ".unc.edu.pe": ["Universidad Nacional de Cajamarca"],
    ".undac.edu.pe": ["Universidad Nacional Daniel Alcides Carrion"],
    ".undc.edu.pe": ["Universidad Nacional de Cañete - UNDC"],
    ".une.edu.pe": [
        "Universidad Nacional de Educación Enrique Guzmán y Valle"
    ],
    ".unh.edu.pe": ["Universidad Nacional de Huancavelica"],
    ".unheval.edu.pe": ["Universidad Nacional Hermilio Valdizan"],
    ".uni.edu.pe": ["Universidad Nacional de Ingeniería"],
    ".unica.edu.pe": ["Universidad Nacional San Luis Gonzaga de Ica"],
    ".unife.edu.pe": ["Universidad Femenina del Sagrado Corazón"],
    ".unitek.edu.pe": ["UNITEK", "UNITEK"],
    ".unitru.edu.pe": ["Universidad Nacional de La Libertad, Trujillo"],
    ".unjbg.edu.pe": ["Universidad Nacional Jorge Basadre Grohmann"],
    ".unjfsc.edu.pe": ["Universidad Nacional José Faustino Sánchez Carrión"],
    ".unmsm.edu.pe": ["Universidad Nacional Mayor de San Marcos"],
    ".unprg.edu.pe": ["UNIVERSIDAD NACIONAL PEDRO RUIZ GALLO"],
    ".unsa.edu.pe": ["Universidad Nacional de San Agustin"],
    ".unsch.edu.pe": ["Universidad Nacional San Cristobal de Huamanga"],
    ".unsm.edu.pe": ["Universidad Nacional de San Martín"],
    ".untels.edu.pe": ["Universidad Nacional Tecnologica de Lima Sur"],
    ".untrm.edu.pe": ["Toribio Rodríguez de Mendoza de Amazonas"],
    ".unu.edu.pe": ["Universidad Nacional de Ucayali"],
    ".up.edu.pe": ["Universidad del Pacifico"],
    ".upagu.edu.pe": ["UNIVERSIDAD PRIVADA ANTONIO GUILLERMO URRELO"],
    ".upao.edu.pe": ["Universidad Privada Antenor Orrego"],
    ".upc.edu.pe": ["Universidad Peruana de Ciencias Aplicadas"],
    ".upch.edu.pe": ["Universidad Peruana Cayetano Heredia"],
    ".upci.edu.pe": [
        "Universidad Peruana de Ciencias e Informatica - UPCI",
        "Peruvian University of Sciences and Informatics - UPCI",
    ],
    ".upeu.edu.pe": ["Universidad Peruana Unión"],
    ".upla.edu.pe": ["Universidad Privada Los Andes"],
    ".upn.edu.pe": ["Universidad Privada del Norte"],
    ".upsc.edu.pe": ["Universidad Privada San Carlos"],
    ".upsjb.edu.pe": ["Universidad Privada San Juan Bautista"],
    ".upt.edu.pe": [
        "Universidad Tecnológica del Perú",
        "Technological University of Peru",
    ],
    ".urp.edu.pe": ["Universidad Ricardo Palma"],
    ".estudiante.usat.edu.pe": [
        "universildad catolica santo toribio de mogrovejo"
    ],
    ".usat.edu.pe": [
        "Universidad Catolica Santo Toribio de Mogrovejo",
        "Santo Toribio de Mogrovejo Catholic University",
    ],
    ".usil.edu.pe": ["Universidad San Ignacio De Loyola"],
    ".usmp.edu.pe": ["Universidad San Martin de Porres"],
    ".usp.edu.pe": ["Universidad San Pablo"],
    ".crece.uss.edu.pe": ["Universidad Señor de Sipan"],
    ".uss.edu.pe": ["Ingenieria de Sistemas", "systems engineer"],
    ".utea.edu.pe": ["Universidad Tecnológica de los Andes de Apurímac"],
    ".utec.edu.pe": ["UTEC", "Universidad de Ingenieria y Tecnologia"],
    ".uwiener.edu.pe": ["Universidad Norbert Wienner"],
    ".vallegrande.edu.pe": ["I.E.S.T.P. VALLE GRANDE"],
    ".inei.gob.pe": [
        "Instituto Nacional de Estadística e Informática",
        "INEI",
        ".group",
    ],
    ".idat.pe": ["Idat", "IDAT EDU"],
    ".isil.pe": ["Instituto San Ignacio de Loyola", "ISIL"],
    ".rcp.net.pe": [
        "Universidad Nacional Daniel Alcides Carrion",
        "Universidad Nacional Pedro Ruíz Gallo",
    ],
    ".newton.pe": ["Newton college, Peru"],
    ".pucp.pe": ["Pontificia Universidad Católica del Perú"],
    ".uarm.pe": ["Universidad Antonio Ruiz de Montoya"],
    ".uch.pe": [
        "UNIVERSIDAD DE CIENCIAS Y HUMANIDADES",
        "UNIVERSITY OF SCIENCES AND HUMANITIES",
    ],
    ".ucss.pe": ["Universidad Católica Sedes Sapientiae"],
    ".udep.pe": ["Universidad de Piura"],
    ".uigv.pe": ["Universidad Inca Garcilaso de la Vega"],
    ".uladech.pe": [
        "UNIVERSIDAD CATOLICA LOS ANGELES DE CHIMBOTE",
        "systems engineer",
    ],
    ".unac.pe": ["Universidad Nacional del Callao"],
    ".unheval.pe": ["Universidad Nacional Hermilio Valdizán"],
    ".uni.pe": ["Universidad Nacional de Ingenieria"],
    ".unsa.pe": ["Universidad Nacional de San Agustín de Arequipa"],
    ".upch.pe": ["Universidad Peruana Cayetano Heredia"],
    ".upn.pe": ["Universidad Privada del Norte"],
    ".upt.pe": ["Universidad Privada De Tacna", "Private University Of Tacna"],
    ".urp.pe": ["Universidad Ricardo Palma"],
    ".usat.pe": [
        "Universidad Católica Santo Torivio de Mogrovejo",
        "Catholic University of Santo Toribio de Mogrovejo",
    ],
    ".usil.pe": [
        "UNIVERSIDAD SAN IGNACIO DE LOYOLA",
        "SAN IGNACIO UNIVERSITY",
    ],
    ".zegel.pe": ["Zegel SERVICIO EDUCATIVO EMPRESARIAL S.A.C.", "Zegel Ipae"],
    ".zegelipae.pe": ["Instituto Zegel Ipae", "https://www.zegelipae.pe/"],
    ".ac-polynesie.pf": ["French polynesia academy"],
    ".clm.ddec.pf": ["LYCEE LA MENNAIS"],
    ".clm.ddec.edu.pf": ["Lycée La Mennais"],
    ".upf.pf": ["Université de la Polynésie Française"],
    ".dwu.ac.pg": ["Divine Word University"],
    ".pau.ac.pg": ["Pacific Adventist University"],
    ".unitech.ac.pg": ["Papua New Guinea University of Technology"],
    ".uog.ac.pg": ["University of Goroka"],
    ".upng.ac.pg": ["University of Papua New Guinea"],
    ".globe.com.ph": ["University of the Immaculate Conception"],
    ".oed.com.ph": ["AMA University Online Education"],
    ".depedmarikina.ph": ["Sta. Elena High School in the Philippines"],
    ".dlsu.ph": ["De La Salle University - Manila"],
    ".access.edu.ph": ["Access Computer College"],
    ".aclcbutuan.edu.ph": ["AMA Computer Learning Center College of Butuan"],
    ".addu.edu.ph": ["Ateneo de Davao University"],
    ".admu.edu.ph": ["Ateneo de Manila University"],
    ".adnu.edu.ph": ["Ateneo de Naga University"],
    ".adzu.edu.ph": ["Ateneo de Zamboanga University"],
    ".aes.edu.ph": ["Albert Einstein School", "Albert Einstein School"],
    ".ama.edu.ph": [
        "AMA Computer University - Main Campus",
        "AMA Computer College - Branches",
    ],
    ".antiquespride.edu.ph": ["University of Antique"],
    ".apc.edu.ph": ["Asia Pacific College"],
    ".apecschools.edu.ph": ["APEC Schools"],
    ".arellano.edu.ph": ["Arellano University"],
    ".asiancollege.edu.ph": ["Asian College", "ACSAT"],
    ".auf.edu.ph": ["Angeles University"],
    ".aup.edu.ph": ["Adventist University of the Philippines"],
    ".benilde.edu.ph": ["De La Salle-College of Saint Benilde"],
    ".bicol-u.edu.ph": ["Bicol University"],
    ".bisu.edu.ph": ["Bohol Island State University- Main Campus"],
    ".bpsu.edu.ph": ["Bataan Peninsula State University"],
    ".bsu.edu.ph": ["Benguet State University"],
    ".buksu.edu.ph": ["Bukidnon State University"],
    ".bulsu.edu.ph": ["Bulacan State University"],
    ".capsu.edu.ph": ["Capiz State University"],
    ".carsu.edu.ph": ["Caraga State University"],
    ".cbsua.edu.ph": ["Central Bicol State University of Agriculture"],
    ".cca.edu.ph": ["City College of Angeles"],
    ".ccc.edu.ph": ["City College of Calamba"],
    ".ccdc.edu.ph": ["Cordillera Career Development College"],
    ".cdm.edu.ph": ["Colegio de Muntinlupa"],
    ".ceu.edu.ph": ["Centro Escolar University"],
    ".ciit.edu.ph": ["CIIT College of Arts and Technology"],
    ".cis.edu.ph": ["Cebu International School"],
    ".cityofmalabonuniversity.edu.ph": ["City of Malabon University"],
    ".cksc.edu.ph": ["Chiang Kai Shek College"],
    ".clsu.edu.ph": ["Central Luzon State University"],
    ".cmu.edu.ph": ["Central Mindanao University"],
    ".cnu.edu.ph": ["Cebu Normal University"],
    ".cpu.edu.ph": ["Central Philippine University"],
    ".csav.edu.ph": ["Colegio de Sta. Ana de Victorias"],
    ".cspc.edu.ph": ["Camarines Sur Polytechnic Colleges"],
    ".csr-scc.edu.ph": [
        "Colegio de Santa Rita de San Carlos, Inc (Tibuco Campus)",
        "Colegio de Santa Rita de San Carlos, Inc. Main Campus",
    ],
    ".csucarig.edu.ph": [
        "Cagayan State University Carig Campus",
        "Cagayan State University Carig Campus",
    ],
    ".csucc.edu.ph": [
        "Caraga State University Cabadbaran City",
        "Caraga State University Cabadbaran City",
    ],
    ".ctu.edu.ph": ["Cebu Technological University"],
    ".cu.edu.ph": ["Capitol University"],
    ".cultural.edu.ph": ["Philippine Cultural College"],
    ".cvsu.edu.ph": ["Cavite State University"],
    ".davaodoctors.edu.ph": ["Davao Doctors College"],
    ".dccp.edu.ph": [
        "Data Center College Of The Philippines in Baguio City Inc",
        "Data Center College Of The Philippines in Baguio City",
    ],
    ".dhvsu.edu.ph": [
        "Don Honorio Ventura State University",
        "Don Honorio Ventura State University",
    ],
    ".dlsl.edu.ph": ["De La Salle Lipa"],
    ".dlsu.edu.ph": [
        "De La Salle University",
        "De La Salle University, Araneta",
    ],
    ".dmmmsu.edu.ph": ["Don Mariano Marcos Memorial State University"],
    ".dnsc.edu.ph": ["Davao del Norte State College"],
    ".donbosco.edu.ph": [
        "Don Bosco Educational Centers (DBEC) - Philippines",
        "Don Bosco College",
        ".group",
    ],
    ".dorsu.edu.ph": ["Davao Oriental State University"],
    ".dotclsu.edu.ph": ["CENTRAL LUZON STATE UNIVERSITY-DOTUNI"],
    ".dwcc.edu.ph": ["Divine Word College of Calapan"],
    ".eac.edu.ph": ["Emilio Aguinaldo College-Cavite Campus"],
    ".eclaro.edu.ph": ["Eclaro Academy"],
    ".epcst.edu.ph": [
        "Eastwoods Professional College of Science and Technology"
    ],
    ".evsu.edu.ph": ["Eastern Visayas State University"],
    ".student.fatima.edu.ph": [
        "Our Lady of Fatima University",
        "Website: https://www.fatima.edu.ph/",
        "IT Course URL: https://www.fatima.edu.ph/degree-program/college-of-computer-studies/",
    ],
    ".featiu.edu.ph": ["Feati University"],
    ".feu.edu.ph": ["Far Eastern University"],
    ".feualabang.edu.ph": [
        "Far Eastern University",
        "Far Eastern University Alabang",
        "FEU Alabang",
    ],
    ".feuroosevelt.edu.ph": ["FEU Roosevelt", "FEU Roosevelt"],
    ".feutech.edu.ph": ["FEU Institute of Technology"],
    ".firstasia.edu.ph": [
        "First Asia Institute of Technology and Humanities (FAITH Colleges)"
    ],
    ".fit.edu.ph": ["FEU Institute of Technology"],
    ".gadtc.edu.ph": [
        "Tangub City Global College",
        "Tangub City Global College",
    ],
    ".gordoncollege.edu.ph": ["Gordon College"],
    ".hau.edu.ph": ["Holy Angel University"],
    ".hcdc.edu.ph": ["Holy Cross of Davao College"],
    ".heroes1979.edu.ph": ["Bataan Heroes College"],
    ".holycrosscollegepampanga.edu.ph": ["Holy Cross College"],
    ".holyspirit.edu.ph": ["College of the Holy Spirit"],
    ".online.htcgsc.edu.ph": ["Holy Trinity College of General Santos City"],
    ".iacademy.edu.ph": [
        "iAcademy, Information and Communications Technology Academy"
    ],
    ".ici.edu.ph": [
        "Iligan Computer Institute, Inc.",
        "Iligan Computer Institute, Inc.",
    ],
    ".informatics.edu.ph": ["Informatics Philippines"],
    ".students.isatu.edu.ph": ["Iloilo Science and Technology University"],
    ".isatu.edu.ph": ["Iloilo Science and Technology University"],
    ".ispsc.edu.ph": [],
    ".isu.edu.ph": ["Isabela State University"],
    ".isufst.edu.ph": [
        "Iloilo State University of Fisheries Science and Technology"
    ],
    ".jmc.edu.ph": ["Jose Maria College"],
    ".joffc.edu.ph": [
        "Journeys of Faith Formative Center",
        "Journeys of Faith Formative Center",
    ],
    ".kcast.edu.ph": ["Kapalong College of Agriculture Sciences & Technology"],
    ".kld.edu.ph": ["Kolehiyo ng Lungsod ng Dasmariñas"],
    ".ksu.edu.ph": ["Kalinga State University"],
    ".lcup.edu.ph": ["La Consolacion University Philippines"],
    ".liceo.edu.ph": ["Liceo de Cagayan University"],
    ".lpubatangas.edu.ph": ["Lyceum of the Philippines University-Batangas"],
    ".lspu.edu.ph": ["Laguna State Polytechnic University"],
    ".lsu.edu.ph": ["La Salle University Ozamiz"],
    ".mapua.edu.ph": ["Mapua University"],
    ".mc-knoller.edu.ph": ["Miriam College"],
    ".mmdc.mcl.edu.ph": ["Mapúa Malayan Colleges Laguna"],
    ".mcm.edu.ph": ["Mapua Malayan Colleges Mindanao"],
    ".mcu.edu.ph": ["Manila Central University"],
    ".minsu.edu.ph": ["Mindoro State University", "Mindoro State University"],
    ".mintcollege.edu.ph": ["MINT College"],
    ".mlqu.edu.ph": ["Manuel L. Quezon University"],
    ".mmsu.edu.ph": ["Mariano Marcos State University"],
    ".mscmarinduque.edu.ph": ["Marinduque State College"],
    ".mseuf.edu.ph": ["Manuel S. Enverga University Foundation"],
    ".msugensan.edu.ph": ["Mindanao State University - General Santos"],
    ".msuiit.edu.ph": [
        "Mindanao State University - Iligan Institute of Technology"
    ],
    ".msumain.edu.ph": ["Mindanao State University"],
    ".msunaawan.edu.ph": ["Mindanao State University - Naawan"],
    ".mvc.edu.ph": ["Mountain View College"],
    ".students.national-u.edu.ph": ["National University Philippines"],
    ".nbsc.edu.ph": ["Northern Bukidnon State College"],
    ".ncf.edu.ph": [
        "Naga College Foundation, Inc.",
        "Naga College Foundation, Inc.",
    ],
    ".ncst.edu.ph": [
        "NCST - National College of Science and Technology, Dasmariñas"
    ],
    ".ndmc.edu.ph": ["Notre Dame of Midsayap College, INC"],
    ".ndmu.edu.ph": ["Notre Dame of Marbel University"],
    ".nemsu.edu.ph": ["North Eastern Mindanao State University"],
    ".neu.edu.ph": ["New Era University"],
    ".newbrighton.edu.ph": ["New Brighton School of the Philippines, Inc."],
    ".nonescost.edu.ph": [
        "Northern Negros State College of Science and Technology"
    ],
    ".norsu.edu.ph": ["Negros Oriental State University", "NORSU"],
    ".ntc.edu.ph": ["National Teachers College"],
    ".students.nu-dasma.edu.ph": ["National University - Dasmariñas"],
    ".students.nu-fairview.edu.ph": ["National Univeristy-Fairview"],
    ".students.nu-lipa.edu.ph": ["National University Lipa"],
    ".nu.edu.ph": ["National University"],
    ".psu.palawan.edu.ph": ["Palawan State University"],
    ".paterostechnologicalcollege.edu.ph": ["Pateros Technological College"],
    ".pcu.edu.ph": ["Philippine Christian University"],
    ".philsca.edu.ph": ["Philippine State College of Aeronautics"],
    ".phinma.edu.ph": ["University of lloilo"],
    ".plmun.edu.ph": ["Pamantasan ng Lungsod ng Muntinlupa"],
    ".plpasig.edu.ph": ["Pamantasan ng Lungsod ng Pasig"],
    ".pnunl.edu.ph": [
        "Philippine Normal University North Luzon",
        "Philippine Normal University North Luzon",
    ],
    ".prmsu.edu.ph": [
        "President Ramon Magsaysay State University",
        "President Ramon Magsaysay State University",
    ],
    ".psu.edu.ph": ["Pangasinan State University"],
    ".iskolarngbayan.pup.edu.ph": [
        "Polytechnic University of the Philippines"
    ],
    ".purisima.edu.ph": ["Colegio dela Purisima Concepcion"],
    ".qcu.edu.ph": ["Quezon City University"],
    ".rsu.edu.ph": ["Romblon State University", "Romblon State University"],
    ".sccpag.edu.ph": ["Saint Columban College"],
    ".scha.edu.ph": ["South City Homes Academy", "South City Homes Academy"],
    ".sdca.edu.ph": ["ST. DOMINIC COLLEGE OF ASIA"],
    ".sdssu.edu.ph": ["North Eastern Mindanao State University"],
    ".sgen.edu.ph": ["Southville International School and College"],
    ".shc.edu.ph": ["Sacred Heart College"],
    ".sjcs.edu.ph": ["Saint Jude Catholic School"],
    ".sjit.edu.ph": ["Saint Joseph Insitute of Technology"],
    ".sksu.edu.ph": [
        "Sultan Kudarat State University",
        "Sultan Kudarat State University",
    ],
    ".slcd.edu.ph": [
        "San Lorenzo College of Davao, Inc.",
        "San Lorenzo College of Davao, Inc.",
    ],
    ".slsu.edu.ph": ["Southern Luzon State University", "SLSU"],
    ".slu.edu.ph": ["Saint Louis University"],
    ".my.smciligan.edu.ph": ["St. Michael's College"],
    ".smu.edu.ph": ["Saint Mary's University"],
    ".sorsu.edu.ph": ["Sorsogon State University"],
    ".southernleytestateu.edu.ph": [
        "Southern Leyte State University - College of Teacher Education Tomas Oppus Campus"
    ],
    ".southlandcollege.edu.ph": ["Southland College"],
    ".spcba.edu.ph": [
        "San Pedro College of Business Administration",
        "San Pedro College of Business Administration",
    ],
    ".spcpasig.edu.ph": ["Saint Paul College of Pasig"],
    ".ssct.edu.ph": [
        "Surigao del Norte State University (formerly known as Surigao State College of Technology)"
    ],
    ".ssu.edu.ph": ["Samar State University"],
    ".stellamarisdavao.edu.ph": ["Stella Maris Academy of Davao"],
    ".caloocan.sti.edu.ph": ["STI Caloocan"],
    ".carmona.sti.edu.ph": ["STI College Carmona", "STI College Carmona"],
    ".davao.sti.edu.ph": ["STI College Davao"],
    ".legazpi.sti.edu.ph": ["STI College Legazpi"],
    ".lucena.sti.edu.ph": ["STI College Lucena", "STI College Lucena"],
    ".stjude.edu.ph": ["St. Jude College Dasmariñas Cavite"],
    ".su.edu.ph": ["Silliman University"],
    ".sunn.edu.ph": ["State University of Northern Negros"],
    ".swu.edu.ph": ["Southwestern University"],
    ".tau.edu.ph": ["Tarlac Agricultural University"],
    ".thelewiscollege.edu.ph": ["The Lewis College", "The Lewis College"],
    ".tip.edu.ph": ["Technological Institute of the Philippines"],
    ".trimexcolleges.edu.ph": ["Trimex Colleges Inc."],
    ".tsu.edu.ph": ["Tarlac State University"],
    ".tup.edu.ph": ["Technological University of the Philippines"],
    ".ua.edu.ph": ["University of the Assumption"],
    ".ub.edu.ph": ["University of Batangas"],
    ".uc.edu.ph": ["University of Cebu - Banilad Campus"],
    ".ucc-caloocan.edu.ph": ["University Of Caloocan City"],
    ".ucu.edu.ph": ["Urdaneta City University"],
    ".udm.edu.ph": ["Universidad De Manila"],
    ".ue.edu.ph": [
        "University of the East, Coloocan",
        "University of the East, Manila",
    ],
    ".uerm.edu.ph": [
        "University of the East, Ramon Magsaysay Memorial Medical Center"
    ],
    ".uic.edu.ph": ["University of the Immaculate Conception"],
    ".umak.edu.ph": ["University of Makati", "University of Makati"],
    ".umindanao.edu.ph": ["University of Mindanao"],
    ".unc.edu.ph": ["University of Nueva Caceres"],
    ".unep.edu.ph": ["University of Northeastern Philippines"],
    ".uno-r.edu.ph": ["University of Negros Occidental-Recoletos"],
    ".unp.edu.ph": ["University of Northern Philippines"],
    ".up.edu.ph": ["University of the Philippines"],
    ".upb.edu.ph": ["University of the Philippines Baguio"],
    ".uphsl.edu.ph": ["University of Perpetual Help System DALTA"],
    ".uplb.edu.ph": ["University of the Philippines Los Banos"],
    ".upm.edu.ph": ["University of the Philippines Manila"],
    ".upmin.edu.ph": ["University of the Philippines Mindanao"],
    ".upv.edu.ph": ["University of the Philippines Visayas"],
    ".urios.edu.ph": ["Father Saturnino Urios University"],
    ".urs.edu.ph": [
        "University of Rizal System",
        "University of Rizal System",
    ],
    ".usa.edu.ph": ["University of San Agustin"],
    ".usc.edu.ph": ["University of San Carlos"],
    ".usep.edu.ph": ["University of Southeastern Philippines"],
    ".usi.edu.ph": ["Unibersidad de Sta Isabel"],
    ".usjr.edu.ph": ["University of San Jose Recoletos"],
    ".usls.edu.ph": ["University of St La Salle"],
    ".usm.edu.ph": ["University of Southern Mindanao"],
    ".ust-legazpi.edu.ph": ["University of Santo Tomas-Legazpi"],
    ".ust.edu.ph": ["University of Santo Tomas"],
    ".ustp.edu.ph": [
        "The University of Science and Technology of The Philippines"
    ],
    ".vmuf.edu.ph": ["Virgen Milagrosa University Foundation"],
    ".vsu.edu.ph": ["Visayas State University", "Visayas State University"],
    ".wit.edu.ph": [
        "Western Institute of Technology",
        "Western Institute of Technology",
    ],
    ".wlcormoc.edu.ph": ["Western Leyte College of Ormoc"],
    ".wmsu.edu.ph": ["Western Mindanao State University"],
    ".wvsu.edu.ph": ["West Visayas State University"],
    ".xs.edu.ph": ["Xavier School San Juan", "Xavier School Nuvali"],
    ".xu.edu.ph": ["Xavier University"],
    ".educ.ph": ["University of Eastern Philippines"],
    ".iacademy.ph": ["Information and Communications Technology Academy"],
    ".evis.net.ph": ["Leyte Normal University"],
    ".mfi.org.ph": ["MFI Polytechnic Institute"],
    ".pma.ph": ["Philippine Military Academy"],
    ".fairview.sti.ph": ["STI College Fairview"],
    ".novaliches.sti.ph": ["STI College, Philippines"],
    ".usp.ph": ["University of Southern Philippines Foundation"],
    ".cust.pk": ["Capital University of Science and Technology"],
    ".abasyn.edu.pk": ["Abasyn University Peshawar"],
    ".abasynisb.edu.pk": [
        "Abasyn University Islamabad Campus",
        "Abasyn University Islamabad Campus",
    ],
    ".acecollege.edu.pk": ["ACE College for Women"],
    ".agc.edu.pk": ["Apex group of colleges", "Apex group of colleges"],
    ".aiou.edu.pk": ["Allama Iqbal Open University"],
    ".aitchison.edu.pk": ["Aitchison College Lahore"],
    ".ajku.edu.pk": ["Azad Jammu and Kashmir University"],
    ".aldirasat.edu.pk": ["University of Islamic Studies"],
    ".aligarh.edu.pk": ["Aligarh Institute of Technology"],
    ".alkhair.edu.pk": ["Al-Khair University"],
    ".ami.edu.pk": ["Asian Management Institute"],
    ".angelscollege.edu.pk": ["angels international college"],
    ".apiit.edu.pk": [
        "Asia Pacific Institute of Information Technology Pakistan (APIIT PAK)"
    ],
    ".aror.edu.pk": [
        "Aror University",
        "Aror University of Art, Architecture, Design and Heritage",
    ],
    ".au.edu.pk": ["Air University"],
    ".aup.edu.pk": ["North West Frontier Province Agricultural University"],
    ".awkum.edu.pk": [
        "Abdul Wali Khan University Mardan, Khyber Pakhtunkhwa Pakistan",
        "Abdul Wali Khan University Mardan, Khyber Pakhtunkhwa Pakistan",
    ],
    ".bahria.edu.pk": ["Bahria University"],
    ".bbsul.edu.pk": ["Benazir Bhutto Shaheed University Lyari"],
    ".beaconite.edu.pk": [
        "Beaconhouse School System",
        "Beaconhouse School System",
    ],
    ".bh.edu.pk": [
        "Beaconhouse National University",
        "Beaconhouse National University",
    ],
    ".bisemultan.edu.pk": [
        "Board of Intermediate & Secondary Education, Multan"
    ],
    ".bnu.edu.pk": [
        "Beacon House National University ",
        "Beacon House National University",
    ],
    ".buetk.edu.pk": [
        "Balochistan University of Engineering and Technology Khuzdar"
    ],
    ".buitms.edu.pk": [
        "Balochistan University of Information Technology &amp; Management Sciences "
    ],
    ".bvsparsischool.edu.pk": [
        "BAI VIRBAIJI SOPARIVALA PARSI HIGH SCHOOL",
        "BAI VIRBAIJI SOPARIVALA PARSI HIGH SCHOOL",
    ],
    ".bzu.edu.pk": ["Bahauddin Zakariya University, Multan"],
    ".case.edu.pk": ["CASE"],
    ".cecos.edu.pk": ["Cecos Univeristy of Information Technology"],
    ".cedar.edu.pk": ["Cedar College"],
    ".ce.ceme.edu.pk": ["CEME, NUST Pakistan", "CEME, NUST Pakistan"],
    ".mts.ceme.edu.pk": [
        "College of Electrical and Mechanical Engineering, NUST, Pakistan"
    ],
    ".ciit-attock.edu.pk": [
        "COMSATS Institute of Information Technology, Attock"
    ],
    ".ciitlahore.edu.pk": [
        "COMSATS Institute of Information Technology, Lahore"
    ],
    ".ciitwah.edu.pk": ["COMSATS INSTITUTE OF INFORMATION AND TECHNOLOGY"],
    ".student.comsats.edu.pk": [
        "Comsats University Islamabad",
        "Comsats University Islamabad",
    ],
    ".concordia.edu.pk": ["Concordia Colleges"],
    ".cosmiq.edu.pk": ["COSMIQ Institute of Technology"],
    ".crescentschool.edu.pk": ["Crescent Model Higher Secondary School"],
    ".cuiatd.edu.pk": [
        "Comsats University Abbottabad Campus",
        "Comsats University Abbottabad Campus",
    ],
    ".cuiatk.edu.pk": ["COMSATS University Islamabad"],
    ".cuilahore.edu.pk": ["COMSATS University Islamabad, Lahore Campus"],
    ".cuisahiwal.edu.pk": [
        "COMSATS University Islamabad - Sahiwal Campus",
        "Comsats University Sahiwal",
    ],
    ".cuivehari.edu.pk": ["COMSATS university Islamabad"],
    ".cuiwah.edu.pk": ["COMSATS University Islamabad, Wah Cantt"],
    ".dadabhoy.edu.pk": ["Dadabhoy Institute of Higher Education"],
    ".duet.edu.pk": ["Dawood University of Engineering and Technology"],
    ".duhs.edu.pk": ["Dow University of Health Sciences"],
    ".engroschools.edu.pk": ["Engro Grammar School"],
    ".fast.edu.pk": ["The Fast School & Science Academy"],
    ".formanite.fccollege.edu.pk": [
        "Forman Christian College (A Chartered University)"
    ],
    ".fccollege.edu.pk": ["Forman Christian College"],
    ".fcoe.edu.pk": ["Fazaia college of education for women"],
    ".fgqadc.edu.pk": ["FG Quaid-i-Azam Degree College, Rawalpindi, Pakistan"],
    ".bhs.fjwu.edu.pk": [
        "Fatima Jinnah Women University, Rawalpindi, Pakistan ",
        "Fatima Jinnah Women University, Rawalpindi, Pakistan",
    ],
    ".se.fjwu.edu.pk": ["Fatima Jinnah Women University, Rawalpindi"],
    ".fmhcmd.edu.pk": ["Fatima Memorial College of Medicine and Dentistry"],
    ".fps.edu.pk": ["Foundation Public School"],
    ".froebels.edu.pk": [
        "Froebel's International School",
        "Froebel's International School",
    ],
    ".fu.edu.pk": ["FATA University"],
    ".fuuast.edu.pk": [
        "Federal Urdu University of Arts,Science and Technology"
    ],
    ".fuuastisb.edu.pk": [
        "Federal Urdu University of Arts, Sciences & Technology",
        "Federal Urdu University of Arts, Sciences & Technology",
    ],
    ".gandhara.edu.pk": ["Gandhara Institute of Medical Sciences"],
    ".gcbskp.edu.pk": ["Govt. Graduate College, Civil Lines, Sheikhupura"],
    ".gcslahore.edu.pk": [
        "Govt Graduate College of Science Wahdat Road Lahore"
    ],
    ".gcuf.edu.pk": ["Government College University Faisalabad"],
    ".gcwuf.edu.pk": ["Government College Women University Faisalabad"],
    ".gift.edu.pk": ["Gift University"],
    ".giki.edu.pk": ["Ghulam Ishaq Khan Institute"],
    ".gim.edu.pk": [
        "Gujrat Institute of Management Sciences",
        "Gujrat Institute of Management Sciences",
    ],
    ".gist.edu.pk": ["Gangdara Institute Of Science &amp; Technology"],
    ".global.edu.pk": ["The Global College Lahore"],
    ".gu.edu.pk": ["Gomal University"],
    ".sse.habib.edu.pk": ["Habib University"],
    ".st.habib.edu.pk": ["Habib University"],
    ".habibschools.edu.pk": ["Habib Schools"],
    ".hamdard.edu.pk": ["Hamdard University"],
    ".hitecuni.edu.pk": ["Hitec University"],
    ".hu.edu.pk": ["Hazara University"],
    ".hup.edu.pk": ["HAJVERY UNIVERSITY"],
    ".iac.edu.pk": ["Institute for Art and Culture"],
    ".iba-suk.edu.pk": ["Institute Of Business Administration Sukkur"],
    ".iba.edu.pk": ["Institute of Business Administration (IBA)"],
    ".ibacc.edu.pk": ["IBA Community Colleges & Schools"],
    ".ibitpu.edu.pk": [
        "Institute of Business and Information Technology",
        "University of the Punjab",
        "Quaid-i-Azam Campus, Lahore, Punjab",
    ],
    ".icp.edu.pk": ["Islamia College Peshawar"],
    ".ifs.edu.pk": ["Isra Foundation Schools"],
    ".iiee.edu.pk": ["Institute of Industrial Electronics Engineering"],
    ".iiu.edu.pk": ["International Islamic University"],
    ".imcbf10-3.edu.pk": [
        "Islamabad Model College for Boys F-10/3, Islamabad, Pakistan",
        "Islamabad Model College for Boys F-10/3, Islamabad",
    ],
    ".imsciences.edu.pk": ["Institute of Management Sciences"],
    ".indus.edu.pk": ["Indus Institute of Higher Education"],
    ".inuswat.edu.pk": ["IQRA National University - Swat Campus"],
    ".iobm.edu.pk": ["Institute Of Business Management"],
    ".iqra.edu.pk": ["iqra university"],
    ".iqraisb.edu.pk": ["Iqra University"],
    ".isra.edu.pk": ["Isra University"],
    ".itu.edu.pk": ["Information Technology University"],
    ".iunc.edu.pk": ["Iqra University", "Iqra University"],
    ".jinnah.edu.pk": ["Mohammad Ali Jinnah University"],
    ".juw.edu.pk": ["Jinnah University for Women"],
    ".kasbit.edu.pk": ["KASB Institute of Technology"],
    ".kfueit.edu.pk": [
        "Khwaja Fareed University of Engineering and Information Technology",
        "Khwaja Fareed University of Engineering and Information Technology",
    ],
    ".kiet.edu.pk": ["Karachi Institute of Economics & Technology (KIET)"],
    ".kite.edu.pk": ["Karachi Institute of Technology and Entrepreneurship"],
    ".kiu.edu.pk": ["Karakoram International University"],
    ".kkkuk.edu.pk": ["Khushal Khan Khattak University Karak"],
    ".kmdc.edu.pk": ["Karachi Medical and Dental College"],
    ".ksa.edu.pk": ["Karachi School of Art"],
    ".ksbl.edu.pk": ["Karachi School of Business & Leadership"],
    ".kust.edu.pk": ["Kohat University of Science and Technology  (KUST)"],
    ".lcwu.edu.pk": ["Lahore College for Women University"],
    ".leads.edu.pk": [
        "Lahore Leads University, Lahore, Pakistan.",
        "Lahore Leads University, Lahore, Pakistan.",
    ],
    ".lgsparagon.edu.pk": ["Lahore Grammar School Paragon City"],
    ".lgu.edu.pk": ["Lahore Garrison University"],
    ".lmdc.edu.pk": ["Lahore Medical and Dental College"],
    ".luawms.edu.pk": [
        "Lasbela University of Agriculture, Water & Marine Sciences"
    ],
    ".lumhs.edu.pk": [
        "Liaquat University of Medical &amp; Health Sciences Jamshoro"
    ],
    ".lums.edu.pk": ["Lahore University of Management Sciences"],
    ".lyceumschool.edu.pk": ["Lyceum School"],
    ".maju.edu.pk": [
        "Muhammad Ali Jinnah University",
        "Muhammad Ali Jinnah University",
    ],
    ".maven.edu.pk": ["Maven School System", "Maven School System"],
    ".students.mcs.edu.pk": ["Military College of Signals"],
    ".mehrancolleges.edu.pk": ["Mehran Colleges", "Mehran Colleges"],
    ".miu.edu.pk": ["Mohi-ud-Din Islamic University"],
    ".mnsuam.edu.pk": [
        "Muhammad Nazwaz Shareef University of Agriculture, Multan",
        "MNS-University of Agriculture, Multan",
    ],
    ".mnsuet.edu.pk": [
        "Muhammad Nawaz Sharif University of Engineering and Technology"
    ],
    ".muet.edu.pk": ["Mehran University of Engineering &amp; Technology"],
    ".muetkhp.edu.pk": [
        "Mehran University of Engineering and Technology, Shaheed Zulfiquar Ali Bhutto Campus, Khairpur Mir's"
    ],
    ".myers.edu.pk": ["Myer's College"],
    ".namal.edu.pk": ["Namal Institute Minawali"],
    ".nca.edu.pk": ["National College of Arts"],
    ".ncbae.edu.pk": [
        "National College Of Business Administration And Economics, Lahore Pakistan",
        "National College Of Business Administration And Economics, Lahore Pakistan",
    ],
    ".neduet.edu.pk": ["NED University of Engineering and Technology Karachi"],
    ".nfciet.edu.pk": [
        "NFC Institute of Engineering and Technology",
        "NFC Institute of Engineering and Technology, Multan, Pakistan",
    ],
    ".nhu.edu.pk": ["Nazeer Hussain University", "Nazeer Hussain University"],
    ".niit.edu.pk": ["NASTP Institute of Information Technology"],
    ".nsu.edu.pk": ["National Skills University, Islamabad"],
    ".student.nu.edu.pk": [
        "National Univeristy of Computer and Emerging Science (NUCES)",
        "The Foundation for Advancement of Science and Technology (FAST)",
    ],
    ".nu.edu.pk": [
        "FAST - National University of Computer and Emerging Sciences (NUCES)",
        "National University of Computer &amp; Emerging Sciences",
    ],
    ".numl.edu.pk": ["National University of Modern Languages"],
    ".numls.edu.pk": ["National University of Modern Languages", "NUML "],
    ".nust.edu.pk": ["National University of Science and Technology"],
    ".nutech.edu.pk": [
        "National University of Technology (NUTECH), Islamabad"
    ],
    ".nwfpuet.edu.pk": ["University of Engineering and Technology Peshawar"],
    ".fecid.paf-iast.edu.pk": [
        "Pak-Austria Fachhochschule Institute of Applied Sciences and Technology",
        "Pak-Austria Fachhochschule Institute of Applied Sciences and Technology",
    ],
    ".pafkiet.edu.pk": ["Karachi Institute Of Economics And Technology"],
    ".pakaims.edu.pk": ["Institute of Management Sciences, Lahore (IMS)"],
    ".pics.edu.pk": ["Punjab Institute of Computer science"],
    ".pieas.edu.pk": [
        "Pakistan Institute of Engineering and Applied Sciences"
    ],
    ".pscit.edu.pk": ["Peak Solutions"],
    ".pu.edu.pk": ["University of the Punjab"],
    ".pucit.edu.pk": ["Punjab University College of Information Tecnology"],
    ".pugc.edu.pk": ["University of the Punjab, Gujranwala Campus"],
    ".qau.edu.pk": ["Quaid-i-Azam University"],
    ".qu.edu.pk": ["Qarshi University"],
    ".quest.edu.pk": [
        "Quaid-e-Awam University of Engineering, Science and Technology, Nawabshah, District Shaheed Benazirabad, Sindh, Pakistan"
    ],
    ".qurtuba.edu.pk": [
        "Qurtuba University of Science and Infromation Technology"
    ],
    ".riphah.edu.pk": ["Riphah International Univeristy"],
    ".salu.edu.pk": ["Shah Abdul Latif University Khairpur"],
    ".scarsdale.edu.pk": ["Scarsdale International School"],
    ".seecs.edu.pk": ["School of Electrical Engineering and Computer Science"],
    ".shu.edu.pk": ["Salim Habib University"],
    ".simat.edu.pk": ["Sindh Institute of Management & Technology (SIMT)"],
    ".smiu.edu.pk": ["Sindh Madrassatul Islam University"],
    ".smme.edu.pk": [
        "School of Mechanical and Manufacturing Engineering, National University of Sciences and Technology, Islamabad, Pakistan"
    ],
    ".st-michaels.edu.pk": ["St Michaels College", "St Michaels Alevels"],
    ".suit.edu.pk": [
        "Sarhad University of Science &amp; Information Technology, Peshawar "
    ],
    ".sundarstem.edu.pk": ["SundarSTEM"],
    ".superior.edu.pk": ["The Superior College "],
    ".szabist.edu.pk": ["SZABIST University"],
    ".tip.edu.pk": ["Textile Institute of Pakistan"],
    ".tme.edu.pk": [
        "Roots millennium school",
        "Roots millennium school ( The Millennium Education)",
    ],
    ".tmhs.edu.pk": ["Tahir Model High School Choti Zareen"],
    ".scholar.tu.edu.pk": ["Thal University Bhakkar"],
    ".tuf.edu.pk": ["University of Faisalabad"],
    ".uaar.edu.pk": ["University of Arid Agriculture Rawalpindi"],
    ".ucp.edu.pk": ["University of Central Punjab"],
    ".ue.edu.pk": ["University of Education"],
    ".student.uet.edu.pk": [
        "University of Engineering and Technology Lahore, Pakistan",
        "University of Engineering and Technology Lahore, Pakistan",
    ],
    ".uetmardan.edu.pk": [
        "The University of Engineering & Technology, Mardan"
    ],
    ".uetpeshawar.edu.pk": [
        "Khyber Pakhtunkhwa University of Engineering & Technology Peshawar",
        "University of Engineering and Technology, Peshawar",
    ],
    ".uettaxila.edu.pk": ["University of Engineering and Technology Taxila"],
    ".uitu.edu.pk": ["UIT University"],
    ".umt.edu.pk": ["University of Management and Technology"],
    ".unw.edu.pk": ["University of NorthWest"],
    ".um.uob.edu.pk": [
        "University of Balochistan",
        "University of Balochistan, Quetta, Pakistan.",
    ],
    ".uoe.edu.pk": ["University of East"],
    ".uog.edu.pk": ["University of Gujrat"],
    ".uok.edu.pk": ["University of Karachi"],
    ".uol.edu.pk": ["The University of Lahore"],
    ".uom.edu.pk": ["University of Malakand"],
    ".uop.edu.pk": ["University of Peshawar"],
    ".uos.edu.pk": ["University of Sargodha"],
    ".uosahiwal.edu.pk": ["University of sahiwal"],
    ".uot.edu.pk": ["University of Turbat"],
    ".student.uow.edu.pk": ["University of Wah"],
    ".usa.edu.pk": ["University of South Asia"],
    ".usindh.edu.pk": ["University of Sindh"],
    ".uskt.edu.pk": ["University of Sialkot"],
    ".ustb.edu.pk": ["University of Science &amp; Technology Bannu"],
    ".uvas.edu.pk": ["University of Veterinary &amp; Animal Science"],
    ".vcomsats.edu.pk": ["Comsats University Islamabad (Virtual Campus)"],
    ".vu.edu.pk": [
        "Pakistan Virtual University",
        "Virtual University of Pakistan",
    ],
    ".wahmedicalcollege.edu.pk": ["Wah Medical College"],
    ".westminster.edu.pk": ["Westminster Academy Islamabad"],
    ".wisdomhouse.edu.pk": ["Wisdom House Degree College"],
    ".zawiya.edu.pk": ["Zawiya Academy"],
    ".zu.edu.pk": ["The Ziauddin University"],
    ".niab.org.pk": ["Nuclear Institute for Agriculture and Biology (NIAB)"],
    ".szabist-isb.pk": [
        "Shaheed Zulfiqar Ali Butto Institute of Information Technology"
    ],
    ".szabist.pk": [
        "Szabist - Shaheed Zulfikar Ali Bhutto Institute of Science and Technology"
    ],
    ".2lo.pl": [
        "Vocational Technical High School for Computer Science No. 2 name of Henryk Sienkiewicz in Kolobrzeg"
    ],
    ".2lopoznan.pl": [
        "II Liceum Ogólnokształcące im. Generałowej Zamoyskiej i Heleny Modrzejewskiej w Poznaniu"
    ],
    ".2slo.pl": [
        "2 Społeczne Liceum Ogólnokształcące STO",
        "2nd SLO Jasienica High School",
    ],
    ".ahns.pl": [
        "Akademia Handlowa Nauk Stosowanych w Radomiu",
        "Radom Academy of Economics",
    ],
    ".dyd.akademiabialska.pl": [
        "Akademia Bialska im. Jana Pawła II",
        "John Paul II University in Biała Podlaska",
    ],
    ".stud.akademiabialska.pl": [
        "Akademia Bialska im. Jana Pawła II",
        "John Paul II University in Biała Podlaska",
    ],
    ".student.akademiaslaska.pl": [
        "Akademia Śląska",
        "Higher Technical School in Katowice (Akademia Śląska)",
    ],
    ".akademiata.pl": [
        "Akademia Techniczno-Artystyczna Nauk Stosowanych w Warszawie"
    ],
    ".aktywnaedukacja.pl": ["NoBell"],
    ".ans-elblag.pl": [
        "Akademia Nauk Stosowanych w Elblągu",
        "University of Applied Sciences in Elbląg",
    ],
    ".student.ansleszno.pl": [
        "Akademia Nauk Stosowanych im. J. A. Komeńskiego"
    ],
    ".atins.pl": ["Akademia Techniczno-Informatyczna w Naukach Stosowanych"],
    ".pb.bialystok.pl": ["Technical University of Bialystok"],
    ".ath.bielsko.pl": ["University of Bielsko-Biala"],
    ".lo5.bielsko.pl": ["V Liceum Ogólnokształcące"],
    ".wsa.bielsko.pl": ["School of Administration"],
    ".biskupiak.pl": [
        "XXI Liceum Ogólnokształcące im. św. Stanisława Kostki w Lublinie (BISKUPIAK)"
    ],
    ".zs1.bochnia.pl": ["Zespół Szkół Nr 1  im. Stanisława Staszica w Bochni"],
    ".zse.boleslawiec.pl": [
        "Zespół Szkół Elektronicznych im. Ignacego Domeyki w Bolesławcu"
    ],
    ".amuz.bydgoszcz.pl": ["Music Academy Felix Nowowiejski in Bydgoszcz"],
    ".student.wsb.bydgoszcz.pl": ["Wyższa Szkoła Bankowa w Bydgoszczy"],
    ".4lo.bytom.pl": [
        "IV Liceum Ogólnokształcące im. Bolesława Chrobrego w Bytomiu"
    ],
    ".cdv.pl": ["Collegium Da Vinci"],
    ".cedim.pl": ["Children and Youth Programming School"],
    ".pwsz.chelm.pl": [
        "Państwowa Wyższa Szkoła Zawodowa w Chełmie",
        "The State School of Higher Education in Chełm",
    ],
    ".zst.chelm.pl": [
        "Zespół Szkół Technicznych w Chełmie",
        "Technical School Complex in Chełm",
    ],
    ".zsoiz.ciezkowice.pl": [
        "Zespol Szkol Ogolnoksztalcacych i Zawodowych imieniem Ignacego Jana Paderewskiego w Ciezkowicach"
    ],
    ".cksulechow.pl": [
        "Centrum Kształcenia Zawodowego i Ustawicznego w Sulechowie.",
        "Center for Vocational and Continuing Education in Sulechow.",
        "https://cksulechow.pl",
        "https://www.google.pl/maps/place/Centrum+Kszta%C5%82cenia+Zawodowego+i+Ustawicznego/@52.0781824,15.6279251,14z/data=!4m6!3m5!1s0x47066dcd4058d51f:0x4a38ebc1da9cf9b0!8m2!3d52.080011!4d15.6174282!16s%2Fg%2F11cs04kv9_?entry=ttu&g_ep=EgoyMDI1MDIyNC4wIKXMDSoASAFQAw%3D%3D",
        "roman.stohnii@cksulechow.pl",
    ],
    ".online.ckziu-elektryk.pl": ["CKZiU Elektryk"],
    ".ckztarnow.pl": [
        "Centrum Kształcenia Zawodowego,Tarnów",
        "Center for Vocational Education,Tarnow",
    ],
    ".studenci.collegiumwitelona.pl": [
        "Collegium Witelona Uczelnia Państwowa",
        "Witelon Collegium State University",
    ],
    ".collegiumwitelona.pl": [
        "Collegium Witelona Uczelnia Państwowa",
        "Witelon Collegium State University",
    ],
    ".onlineszkolafilmowa.com.pl": [
        "Warszawska Szkoła Filmowa",
        "Warsaw Film School",
    ],
    ".primus.com.pl": ["Robert Schuman High School of Primus Foundation"],
    ".sp1.skawina.com.pl": ["Szkoła Podstawowa nr 1 w Skawinie"],
    ".sp13leszno.com.pl": [
        "Szkoła Podstawowa nr 13, z oddziałami integracyjnymi im. Jana Pawła II w Lesznie"
    ],
    ".spoleczna.com.pl": ["Group of social schools STO in Augustow"],
    ".technikumlodz.com.pl": ["TECHNIKUM ADMINISTRACYJNO-USŁUGOWE, Lodz"],
    ".wst.com.pl": [
        "Wyższa Szkoła Techniczna w Katowicach",
        "University of Technology, Katowice, Poland",
    ],
    ".cyfroweszkoly.pl": ["XI Liceum ogólnokształcące w Olsztynie"],
    ".zsoit.czeladz.pl": [
        "Zespół Szkół Ogólnokształcących i Technicznych w Czeladzi"
    ],
    ".ajd.czest.pl": ["Jan Dlugosz University in Czestochowa"],
    ".lo3msz.czest.pl": [
        "W. Biegański School Complex in Czestochowa",
        "http://lo3msz.czest.pl",
        "lo3@edukacja.czestochowa.pl",
    ],
    ".pcz.czest.pl": ["Technical University of Czestochowa"],
    ".debinka.pl": ["Kolegium Edukacyjne PSO"],
    ".domeyko.pl": ["CXXII Liceum Ogólnokształcące im. Ignacego Domeyki"],
    ".live.edja.pl": [
        "Prywatna Szkoła Podstawowa i Liceum im. Królowej Jadwigi w Lublinie"
    ],
    ".ib.1slo.edu.pl": [
        "I Społeczne Liceum Ogólnokształcące z Oddziałami Międzynarodowymi (IB) im. Maharadży Jam Saheba Digvijay Sinhji"
    ],
    ".3lo.edu.pl": [
        "3LO im. Stefana Batorego w Chorzowie, Polska",
        "3LO named after Stefan Batory in Chorzów, Poland",
    ],
    ".afm.edu.pl": [
        "Krakowska Akademia im. Andrzeja Frycza Modrzewskiego",
        "Andrzej Frycz Modrzewski Krakow University",
    ],
    ".student.agh.edu.pl": ["AGH University of Science and Technology"],
    ".agh.edu.pl": ["AGH University of Science and Technology"],
    ".student.ajp.edu.pl": [
        "Akademia im. Jakuba z Paradyża w Gorzowie Wielkopolskim"
    ],
    ".ajp.edu.pl": [
        "The Jacob of Paradies University in Gorzow Wielkopolski",
        "Akademia im. Jakuba z Paradyża w Gorzowie Wielkopolskim",
    ],
    ".akademeia.edu.pl": ["Akademeia Tutorial College"],
    ".akademiakaliska.edu.pl": [
        "Akademia Kaliska im. Prezydenta Stanisława Wojciechowskiego"
    ],
    ".akademiata.edu.pl": [
        "Wyższa Szkoła Ekologii i Zarządzania w Warszawie",
        "University of Ecology and Management",
    ],
    ".aksim.edu.pl": [
        "Akademia Kultury Społecznej i Medialnej",
        "Academy of Social and Media Culture",
    ],
    ".stu.al.edu.pl": ["Akademia Łomżyńska", "University of Lomza"],
    ".al.edu.pl": ["Akademia Łomżyńska", "University of Lomza"],
    ".alestaszic.edu.pl": [
        "Zespół Szkół Zawodowych im. Stanisława Staszica w Aleksandrowie Łódzkim"
    ],
    ".ali.edu.pl": ["Uniwersytet Ali im. Harmonii"],
    ".amb.edu.pl": ["Medical Academy in Bialystok"],
    ".amwaw.edu.pl": ["Medical Academy in Warszawa"],
    ".studenci.ans-gniezno.edu.pl": [
        "Akademia Nauk Stosowanych im. Hipolita Cegielskiego w Gnieźnie",
        "Hipolit Cegielski State University of Applied Sciences in Gniezno",
    ],
    ".student.ans-ns.edu.pl": [
        "Akademia Nauk Stosowanych w Nowym Sączu",
        "https://www.ans-ns.edu.pl/",
    ],
    ".ansgk.edu.pl": [
        "Akademia Nauk Stosowanych Gospodarki Krajowej w Kutnie"
    ],
    ".student.anstar.edu.pl": [
        "Akademia Nauk Stosowanych w Tarnowie",
        "Academy of Science in Tarnow",
    ],
    ".ap.edu.pl": ["Polonia University in Częstochowa"],
    ".aps.edu.pl": [
        "Akademia Pedagogiki Specjalnej",
        "The Academy of Special Education (The Maria Grzegorzewska University)",
    ],
    ".aspkat.edu.pl": ["Fine Arts Academy in Katowice"],
    ".aster.edu.pl": [
        "Instytut Edukacji Aster",
        "The Aster Institute of Education",
    ],
    ".at.edu.pl": ["Aleksander Zelwerowicz State Theatre Academy"],
    ".student.atar.edu.pl": ["Akademia Tarnowska"],
    ".ath.edu.pl": ["University of Bielsko-Biala"],
    ".augustyniak.edu.pl": [
        "Prywatna Szkoła Podstawowa Krzysztofa Augustyniaka"
    ],
    ".awf.edu.pl": ["Physical Education Academy Jozef Pilsudski in Warsaw"],
    ".awl.edu.pl": [
        "General Tadeusz Kościuszko Military University of Land Forces"
    ],
    ".batory.edu.pl": ["Liceum im. Stefana Batorego"],
    ".brzozowa5.edu.pl": [
        "Zespół Szkół Polskiego Górnictwa Naftowego i Gazownictwa",
        "Complex of Schools of Polish Oil Mining and Gas Industry",
    ],
    ".bsr.edu.pl": ["Bednarska Szkoła Realna"],
    ".camk.edu.pl": [
        "Nicolaus Copernicus Astronomical Center Polish Academy of Sciences",
        "Centrum Astronomiczne im. Mikołaja Kopernika Polskiej Akademii Nauk",
    ],
    ".cft.edu.pl": [
        "Center for Theoretical Physics, Polish Academy of Sciences"
    ],
    ".chopin.edu.pl": ["Music Academy Fryderyk Chopin in Warszaw"],
    ".civitas.edu.pl": ["Collegium Civitas"],
    ".classicalschool.edu.pl": ["Classical School"],
    ".collegium.edu.pl": ["Collegium Civitas"],
    ".davinci.edu.pl": [
        "Leonardo Da Vinci Niepubliczna Szkoła Podstawowa",
        "Leonardo Da Vinci Nonpublic Elementary School",
    ],
    ".student.dsw.edu.pl": [
        "Dolnośląska Szkoła Wyższa",
        "University of Lower Silesia",
    ],
    ".dsw.edu.pl": ["\ufeffDolnośląska Szkoła Wyższa"],
    ".eans-nt.edu.pl": ["Akademia Nauk Stosowanych w Nowym Targu"],
    ".eas.edu.pl": ["European Academy of Arts in Warsaw"],
    ".sluchacz.effekt.edu.pl": ["EFFEKT"],
    ".ek.edu.pl": [
        "II Ogólnokształcące Liceum Ekologiczne z Oddziałami Integracyjnymi w Zielonej Górze"
    ],
    ".elektronik.edu.pl": [
        "Zespół Szkół Elektronicznych im. Bohaterów Westerplatte w Radomiu",
        "Westerplatte Heroes Electronic Schools Complex, Radom",
    ],
    ".elektryk.edu.pl": ["Zespol Szkol Elektrycznych"],
    ".lo1.elodz.edu.pl": [
        "I Liceum Ogólnokształcące im. Mikołaja Kopernika w Łodzi, Polska",
        "I High School in Lodz, Poland",
    ],
    ".lo12.elodz.edu.pl": [
        "XII Liceum Ogólnokształcące im. Stanisława Wyspiańskiego w Łodzi",
        "Stanislaw Wyspianski 12th High School in Lodz",
    ],
    ".lo25.elodz.edu.pl": [
        "XXV Liceum Ogólnokształcące im. Stefana Żeromskiego w Łodzi",
        "Stefan Zeromski 25th High School in Lodz",
    ],
    ".lo26.elodz.edu.pl": [
        "XXVI Liceum Ogólnokształcące im. Krzysztofa Kamila Baczyńskiego w Łodzi",
        "Krzysztof Kamil Baczynski 26th High School in Lodz",
    ],
    ".lo31.elodz.edu.pl": [
        "\ufeffXXXI Liceum Ogólnokształcące im. Ludwika Zamenhofa w Łodzi",
        "Ludwik Zamenhof 31st High School in Lodz",
    ],
    ".sp34.elodz.edu.pl": [
        "SP34",
        "PRIMARY SCHOOL NO. 34  IM.WISLAWA SZYMBORSKA IN LODZ",
    ],
    ".zsgt.elodz.edu.pl": ["ZESPÓŁ SZKÓŁ GEODEZYJNO-TECHNICZNYCH W ŁODZI"],
    ".zsp10.elodz.edu.pl": [
        "Zespół szkół elektroniczno-informatycznych imienia Jana Szczepanika w Łodzi"
    ],
    ".zsp20.elodz.edu.pl": [
        "Zespół Szkół Edukacji Technicznej im. Marszałka Józefa Piłsudskiego w Łodzi",
        "School Complex of Technical Education named after Marshal Joseph Pilsudski in Lodz",
    ],
    ".zsp5.elodz.edu.pl": [
        "Zespół Szkół Ponadpodstawowych Nr 5 im. Króla Bolesława Chrobrego"
    ],
    ".zsp9.elodz.edu.pl": [
        "Zespół Szkół Politechnicznych im. Komisji Edukacji Narodowej",
        "al. Politechniki 38,",
        "93-590 Łódź",
    ],
    ".zsti.elodz.edu.pl": [
        "Zespół Szkół Techniczno - Informatycznych w Łodzi"
    ],
    ".eppuz.edu.pl": ["Akademia Nauk Stosowanych w Nowym Targu"],
    ".europejskauczelnia.edu.pl": [
        "Europejska Uczelnia Ekonomiczno-Informatyczna"
    ],
    ".ewsie.edu.pl": [
        "Europejska Uczelnia Informatyczno - Ekonomiczna w Warszawie"
    ],
    ".ezn.edu.pl": ["Elektroniczne Zakłady Naukowe"],
    ".fsdm.edu.pl": ["Fundacja SPEŁNIENIE DZIECIĘCYCH MARZEŃ"],
    ".fundacjaszkolna.edu.pl": ["Liceum Fundacji Szkolnej"],
    ".fuw.edu.pl": [
        "Wydział Fizyki Uniwersytetu Warszawskiego",
        "Faculty of Physics University of Warsaw",
        "# fuw.edu.pl for teachers",
        "# okwf.fuw.edu.pl for students",
        "# https://www.fuw.edu.pl/poczta.html",
    ],
    ".gssr.edu.pl": [
        "The Graduate School for Social Research, Institute of Philosophy and Sociology Polish Academy of Sciences"
    ],
    ".gwsp.edu.pl": [
        "Górnośląska Wyższa Szkoła Przedsiębiorczości im. Karola Goduli",
        "Upper Silesian University of Entrepreneurship Karola Goduli",
    ],
    ".herbert99lo.edu.pl": [
        "XCIX Liceum Ogólnokształcące z Oddziałami Dwujęzycznymi im. Zbigniewa Herberta w Warszawie"
    ],
    ".humanitas365.edu.pl": [
        "Wyższa szkoła Humanitas",
        "High school humanitas in Sosnowiec",
    ],
    ".icm.edu.pl": [
        "Interdyscyplinarne Centrum Modelowania Matematycznego i Komputerowego Uniwersytetu Warszawskiego",
        "Interdisciplinary Centre for Mathematical and Computational Modelling University of Warsaw",
    ],
    ".ifj.edu.pl": ["Institute of Nuclear Physics Polish Academy of Sciences"],
    ".igf.edu.pl": [
        "Instytut Geofizyki Polskiej Akademii Nauk",
        "Institute of Geophysics, Polish Academy of Sciences",
    ],
    ".student.ignatianum.edu.pl": ["Akademia Ignatianum"],
    ".ikifp.edu.pl": [
        "Instytut Katalizy i Fizykochemii Powierzchni PAN im. Jerzego Habera",
        "Jerzy Haber Institute of Catalysis and Surface Chemistry, Polish Academy of Sciences",
    ],
    ".infotech.edu.pl": [
        "Technikum Programistyczne INFOTECH w Białymstoku",
        "Software Development Technical High School INFOTECH in Białystok",
    ],
    ".ios.edu.pl": [
        "Instytut Ochrony Środowiska - Państwowy Instytut Badawczy",
        "Institute of Environment Protection - National Research Institute",
    ],
    ".kasprzak.edu.pl": [
        "Zespol Szkol nr 36 im. Marcina Kasprzaka w Warszawie",
        "School Complex No. 36 Marina Kasprzaka in Warsaw",
    ],
    ".kcpd.edu.pl": ["Krishna Chand Schools", "Krishna Chand Schools"],
    ".kopernik.edu.pl": [
        "XXXIII Liceum Ogólnokształcące Dwujęzyczne im. Mikołaja Kopernika w Warszawie"
    ],
    ".kozminski.edu.pl": [
        "Akademia Leona Koźmińskiego",
        "Kozminski University",
    ],
    ".ksw.edu.pl": ["Andrzej Frycz Modrzewski Cracow College"],
    ".student.kul.edu.pl": [
        "Katolicki Uniwersytet Lubelski Jana Pawła II",
        "John Paul II Catholic University of Lublin",
    ],
    ".kut.edu.pl": [
        "Koszalin University of Technology",
        "Koszalin University of Technology",
    ],
    ".kwspz.edu.pl": ["Krakowska Wyższa Szkoła Promocji Zdrowia"],
    ".law.edu.pl": ["Lotnicza Akademia Wojskowa"],
    ".lazarski.edu.pl": ["Uczelnia Łazarskiego", "Lazarski University"],
    ".lckziu.edu.pl": [
        "Lubelskie Centrum Kształcenia Zawodowego i Ustawicznego"
    ],
    ".gsuite.pwsz.legnica.edu.pl": [
        "The Witelon State University of Applied Sciences in Legnica",
        "Państwowa Wyższa Szkoła Zawodowa im Witelona w Legnicy",
    ],
    ".stud.pwsz.legnica.edu.pl": [
        "The Witelon State University of Applied Sciences in Legnica",
        "Państwowa Wyższa Szkoła Zawodowa im Witelona w Legnicy",
    ],
    ".studenci.pwsz.legnica.edu.pl": [
        "The Witelon State University of Applied Sciences in Legnica",
        "Państwowa Wyższa Szkoła Zawodowa im Witelona w Legnicy",
    ],
    ".pwsz.legnica.edu.pl": [
        "Państwowa Wyższa Szkoła Zawodowa im. Witelona w Legnicy",
        "The Witelon State University of Applied Sciences in Legnica",
    ],
    ".wa.legnica.edu.pl": [
        "Technikum Akademickie w Legnicy",
        "Liceum Akademickie w Legnicy",
    ],
    ".zsa.legnica.edu.pl": ["Technikum Akademickie", "Liceum Akademickie"],
    ".uczen.liceum-andrychow.edu.pl": [
        "Liceum Ogólnokształczące im. Mari Skłodowskiej-Curie nr 1"
    ],
    ".liceum-wolsztyn.edu.pl": [
        "Liceum Ogólnokształcące im. Marii Skłodowskiej-Curie w Wolsztynie"
    ],
    ".liceum3-konin.edu.pl": ["III Liceum im. Cypriana Kamila Norwida"],
    ".liceum7.edu.pl": [
        "VII Liceum Ogólnokształcące Imienia Juliusza Słowackiego w Warszawie",
        "VII Słowacki secondary school",
    ],
    ".lo-ozorkow.edu.pl": [
        "I Liceum Ogólnokształcące im. Stefana Żeromskiego w Ozorkowie"
    ],
    ".uczen.lo2kk.edu.pl": [
        "II Liceum Ogólnokształcące im. Mikołaja Kopernika"
    ],
    ".lo2kk.edu.pl": [
        "II Liceum Ogólnokształcące im. Mikołaja Kopernika w Kędzierzynie-Koźlu"
    ],
    ".lo49.edu.pl": [
        "XLIX Liceum Ogólnokształcące Z Oddziałami Dwujęzycznymi im. Johanna Wolfganga Goethego",
        "Johann Wolfang Goethe 49th High School in Warsaw",
    ],
    ".lo50.edu.pl": [
        "L Liceum Ogólnokształcące z Oddziałami integracyjnymi im. Ruy Barbosy"
    ],
    ".malachowianka.edu.pl": [
        "Liceum Ogólnokształcące im. Marszałka Stanisława Małachowskiego"
    ],
    ".mateja.edu.pl": ["II Liceum Ogólnokształcące im. Jana Matejki"],
    ".mazowiecka.edu.pl": [
        "Akademia Mazowiecka w Płocku",
        "Mazovian University in Płock",
    ],
    ".mickiewicz.edu.pl": [
        "IV Liceum Ogólnokształcące im. Adama Mickiewicza w Warszawie",
        "Adam Mickiewicz 4th High School in Warsaw",
    ],
    ".mimuw.edu.pl": [
        "The University of Warsaw",
        "Uniwersytet Warszawski",
        "Faculty of Mathematics, Informatics and Mechanics",
        "Wydział Matematyki, Informatyki i Mechaniki Uniwersytetu Warszawskiego (MIMUW)",
    ],
    ".mum.edu.pl": ["Warszawska Akademia Medyczna Nauk Stosowanych"],
    ".student.mup.edu.pl": [
        "Małopolska Uczelnia Państwowa imienia rotmistrza Witolda Pileckiego w Oświęcimiu",
        "The Witold Pilecki University of Applied Sciences in Oświęcim",
    ],
    ".mup.edu.pl": [
        "Małopolska Uczelnia Państwowa im. rotmistrza Witolda Pileckiego w Oświęcimiu",
        "MUP",
    ],
    ".narwik.edu.pl": ["Zespół Szkół im. Bohaterów Narwiku"],
    ".nencki.edu.pl": [
        "Instytut Biologii Doświadczalnej im. M. Nenckiego PAN",
        "Nencki Institute of Experimental Biology PAS",
    ],
    ".newtech.edu.pl": ["Technikum New Technology"],
    ".nobell.edu.pl": ["NoBell"],
    ".osw.edu.pl": [
        "Olsztyńska Szkoła Wyższa",
        "Olsztyn School of Higher Education",
    ],
    ".pack.edu.pl": [
        "VIII Prywatne Akademickie Liceum Ogólnokształcące",
        "Private Academic High School No 8 of Krakow, Poland",
    ],
    ".student.pansim.edu.pl": [
        "Państwowa Akademia Nauk Stosowanych im. Ignacego Mościckiego w Ciechanowie"
    ],
    ".s.pansjar.edu.pl": [
        "Państwowa Akademia Nauk Stosowanych im. ks. Bronisława Markiewicza w Jarosławiu",
        "National Academy of Applied Sciences in Jarosław",
    ],
    ".pb.edu.pl": ["Bialystok University of Technology"],
    ".pbs.edu.pl": ["Bydgoszcz University of Science and Technology"],
    ".pg.edu.pl": ["Technical University of Gdansk"],
    ".pio.edu.pl": ["Katolicka Szkoła Podstawowa im. św. Ojca Pio w Zamościu"],
    ".pja.edu.pl": [
        "Polish-Japanese Academy of Information Technology in Warsaw"
    ],
    ".pjwstk.edu.pl": [
        "Polish-Japanese Institute of Information Technology in Warsaw"
    ],
    ".pk.edu.pl": ["Technical University of Cracow"],
    ".student.po.edu.pl": [
        "Opole University of Technology",
        "Politechnika Opolska",
    ],
    ".pollub.edu.pl": ["Lublin University of Technology"],
    ".prz.edu.pl": ["Politechnika Rzeszowska im. Ignacego Łukasiewicza"],
    ".pspo.edu.pl": [
        "Liceum Ogólnokształcące Niepubliczne nr 43 z Oddziałami Dwujęzycznymi"
    ],
    ".student.pswbp.edu.pl": [
        "Państwowa Szkoła Wyższa im. Papieża Jana Pawła II w Białej Podlaskiej",
        "Pope John Paul II State School Of Higher Education in Biała Podlaska",
    ],
    ".ptz.edu.pl": [
        "Prywatne Technikum Zawodowe w Nowym Sączu",
        "Technical school Prywatne Technikum Zawodowe in Nowy Sącz",
    ],
    ".puls.edu.pl": ["Poznan University of Life Sciences"],
    ".pum.edu.pl": ["Pomorski Uniwersytet Medyczny w Szczecinie"],
    ".put.edu.pl": ["Technical University of Poznan"],
    ".puzim.edu.pl": [
        "Państwowa Uczelnia Zawodowa im. Ignacego Mościckiego w Ciechanowie",
        "Ignacy Mościcki’s University of Applied Sciences in Ciechanów",
    ],
    ".pw.edu.pl": ["Warsaw University of Technology"],
    ".student.pwr.edu.pl": [
        "Politechnika Wrocławska",
        "Wrocław University of Science and Technology",
    ],
    ".pwr.edu.pl": [
        "Politechnika Wrocławska",
        "Wrocław University of Science and Technology",
    ],
    ".pwsip.edu.pl": [
        "Państwowa Wyższa Szkoła Informatyki i Przedsiębiorczości w Łomży",
        "Lomza State University of Applied Sciences",
    ],
    ".pwste.edu.pl": [
        "Panstwowa Wyzsza Szkola Techniczno-Ekonomiczna w Jaroslawiu",
        "The State Higher School of Technology and Economics in Jaroslaw",
    ],
    ".m.student.pwsz.edu.pl": [
        "PWSZ im. J.A. Komeńskiego w Lesznie",
        "Jan Amos Komeński State School of Higher Vocational Education in Leszno",
    ],
    ".student.pwsz.edu.pl": ["PWSZ Leszno, Poland"],
    ".studenci.pwsz-gniezno.edu.pl": [
        "Państwowa Wyższa Szkoła Zawodowa im. Hipolita Cegielskiego w Gnieźnie"
    ],
    ".pwsz-kalisz.edu.pl": ["Państwowa Wyższa Szkoła Zawodowa w Kaliszu"],
    ".pwsz-ns.edu.pl": [
        "\ufeffPaństwowa Wyższa Szkoła Zawodowa w Nowym Sączu"
    ],
    ".pwszchelm.edu.pl": [
        "Państwowa Wyższa Szkoła Zawodowa w Chełmie",
        "The State School of Higher Education in Chełm",
    ],
    ".student.pwsztar.edu.pl": ["Państwowa Wyższa Szkoła Zawodowa w Tarnowie"],
    ".pwsztar.edu.pl": [
        "Państwowa Wyższa Szkoła Zawodowa w Tarnowie",
        "State Higher Vocational School in Tarnów",
    ],
    ".pzslopuszno.edu.pl": ["Zespół szkół Powiatowych w Łopusznie"],
    ".student.pwsz.raciborz.edu.pl": ["Akademia Nauk Stosowanych w Raciborzu"],
    ".zsm.raciborz.edu.pl": [
        "Centrum Kształcenia Zawodowego i Ustawicznego nr 2 „Mechanik”"
    ],
    ".realizacjadzwieku.edu.pl": [
        "Akademia Dziennikarstwa i Realizacji Dźwięku",
        "Academy of Journalism and Sound Editing",
    ],
    ".rt.edu.pl": ["Robert Technical University"],
    ".san.edu.pl": ["Społeczna Akademia Nauk"],
    ".sci.edu.pl": ["Szczecinskie Technikum Informatyczne SCI"],
    ".sggw.edu.pl": [
        "Szkoła Głowna Gospodarstwa Wiejskiego",
        "Warsaw University of Life Science",
    ],
    ".skarga.edu.pl": ["Katolicki Zespół Edukacyjny"],
    ".smcebi.edu.pl": [
        "Silesian Centre for Education and Interdisciplinary Research"
    ],
    ".snc.edu.pl": ["Medical School"],
    ".sp12w.edu.pl": ["Szkoła Podstawowa nr 12 im. Powstańców Śląskich"],
    ".sp341.edu.pl": [
        'Szkoła Podstawowa z Oddziałami Integracyjnymi nr 341 Im. "Twórców Literatury Dziecięcej"'
    ],
    ".sp6rumia.edu.pl": [
        "Szkola Podstawowa nr 6 w Rumi",
        "Elementary School 6 in Rumia",
    ],
    ".spark.edu.pl": ["Spark Academy - Liceum Ogólnokształcące"],
    ".sredniawski.edu.pl": [
        "Zespół Szkół im. Andrzeja Średniawskiego w Myślenicach"
    ],
    ".student-afm.edu.pl": [
        "Krakowska Akademia im. Andrzeja Frycza Modrzewskiego",
        "Andrzej Frycz Modrzewski Krakow University",
    ],
    ".sum.edu.pl": [
        "Śląski Uniwersytet Medyczny",
        "Medical University of Silesia",
    ],
    ".swps.edu.pl": ["Warsaw School of Social Psychology"],
    ".szkola8.edu.pl": ["Szkoła №8", "szkola8"],
    ".szkolakolumba.edu.pl": [
        "Niepubliczna szkoła podstawowa nr 1 im. Krzysztofa Kolumba w Żyrardowie"
    ],
    ".t1piaseczno.edu.pl": ["Zespół Szkół nr 1 w Piasecznie"],
    ".teb.edu.pl": ["Technikum TEB Edukacja"],
    ".technikum-brzesko.edu.pl": [
        "Technikum im. J. Piłsudskiego w Brzesku",
        "J. Pilsudski Technical High School in Brzesko",
    ],
    ".technikum19.edu.pl": [
        "Technikum nr 19 Im. Marszałka Józefa Piłsudskiego"
    ],
    ".tis.edu.pl": [
        "Centrum Kształcenia Zawodowego i Ustawicznego w Strzelinie (Technikum Strzelin)"
    ],
    ".tm1.edu.pl": ["Zespół Szkół Licealnych i Technicznych nr 1 w Warszawie"],
    ".to.edu.pl": [
        "Społeczna Szkoła Podstawowa Im. Księcia J. Poniatowskiego Towarzystwa Oświatowego Edukacja W Łodzi",
        "Społeczna Szkoła Podstawowa Im. Księcia J. Poniatowskiego Towarzystwa Oświatowego Edukacja W Łodzi",
    ],
    ".tti.edu.pl": ["Toruńskie Technikum Informatyczne"],
    ".zs4.tychy.edu.pl": [
        "Zespół Szkół nr 4 im. Janusza Groszkowskiego w Tychach"
    ],
    ".tyszkiewicz.edu.pl": [
        "Józef Tyszkiewicz College of Business and Computer Science in Bielsko-Biala"
    ],
    ".tzn.edu.pl": [
        "Technikum nr 5 w Częstochowie ",
        "Technical Secondary School No. 5 in Częstochowa",
    ],
    ".student.tzndg.edu.pl": [
        "Techniczne Zakłady Naukowe w Dąbrowie Górniczej"
    ],
    ".uap.edu.pl": [
        "Uniwersytet Artystyczny im. Magdaleny Abakanowicz w Poznaniu",
        "Magdalena Abakanowicz University of the Arts Poznan",
    ],
    ".student.ubb.edu.pl": ["Uniwersytet Bielsko-Bialski"],
    ".ubb.edu.pl": ["University of Bielsko-Biala"],
    ".student.uczelniaoswiecim.edu.pl": [
        "Małopolska Uczelnia Państwowa imienia rotmistrza Witolda Pileckiego w Oświęcimiu",
        "The Witold Pilecki University of Applied Sciences in Oświęcim",
    ],
    ".uekat.edu.pl": ["University of Economics in Katowice"],
    ".ug.edu.pl": ["University of Gdansk"],
    ".uj.edu.pl": [
        "Jagiellonian University Cracow",
        "Jagiellonian University in Krakow",
    ],
    ".ujd.edu.pl": [
        "Uniwersytet im. Jana Długosza w Częstochowie",
        "Jan Dlugosz University in Czestochowa",
    ],
    ".student.ujk.edu.pl": [
        "Uniwersytet Jana Kochanowskiego w Kielcach",
        "Jan Kochanowski University in Kielce",
    ],
    ".ujk.edu.pl": [
        "Uniwersytet Jana Kochanowskiego w Kielcach",
        "Jan Kochanowski University (JKU) in Kielce",
    ],
    ".uksw.edu.pl": ["Cardinal Stefan Wyszynski University in Warsaw"],
    ".ukw.edu.pl": ["Kazimierz Wielki University"],
    ".ulu.edu.pl": ["Uczelnia Łukaszewski"],
    ".umb.edu.pl": [
        "Uniwersytet Medyczny w Białymstoku",
        "Medical University of Bialystok",
    ],
    ".live.umcs.edu.pl": ["Maria Curie Skłodowska University in Lublin"],
    ".umg.edu.pl": ["Gdynia Maritime University"],
    ".ump.edu.pl": [
        "Uniwersytet Medyczny im. Karola Marcinkowskiego w Poznaniu",
        "Poznan University of Medical Sciences",
        "Domains:",
        "@ump.edu.pl ",
        "@student.ump.edu.pl - studenta, PhD candidates",
    ],
    ".student.umw.edu.pl": [
        "Uniwersytet Medyczny im. Piastów Śląskich we Wrocławiu",
        "Wroclaw Medical University",
    ],
    ".umw.edu.pl": [
        "Uniwersytet Medyczny im. Piastów Śląskich we Wrocławiu",
        "Wroclaw Medical University",
    ],
    ".uniwersytetkaliski.edu.pl": ["Uniwersytet Kaliski"],
    ".student.up.edu.pl": [
        "Uniwersytet Przyrodniczy w Lublinie",
        "University of Life Science in Lublin",
    ],
    ".uph.edu.pl": [
        "Siedlce University of Natural Sciences and Humanities",
        "Uniwersytet Przyrodniczo-Humanistyczny w Siedlcach",
    ],
    ".upjp2.edu.pl": [
        "Uniwersytet Papieski Jana Pawła II w Krakowie",
        "Pontifical University of John Paul II",
    ],
    ".student.upwr.edu.pl": [
        "Uniwersytet Przyrodniczy we Wrocławiu",
        "Wrocław University of Environmental and Life Sciences",
    ],
    ".upwr.edu.pl": [
        "Uniwersytet Przyrodniczy we Wrocławiu",
        "Wroclaw University of Environmental and Life Science",
    ],
    ".ur.edu.pl": [
        "Uniwersytet Rzeszowski",
        "University of Rzeszow",
        ".stud .dokt",
    ],
    ".urk.edu.pl": [
        "UNIWERSYTET ROLNICZY IM. HUGONA KOŁŁĄTAJA W KRAKOWIE",
        "UNIVERSITY OF AGRICULTURE IN KRAKOW",
    ],
    ".us.edu.pl": ["University of Silesia"],
    ".usz.edu.pl": ["University of Szczecin"],
    ".uth.edu.pl": [
        "Helena Chodkowska University of Technology and Economics"
    ],
    ".utp.edu.pl": ["Politechnika Bydgoska im. Jana i Jędrzeja Śniadeckich"],
    ".uw.edu.pl": ["University of Warsaw"],
    ".uwb.edu.pl": ["University of Bialystok"],
    ".uwm.edu.pl": ["University of Wamia and Masuria in Olsztyn"],
    ".uwr.edu.pl": ["University of Wroclaw"],
    ".uws.edu.pl": ["Uniwersytet w Siedlcach", "University of Siedlce"],
    ".viiipalo.edu.pl": [
        "VIII Prywatne Akademickie Liceum Ogólnokształcące",
        "VIII PALO",
        "8th Private Academic High School",
    ],
    ".vilo.edu.pl": ["\ufeffVI Liceum Ogólnokształcące w Białymstoku "],
    ".vistula.edu.pl": ["Akademia Finansow i Biznesu Vistula"],
    ".student.wab.edu.pl": [
        "Wrocławska Akademia Biznesu",
        "The Academy of Business in Wroclaw",
    ],
    ".wab.edu.pl": [
        "Wrocławska Akademia Biznesu w Naukach Stosowanych",
        "Wroclaw Business University of Applied Sciences",
    ],
    ".woli.wat.edu.pl": [
        "Wojskowe Ogólnokształcące Liceum Informatyczne im. Polskich Kryptologów"
    ],
    ".wat.edu.pl": ["Military University of Technology in Warsaw"],
    ".wit.edu.pl": [
        "Warsaw School of Information Technology",
        "Wyższa Szkoła Informatyki Stosowanej i Zarządzania",
    ],
    ".woli.edu.pl": [
        "Wojskowe Ogólnokształcące Liceum Informatyczne im. Polskich Kryptologów"
    ],
    ".wsb-nlu.edu.pl": [
        "Higher School o Business/National Louis University(WSB/NLU) in Nowy Sacz"
    ],
    ".wsb.edu.pl": ["Akademia WSB", "WSB University"],
    ".wse.edu.pl": [
        "Wyższa Szkoła Ekonomiczna w Białymstoku",
        "Bialystok School of Economic",
    ],
    ".wsei.edu.pl": [
        "Higher School of Economics and Computer Science in Krakow",
        "Wyższa Szkoła Ekonomii i Informatyki w Krakowie",
        "WSEI",
    ],
    ".wseiz.edu.pl": ["Wyższa Szkoła Ekologii i Zarządzania"],
    ".wsfip.edu.pl": ["Bielsko-Biala School of Finances and Law"],
    ".wsfiz.edu.pl": ["University of Finance and Management in Bialystok"],
    ".wsge.edu.pl": [
        "Wyższa Szkoła Gospodarki Euroregionalnej im. Alcide de Gasperi w Józefowie"
    ],
    ".wsh.edu.pl": ["Aleksander Gieysztor School of Humanities in Pultusk"],
    ".stud.wsi.edu.pl": [
        "Wyższa Szkoła Informatyki i Zarządzania w Bielsku-Białej"
    ],
    ".wsi.edu.pl": [
        "Wyższa Szkoła Informatyki i Zarządzania",
        "Institute of Management and Information Technology, Bielsko-Biała, Poland",
    ],
    ".wsinf.edu.pl": ["College of Computer Science in Lodz"],
    ".wsisiz.edu.pl": ["Warsaw School of Information Technology"],
    ".wsiz.edu.pl": [
        "University of Information Technology and Management in Rzeszow",
        "Wyższa Szkoła Informatyki i Zarządzania w Rzeszowie",
    ],
    ".wsksim.edu.pl": ["\ufeffWyższa Szkoła Kultury Społecznej i Medialnej"],
    ".wsosp.edu.pl": ["Polish Air Force Academy"],
    ".wspa.edu.pl": [
        "Wyższa Szkoła Przedsiębiorczości i Administracji w Lublinie",
        "University College of Enterprise and Administration in Lublin ",
        "WSPA",
    ],
    ".wspiz.edu.pl": [
        "Leon Kozminski Academy of Entrepreneurship and Mangement",
        "Leon Kozminski Academy of Entrepreneurship and Mangement in Warsaw",
    ],
    ".wsse.edu.pl": [
        "Wyższa Szkoła Społeczno-Ekonomiczna w Gdańsku",
        "The University of Social and Economics in Gdańsk",
    ],
    ".wszib.edu.pl": [
        "The School of Banking and Management in Cracow",
        "Wyższa Szkoła Zarządzania i Bankowości w Krakowie",
    ],
    ".wszim.edu.pl": ["University of Management and Marketing"],
    ".student.wum.edu.pl": [
        "Warszawski Uniwersytet Medyczny",
        "Medical University of Warsaw",
    ],
    ".wum.edu.pl": [
        "Warszawski Uniwersytet Medyczny",
        "Medical University of Warsaw",
    ],
    ".wumed.edu.pl": ["Warszawska Uczelnia Medyczna im. Tadeusza Koźluka"],
    ".wwsi.edu.pl": [
        "Warsaw School of Computer Science",
        "Warszawska Wyższa Szkoła Informatyki",
        "http://www.wwsi.edu.pl/",
    ],
    ".a.xzc.edu.pl": ["山河大学"],
    ".zamoyski.edu.pl": [
        "XVIII Liceum Ogólnokształcące im. Jana Zamoyskiego w Warszawie"
    ],
    ".zs1goleniow.edu.pl": ["Zespół Szkół nr 1 w Goleniowie"],
    ".live.zs1mm.edu.pl": [
        "Zespol Szkol Nr 1 im. Kazimierza Wielkiego w Minsku Mazowieckim, Poland",
        "Website: http://zs1mm.edu.pl",
    ],
    ".zs1piekary.edu.pl": ["ZESPÓŁ SZKÓŁ NR 1"],
    ".zs6sobieski.edu.pl": [
        "Zespół Szkół nr 6 im. Króla Jana III Sobieskiego"
    ],
    ".zsart.edu.pl": [
        "Zespół Szkół Rzemiosł Artystycznych im. Stanisława Wyspiańskiego"
    ],
    ".student.zschie.edu.pl": [
        "Zespół Szkół Chłodniczych i Elektronicznych w Gdyni",
        "Refrigeration and Electronics School Complex in Gdynia",
    ],
    ".zseeim.edu.pl": ["zseeim.edu.pl"],
    ".zseil.edu.pl": [
        "Zespół Szkół Elektronicznych i Licealnych",
        "Complex of Electronic and Secondary Schools",
    ],
    ".zsel.edu.pl": ["Zespół Szkół Elektrycznych we Włocławku"],
    ".ucn.zsem.edu.pl": [
        "Zespół Szkół Elektryczno-Mechanicznych im. gen. Józefa Kustronia"
    ],
    ".zsgdow.edu.pl": ["Zespół Szkół Gdów", "School Complex in Gdów"],
    ".zsgorzyce.edu.pl": ["Zespół Szkół w Gorzycach im por. Józefa Sarny"],
    ".zsh.edu.pl": [
        "Zespół Szkół Handlowych im. Bohaterów Poznańskiego Czerwca '56 w Poznaniu",
        "Trade School Complex of the Heroes of Poznań June '56",
    ],
    ".zsnr4.edu.pl": ["Zespół Szkół Nr 4 w Dębicy im. Mikołaja Kopernika"],
    ".zsoiz-krobia.edu.pl": [
        "Zespół Szkół Ogólnokształcących i Zawodowych w Krobi"
    ],
    ".zsp1piotrkow.edu.pl": [
        "Zespól Szkól Ponadpodstawowych nr 1 w Piotrkowie Trybunalskim"
    ],
    ".zspwni.edu.pl": ["Szkoła Podstawowa w Nowej Iwicznej"],
    ".zst-ostrow.edu.pl": [
        "Zespół Szkół Technicznych w Ostrowie Wielkopolskim",
        "Technical School Complex in Ostrów Wielkopolski",
    ],
    ".zst-sopot.edu.pl": ["Zespół Szkół Technicznych w Sopocie", "ZSTSOPOT"],
    ".zstib.edu.pl": [
        "Zespół Szkół Technicznych i Branżowych im. Bohaterów Westerplatte w Brzesku"
    ],
    ".zstie.edu.pl": [
        "ZSTIE - Zespół Szkół Teleinformatycznych i Elektronicznych"
    ],
    ".zstio.edu.pl": [
        "Zespół Szkół Technicznych i Ogólnokształcacych im. Jana Pawła II"
    ],
    ".zstsk.edu.pl": [
        "Zespół Szkół Technicznych im. Armii Krajowej w Skarżysku - Kamiennej"
    ],
    ".zstu.edu.pl": ["Zespół Szkół Techniczno-Usługowych w Trzebini"],
    ".zstz.edu.pl": [
        "Zespół Szkół Techniczno-Zawodowych w Piekarach Śląskich",
        "Complex of Technical and Vocational Schools in Piekary Śląskie",
    ],
    ".zsz1.edu.pl": ["Zespół Szkół Zawodowych nr 1 w Białej Podlaskiej"],
    ".zsziok.edu.pl": [
        "Zespół Szkół Zawodowych i Ogólnokształcących w Kartuzach"
    ],
    ".zszpultusk.edu.pl": [
        "Zespół Szkół Zawodowych im. Jana Ruszkowskiego w Pułtusku",
        "Vocational School Complex Jan Ruszkowski in Pułtusk",
    ],
    ".zut.edu.pl": ["Zachodniopomorska School of Science and Engineering"],
    ".zyrardow.edu.pl": [
        "Liceum Ogólnokształcące im. Stefana Żeromskiego w Żyrardowie"
    ],
    ".uczen.eduwarszawa.pl": [
        "Szkoły publiczne w Warszawie (domena zbiorowa)",
        "Public schools in Warsaw (collective domain)",
    ],
    ".eduwarszawa.pl": [
        "Zespół Szkół nr 10 im. St. Staszica Technikum nr 25 w Warszawie"
    ],
    ".ekonomikzamosc.pl": ["Technikum nr 1 w Zamościu"],
    ".elektronikonline.pl": [
        "Zespół Szkół Elektronicznych im. Bohaterów Westerplatte w Radomiu",
        "Westerplatte Heroes Electronic Schools Complex, Radom",
    ],
    ".edu.erzeszow.pl": [
        "Rzeszowskie Szkoły w Chmurze Microsoft - platforma Office 365 dla edukacji",
        ".group",
    ],
    ".ezse.pl": [
        "ZESPÓŁ SZKÓŁ ELEKTRYCZNYCH W KIELCACH",
        "ZESPÓŁ SZKÓŁ ELEKTRYCZNYCH W KIELCACH",
    ],
    ".amg.gda.pl": ["Medical Academy in Gdansk"],
    ".amuz.gda.pl": ["Music Academy Stanislaw Moniuszko in Gdansk"],
    ".asp.gda.pl": ["Fine Arts Academy in Gdansk"],
    ".awf.gda.pl": ["Physical Education Academy Jedrzej Sniadecki in Gdansk"],
    ".imp.gda.pl": [
        "INSTYTUT MASZYN PRZEPŁYWOWYCH im. Roberta Szewalskiego Polskiej Akademii Nauk",
        "The Szewalski Institute of Fluid-Flow Machinery, Polish Academy of Sciences",
    ],
    ".pg.gda.pl": ["Technical University of Gdansk"],
    ".univ.gda.pl": ["University of Gdansk"],
    ".wsb.gda.pl": ["Gdansk's School of Banking"],
    ".sp61.edu.gdansk.pl": [
        "Szkoła Podstawowa nr 61 w Gdansku",
        "Primary School no 61 in Gdansk",
    ],
    ".edu.gdansk.pl": [
        ".group",
        "Technikum Szkół Łączności w Gdańsku im. Obrońców Poczty Polskiej, Gdansk, Poland",
        "Technical High School of Communication in Gdansk named after defenders of the Polish Post Office, Gdansk, Poland",
    ],
    ".amw.gdynia.pl": ["Polish Naval Academy"],
    ".lo3.gdynia.pl": [
        "III Liceum Ogólnokształcące im. Marynarki Wojennej RP w Gdyni",
        "Navy 3rd High School in Gdynia",
    ],
    ".wsb.gdynia.pl": [
        "Wyższa Szkoła Bankowa w Gdańsku",
        "WSB University in Gdańsk",
    ],
    ".zsl.gliwice.pl": ["Zespół Szkół Łączności w Gliwicach"],
    ".zsti.gliwice.pl": [
        "Zespół Szkół Techniczno-Informatycznych",
        "Informatics-Technical School",
    ],
    ".iimcb.gov.pl": [
        "International Institute of Molecular and Cell Biology in Warsaw (IIMCB)"
    ],
    ".ippt.gov.pl": [
        "Instytut Podstawowych Problemów Techniki Polskiej Akademii Nauk",
        "Institute of Fundamental Technological Research Polish Academy of Sciences",
    ],
    ".nencki.gov.pl": [
        "Nencki Institute of Experimental Biology, Polish Academy of Sciences"
    ],
    ".gwsh.pl": ["Katowice School of Economics"],
    ".iitis.pl": [
        "Institute of Theoretical and Applied Informatics, Polish Academy of Sciences"
    ],
    ".ilo.pl": [
        "I Liceum Ogólnokształcące im. Adama Mickiewicza w Białymstoku",
        "Adam Mickiewicz High School in Białystok",
    ],
    ".impan.pl": ["Institute of Mathematics, Polish Academy of Sciences"],
    ".lo1.info.pl": [
        "I Liceum Ogólnokształcące im. Marii Skłodowskiej-Curie w Ostrzeszowie"
    ],
    ".zste.kalisz.pl": ["Zespół Szkół Techniczno-Elektronicznych w Kaliszu"],
    ".am.katowice.pl": ["Music Academy Karol Szymanowski in Katowice"],
    ".awf.katowice.pl": ["Physical Education Academy in Katowice"],
    ".slam.katowice.pl": ["Silesian Academy of Medicine in Katowice"],
    ".sltzn.katowice.pl": ["Śląskie Techniczne Zakłady Naukowe"],
    ".ue.katowice.pl": ["University of Economics in Katowice"],
    ".katowice.zdz.katowice.pl": [
        "Technikum Lotnicze w Katowicach",
        "Aviation Technical School in Katowice",
    ],
    ".sosnowiec.zdz.katowice.pl": [
        "Zespół Szkół w Sosnowcu ZDZ w Katowicach",
        "School Complex in Sosnowiec ZDZ in Katowice",
    ],
    ".tu.kielce.pl": ["Kielce University of Technology"],
    ".zsi.kielce.pl": [
        "Zespół Szkół Informatycznych im. gen. Józefa Hauke Bosaka w Kielcach",
        "Zespol Szkol Informatycznych im. gen. Jozefa Hauke Bosaka w Kielcach",
    ],
    ".zslt.klucznet.pl": ["ZSLT in Kluczbork"],
    ".zst.kolbuszowa.pl": [
        "Technikum w Zespole Szkół Technicznych im.Bohaterów Września 1939 r. w Kolbuszowej",
        "technical school in the Technical School Complex of the Heroes of September 1939 in Kolbuszowa",
    ],
    ".kopernikus.pl": ["ZS 6 im. Mikołaja Kopernika"],
    ".tu.koszalin.pl": ["Koszalin University of Technology"],
    ".ae.krakow.pl": ["Academy of Economics in Cracow"],
    ".amuz.krakow.pl": ["Music Academy in Cracow"],
    ".ar.krakow.pl": ["Agricultural University of Cracow"],
    ".stud.asp.krakow.pl": ["Akademia Sztuk Pięknych w Krakowie"],
    ".awf.krakow.pl": ["University School of Physical Education"],
    ".gsuite.elektryk2.krakow.pl": ["Technikum elektryczne nr 2"],
    ".lo31.krakow.pl": ["XXXI Liceum im. Romana Ingardena Kraków"],
    ".mjo.krakow.pl": [
        "Zespół Szkół Mechanicznych nr 1 im. Szczepana Humberta w Krakowie"
    ],
    ".student.sobieski.krakow.pl": [
        "II Liceum Ogólnokształcące im. Króla Jana III Sobieskiego w Krakowie",
        "http://www.sobieski.krakow.pl",
    ],
    ".tk.krakow.pl": [
        "Technikum Komunikacyjne nr 25",
        "Technical School Of Communication 25",
    ],
    ".tl.krakow.pl": [
        "Zespół Szkół Łączności ",
        "im. Obrońców Poczty Polskiej w Gdańsku",
        "W KRAKOWIE",
    ],
    ".uek.krakow.pl": ["Cracow University of Economics"],
    ".student.uken.krakow.pl": [
        "Uniwersytet Komisji Edukacji Narodowej w Krakowie",
        "University of the National Education Commission, Krakow",
    ],
    ".uken.krakow.pl": [
        "Uniwersytet Komisji Edukacji Narodowej w Krakowie",
        "University of the National Education Commision, Cracow",
    ],
    ".up.krakow.pl": [
        "Pedagogical University of Cracow",
        "Uniwersytet Pedagogiczny w Krakowie",
    ],
    ".ur.krakow.pl": [
        "University of Agriculture in Cracow",
        "Uniwersytet Rolniczy w Krakowie",
    ],
    ".v-lo.krakow.pl": ["August Witkowski 5th High School"],
    ".wse.krakow.pl": ["native language Polish", "Wyższa Szkoła Europejska"],
    ".wsp.krakow.pl": ["Pedagogical University of Krakow"],
    ".wszib.krakow.pl": ["School of Banking and Management in Cracow"],
    ".xlilo.krakow.pl": ["XLI Liceum Ogólnokształcące"],
    ".zse.krakow.pl": [
        "Zespół Szkół Energetycznych nr 9 im.Tadeusza Kościuszki w Krakowie"
    ],
    ".zsel1.krakow.pl": [
        "Zespół Szkół Elektrycznych nr 1 w Krakowie",
        "Zespół Szkół Elektrycznych nr 1 w Krakowie",
    ],
    ".zsm1.krakow.pl": [
        "Zespół Szkół Mechanicznych nr 1 im. Szczepana Humberta w Krakowie"
    ],
    ".zszhs.krakow.pl": [
        "Zespół Szkół Zawodowych Huty im. Tadeusza Sendzimira",
        "Tadeusz Sendzimir Vocational School Complex of the Steelworks",
    ],
    ".krasiniak.pl": [
        "I Liceum Ogólnokształcące im. Zygmunta Krasińskiego w Ciechanowie"
    ],
    ".kpu.krosno.pl": ["Karpacka panstwowa uczelnia w krośnie"],
    ".kul.pl": ["John Paul II Catholic University of Lublin"],
    ".kwspz.pl": ["Krakowska Wyższa Szkoła Promocji Zdrowia"],
    ".lazarski.pl": ["Lazarski School of Commerce and Law"],
    ".rcezbilgoraj.lbl.pl": [
        "Regionalne Centrum Edukacji Zawodowej w Biłgoraju"
    ],
    ".zset.leszno.pl": [
        "Zespol Szkol Elektroniczno Telekomunikacyjnych w Lesznie"
    ],
    ".liceum-davinci.pl": [
        "Społeczne Liceum Da Vinci w Krakowie",
        "DaVinci Community High School in Cracow",
    ],
    ".liceumwchmurze.pl": ["Liceum w Chmurze"],
    ".lo-niepolomice.pl": ["Zespół Szkół im. Ojca Świętego Jana Pawła II"],
    ".lo2gdynia.pl": [
        "II Liceum Ogólnokształcące z Oddziałami Dwujęzycznymi im. Adama Mickiewicza",
        "II Secondary School with Bilingual Departments Adam Mickiewicz in Gdynia",
    ],
    ".lobiecz.pl": [
        "Liceum Ogólnokształcące im. Stanisława Wyspiańskiego w Bieczu"
    ],
    ".ahe.lodz.pl": [
        "Akademia Humanistyczno-Ekonomiczna w Łodzi",
        "University of Humanities and Economics in Lodz",
    ],
    ".edu.asp.lodz.pl": [
        "Akademia Sztuk Pięknych im. Władysława Strzemińskiego w Łodzi",
        "Władysław Strzemiński Academy of Fine Arts in Łódź",
    ],
    ".mail.asp.lodz.pl": [
        "Akademia Sztuk Pięknych im. Władysława Strzemińskiego",
        "Academy of Fine Art in Łódź",
    ],
    ".student.filmschool.lodz.pl": [
        "Państwowa Wyższa Szkoła Filmowa, Telewizyjna i Teatralna im. Leona Schillera w Łodzi",
        "Lodz Film School",
    ],
    ".edu.p.lodz.pl": ["Technical University of Lodz"],
    ".liceum.p.lodz.pl": ["Technical High School of Lodz"],
    ".p.lodz.pl": ["Lodz University of Technology"],
    ".stud.umed.lodz.pl": [
        "Uniwersytet Medyczny w Łodzi",
        "Medical University of Lodz",
    ],
    ".umed.lodz.pl": [
        "Uniwersytet Medyczny w Łodzi",
        "Medical University of Lodz",
    ],
    ".math.uni.lodz.pl": ["Faculty of Mathematics and Computer Science"],
    ".uni.lodz.pl": ["University Of Lodz"],
    ".uns.lodz.pl": ["Uczelnia Nauk Społecznych"],
    ".student.wsb.lodz.pl": [
        "Wyższa Szkoła Bankowa w Łodzi",
        "Higher School of Bankong in Lodz",
    ],
    ".loilza.pl": ["Liceum Ogólnokształcące im. M. Kopernika w Iłży"],
    ".loskawina.pl": [
        "Liceum Ogólnokształcące im. Marii Skłodowskiej-Curie w Skawinie",
        "Maria Skłodowska-Curie Secondary School in Skawina",
    ],
    ".zs2.lubartow.pl": [
        "Zespół Szkół nr 2 im. Księcia Pawła Karola Sanguszki w Lubartowie "
    ],
    ".jadwiga.lublin.pl": [
        "Prywatna Szkola Podstawowa i Liceum im. Krolowej Jadwigi w Lublinie",
        "@jadwiga.lublin.pl",
        "@live.edja.pl",
        "@edja.pl",
    ],
    ".kul.lublin.pl": [
        "John Paul II Catholic University of Lublin",
        "@student.kul.lublin.pl",
        "@kul.lublin.pl",
        "@kul.pl",
    ],
    ".paderewski.lublin.pl": [
        "Międzynarodowe Liceum Ogólnokształcące Paderewski w Lublinie",
        "Paderewski International High School in Lublin",
    ],
    ".umcs.lublin.pl": ["Maria Curie Skłodowska University in Lublin"],
    ".wsei.lublin.pl": ["University of Economics and Innovation in Lublin"],
    ".zs3.lukow.pl": [
        " Zespół Szkół nr 3   im. Władysława Stanisława Reymonta w Łukowie"
    ],
    ".uczen.mechaniktg.pl": [
        "Zespół Szkół Technicznych i Ogólnokształcących „Mechanik”"
    ],
    ".student.bydgoszcz.merito.pl": ["Uniwersytet WSB Merito Bydgoszcz"],
    ".student.gdansk.merito.pl": ["Uniwersytet WSB Merito w Gdańsku"],
    ".student.gdynia.merito.pl": ["Uniwersytet WSB Merito w Gdyni"],
    ".student.poznan.merito.pl": ["WSB Merito Poznań"],
    ".student.torun.merito.pl": [
        "Uniwersytet WSB Merito Toruń",
        "WSB Merito University Torun",
    ],
    ".student.warszawa.merito.pl": ["Uczelnia WSB Merito Warszawa"],
    ".student.wroclaw.merito.pl": ["Uniwersytet WSB Merito we Wrocławiu"],
    ".merito.pl": [
        "Uniwersytetami WSB Merito",
        "Wyższe Szkoły Bankowe",
        "formerly known as  Higher Banking Schools (Wyższe Szkoły Bankowe)",
        ".group",
    ],
    ".kopernik.mielec.pl": [
        "II Liceum Ogólnokształcące im. Mikołaja Kopernika",
        "website: http://kopernik.mielec.pl/",
        "facebook: https://www.facebook.com/IILOwMielcu/",
    ],
    ".student.akademia.mil.pl": [
        "Akademia Sztuki Wojennej",
        "War Studies University",
    ],
    ".law.mil.pl": ["Lotnicza Akademia Wojskowa"],
    ".mojasiodemka.pl": [
        "Szkoła Podstawowa nr 7 im. Erazma z Rotterdamu, ul. Galileusza 14, 60-158 Poznań"
    ],
    ".mojcosinus.pl": ["Cosinus"],
    ".muzycznaradom.pl": ["Oskar Kolberg Music School Complex in Radom"],
    ".zst.net.pl": [
        "Zespół Szkół Technicznych im. gen. prof. Sylwestra Kaliskiego",
        "Complex of Technical School im. gen. prof. Sylwestra Kaliskiego",
    ],
    ".st.pans.nysa.pl": [
        "Państwowa Akademia Nauk Stosowanych w Nysie",
        "University Of Applied Sciences in Nysa",
    ],
    ".st.pwsz.nysa.pl": ["Państwowa Wyższa Szkoła Zawodowa w Nysie"],
    ".zsek.olsztyn.pl": [
        "Zespół Szkół Ekonomicznych im. Mikołaja Kopernika w Olsztynie",
        "Nicolaus Copernicus's Economical School Complex in Olsztyn",
    ],
    ".uczen.akademiarzemiosla.opole.pl": [
        "Akademia rzemiosła i przedsiębiorczości"
    ],
    ".ekonomik.opole.pl": ["Zespół Szkół Ekonomicznych w Opolu"],
    ".po.opole.pl": ["Technical University of Opole"],
    ".student.wsb.opole.pl": ["Wyższa Szkoła Bankowa we Wrocławiu"],
    ".g.wszia.opole.pl": [
        "\ufeffWyższa Szkoła Zarządzania i Administracji w Opolu"
    ],
    ".zse.opole.pl": ["Zespół Szkół Ekonomicznych w Opolu"],
    ".eszkola.opolskie.pl": [
        "Zespół Szkół Elektrycznych  im. Tadeusza Kościuszki w Opolu "
    ],
    ".office.mans.org.pl": [
        "Menedzerska Akademia Nauk Stosowanych w Warszawie",
        "Management Academy of Applied Sciences in Warsaw",
    ],
    ".zs2.zs2.ostrzeszow.pl": [
        "Zespół Szkół Nr 2 im. Przyjaźni Polsko-Norweskiej w Ostrzeszowie"
    ],
    ".psych.pan.pl": [
        "Instytut Psychologii Polskiej Akademii Nauk",
        "Institute of Psychology of the Polish Academy of Sciences",
    ],
    ".s.pansp.pl": ["Państwowa Akademia Nauk Stosowanych w Przemyślu"],
    ".pcz.pl": ["Czestochowa University of Technology"],
    ".liceum.pijarzy.pl": [
        "Liceum Ogólnokształcące Zakonu Pijarów im. ks. Stanisława Konarskiego w Krakowie",
        "High School of the Piarist Order them. Fr. Stanisław Konarski in Krakow",
    ],
    ".pwsz.pila.pl": ["Staszic Pila College"],
    ".pollub.pl": ["Lublin University of Technology"],
    ".polsl.pl": ["Silesian University of Technology"],
    ".au.poznan.pl": ["Agricultural University of Poznan"],
    ".awf.poznan.pl": [
        "Physical Education Academy Eugeniusz Piasecki in Poznan"
    ],
    ".ibch.poznan.pl": [
        "Institute of Bioorganic Chemistry, Polish Academy of Sciences"
    ],
    ".ilim.poznan.pl": ["The Institute of Logistics and Warehousing (ILiM)"],
    ".edu.lo4.poznan.pl": [
        "IV Liceum Ogólnokształcące im. Komisji Edukacji Narodowej"
    ],
    ".put.poznan.pl": ["Technical University of Poznan"],
    ".ue.poznan.pl": ["Poznan University of Economics"],
    ".up.poznan.pl": ["Poznan University Of Life Sciences"],
    ".usoms.poznan.pl": [
        "Medical Academy \x93Karol Marcinkowski\x94 in Poznan"
    ],
    ".wsb.poznan.pl": ["Poznan School of Banking"],
    ".zsk.poznan.pl": ["Zespół Szkół Komunikacji im. Hipolita Cegielskiego"],
    ".zsl.poznan.pl": [
        "Zespół Szkół Łączności w Poznaniu im. Mikołaja Kopernika"
    ],
    ".1lo.pulawy.pl": ['1 Liceum Ogólnokształcące "Czartorych" w Puławach'],
    ".pwste.pl": [
        "The Bronisław Markiewicz State Higher School of Technology and Economics in Jarosław"
    ],
    ".pwsz.pl": [
        "The Jacob of Paradyz University of Applied Sciences in Gorzow Wielkopolski"
    ],
    ".pwszchelm.pl": [
        "Państwowa Wyższa Szkoła Zawodowa w Chełmie",
        "The State School of Higher Education in Chełm",
    ],
    ".pzsbierun.pl": ["Powiatowy Zespół Szkół w Bieruniu (PZS Bieruń)"],
    ".zss.q4.pl": ["\ufeffZespół Szkół Samochodowych we Włocławku"],
    ".2lo.radom.pl": ["Maria Konopnicka 2nd High School in Radom"],
    ".czachowski.radom.pl": ["Dionizy Czachowski 3rd High School in Radom"],
    ".kochanowski.radom.pl": [
        "VI Liceum Ogólnokształcące z oddziałami dwujęzycznymi im. Jana Kochanowskiego w Radomiu"
    ],
    ".man.radom.pl": ["Technical University of Radom"],
    ".zst.radom.pl": [
        "Zespół Szkół Technicznych im. Tadeusza Kościuszki w Radomiu"
    ],
    ".1lo.rzeszow.pl": [
        "I Liceum Ogólnokształcące w Rzeszowie  im. ks. Stanisława Konarskiego"
    ],
    ".prz.rzeszow.pl": ["Technical University of Rzeszow"],
    ".urstud.rzeszow.pl": ["University of Rzeszow"],
    ".student.wsiz.rzeszow.pl": [
        "University of Information Technology and Management in Rzeszow",
        "Wyższa Szkoła Informatyki i Zarządzania w Rzeszowie",
    ],
    ".wsiz.rzeszow.pl": [
        "University of Information Technology and Management in Rzeszow",
        "Wyższa Szkoła Informatyki i Zarządzania w Rzeszowie",
    ],
    ".uczen.2lo.sandomierz.pl": [
        "II Liceum Ogólnokształcące im. Tadeusza Kościuszki w Sandomierzu",
        "II Thaddeus Kosciuszko High School in Sandomierz.",
    ],
    ".zs2.sanok.pl": [
        "Zespół Szkół nr 2 im. Grzegorza z Sanoka w Sanoku",
        "School No. 2 for them. Gregory of Sanok",
    ],
    ".sggw.pl": ["Warsaw University of Life Sciences"],
    ".ap.siedlce.pl": ["Akademia Podlaska"],
    ".slosw.pl": [
        "Samorządowe Liceum Ogólnokształcące im. Cypriana Kamila Norwida w Stalowej Woli"
    ],
    ".drzewniak.slupsk.pl": ["Zespół Szkół Technicznych w Słupsku"],
    ".zselektryk.slupsk.pl": [
        'Zespół szkół nr. 1 im. Noblistów Polskich w Słupsku "Elektryk"',
        "Polish Nobel Prize Winners Upper-Secondary School Complex No. 1",
    ],
    ".sbs.sniadek.pl": [
        "II LICEUM OGÓLNOKSZTAŁCĄCE IM. JANA ŚNIADECKIEGO W KIELCACH",
        "Second High comprehensive school Jana Śniadeckiego in Kielce",
    ],
    ".sp13bielsko.pl": ["Szkoła Podstawowa nr 13"],
    ".sp1mragowo.pl": [
        "Szkoła Podstawowa nr. 1 im. Mikołaja Kopernika w Mrągowie"
    ],
    ".sp1ozarow.pl": [
        "Szkoła Podstawowa Nr 1 im. Janusza Kusocińskiego w Ożarowie Mazowieckim",
        "Primary School No. 1 in Ozarow Mazowiecki",
    ],
    ".sp25krakow.pl": [
        "Szkoła Podstawowa nr 25 w Krakowie im. Tadeusza Kościuszki"
    ],
    ".sp2kroscienko.pl": [
        "Publiczna Szkoła Podstawowa im. Jana Pawła II w Krościenku n/D"
    ],
    ".spolecznaczworka.pl": ["Liceum Społeczna Czwórka"],
    ".lodz.spsk.pl": ["Katolicka Szkola Lodz"],
    ".spzoi151.pl": [
        "Szkoła Podstawowa z Oddziałami Integracyjnymi nr 151 w Krakowie im. Uniwersytetu Jagiellońskiego"
    ],
    ".ssp26.pl": [
        "Społeczna Szkoła Podstawowa nr 26 w Warszawie im. prof. Jigoro Kano Społecznego Towarzystwa Oświatowego",
        "26th Community Primary School in Warsaw",
    ],
    ".ssw-sopot.pl": [
        "Sopocka Akademia Nauk Stosowanych",
        "Sopot University of Applied Sciences",
    ],
    ".u.zs1.stargard.pl": ["Zespół Szkół nr 1 im. Mieszka I w Stargardzie"],
    ".stipendium.pl": ["Institute of Science and Technology Stipendium"],
    ".studentwsei.pl": ["University of Economics and Innovation in Lublin"],
    ".zst.suwalki.pl": ["Group of Technical Schools"],
    ".swps.pl": ["Uniwersytet Swps"],
    ".ar.szczecin.pl": ["Agricultural University of Szczecin"],
    ".lo14.szczecin.pl": [
        "XIV Liceum Ogólnokształcące z Oddziałami Dwujęzycznymi",
        "XIV High School",
    ],
    ".pm.szczecin.pl": [
        "Politechnika Morska w Szczecinie",
        "Maritime University of Szczecin",
    ],
    ".tuniv.szczecin.pl": ["Technical University of Szczecin"],
    ".univ.szczecin.pl": ["University of Szczecin"],
    ".student.wsb.szczecin.pl": [
        "Wyższa Szkoła Bankowa w Szczecinie",
        "School of Banking",
    ],
    ".zpsb.szczecin.pl": ["West Pomeranian Business School in Szczecin"],
    ".zsee.szczecin.pl": [
        "Zespół Szkół Elektryczno-Elektronicznych im. prof. Maksymiliana Tytusa Hubera w Szczecinie",
        "Electrical-Electronic Schools Complex named after Prof. Maksymilian Tytus Huber in Szczecin",
    ],
    ".szkola1.pl": [
        "Zespół Szkół Nr 1 Centrum Kształcenia Praktycznego w Aleksandrowie Kujawskim."
    ],
    ".ii-lo.tarnow.pl": [
        "II Liceum ogólnokształcące Im. Jana Hetmana Tarnowskiego w Tarnowie"
    ],
    ".iii-lo.tarnow.pl": ["III Liceum Ogólnokształcące"],
    ".zsme.tarnow.pl": ["Zespół Szkół Mechaniczno-Elektrycznych w Tarnowie"],
    ".zst.tarnow.pl": [
        "Zespół Szkół Technicznych im. I. Mościckiego w Tarnowie"
    ],
    ".tarnowckz.pl": [
        "Centrum Kształcenia Zawodowego,Tarnów",
        "Center for Vocational Education,Tarnow",
    ],
    ".tech3malbork.pl": [
        "Technikum Nr.3 w Malborku",
        "Technical Highschool no.3 in Malbork",
    ],
    ".technikumkreatywne.pl": ["Technikum Kreatywne w Szczecinie"],
    ".thebritishschool.pl": ["The British School Warsaw"],
    ".gimakad.torun.pl": ["Gimnazjum i Liceum Akademickie w Toruniu"],
    ".loiv.torun.pl": [
        "IV Liceum Ogólnokształcące im. Tadeusza Kościuszki w Toruniu",
        "General Tadeusz Kosciuszko High School #4 in Torun",
    ],
    ".student.wsb.torun.pl": ["Wyższa Szkoła Bankowa w Toruniu"],
    ".zsmeie.torun.pl": [
        "Zespół Szkół Mechanicznych Elektrycznych i Elektronicznych im. prof. Sylwestra Kaliskiego w Toruniu",
        "Professor Sylwester Kaliski Mechanical School Of Electrical And Electronic in Torun",
    ],
    ".uekat.pl": ["University of Economics in Katowice"],
    ".student.ujw.pl": [
        "Uczelnia Jana Wyżykowskiego",
        "Jan Wyżykowski University",
    ],
    ".office.umcs.pl": [
        "Uniwersytet Marii Curie-Skłodowskiej w Lublinie",
        "Maria Curie-Skłodowska University",
    ],
    ".umcs.pl": [
        "Uniwersytet Marii Curie-Skłodowskiej",
        "Maria Curie-Sklodowska University",
    ],
    ".umk.pl": ["Nicolaus Copernicus University in Toruń"],
    ".student.umlub.pl": [
        "Medical University of Lublin",
        "@student.umlub.pl",
        "@umlub.pl",
    ],
    ".umlub.pl": [
        "Medical University of Lublin",
        "@student.umlub.pl",
        "@umlub.pl",
    ],
    ".uth.pl": ["Helena Chodkowska University of Technology and Economics"],
    ".uthrad.pl": ["Technical University of Radom"],
    ".viiilo.pl": ["VIII Liceum Ogólnokształcące im. dra Emila Warmińskiego"],
    ".vizja.pl": [
        "Wyższa Szkoła Finansów i Zarządzania w Warszawie",
        "University of Finance aand Management in Warsaw",
    ],
    ".vmickiewicz.pl": [
        "V Liceum Ogólnokształcące w Częstochowie im. A. Mickiewicza"
    ],
    ".student.wsb.warszawa.pl": ["Wyższa Szkoła Bankowa w Warszawie"],
    ".wsm.warszawa.pl": [
        "Warsaw Management University",
        "Wyzsza Szkola Menedzerska w Warszawie",
    ],
    ".asp.waw.pl": ["Fine Arts Academy in Warsaw"],
    ".cbk.waw.pl": [
        "Centrum Badań Kosmicznych Polskiej Akademii Nauk",
        "Space Research Centre of the Polish Academy of Sciences",
    ],
    ".ibb.waw.pl": [
        "Institute of Biochemistry and Biophysics Polish Academy of Sciences"
    ],
    ".ibspan.waw.pl": [
        "Systems Research Institute Polish Academy of Sciences",
        "Instytut Badan Systemowych Polskiej Akademii Nauk",
    ],
    ".ipipan.waw.pl": [
        "Institute of Computer Science Polish Academy of Sciences"
    ],
    ".lopiaseczno.waw.pl": [
        "IV Liceum Ogólnokształcące im. rtm. Witolda Pileckiego w Piasecznie",
        "Witold Pilecki 4th High School in Piaseczno",
    ],
    ".sggw.waw.pl": ["Agricultural University of Warsaw"],
    ".sgh.waw.pl": ["Warsaw School of Economics"],
    ".staszic.waw.pl": [
        "XIV Liceum Ogólnokształcące im. Stanisława Staszica w Warszawie",
        "Stanisław Staszic 14th High School in Warsaw",
    ],
    ".pans.wloclawek.pl": [
        "Państwowa Akademia Nauk Stosowanych we Włocławku",
        "The State Academy of Applied Sciences in Włocławek",
    ],
    ".puz.wloclawek.pl": [
        "Państwowa Uczelnia Zawodowa we Włocławku",
        "State Vocational University in Włocławek",
    ],
    ".pwsz.wloclawek.pl": ["National Higher Vocational School of Wloclawek"],
    ".2lo.wlodawa.pl": [
        "Zespół Szkół Zawodowych Nr 1 i II Liceum Ogólnokształcące we Włodawie"
    ],
    ".wlodkowic.pl": ["Pawel Wlodkowic University College in Plock"],
    ".ZS1.wroc.pl": ["ZS nr 1 we Wrocławiu - IT specialist"],
    ".am.wroc.pl": ["Medical Academy in Wroclaw"],
    ".amuz.wroc.pl": ["Music Academy Karol Lipinski in Wroclaw"],
    ".ar.wroc.pl": ["Agricultural University of Wroclaw"],
    ".asp.wroc.pl": ["Fine Arts Academy in Wroclaw"],
    ".awf.wroc.pl": ["Physical Education Academy in Wroclaw"],
    ".lo16.wroc.pl": ["XVI Liceum Wrocław"],
    ".lo2.wroc.pl": [
        "II Liceum Ogólnokształcące im. Piastów Śląskich we Wrocławiu"
    ],
    ".pwr.wroc.pl": ["Wrocław University of Technology"],
    ".ue.wroc.pl": ["Academy of Economics in Wroclaw"],
    ".umed.wroc.pl": [
        "Uniwersytet Medyczny im. Piastów Śląskich we Wrocławiu",
        "Wroclaw Medical University",
        "+Faculty of Pharmacy with Division of Laboratory Diagnostics",
    ],
    ".uni.wroc.pl": ["University of Wroclaw"],
    ".up.wroc.pl": ["Wroclaw University of Environmental and Life Sciences"],
    ".wsiz.wroc.pl": ["Wyższa Szkoła Informatyki i Zarządzania we Wrocławiu"],
    ".edu.wroclaw.pl": [
        "XIV Liceum Ogólnokształcące im. Polonii Belgijskiej we Wrocławiu",
        "14th High School of Polonia Belgijska in Wroclaw",
        ".group",
    ],
    ".wsb.wroclaw.pl": ["WSB University in Wroclaw"],
    ".wroclawskaedukacja.pl": [
        "I Liceum Ogólnokształcące im. Danuty Siedzikówny „Inki” we Wrocławiu"
    ],
    ".chorzow.wsb.pl": [
        "Chorzow/Katowice branch of Higher School of Business"
    ],
    ".wseh.pl": ["University of Economics and Humanities"],
    ".student.wsg.pl": ["Wyższa Szkoła Gospodarki", "University of Economy"],
    ".wsiz.pl": [
        "University of Information Technology and Management in Rzeszow",
        "Wyższa Szkoła Informatyki i Zarządzania w Rzeszowie",
    ],
    ".wsnhid.pl": ["School of Humanities and Journalism"],
    ".wsosp.pl": ["Polish Air Force Academy"],
    ".wspa.pl": [
        "The University College of Enterprise and Administration in Lublin"
    ],
    ".office.wst.pl": [
        "Wyższa Szkoła Techniczna w Katowicach",
        "University of Technology, Katowice, Poland",
    ],
    ".stud.wst.pl": [
        "Wyższa Szkoła Techniczna w Katowicach",
        "University of Technology, Katowice, Poland",
    ],
    ".wst.pl": [
        "Wyższa Szkoła Techniczna w Katowicach",
        "University of Technology, Katowice, Poland",
    ],
    ".wsti.pl": ["Katowice Institute of Information Technologies"],
    ".wsz.pl": ["Gdansk Management College"],
    ".wwsse.pl": [
        "Wielkopolska Wyższa Szkoła Społeczno-Ekonomiczna ",
        "Greater Poland School of Social and Economics",
    ],
    ".zs.zaczernie.pl": ["Zespół Szkół im. Armii Krajowej w Zaczerniu"],
    ".elektronik.zgora.pl": [
        'Centrum Kształcenia Zawodowego i Ustawicznego nr 2 "Elektronik" w Zielonej Górze',
        'Centre for Vocational and Continuing Education No. 2 "Elektronik" in Zielona Góra',
    ],
    ".jedynka.zgora.pl": [
        "\ufeffI Liceum Ogólnokształcące im. Edwarda Dembowskiego"
    ],
    ".uz.zgora.pl": ["University of Zielona Gora"],
    ".zpsb.pl": [
        "Zachodniopomorska Szkoła Biznesu w Szczecinie",
        "West Pomeranian School of Business",
    ],
    ".zs1-swarzedz.pl": [
        "Zespół Szkół nr 1 im. Powstańców Wielkopolskich w Swarzędzu"
    ],
    ".zsbrybnik.pl": ["Zespół Szkół Budowlanych w Rybniku"],
    ".zsdil.pl": [
        "Zespół Szkół Technicznych i Leśnych w Żywcu",
        "Complex of Technical and Forest Schools in Żywiec",
    ],
    ".zsegw.pl": [
        "Zespół Szkół Elektrycznych w Gorzowie Wielkopolskim",
        "ZSEGW",
    ],
    ".zsel1.pl": [
        "Zespół Szkół Elektrycznych nr 1 im. Powstańców Śląskich w Krakowie"
    ],
    ".zsepoznan.pl": [
        "Zespół Szkół Ekonomicznych im. Stanisława Staszica w Poznaniu"
    ],
    ".zsgorowoil.pl": [
        "Liceum Ogólnokształcące w Górowie Iławeckim",
        "Gorowo Ilaweckie High School",
    ],
    ".zsme.pl": [
        "Zespół Szkół Mechaniczno-Elektrycznych im. Tadeusza Kościuszki w Rybniku"
    ],
    ".zsmi.pl": [
        "Zespół Szkoł Mechaniczno-Informatycznych im. prof. Henryka Mierzejewskiego w Lęborku",
        "Mechanical, Informatical School Complex named by professor Henryk Mierzejewski in Lębork",
    ],
    ".zsostargard.pl": [
        "Szkoła Podstawowa nr 2 z Oddziałami Integracyjnymi w Stargardzie"
    ],
    ".zsosto.pl": [
        "Spoleczne Liceum Ogolnoksztalcace nr 1 im. Jana Nowaka-Jezioranskiego STO Warszawa"
    ],
    ".zsp10.pl": [
        "Zespół szkół elektroniczno-informatycznych imienia Jana Szczepanika w Łodzi"
    ],
    ".zsp2garwolin.pl": [
        "Zespol Szkol Ponadgimnazjalnych nr 2 Centrum Ksztalcenia Praktycznego w Garwolinie"
    ],
    ".zsp3zamosc.pl": ["Zespół Szkół Ponadpodstawowych Nr 3 w Zamościu"],
    ".zspwrzesnia.pl": ["Zespół Szkół Politechnicznych we Wrześni"],
    ".zsrogozno.pl": ["zespół szkół im. Hipolita Cegielskiego"],
    ".zstbialystok.pl": ["Zespół Szkół Technicznych im. gen. Wł. Andersa"],
    ".zstchelm.pl": ["Zespół Szkół Technicznych w Chełmie "],
    ".zstckziu.pl": [
        "Zespół Szkół Technicznych - Centrum Kształcenia Zawodowego i Ustawicznego"
    ],
    ".edu.zstjaslo.pl": [
        "Zespół Szkół Technicznych im. Bohaterów Września w Jaśle"
    ],
    ".zstmikolow.pl": [
        "Zespół Szkół Technicznych w Mikołowie",
        "The Complex of Technical Schools in Mikołów",
    ],
    ".zstz-radzymin.pl": [
        "Zespół Szkół Techniczno - Zawodowych im. inż. Czesława Nowaka w Radzyminie"
    ],
    ".zszakrzewo.pl": ["Zespół Szkół w Zakrzewie"],
    ".zszbd.pl": ["Zespół Szkół Zawodowych w Brzegu Dolnym"],
    ".zszglogow.pl": [
        "Zespół Szkół Politechnicznych w Głogowie",
        "Zespol Szkol Politechnicznych in Glogow",
    ],
    ".ucb.edu.pr": ["Universidad Central de Bayamón"],
    ".sanignacio.pr": [
        "Colegio San Ignacio de Loyola",
        "Saint Ignatius of Loyola School",
    ],
    ".ut.pr": ["Universidad del Turabo"],
    ".aaup.edu.ps": ["Arab American University"],
    ".alaqsa.edu.ps": ["Al-Aqsa University"],
    ".alazhar.edu.ps": ["Al-Azhar University of Gaza"],
    ".israa.edu.ps": ["جامعة الإسراء - غزة", "Israa University - Gaza"],
    ".iugaza.edu.ps": ["Islamic University of Gaza"],
    ".muc.edu.ps": ["MODERN UNIVERSITY COLLEGE"],
    ".paluniv.edu.ps": ["جامعة فلسطين الأهلية", "Palestine Ahliya University"],
    ".ppu.edu.ps": [
        "Palestine Polytechnic University",
        "Palestine Polytechnic University",
    ],
    ".ptcdb.edu.ps": ["Palestine Technical College-Dier Elbalah"],
    ".ptuk.edu.ps": [
        "جامعة فلسطين التقنية - خضوري",
        "Palestine Technical University - Kadoorie",
    ],
    ".ucas.edu.ps": ["University College of Applied Sciences"],
    ".uou.edu.ps": ["Ummah University"],
    ".up.edu.ps": ["University of Palestine"],
    ".zust.edu.ps": ["Al Zaytona University of Science and Technology"],
    ".abs.pt": ["\ufeffAtlântico Business School"],
    ".academiamilitar.pt": ["Academia Militar", "Portuguese Military Academy"],
    ".ae-smfeira.pt": [
        "Escola Secundária de Santa Maria da Feira",
        "Santa Maria da Feira Secondary School",
    ],
    ".aebenavente.pt": ["Escola Básica do 2.º e 3.º Ciclos Duarte Lopes"],
    ".aluno.aebenfica.pt": ["Escola secundaria jose gomes ferreira"],
    ".aebentodacruz.pt": ["Agrupamento de Escolas Dr. Bento da Cruz"],
    ".aedah.pt": ["Escola Secundaria D. Afonso Henriques"],
    ".aeds.pt": ["Agrupamento de Escolas Domingos Sequeira"],
    ".aeen.pt": [
        "Escola Básica e Secundária Emídio Navarro",
        "Escola Secundária Emídio Navarro",
    ],
    ".aeestarreja.pt": [
        "Escola Secundária de Estarreja",
        "Estarreja Secondary School",
    ],
    ".aememmartins.pt": ["Agrupamento de Escolas de Mem Martins"],
    ".aemm.pt": ["Agrupamento de Escolas Morgado de Mateus"],
    ".aerbp.pt": ["Agrupamento de Escolas Rafael Bordalo Pinheiro"],
    ".aevf.pt": ["Vergílio Ferreira Secondary School"],
    ".atec.pt": ["ATEC - Academia de Formação"],
    ".autonoma.pt": ["Universidade Autónoma de Lisboa"],
    ".aebatalha.ccems.pt": [
        "Agrupamento de Escolas da Batalha",
        "Schools District of Batalha",
    ],
    ".msft.cesae.pt": ["CESAE Digital"],
    ".formandos.cinel.pt": [
        "CINEL - Centro de Formação Profissional da Indústria Electrónica, Energia, Telecomunicações e Tecnologias da Informação"
    ],
    ".colegiomoderno.pt": ["Colégio Moderno"],
    ".colegiosaogoncalo.pt": ["Colégio de São Fgonçalo - Escola Católica"],
    ".colgaia.pt": ["Colégio de Gaia"],
    ".coriente.pt": ["Colégio Oriente"],
    ".in.cscm-lx.pt": ["Colégio Sagrado do Coração de Maria"],
    ".damiaodegoes.pt": ["Escola Secundaria Damião de Goes"],
    ".ead-aerbp.pt": ["Agrupamento de Escolas Rafael Bordalo Pinheiro"],
    ".ael.edu.pt": ["Agrupamento de Escolas das Laranjeiras"],
    ".espr.edu.pt": ["\ufeffEscola Secundária de Pinhal do Rei "],
    ".ufp.edu.pt": [
        "Universidade Fernando Pessoa",
        "Fernando Pessoa University",
    ],
    ".enautica.pt": ["Escola Nautica Infante D. Henrique"],
    ".enta.pt": ["ENTA - Escola de Novas Tecnologias dos Açores"],
    ".alunos.epbjc.pt": ["Escola Profissional Bento de Jesus Caraça"],
    ".professores.epbjc.pt": ["Escola Profissional Bento de Jesus Caraça"],
    ".epg.pt": [
        "Escola Profissional de Gaia",
        "The official URL: https://epg.pt/",
        "The Page URL of the Programming Course: https://epg.pt/cursos-ensino-secundario/informatica-multimedia/curso-programador-informatica",
    ],
    ".epge.pt": ["Escola Profissional Gustave Eiffel"],
    ".epvl.pt": ["Escola Profissional Vasconcellos Lebre, Mealhada"],
    ".esad.pt": ["Escola Superior de Artes e Design"],
    ".esarganil.pt": ["Agrupamento de Escolas de Arganil"],
    ".alunos.escamoes.pt": [
        "Escola secundária de camões",
        "Camões secondary school",
    ],
    ".alunos.esdacsf.pt": [
        "Escola Secundária Dr. Augusto César da Silva Ferreira"
    ],
    ".esfundao.pt": ["Agrupamento de escolas do Fundão"],
    ".esmaior.pt": ["Santa Maria Maior School Group"],
    ".esramada.pt": ["Escola Secundária da Ramada"],
    ".esrbp.pt": ["Agrupamento de Escolas Rafael Bordalo Pinheiro"],
    ".professores.etic.pt": ["ETIC", "ETIC"],
    ".etla.pt": ["Escola Tecnológica do Litoral Alentejano"],
    ".etpc.pt": ["Escola Técnico Profissional de Cantanhede"],
    ".etpr.pt": ["ETPR - Escola Técnica e Profissional do Rinatejo"],
    ".etpsico.pt": ["Escola Tecnológica e Profissional de Sicó "],
    ".europeia.pt": ["Universidade Europeia"],
    ".ferreiradias.pt": ["\ufeffEscola Secundária Ferreira Dias"],
    ".edu.madeira.gov.pt": [
        "Secretaria Educação Governo da Madeira",
        "Educational Secretary of Madeira Island Goverment",
    ],
    ".iade.pt": ["Instituto de Artes Visuais, Design e Marketing - IADE"],
    ".idjv.pt": ["Instituto D. João V"],
    ".formacao.iefp.pt": [
        "Instituto do Emprego e Formação Profissional ",
        "Institute for Employment and Vocational Training ",
    ],
    ".inp.pt": ["Instituto Superior Novas Profissões - INP"],
    ".inuaf-studia.pt": ["Instituto Superior D. Afonso III - INUAF"],
    ".ipb.pt": ["Instituto Politécnico de Bragança"],
    ".ipbeja.pt": ["Instituto Politécnico de Beja"],
    ".ipc.pt": ["Instituto Politécnico de Coimbra"],
    ".ipca.pt": ["Polytechnic Institute of Cavado and Ave"],
    ".ipcb.pt": ["Instituto Politécnico de Castelo Branco"],
    ".ipcbcampus.pt": ["Instituto Politécnico de Castelo Branco"],
    ".sal.ipg.pt": ["Instituto Politécnico da Guarda"],
    ".ipg.pt": ["Instituto Politécnico da Guarda"],
    ".ipiaget.pt": ["Instituto Piaget", "Piaget institute"],
    ".isel.ipl.pt": [" Instituto Superior de Engenharia de Lisboa"],
    ".ipl.pt": ["Instituto Politécnico de Lisboa"],
    ".iplei.pt": ["Instituto Politécnico de Leiria"],
    ".ipleiria.pt": ["Polytechnic Institute of Leiria"],
    ".mso365.ipluso.pt": ["Instituto Politécnico da Lusofonia"],
    ".ipmaia.pt": ["Instituto Politécnico da Maia"],
    ".ipp.pt": ["Instituto Politecnico do Porto"],
    ".ipportalegre.pt": ["Instituto Politécnico de Portalegre"],
    ".estsetubal.ips.pt": [
        "Escola Superior de Tecnologia de Setúbal, Instituto Politécnico de Setúbal"
    ],
    ".estudantes.ips.pt": [
        "Escola Superior de Tecnologia de Setúbal, Instituto Politécnico de Setúbal"
    ],
    ".ips.pt": ["Instituto Politécnico de Setúbal"],
    ".ipsantarem.pt": ["Instituto Politécnico de Santarém"],
    ".ipt.pt": ["Instituto Politécnico de Tomar"],
    ".ipv.pt": ["Instituto Politécnico de Viseu"],
    ".ipvc.pt": ["Instituto Politécnico de Viana do Castelo"],
    ".isai.pt": ["Instituto Superior de Assistentes e Intérpretes"],
    ".isbb.pt": ["Instituto Superior Bissaya Barreto"],
    ".iscac.pt": [
        "Instituto Superior de Contabilidade e Administração de Coimbra"
    ],
    ".iscet.pt": ["Instituto Superior de Ciências Empresariais e de Turismo"],
    ".iscte-iul.pt": ["ISCTE – University Institute of Lisbon"],
    ".iscte.pt": ["Instituto Superior de Ciências do Trabalho e da Empresa"],
    ".isec.pt": ["ISEC - Instituto Superior de Engenharia de Coimbra"],
    ".isel.pt": ["ISEL - Instituto Superior de Engenharia de Lisboa"],
    ".isg.pt": ["Instituto Superior de Gestão - ISG"],
    ".isla.pt": ["Instituto Superior de Línguas e Administração"],
    ".mail.islagaia.pt": [
        "ISLA - Instituto Politécnico de Gestão e Tecnologia",
        "ISLA - Polytechnic Institute of Management and Technology",
    ],
    ".mail.islasantarem.pt": ["ISLA Santarém - Instituto Politécnico"],
    ".ismai.pt": ["Instituto Superior da Maia"],
    ".ismat.pt": ["INSTITUTO SUPERIOR MANUEL TEIXEIRA GOMES"],
    ".ismt.pt": ["Instituto Superior Miguel Torga", "Miguel Torga Institute"],
    ".ispa.pt": ["Instituto Superior de Psicologia Aplicada"],
    ".ispab.pt": ["Instituto Superior de Paços de Brandão"],
    ".ispgaya.pt": ["Instituto Superior Politécnico Gaya"],
    ".istec.pt": ["Instituto Superior de Tecnologias Avançadas - ISTEC"],
    ".istp.pt": ["Instituto Superior de Transportes e Comunicações"],
    ".novasbe.pt": ["Nova School of Business and Economics"],
    ".oml.pt": ["Academia Nacional Superior de Orquesta"],
    ".pedago.pt": ["Instituto Superior de Ciências Educativas"],
    ".pupilos.pt": ["Instituto dos Pupilos do Exército"],
    ".ua.pt": ["Universidade de Aveiro"],
    ".uab.pt": ["Universidade Aberta Lisboa"],
    ".uac.pt": ["Universidade dos Acores"],
    ".students.ual.pt": ["Universidade Autónoma de Lisboa"],
    ".ual.pt": ["Universidade Autónoma de Lisboa"],
    ".ualg.pt": ["Universidade do Algarve"],
    ".uatlantica.pt": ["Universidade Altântica"],
    ".ubi.pt": [
        "Universidade da Beira Interior",
        "University of Beira Interior",
    ],
    ".uc.pt": ["Universidade de Coimbra"],
    ".ucp.pt": ["Universidade Catolica Portuguesa"],
    ".ucpcrp.pt": [
        "Universidade Católica Portuguesa - Centro Regional do Porto"
    ],
    ".uevora.pt": ["Universidade de Evora"],
    ".ufp.pt": ["Universidade Fernando Pessoa"],
    ".uinternacional.pt": ["Universidade Internacional Lisboa"],
    ".ul.pt": ["Universidade de Lisboa"],
    ".ulisboa.pt": ["Universidade de Lisboa"],
    ".ulusiada.pt": ["Universidade Lusiada"],
    ".ulusofona.pt": ["Universidade Lusófona de Humanidades e Technologias"],
    ".student.uma.pt": ["Universidade da Madeira"],
    ".uma.pt": ["Universidade da Madeira"],
    ".umaia.pt": ["Universidade de Maia", "University of Maia"],
    ".uminho.pt": ["Universidade do Minho"],
    ".umoderna.pt": ["Universidade Moderna de Lisboa"],
    ".uni.pt": ["Universidade Independente"],
    ".universidade-autonoma.pt": [
        "Universidade Autónoma de Lisboa Luís de Camoes",
        "universidade-autonoma.pt , autonoma.pt and ual is for main site and employees",
        "students.ual.pt is for Students and teachers",
    ],
    ".universidadeeuropeia.pt": ["Universidade Europeia"],
    ".unl.pt": ["Universidade Nova de Lisboa"],
    ".up.pt": ["Universidade do Porto"],
    ".uportu.pt": ["Universidade Portucalense Infante D. Henrique"],
    ".alunos.upt.pt": ["Universidade Portucalense Infante D. Henrique"],
    ".utad.pt": ["Universidade de Tras-os-Montes e Alto Douro"],
    ".utl.pt": ["Universidade Tecnica de Lisboa"],
    ".valeovil.pt": ["Agrupamento de Escolas de Vale de Ovil"],
    ".americana.edu.py": ["Universidad Americana"],
    ".campoalto.edu.py": ["Colegio Campoalto - Paraguay"],
    ".columbia.edu.py": ["Universidad Columbia del Paraguay"],
    ".desarrollo.edu.py": [
        "Instituto Desarrollo Paraguay",
        "Development Institute Paraguay",
    ],
    ".fctunca.edu.py": [
        "Facultad de Ciencias y Tecnologias UNC@ (Universidad Nacional de Caaguazu)",
        "Faculty of Sciences and Technologies UNC@ (National University of Caaguazu)",
    ],
    ".filouna.edu.py": [
        "Facultad de Filosofia Universidad Nacional de Asunción",
        "School of Philosophy UNA",
    ],
    ".fiuna.edu.py": [
        "Facultad de Ingenieria Universidad Nacional de Asuncion",
        "School of Engineering UNA",
    ],
    ".fiuni.edu.py": [
        "Universidad Nacional de Itapúa",
        "National University of Itapúa",
    ],
    ".fpuna.edu.py": ["Facultad Politécnica"],
    ".fpune.edu.py": [
        "Universidad Nacional del Este",
        "Universidad Nacional del Este",
    ],
    ".sansebastian.edu.py": ["Universidad Autonoma San Sebastian"],
    ".ua.edu.py": ["Universidad Americana"],
    ".uaa.edu.py": ["Universidad Autónoma de Asunción"],
    ".uamericana.edu.py": ["Universidad Americana"],
    ".uap.edu.py": ["Universidad Autónoma del Paraguay"],
    ".uc.edu.py": ["Universidad Católica Nuestra Senora de la Asunción"],
    ".uca.edu.py": ["Universidad Católica Nuestra Senora de la Asunción"],
    ".ucom.edu.py": ["Universidad Comunera"],
    ".ucsa.edu.py": ["Universidad del Cono Sur de las Américas"],
    ".uds.edu.py": ["Universidad de Desarrollo Sustentable"],
    ".uma.edu.py": ["Universidad Metropolitana de Asunción"],
    ".une.edu.py": ["Universidad Nacional del Este"],
    ".uni.edu.py": [
        "Universidad Nacional de Itapua",
        "National University of Itapua",
    ],
    ".unida.edu.py": [
        "Universidad de la Integración de las Americas (UNIDAD)"
    ],
    ".unigran.edu.py": [
        "Universidad Gran Asunción - UNIGRAN",
        "Gran Asunción University - UNIGRAN",
    ],
    ".uninorte.edu.py": ["Universidad del Norte"],
    ".unisal.edu.py": ["Universidad San Lorenzo"],
    ".unp.edu.py": [
        "Universidad Nacional de Pilar",
        "National University of Pilar",
    ],
    ".upa.edu.py": [
        "Universidad Paraguaya Alemana",
        "German Paraguayan University",
    ],
    ".upe.edu.py": ["Universidad Privada del Este"],
    ".uptp.edu.py": [
        "Universidad Politécnica Taiwán Paraguay",
        "Taiwan Paraguay Polytechnic University",
    ],
    ".usil.edu.py": [
        "Universidad San Ignacio de Loyola – Paraguay",
        "Universidad San Ignacio de Loyola – Paraguay",
    ],
    ".ing.una.py": ["Facultad de Ingenieria, FIUNA"],
    ".pol.una.py": ["Facultad Politécnica"],
    ".www.una.py": ["Universidad Nacional de Asunción"],
    ".cna-qatar.edu.qa": ["College of the North Atlantic"],
    ".qu.edu.qa": ["University of Qatar"],
    ".mila.quebec": ["Mila - Institut québécois d'intelligence artificielle"],
    ".student.42.rio": ["42|RIO", "42 Rio"],
    ".academiadepolitie.ro": ["ACADEMIA DE POLITIE „Al. I. Cuza”"],
    ".academyplus.ro": ["Academy+Plus"],
    ".aisb.ro": ["American International School of Bucharest"],
    ".alazar.ro": ["Liceul Teoretic Aurel Lazar"],
    ".alexandrucelbun.ro": ["Colegiul Alexandru cel Bun Gura Humorului"],
    ".anmb.ro": ['Academia Navala "Mircea cel Batran"'],
    ".apizal.ro": [
        'Colegiul Tehnic "Alesandru Papiu Ilarian" Zalau, Romania',
        '"Alesandru Papiu Ilarian" Technical College from Zalau, Romania',
    ],
    ".armyacademy.ro": ["Academia Forțelor Terestre Nicolae Bălcescu"],
    ".arteiasi.ro": ["Academy of Arts George Enescu Iasi"],
    ".ase.ro": ["Academia de Studii Economice din Bucuresti"],
    ".avenor.ro": ["Avenor College"],
    ".bolyai.ro": ["Bolyai Farkas Elmeleti Liceum"],
    ".bphasdeu.ro": [
        "Colegiul National 'Bogdan Petriceicu Hasdeu' Buzau",
        "National Collage 'Bogdan Petriceicu Hasdeu' Buzau",
    ],
    ".britishschool.ro": [
        "British School of Bucharest",
        "https://britishschool.ro/",
        "student@bsbonline.net",
        "teacher@britishschool.ro",
    ],
    ".carabella.ro": ['Colegiul Național "Constantin Carabella"'],
    ".cdloga.ro": [
        "Colegiul National C.D. Loga Timisoara",
        "National College C.D. Loga Timisoara",
    ],
    ".cnaic.ro": [
        "Colegiul National Alexandru Ioan Cuza",
        "Alexandru Ioan Cuza National College",
    ],
    ".cnaicuza.ro": ["Colegiul Național „Alexandru Ioan Cuza”, Alexandria"],
    ".cnc.ro": [
        'Colegiul Național „Carol I", Craiova',
        '"Carol I" National College, Craiova',
    ],
    ".cncv.ro": ["Colegiul National Cantemir Voda"],
    ".cndssm.ro": [
        "Colegiul Național „Doamna Stanca” Satu Mare",
        '"Doamna Stanca" National College, Satu Mare',
    ],
    ".cnelenacuza.ro": [
        "Colegiul National Elena Cuza Bucuresti",
        "Elena Cuza National College of Bucharest",
    ],
    ".cneminescu.ro": [
        'Colegiul National "Mihai Eminescu" Suceava',
        'National High School "Mihai Eminescu" Suceava',
    ],
    ".cnfb.ro": [
        "Colegiul Național Frații Buzești",
        "Frații Buzești National College",
    ],
    ".cnghsincai.ro": [
        "Colegiul National Gheorghe Sincai",
        '"Gheorghe Sincai" National College',
    ],
    ".cnhurmuzachi.ro": [
        "Colegiul Național „Eudoxiu Hurmuzachi” Rădăuți",
        '"Eudoxiu Hurmuzachi" National College, Radauti',
    ],
    ".cni-sv.ro": [
        'Colegiul National de Informatica "Spiru Haret" Suceava',
        'National College of Informatics "Spiru Haret" Suceava',
    ],
    ".cniasi.ro": ["Colegiul Național Iași", "National College Iasi"],
    ".cnihd.ro": ['Liceul Teoretic "Traian Lalescu"'],
    ".cnilcb.ro": ['Colegiul National "Ion Luca Caragiale" Bucuresti'],
    ".cnimateibasarab.ro": [
        "Colegiul National de Informatica Matei Basarab",
        "National College of Informatics Matei Basarab",
    ],
    ".cnislavici.ro": [
        "Colegiul National „Ioan Slavici” Satu Mare",
        '"Ioan Slavici" National College, Satu Mare',
    ],
    ".cnivor.ro": [
        'Colegiul National "Iosif Vulcan"',
        'National College "Iosif Vulcan"',
    ],
    ".cnmbct.ro": [
        "Colegiul Național ”Mircea cel Bătrân” - Constanța",
        '"Mircea cel Batran" National College of Constanta county, Romania',
    ],
    ".cnmirceavl.ro": ["Colegiul National Mircea cel Batran Rm.Valcea"],
    ".cnmtv.ro": ["Colegiul Național Militar „Tudor Vladimirescu”"],
    ".cnmv.ro": [
        "Colegiul National Mihai Viteazul",
        "Mihai Viteazul National College",
    ],
    ".cnmvslobozia.ro": ['Colegiul Național "Mihai Viteazul" Slobozia'],
    ".cnmvturda.ro": ['Colegiul Național "Mihai Viteazul" Turda'],
    ".cnodobescu.ro": [
        "Colegiul Național Alexandru Odobescu Pitești",
        "National College Alexandru Odobescu of Pitesti",
    ],
    ".cnpcv.ro": ["Colegiul Național „Ștefan Velovan”"],
    ".cnprsv.ro": [
        "Colegiul Național „Petru Rareș” Suceava",
        '"Petru Rareș" National College Suceava',
    ],
    ".cnrg.ro": [
        "Colegiul Național Radu Greceanu",
        "National College Radu Greceanu",
    ],
    ".cnrv.ro": ["Colegiul National Roman Voda"],
    ".cnsm.ro": [
        "Colegiul National Stefan Cel Mare Targu-Neamt",
        'National College "Stephan the Great" Targu-Neamt',
    ],
    ".cnstefancelmare.ro": [
        'Colegiul National "Stefan cel Mare" Suceava',
        'National College "Stefan cel Mare" Suceava',
    ],
    ".cnszalau.ro": [
        "Colegiul National Silvania",
        "Silvania National College",
    ],
    ".cnunirea.ro": [
        "Colegiul Național „Unirea” Brașov",
        "„Unirea” National College, Brasov",
    ],
    ".cnvais.ro": ["Colegiul National Vasile Alecsandri"],
    ".cnvapedia.ro": [
        'Colegiul Național "Vasile Alecsandri", Bacău',
        '"Vasile Alecsandri" National College, Bacău',
    ],
    ".cnvgarad.ro": [
        "Colegiul Național „Vasile Goldiș” Arad",
        "„Vasile Goldiș” Arad National College",
    ],
    ".cnvranceanu.ro": [
        "Colegiul National Gheorghe Vranceanu Bacau",
        "Gheorghe Vranceanu National College",
    ],
    ".colegiulbaiulescu.ro": [
        'Colegiul Tehnic "Maria Baiulescu"',
        '"Maria Baiulescu" Technic College',
    ],
    ".colegiulbanatean.ro": ["Colegiul National Banatean"],
    ".colegiulgib.ro": [
        'Colegiul National "Gib Mihaescu"',
        'National College "Gib Mihaescu"',
    ],
    ".colegiultehnicmedia.ro": [
        "Colegiul Tehnic Media",
        "Media Technic College",
    ],
    ".colegiulunirea.ro": [
        'Colegiul National "Unirea", Târgu Mureș',
        '"Unirea" National college, Târgu Mureș',
    ],
    ".colpedms.ro": ['Colegiul National Pedagogic "Mircea Scarlat"'],
    ".cttbv.ro": [
        "Colegiul Tehnic de Transporturi Brașov",
        "Transport Technical College",
    ],
    ".utcluj.didatec.ro": ["Technical University of Cluj-Napoca"],
    ".e-cdloga.ro": [
        'Colegiul National "Constantin Diaconovici Loga" Timisoara',
        'National College "Constantin Diaconovici Loga" Timisoara',
    ],
    ".e-racovita.ro": [
        'Colegiul Național "Emil Racoviță", Cluj-Napoca',
        'National College "Emil Racovita", Cluj-Napoca',
    ],
    ".e-uvt.ro": ["West University of Timisoara"],
    ".ecat.ro": [
        'Colegiul National "Ecaterina Teodoroiu"',
        'National College "Ecaterina Teodoroiu"',
    ],
    ".ecotgm.ro": [
        'Colegiul Economic "Transilvania" Târgu Mureș',
        '"Transilvania" Economic College of Târgu Mureș',
    ],
    ".cni.nt.edu.ro": [
        "Colegiul National de Informatica Piatra Neamt Romania",
        "National College of Computer Science Piatra Neamt Romania",
    ],
    ".elenacuza.ro": [
        "Colegiul National Elena Cuza Bucuresti",
        "Elena Cuza National College of Bucharest",
    ],
    ".emanuel.ro": ["Emanuel University"],
    ".eminescubucuresti.ro": [
        "Colegiul Național „Mihai Eminescu” Bucuresti",
        'National College "Mihai Eminescu" Bucharest',
    ],
    ".eminescucj.ro": [
        "Liceul Teoretic Mihai Eminescu, Cluj-Napoca",
        "Mihai Eminescu Highschool",
    ],
    ".stu.eminescusm.ro": [
        "Colegiul Național Mihai Eminescu Satu Mare",
        "C N Mihai Eminescu Satu Mare",
    ],
    ".eminescusm.ro": [
        'Colegiul Național "Mihai Eminescu" Satu Mare',
        "Mihai Eminescu National College Satu Mare",
    ],
    ".student.faa.ro": [
        "Faculty of Administration and Business, University of Bucharest"
    ],
    ".fspac.ro": [
        "Universitatea Babeș-Bolyai, Facultatea de Știinte Politice, Administrative și ale Comunicării, suc. Sfântu Gheorghe",
        "Babeș-Bolyai University, Faculty of Political, Administrative and Communication Sciences, Sfântu Gheorghe dep.",
    ],
    ".georgebaritiu.ro": ["Liceu Tehnologic George Baritiu"],
    ".gimi.ro": ["Liceul Teoretic Tamási Áron"],
    ".gogaionescu.ro": [
        "Liceul Tehnologic Goga Ionescu",
        "Goga Ionescu High School",
    ],
    ".informatica.hyperion.ro": [
        '"Hyperion" Facultatea de Stiinte Exacte si Ingineresti',
        '"Hyperion" University of Exact Sciences and Engineering',
        "https://informatica.hyperion.ro/",
        "http://aei.geniu.ro/",
    ],
    ".iaim.ro": ["Institute of Architecture Ion Mincu Bucharest"],
    ".go.ibsb.ro": ["International British School Bucharest"],
    ".ibsb.ro": ["International British School Bucharest"],
    ".ichb.ro": [
        "Liceul International de Informatica Bucuresti",
        "International Informatics High School Bucharest ",
    ],
    ".idanubius.ro": ["Universitatea Danubius Galati, Romania"],
    ".isb.ro": ["International School of Bucharest", "isb.ro"],
    ".itpbucuresti.ro": [
        "Institutul Teologic Penticostal, Bucuresti",
        "Pentecostal Theological Institute, Bucharest",
    ],
    ".kosiskola.ro": ["Liceul Tehnologic Kós Károly"],
    ".elevi.laurian.ro": [
        'Colegiul National "A.T. Laurian"',
        'National College "A.T. Laurian"',
    ],
    ".lbi.ro": [
        'Colegiul National de Informatica "Tudor Vianu"',
        'National College of Computer Science "Tudor Vianu"',
    ],
    ".ldv.ro": [
        "Liceul Special pentru Deficienți de Vedere Cluj-Napoca",
        "Special High School for Visually Impaired Cluj-Napoca",
    ],
    ".liceulangelescu.ro": ["Liceul Teoretic Constantin Angelescu"],
    ".liceulbenjaminfranklin.ro": [
        "Liceul Teoretic Benjamin Franklin, Bucuresti",
        "Benjamin Franklin High School, Bucharest",
    ],
    ".liceulnicolaeoncescu.ro": ["Liceul Technologic Nicoleae Oncescu"],
    ".liceulovidius.ro": [
        'Liceul Teoretic "Ovidius" Constanța',
        '"Ovidius" Theoretical Highschool',
    ],
    ".liceulprodeo.ro": [
        'Liceul Teoretic Crestin "Pro Deo", Cluj-Napoca',
        '"Pro Deo" Highschool, Cluj-Napoca',
    ],
    ".liceulsaligny-tr.ro": [
        'Liceul Tehnologic "Anghel Saligny" Roșiori de Vede',
        '"Anghel Saligny" Technological High School Roșiori de Vede',
    ],
    ".liceulstefanodobleja.ro": [
        "Liceul Teoretic Stefan Odobleja",
        "Stefan Odobleja Theoretical High School",
    ],
    ".liceulteoreticalexandrughica.ro": ["Liceul Teoretic Alexandru Ghica"],
    ".liceultonitza.ro": [
        'Liceul de Arte Plastice "Nicolae Tonitza" București',
        '"Nicolae Tonitza" Fine Arts High School Bucharest',
    ],
    ".liceulunirea.ro": ['Colegiul National "Unirea" Focsani'],
    ".liceulvictorbabescluj.ro": ['Liceul Teoretic "Victor Babeș"'],
    ".liceupetrila.ro": [
        "Colegiul Tehnic „Constantin Brâncuși” Petrila",
        '"Constantin Brâncuși" Technical College Petrila',
    ],
    ".licped.ro": ['Liceul Pedagogic "Matei Basarab"'],
    ".licsfsava.ro": ["\ufeffSfântul Sava National College"],
    ".liis.ro": [
        'Liceul Teoretic de Informatica "Grigore Moisil"',
        'High School of Computer Science "Grigore Moisil"',
    ],
    ".lni.ro": ['Liceul Tehnologic "Nicolae Iorga" Negresti'],
    ".ltamg.ro": ['Liceul Teoretic "Adam Müller Guttenbrunn"'],
    ".ltib.ro": ['Liceul Teoretic "Ion Barbu"'],
    ".ltmcis.ro": [
        "Liceul Teoretic Miron Costin Iasi",
        "High School Miron Costin Iasi",
    ],
    ".ltmeliade.ro": ['Liceul Teoretic "Mircea Eliade"'],
    ".ltsti.ro": [
        "Liceul Teoretic Sfintii Trei Ierarhi",
        "Three Holy Hierarchs High School",
        "http://www.ltsti.ro",
    ],
    ".madgearu.ro": ["Colegiul Economic Virgil Madgearu"],
    ".stud.managusamv.ro": [
        "Universitatea de Știinţe Agronomice şi Medicină Veterinară din Bucureşti - FACULTATEA DE MANAGEMENT ŞI DEZVOLTARE RURALĂ",
        "University of Agronomic Sciences and Veterinary Medicine of Bucharest - FACULTY OF MANAGEMENT AND RURAL DEVELOPMENT",
    ],
    ".moisenicoara.ro": [
        "Colegiul National Moise Nicoara",
        "Moise Nicoara National College",
    ],
    ".moisil.ro": [
        'Colegiul Național "Grigore Moisil" București',
        "Grigore Moisil National College (Bucharest)",
    ],
    ".moisilbv.ro": [
        "Colegiul Național de Informatică „Grigore Moisil” Brașov",
        'NCSC "Grigore Moisil" Brașov',
    ],
    ".moisiltm.ro": ["Liceul Teoretic Grigore Moisil Timisoara"],
    ".mta.ro": ["Academia Tehnica Militara"],
    ".mviteazul.ro": [
        "Colegiul Tehnic Mihai Viteazul Oradea",
        "Technical College Mihai Viteazul Oradea",
    ],
    ".ogoga.ro": [
        'Liceul Teoretic "Octavian Goga" Huedin',
        '"Octavian Goga" Huedin Theoretical High School',
    ],
    ".onisifor-ghibu.ro": [
        'Liceul Teoretic "Onisifor Ghibu" Sibiu',
        'High School "Onisifor Ghibu" Sibiu',
    ],
    ".pedagogic.ro": [
        'COLEGIUL NAȚIONAL PEDAGOGIC "REGINA MARIA"  MUNICIPIUL PLOIEȘTI'
    ],
    ".pedaudv.ro": ["Liceul Pedagogic Benedek Elek"],
    ".pub.ro": ["University POLITEHNICA of Bucharest"],
    ".rau.ro": ["Romanian-American University"],
    ".eminescu.rdsor.ro": [
        "Colegiul National Mihai Eminescu",
        "National College Mihai Eminescu",
    ],
    ".refkol.ro": ["Colegiul Reformat Baczkamadarasi Kis Gergely"],
    ".reginadorohoi.ro": [
        "Liceul Regina Maria Dorohoi",
        "Queen Maria Dorohoi High School",
    ],
    ".romanvoda.ro": ["Colegiul National Roman Voda"],
    ".saguna.ro": [
        'Colegiul National "Andrei Saguna"',
        '"Andrei Saguna" National College',
    ],
    ".sapientia.ro": ["Sapientia Hungarian University of Transylvania"],
    ".scoala-afumati.ro": ["Scoala Afumati"],
    ".scoala-mihaieminescu.ro": [
        'Scoala Gimnazială "Mihai Eminescu" Roşiorii de Vede',
        '"Mihai Eminescu" School Roșiorii de Vede',
    ],
    ".scoala19avramiancu-tm.ro": ["scoala gimnaziala nr 19 Timisoara"],
    ".scoala2bv.ro": ["Diaconu Coresi nr 2"],
    ".scoala45.ro": ["Scoala Gimnaziala Titu Maiorescu 45"],
    ".scoala79.ro": ["Scoala Gimnaziala nr. 79", "Middle School no. 79"],
    ".scoalaghlazar.ro": ["Scoala Gimnaziala Gheorghe Lazar"],
    ".scoalainformala.ro": ["Scoala Informala de IT"],
    ".scoalaiorguiordan.ro": [
        'Scoala Gimnaziala "Iorgu Iordan" Tecuci',
        '"Iorgu Iordan" Secondary School Tecuci',
    ],
    ".scoalaluceafarul.ro": [
        "Școala Gimnazială Luceafărul",
        "Luceafarul Middle School",
    ],
    ".scoalanr178.ro": [
        "Scoala nr 178, Bucuresti",
        "Middle School, Number 178, Bucharest, Sector 1",
    ],
    ".scoalaprincipesamargareta.ro": ["Scoala Principesa Margareta"],
    ".sibiu.ro": ["University of Sibiu"],
    ".sincaibm.ro": ["Colegiul Național „Gheorghe Șincai” Baia Mare"],
    ".snspa.ro": [
        "National School of Political and Administrative Studies Bucharest"
    ],
    ".spiruharet-moinesti.ro": [
        'Liceul Teoretic "Spiru Haret"',
        '"Spiru Haret" Theoretical High School',
    ],
    ".spiruharet.ro": ["Spiru Haret University"],
    ".szekelymikokollegium.ro": [
        "Székely Mikó Kollégium",
        '"Székely Mikó" National College',
    ],
    ".tpopoviciu.ro": ['Liceul de Informatica "Tiberiu Popoviciu"'],
    ".traian-vuia.ro": ["Traian Vuia Bucuresti", "Traian Vuia Bucharest"],
    ".traianlalescu.ro": ['Liceul Teoretic "Traian Lalescu"'],
    ".tuiasi.ro": ["Technical University of Iasi"],
    ".uadventus.ro": [
        "Universitatea Adventus din Cernica",
        "Adventus University from Cernica",
    ],
    ".uaic.ro": ["University Alexandru Ioan Cuza of Iasi"],
    ".uartdcluj.ro": ["University of Art and Design Cluj-Napoca"],
    ".uat.ro": ["Targu-Mures University of Theatre"],
    ".uav.ro": ["University Aurel Vlaicu Arad"],
    ".ub.ro": ["University of Bacau"],
    ".ubbcluj.ro": ["Babes-Bolyai University of Cluj-Napoca"],
    ".ubm.ro": ["North University of Baia Mare"],
    ".ucv.ro": ["University of Craiova"],
    ".uem.ro": ["University of Resita"],
    ".ugal.ro": ["University of Galatzi"],
    ".ulbsibiu.ro": ['Universitatea "Lucian Blaga" din Sibiu'],
    ".umf.ro": [
        '"Carol Davila" University of Medicine and Pharmacy Bucharest',
        "Universitatea de Medicină și Farmacie „Carol Davila” București",
    ],
    ".umfcd.ro": [
        '"Carol Davila" University of Medicine and Pharmacy Bucharest',
        "Universitatea de Medicină și Farmacie „Carol Davila” București",
    ],
    ".umfcluj.ro": ["University of Medicine and Pharmacy of Cluj-Napoca"],
    ".umfcv.ro": ["University of Medicine and Pharmacy of Craiova"],
    ".umfiasi.ro": ["University of Medicine and Pharmacy of Iasi"],
    ".umfst.ro": [
        "UMFST - Universitatea de Medicină, Farmacie, Științe și Tehnologie din Târgu Mureș",
        "UMFST - University of Medicine, Pharmacy, Science and Technology of Tîrgu Mureş",
    ],
    ".umft.ro": ["University of Medicine and Pharmacy of Timisoara"],
    ".umftgm.ro": ["University of Medicine and Pharmacy of Targu Mures"],
    ".unarte.ro": ["National University of Arts"],
    ".unatc.ro": ["National University of Theater and Film Arts"],
    ".unibuc.ro": ["University of Bucharest"],
    ".student.unitbv.ro": ["Transilvania University of Brasov"],
    ".unitbv.ro": ["Transilvania University of Brasov"],
    ".univ-ovidius.ro": ["University of Constanta"],
    ".univagro-iasi.ro": [
        "University of Agriculture and Veterinary Medicine Iasi"
    ],
    ".univcb.ro": ["Constantin Brancoveanu University Pitesti"],
    ".universitateamaritima.ro": ["Maritime University Constanta"],
    ".univnt.ro": [
        "Universitatea Nicolae Titulescu",
        "Nicolae Titulescu University",
    ],
    ".unmb.ro": ["National University of Music"],
    ".uoradea.ro": ["University of Oradea"],
    ".upa.ro": ["University Petre Andrei Iasi"],
    ".upb.ro": ["University POLITEHNICA of Bucharest"],
    ".upet.ro": ["University of Petrosani"],
    ".upg-ploiesti.ro": ["University Oil- Gas Ploiesti"],
    ".upit.ro": ["University of Pitesti"],
    ".upm.ro": ["Petru Maior University of Targu Mures"],
    ".upt.ro": ["Polytechnic University of Timisoara"],
    ".usab-tm.ro": [
        "Banat's University of Agricultural Sciences",
        "University of Agriculture and Veterinary Medicine Timisoara",
    ],
    ".usab.ro": [
        "University of Agriculture and Veterinary Medicine Bucharest"
    ],
    ".agro.usamv.ro": [
        "Universitatea de Științe Agronomice și Medicină Veterinară",
        "University of Agriculture and Veterinary Medicine",
    ],
    ".fmvb.usamv.ro": [
        " UNIVERSITATEA DE ŞTIINŢE AGRONOMICE ŞI MEDICINĂ VETERINARĂ DIN BUCUREŞTI",
        "UNIVERSITY OF AGRONOMIC SCIENCES AND VETERINARY MEDICINE OF BUCHAREST",
    ],
    ".usamvcluj.ro": [
        "University of Agriculture and Veterinary Medicine Cluj-Napoca"
    ],
    ".usm.ro": [
        "Universitatea Ștefan cel Mare Suceava",
        "Stefan cel Mare University of Suceava",
    ],
    ".usv.ro": ["University of Suceava"],
    ".utcb.ro": ["Technical University of Civil Engineering Bucharest"],
    ".utcluj.ro": ["Technical University of Cluj-Napoca"],
    ".utgjiu.ro": ["University of Targu Jiu"],
    ".utm.ro": ["University Titu Maiorescu"],
    ".utt.ro": ["Technical University of Timisoara"],
    ".uvt.ro": ["West University of Timisoara"],
    ".uvvg.ro": ['Universitatea de Vest "Vasile Goldis" din Arad'],
    ".valahia.ro": ["Valahia University of Targoviste"],
    ".wurmbrand.ro": [
        "Colegiul Richard Wurmbrand",
        "Richard Wurmbrand School",
    ],
    ".viona.rocks": [
        "IBB Institut für Berufliche Bildung AG",
        "Homepage: https://www.ibb.com/",
        "Contact Site: https://www.ibb.com/kontakt",
        "Addresses: Many places throughout  Germany",
        "Institute Mail Example: example@@ibb.com",
        "Students Mail Example: example@viona.rocks",
        "Course URL: https://www.ibb.com/umschulung/fachinformatiker-in-anwendungsentwicklung-umschulung",
        "Proof URL: https://us.ibb.com/",
    ],
    ".etf.bg.ac.rs": [
        "University of Belgrade, School of Electrical Engineering"
    ],
    ".matf.bg.ac.rs": ["University of Belgrade, Faculty of Mathematics"],
    ".bg.ac.rs": [
        "University of Belgrade",
        "University of Fine Arts Belgrade",
        ".group",
    ],
    ".eu.ac.rs": ["European University"],
    ".kg.ac.rs": ["University of Kragujevac"],
    ".metropolitan.ac.rs": ["Metropolitan University"],
    ".ni.ac.rs": ["University of Nis"],
    ".np.ac.rs": ["Drzavni Univerzitet u Novom Pazaru"],
    ".vps.ns.ac.rs": [
        "Visoka Poslovna Škola Novi Sad",
        "Novi Sad School Of Business",
    ],
    ".pr.ac.rs": ["University of Priština"],
    ".singidunum.ac.rs": ["UNIVERZITET SINGIDUNUM", "Singidunum University"],
    ".vts.su.ac.rs": [
        "Subotica Tech - College of Applied Sciences",
        "Visoka tehnička škola strukovnih studija Subotica",
    ],
    ".uns.ac.rs": [
        "Fakultet tehničkih nauka, Novi Sad",
        "Faculty of technical sciences, Novi Sad",
    ],
    ".akademijakm.edu.rs": [
        "АКАДЕМИЈА СТРУКОВНИХ СТУДИЈА КОСОВСКО МЕТОХИЈСКА",
        "KOSOVO AND METOHIJA ACADEMY OF APPLIED STUDIES",
    ],
    ".asss.edu.rs": ["Aкадемија Струковних Студија Шумадија"],
    ".atssb.edu.rs": [
        "Академија техничких струковних студија БЕОГРАД",
        "Academy of Technical Vocational Studies BELGRADE",
    ],
    ".atvsspirot.edu.rs": [
        "Akademija tehničko-vaspitačkih strukovnih studija - Odsek Pirot"
    ],
    ".bba.edu.rs": [
        "Beogradska bankarska akademija - Fakultet za bankarstvo, osiguranje i finansije",
        "Belgrade banking academy  - faculty of banking, insurance and finance",
    ],
    ".bbs.edu.rs": ["Belgrade Business and Arts Academy of Applied Studies"],
    ".borastankovic.edu.rs": [
        "Гимназија „Бора Станковић”, Ниш",
        "Gimnazija „Bora Stanković”, Niš",
        "Grammar School “Bora Stanković”, Niš",
    ],
    ".bpa.edu.rs": ["Belgrade Business and Arts Academy of Applied Studies"],
    ".elitna.edu.rs": [
        "Elitna privatna ekonomska škola i gimnazija, Novi Sad"
    ],
    ".ets-zemun.edu.rs": [
        'Elektrotehnička škola "Zemun", Beograd ',
        'The Secondary School of Electrical Engineering "Zemun" Beograd',
    ],
    ".etsntesla.edu.rs": [
        'Elektrotehnička škola "Nikola Tesla" Pančevo',
        'The Secondary School of Electrical Engineering "Nikola Tesla" Pancevo',
    ],
    ".fdb.edu.rs": ["Faculty of Diplomacy and Security, University Union NT"],
    ".fimek.edu.rs": [
        "Fakultet za ekonomiju i inženjerski menadžment",
        "University Business Academy in Novi Sad",
    ],
    ".fmk.edu.rs": ["Singidunum University"],
    ".ftn.edu.rs": ["Fakultet Tehnickih Nauka u Cacku"],
    ".gimnazijapirot.edu.rs": ["Gimnazija Pirot"],
    ".gimnazijasm.edu.rs": ["Mitrovačka Gimnazija"],
    ".gimnazijatvrdjava.edu.rs": ["Privatna Gimnazija Tvrđava"],
    ".ict.edu.rs": ["Visoka ICT škola (ICT College of Vocational Studies)"],
    ".isb.edu.rs": ["The International School of Belgrade"],
    ".iths.edu.rs": [
        "Srednja skola za informacione tehnologije, Beograd",
        "Information technology high school",
    ],
    ".its.edu.rs": [
        "ITS - Visoka škola strukovnih studija za informacione tehnologije | Beograd"
    ],
    ".jjzmaj.edu.rs": ["Gimnazija Jovan Jovanovic Zmaj"],
    ".loznickagimnazija.edu.rs": [
        'Gimnazija "Vuk Karadžić"',
        'High School "Vuk Karadžić"',
    ],
    ".matgim.edu.rs": ["Mathematical Grammar School, Belgrade"],
    ".mef.edu.rs": [
        "Fakultet za primenjeni menadzment, ekonomiju i finansije",
        "Faculty for applied management, economics and finances",
    ],
    ".metropolitan.edu.rs": ["Metropolitan University"],
    ".msstankovic.edu.rs": [
        "Музичка школа „Станковић“ Београд",
        "Stanković Musical School",
    ],
    ".muzickaskolapancevo.edu.rs": [
        'OMS i SMS "Jovan Bandur" u Pancevu',
        'Elementary and High Music School "Jovan Bandur" in Pancevo',
    ],
    ".osboskovic.edu.rs": ["Ruđer Bošković Škola", "Rudjer Boskovic School"],
    ".osmagimnazija.edu.rs": [
        "8. beogradska gimnazija",
        "Eighth Belgrade Grammar School",
    ],
    ".osmilandjmilicevic.edu.rs": [
        'Osnovna škola "Milan Đ. Milicevic"',
        'Elementary School "Milan D. Milicevic"',
    ],
    ".osvukkaradzic-krnjevo.edu.rs": [
        "ОШ ВУК КАРАДЖИЋ",
        "VUK KARADZIC ELEMENTARY SCHOOL",
    ],
    ".osvukknjazevac.edu.rs": [
        "osvukknjazevac",
        "OS Vuk Karadzic u Knjazevcu ",
        "Elementary School Vuk karadzic in Knjazevac",
    ],
    ".pmf.edu.rs": ["Prirodno Matematicki Fakultet Nis"],
    ".politehnika.edu.rs": [
        "Akademija Tehničkih Strukovnih Studija Beograd, odsek Beogradska Politehnika",
        "The Academy of Applied Technical Studies Belgrade, department of Belgrade Polytechnic",
    ],
    ".poly.edu.rs": ["Српски политехнички универзитет"],
    ".privrednaakademija.edu.rs": ["Privredna Akademija (Business Academy)"],
    ".raf.edu.rs": ["Racunarski Fakultet ", "School of Computing"],
    ".rg.edu.rs": ["Racunarska gimazija"],
    ".singidunum.edu.rs": ["Singidunum University"],
    ".smart.edu.rs": [
        'Računarska gimnazija "Smart" Novi Sad',
        'Computer Science High School "Smart" Novi Sad',
    ],
    ".sveti-sava.edu.rs": ['Gimnazija "Sveti Sava" Beograd'],
    ".tehnickacacak.edu.rs": [
        "Srednja Tehnicka Skola Cacak",
        "Highschool of Technical Engineering Cacak",
    ],
    ".tehnickaskolaknjazevac.edu.rs": [
        "Srednja Tehnička skola knjaževac",
        "Secondary Technical School Knjaževac",
    ],
    ".teslabg.edu.rs": [
        'ETS "Nikola Tesla"',
        "Electrotechnical Middle School Nikola Tesla",
    ],
    ".trecagimnazija.edu.rs": [
        "Treća Beogradska Gimnazija",
        "Third Belgrade High School",
    ],
    ".tsis.edu.rs": [
        "Tehnička škola 'Ivan Sarić'",
        "Technical School 'Ivan Sarić'",
    ],
    ".tsp.edu.rs": ["Tehnička škola Pirot"],
    ".uninp.edu.rs": ["International University of Novi Pazar"],
    ".valjevskagimnazija.edu.rs": ["Valjevska gimnazija", "Valjevo gymnasium"],
    ".vhts.edu.rs": [
        "Visoka tehničko-tehnološka škola strukovnih studija - Kruševac, Srbija (College of applied technical & technological studies - Krusevac, Serbia)"
    ],
    ".ucionica.vigimnazija.edu.rs": ["Šesta beogradska gimnazija "],
    ".vipos.edu.rs": [
        "Visoka poslovna škola strukovnih studija, Valjevo",
        "Valjevo Business School of Applied Studies",
    ],
    ".gs.viser.edu.rs": [
        "Visoka škola elektrotehnike i računarstva strukovnih studija, Beograd"
    ],
    ".viser.edu.rs": [
        "Akademija tehničko-umetničkih studija Beograd - Odsek Visoka škola elektrotehnike i računarstva",
        "Academy of Technical and Art Applied Studies - School of Electrical and Computer Engineering",
    ],
    ".vsar.edu.rs": [
        "Висока школа струковних студија Аранђеловац",
        "College of Applied Technology Science Arandjelovac",
    ],
    ".xiigimnazija.edu.rs": [
        "Dvanaesta beogradska gimnazija",
        "12. beogradska gimnazija",
        "The 12th Belgrade Grammar School",
        "The Twelfth Belgrade Grammar School",
    ],
    ".elfak.rs": ["University of Nis, Faculty of Electronic Engineering"],
    ".etf.rs": ["University of Belgrade, School of Electrical Engineering"],
    ".fink.rs": ["University of Kragujevac, Faculty of Engineering"],
    ".isb.rs": ["The International School of Belgrade"],
    ".raf.rs": ["Racunarski Fakultet, Belgrade"],
    ".tfzr.rs": [
        'University of Novi Sad - Technical faculty "Mihajlo Pupin" Zrenjanin'
    ],
    ".vtsnis.rs": [
        "College of Applied Technical Sciences Nis",
        "Visoka tehnicka skola strukovnih studija Nis",
        "Visoka tehnička škola strukovnih studija Niš",
        "Visoka thnička škola Niš",
        "Visoka tehnicka skola Nis",
    ],
    ".1060.ru": [
        "ГБОУ Школа №627, Москва",
        "УК-4 Вальдорфская школа имени А.А. Пинского",
        "GBOU School #627, Moscow",
    ],
    ".1514.ru": ["ГБОУ Школа №1514"],
    ".1561.ru": ["ГБОУ Школа №1561", "https://sch1561uz.mskobr.ru/"],
    ".1580.ru": [
        '\ufeffГосударственное бюджетное общеобразовательное учреждение города Москвы "Бауманская инженерная школа № 1580"'
    ],
    ".1581mgtu.ru": [
        "Gosudarstvennoe obrazovatelnoe uchrezhdenie goroda Moskvy Licej N1581 "
    ],
    ".179.ru": ["Moscow Konstantinov School"],
    ".1msmu.ru": ["First Moscow State Medical University"],
    ".21-school.ru": ["Школа 21", "21 School"],
    ".2101sch.ru": [
        'Государственное бюджетное общеобразовательное учреждение города Москвы "Школа № 2101"'
    ],
    ".239.ru": ["Physics and Mathematics Lyceum No. 239, St. Petersburg"],
    ".Ioffe.ru": [
        "Ioffe Physical-Technical Institute of the Russian Academy of Sciences "
    ],
    ".a-pet.ru": [
        "Ангарский промышленно-экономический техникум",
        "Angarskiy Promyshlenno-Ekonomicheskiy Tekhnikum",
    ],
    ".aanet.ru": [
        "Санкт-Петербургский государственный университет аэрокосмического приборостроения",
        "St. Petersburg State University of Aerospace Instrumentation",
    ],
    ".aas.ru": ["Anglo-American School of Moscow"],
    ".ivanovo.ac.ru": ["Ivanovo State University", "Ivanovo State University"],
    ".mgul.ac.ru": [
        "Moscow State University of Forestry Engineering",
        "Moscow State University of Forestry Engineering",
    ],
    ".mpei.ac.ru": [
        "Moscow Power Engineering Institute (Technical University)",
        "Moscow Power Engineering Institute (Technical University)",
    ],
    ".novsu.ac.ru": ["Novgorod State University", "Novgorod State University"],
    ".pspu.ac.ru": [
        "Perm State Pedagogical University",
        "Perm State Pedagogical University",
    ],
    ".pstu.ac.ru": [
        "Perm State Academy of Agriculture",
        "Perm State Technical University",
        "Perm State Academy of Agriculture",
        "Perm State Technical University",
    ],
    ".ugatu.ac.ru": [
        "Ufa State Aviation Technical University",
        "Ufa State Aviation Technical University",
    ],
    ".uni-vologda.ac.ru": [
        "Vologda State Pedagogical University",
        "Vologda State Pedagogical University",
    ],
    ".uniyar.ac.ru": [
        "Yaroslavl State University",
        "Yaroslavl State University",
    ],
    ".unn.ac.ru": [
        "Nizhny Novgorod State University",
        "Nizhny Novgorod State University",
    ],
    ".urc.ac.ru": [
        "Cheljabinsk State Institute of Teacher Training",
        "Cheljabinsk University of Agricultural Engineering",
        "Cheljabinsk State Institute of Teacher Training",
        "Cheljabinsk University of Agricultural Engineering",
    ],
    ".vspu.ac.ru": [
        "Voronezh State Pedagogical University",
        "Voronezh State Pedagogical University",
    ],
    ".yma.ac.ru": [
        "Yaroslavl State Medical Academy",
        "Yaroslavl State Medical Academy",
    ],
    ".academicol.ru": [
        'ANPOO "Akademicheskij kolledzh"',
        'ANPOO "Akademicheskij kolledzh"',
    ],
    ".achtng.ru": [
        "Краевое государственное автономное профессиональное образовательное учреждение «Ачинский техникум нефти и газа имени Е.А.Демьяненко»",
        "Achinsk college of oil and gas",
    ],
    ".aclic.ru": ["Tomsk Academic Lyceum", "Tomsk Academic Lyceum"],
    ".acxk.ru": ["Гбпоу Асхк", "ASHK Colledge"],
    ".adygnet.ru": ["Adygeja State University", "Adygeja State University"],
    ".ael.ru": [
        "Khabarovsk State Academy of Economics and Law",
        "Khabarovsk State Academy of Economics and Law",
    ],
    ".agatu.ru": [
        "ФЕДЕРАЛЬНОЕ ГОСУДАРСТВЕННОЕ БЮДЖЕТНОЕ ОБРАЗОВАТЕЛЬНОЕ УЧРЕЖДЕНИЕ ВЫСШЕГО ОБРАЗОВАНИЯ АРКТИЧЕСКИЙ ГОСУДАРСТВЕННЫЙ АГРОТЕХНОЛОГИЧЕСКИЙ УНИВЕРСИТЕТ",
        "Arctic State Agrotechnological University",
    ],
    ".agtu.ru": [
        "Arhangelsk State Technical University",
        "Arhangelsk State Technical University",
    ],
    ".akvt.ru": ["Astrakhan's College of Computed Technics"],
    ".almazovcentre.ru": [
        "ФГБУ «НМИЦ им. В. А. Алмазова» Минздрава России",
        "Almazov National Medical Research Centre",
    ],
    ".altgtu.ru": [
        "Алтайский государственный технический университет им. И.И. Ползунова",
        "Polzunov Altai State Technical University",
    ],
    ".ame.ru": [
        "Academy of Management and Entrepreneurship",
        "Academy of Management and Entrepreneurship",
    ],
    ".amursu.ru": ["Amur State University", "Amur State University"],
    ".angtu.ru": ["Ангарский государственный технический университет"],
    ".ap47.ru": [
        'Regional state budgetary vocational educational institution "Amurskiy Polytechnic College"',
        "In Russian, short: КГБ ПОУ АПТ",
        "In Russian, full official: Краевое государственное бюджетное профессиональное образовательное учреждение «Амурский политехнический техникум»",
    ],
    ".aptu.ru": ["St. Petersburg Academic University"],
    ".arcotel.ru": [
        "Arkhangelsk college of telecommunications",
        "Архангельский колледж телекоммуникаций (филиал) СПбГУТ им. проф. М.А. Бонч-Бруевича ",
    ],
    ".artcollege.ru": [
        "Первый Московский образовательный комплекс 1-й МОК",
        "1st MOK",
    ],
    ".asau.ru": [
        "Алтайский Государственный Аграрный Университет",
        "Altai State Agricultural University",
    ],
    ".aserhovo.ru": [
        "МБОУ Асерховская средняя общеобразовательная школа Собинского района"
    ],
    ".asmu.ru": [
        "Altai State Medical University",
        "Altai State Medical University",
    ],
    ".aspc-edu.ru": [
        'ГБПОУ АО "Астраханский государственный политехнический колледж"',
        "Astrakhan State Polytechnic College",
    ],
    ".aspu.ru": ["Astrakhan State University", "Astrakhan State University"],
    ".astranet.ru": [
        "Astrahan State Medical Academy",
        "Astrahan State Medical Academy",
    ],
    ".asu.ru": ["Altai State University", "Altai State University"],
    ".asugubkin.ru": [
        "Automated Control Systems Departments of Gubkin Russian State University of Oil and Gas (National Research University)"
    ],
    ".aucu.ru": [
        "Astrakhan State University of Architecture and Civil Engineering"
    ],
    ".avtlg.ru": ["Volgograd Medical Academy", "Volgograd Medical Academy"],
    ".ismu.baikal.ru": ["Irkutsk Medical University"],
    ".bashedu.ru": [
        "Bashkir State Agrarian University",
        "Bashkir State Medical University",
        "Bashkir State Pedagogical Institute",
        "Bashkir State University",
        "Birsk State Pedagogical Institute",
        "Sterlitamak State Pedagogical Institute",
        "Ufa State Institute of Arts",
        "Bashkir State Agrarian University",
        "Bashkir State Medical University",
        "Bashkir State Pedagogical Institute",
        "Bashkir State University",
        "Birsk State Pedagogical Institute",
        "Sterlitamak Branch Bashkir State University",
        "Ufa State Institute of Arts",
    ],
    ".belevbolotoschool.ru": [
        'Муниципальное общеобразовательное учреждение "Болотская средняя общеобразовательная школа" Белевского района Тульской области'
    ],
    ".bfmiit.ru": [
        "Bryansk branch Moscow State University of Railway Engineering (BfMIIT)",
        "Брянский филиал Московского государственного университета путей сообщения (БфМИИТ)",
    ],
    ".bgpu.ru": ["Blagoveshchensk State Pedagogical University"],
    ".bgu.ru": [
        "Байкальский Государственный Университет ",
        "Baikal State University",
    ],
    ".birsk.ru": ["Bashkir State University Birsk Branch"],
    ".biysk-liceum.ru": ["Biysk Liceum"],
    ".biysk.ru": [
        "Biysk State Padagogical University after V.M. Shukshin ",
        "Biysk State Padagogical University after V.M. Shukshin ",
    ],
    ".bktis.ru": ["Baikal college of tourism and service"],
    ".blpk-uu.ru": [
        "Бурятский лесопромышленный колледж",
        "Burjat forestry college",
    ],
    ".bmstu-kaluga.ru": [
        "Kaluga branch of Bauman Moscow State Technical University"
    ],
    ".bmstu.ru": [
        "Bauman Moscow State Technical University",
        "Bauman Moscow State Technical University",
    ],
    ".britishdesign.ru": ["British Higher School of Art & Design"],
    ".brstu.ru": [
        "Bratsk State Technical University",
        "Bratsk State Technical University",
    ],
    ".bsaa.ru": [
        "Belgorod State Agricultural Academy",
        "Belgorod State Agricultural Academy",
    ],
    ".bspu.ru": [
        'Федеральное государственное бюджетное образовательное учреждение высшего образования "Башкирский государственный педагогический университет им. М.Акмуллы" (ФГБОУ ВО "БГПУ им. М.Акмуллы")',
        "Bashkir State Pedagogical University n. a. M. Akmulla",
    ],
    ".bstu.ru": [
        "Belgorod State Technical University",
        "Belgorod State Technical University",
    ],
    ".bsu.ru": ["Burjat State University"],
    ".bukep.ru": [
        'АНО ВО "Белгородский университет кооперации, экономики и права"',
        "Belgorod University of Cooperation, Economics and Law",
    ],
    ".burnet.ru": [
        "Burjat State University",
        "East-Siberian State Institute of Culture",
        "Burjat State University",
        "East-Siberian State Institute of Culture",
    ],
    ".ccfebras.ru": ["Computing Center FEB RAS"],
    ".cchgeu.ru": [
        "Воронежский государственный технический университет",
        "Voronezh State Technical University",
    ],
    ".centro.ru": [
        "Maxim Gorky Institute of Literature",
        "Maxim Gorky Institute of Literature",
    ],
    ".cfuv.ru": ["V.I. Vernadsky Crimean Federal University"],
    ".chat.ru": [
        "Moscow External University of the Humanities",
        "Moscow External University of the Humanities",
    ],
    ".chesu.ru": ["Chechen State University"],
    ".chgaki.ru": [
        "The Chelyabinsk State Institute of Culture and Arts",
        "https://chgaki.ru",
    ],
    ".chgik.ru": [
        "The Chelyabinsk State Institute of Culture and Arts",
        "https://chgik.ru",
    ],
    ".chsu.ru": ["Cherepovets State University"],
    ".chtptu.ru": ["Чайковский техникум промышленных технологий и управления"],
    ".chuvsu.ru": ["Chuvash State University", "Chuvash State University"],
    ".cit-psu.ru": ["CIT Perm State University"],
    ".ck41.ru": ["Московский Индустриальный Колледж"],
    ".college57.ru": [
        "ГБПОУ ТПСК им. В.М. Максимчука",
        "Technical fire and rescue college named by V.M. Maksimchuk",
    ],
    ".collegelan.ru": ["\ufeffЛангепасский политехнический колледж"],
    ".drbit.com.ru": [
        "Novosibirsk State Academy of Economics and Mangement",
        "Novosibirsk State Academy of Economics and Mangement",
    ],
    ".compscicenter.ru": [
        "Computer Science Center",
        "Computer Science Center",
    ],
    ".conservatoire.ru": [
        "Novosibirsk State Music Academy M. Glinka",
        "Novosibirsk State Music Academy M. Glinka",
    ],
    ".conservatory.ru": [
        "St. Petersburg State Conservatory",
        "St. Petersburg State Conservatory",
    ],
    ".cspu.ru": ["Chelyabinsk State Pedagogical University"],
    ".csu.ru": ["Cheljabinsk State University"],
    ".da.ru": [
        "Rostov State Medical University",
        "Rostov State Medical University",
    ],
    ".dakad.ru": ["ЧОУ «ДЕТСКАЯ АКАДЕМИЯ»"],
    ".dgu.ru": ["Dagestan State University", "Dagestan State University"],
    ".dgunh.ru": [
        "Дагестанский государственный университет народного хозяйства"
    ],
    ".donstu.ru": [
        "Don State Technical University",
        "Don State Technical University",
    ],
    ".dstu.ru": [
        "Дагестанский государственный технический университет",
        "Dagestan State Technical University",
    ],
    ".dvfu.ru": ["Far Eastern Federal University"],
    ".dvgu.ru": [
        "Far Eastern State University",
        "Far Eastern State University",
    ],
    ".e-43.ru": ["Kirov State All School Network"],
    ".eastsib.ru": [
        "East-Siberian State University",
        "East-Siberian State University",
    ],
    ".ects.ru": ["ECTS", "Yekaterinburg College Of Transport Construction"],
    ".agp.edu.ru": [
        "Академия Управления Городской Средой, Градостроительства и Печати",
        "Academy of Urban Management, Planning and Printing",
    ],
    ".asu.edu.ru": ["Astrakhan State University"],
    ".dstu.edu.ru": [
        "Don State Technical University",
        "Don State Technical University",
    ],
    ".herzen.edu.ru": [
        "Российский государственный педагогический университет им. А. И. Герцена",
        "The Herzen State Pedagogical University of Russia",
    ],
    ".ksaa.edu.ru": [
        "Костромская государственная сельскохозяйственная академия"
    ],
    ".kstu.edu.ru": [
        "Kostroma State Technological University",
        "Kostroma State Technological University",
    ],
    ".mstu.edu.ru": [
        "Murmansk State Technical University",
        "Murmansk State Technical University",
    ],
    ".muctr.edu.ru": [
        "Mendeleev Russian University of Chemical Technology",
        "Mendeleev Russian University of Chemical Technology",
    ],
    ".nsau.edu.ru": [
        "Novosibirsk State Agricultural University",
        "Novosibirsk State Agricultural University",
    ],
    ".pfu.edu.ru": [
        "People' s Friendship University of Russia",
        "People' s Friendship University of Russia",
    ],
    ".shgpi.edu.ru": [
        "Shadrinsk State Pedagogical University",
        "Shadrinsk State Pedagogical University",
    ],
    ".spmi.edu.ru": [
        "St. Petersburg State Mining Institute (Technical University)",
        "St. Petersburg State Mining Institute (Technical University)",
    ],
    ".technolog.edu.ru": [
        "Санкт-Петербургский государственный технологический институт (Технический университет)"
    ],
    ".tspu.edu.ru": [
        "Tomsk State Pedagogical University",
        "Tomsk State Pedagogical University",
    ],
    ".eduhouse.ru": [
        "Санкт–Петербургский Технический колледж управления и коммерции",
        "St. Petersburg Technical College of Management and Commerce",
    ],
    ".eetk.ru": [
        'ГАПОУ СО "Екатеринбургский экономико-технологический колледж"'
    ],
    ".eimb.ru": ["Engelhardt Institute of Molecular Biology"],
    ".ekvl.ru": ["Industrial College of Energy and Communications"],
    ".eltech.ru": [
        "St. Petersburg State Electrotechnical University",
        "St. Petersburg State Electrotechnical University",
    ],
    ".stud.engec.ru": [
        "St. Petersburg State University of Economics",
        "St. Petersburg State University of Economics",
    ],
    ".engec.ru": [
        "St. Petersburg State Academy for Engineering Economics (ENGECON)",
        "St. Petersburg State University of Engineering and Economics",
        "St. Petersburg State Academy for Engineering Economics (ENGECON)",
        "St. Petersburg State University of Engineering and Economics",
    ],
    ".esstu.ru": [
        "East-Siberian State University of Technology",
        "East-Siberian State University of Technology",
    ],
    ".etu.ru": [
        "St. Petersburg State Electrotechnical University",
        "St. Petersburg State Electrotechnical University",
    ],
    ".externat1.ru": ["Первый экстернат", "First externat"],
    ".fa.ru": ["Finance Academy", "Finance Academy"],
    ".festu.ru": [
        "Far Eastern State Technical University",
        "Far Eastern State Technical University",
    ],
    ".fevschool.ru": ['МБОУ "Февральская СОШ"', "MBOU Fevralsk Middle School"],
    ".fml31.ru": [
        "Physics and Mathematics Lyceum No. 31, Chelyabinsk",
        'МБОУ "ФМЛ № 31 г. Челябинска"',
    ],
    ".fms2007.ru": [
        "State budgetary educational institution of the city of Moscow School No. 2007 FMS",
        "Государственное бюджетное общеобразовательное учреждение города Москвы Школа № 2007 ФМШ",
    ],
    ".fmschool72.ru": ['ГАОУ ТО "Физико-математическая школа"'],
    ".fta-mo.ru": [
        "Finance and Technology Academy",
        "Finance and Technology Academy",
    ],
    ".ftacademy.ru": [
        "St. Petersburg State Forest-Technical Academy",
        "St. Petersburg State Forest-Technical Academy",
    ],
    ".gasu.ru": [
        "Gorno-Altaisk State University",
        "Gorno-Altaisk State University",
    ],
    ".gazsl.ru": [
        "Муниципальное бюджетное общеобразовательное учреждение Газ- Салинская средняя общеобразовательная школа"
    ],
    ".gimnaziya-dzr.ru": ["Orthodox Gymnasium of Seraphim of Sarov"],
    ".gkl-kemerovo.ru": [
        "Кемеровский Городской Классический Лицей",
        "Kemerovo Municipal Classical Lyceum",
    ],
    ".gma.ru": ["State Maritine Academy", "State Maritine Academy"],
    ".gnesin-academy.ru": [
        "Gnesins Russian Academy of Music",
        "Gnesins Russian Academy of Music",
    ],
    ".gnt-oil.ru": [
        'Государственное бюджетное профессиональное образовательное учреждение "Жирновский нефтяной техникум"',
        'State budgetary professional educational institution "Zhirnovskiy oil technical college"',
    ],
    ".gourpt.ru": [
        "ГОУ СПО Рыбницкий политехнический техникум",
        "GOU SPO RPT",
    ],
    ".goushet.ru": [
        "Государственное бюджетное профессиональное образовательное учреждение Московской области «Шатурский энергетический техникум»"
    ],
    ".gpma.ru": [
        "St. Petersburg State Pediatric Medical Academy",
        "St. Petersburg State Pediatric Medical Academy",
    ],
    ".gs8.ru": ["Gymnasium no. 8, Sochi, Russia"],
    ".gstou.ru": [
        "Грозненский государственный нефтяной технический университет имени академика М. Д. Миллионщикова",
        "Grozny State Oil Technical University named after Academician M. D. Millionshchikov",
    ],
    ".guap.ru": [
        "Saint-Petersburg State University of Aerospace Instrumentation",
        "Saint-Petersburg State University of Aerospace Instrumentation",
    ],
    ".gubkin.ru": [
        "Gubkin Russian State University of Oil and Gas",
        "Gubkin Russian State University of Oil and Gas",
    ],
    ".gukit.ru": [
        "St. Petersburg State Cinema and TV University",
        "St. Petersburg State Cinema and TV University",
    ],
    ".gumrf.ru": [
        "Admiral Makarov State University of Maritime and Inland Shipping"
    ],
    ".gup.ru": ["St. Petersburg University of Humanities"],
    ".guu.ru": [
        "State University of Management",
        "State University of Management",
    ],
    ".gym1505.ru": [
        'Государственное бюджетное общеобразовательное учреждение города Москвы "Школа № 1505 "Преображенская"',
        'The state budgetary educational institution of the city of Moscow "School No. 1505 "Preobrazhenskaya"',
    ],
    ".gym1517.ru": ["ГБОУ школа №1517", "GBOU school No. 1517"],
    ".gymn1576.ru": ["ГБОУ Школа 1576", "ГБОУ Школа 1576"],
    ".hexly.ru": ["Хекслет Колледж", "Hexlet College"],
    ".hiik.ru": [
        "Siberian State University of Telecommunications and Information Sciences Khabarovsk Branch"
    ],
    ".hse.ru": ["Higher School of Economics", "Higher School of Economics"],
    ".hspm.ru": ["Graduate School of Press and Media Technologies SPbSUITD"],
    ".i-klgtu.ru": [
        "Федеральное государственное бюджетное образовательное учреждение высшего образования «Калининградский государственный технический университет»",
        "Federal State Budget Educational Institution of Higher Education «Kaliningrad State Technical University»",
    ],
    ".ibp-moscow.ru": [
        "Institute of Business and Politics",
        "Institute of Business and Politics",
    ],
    ".icc.ru": [
        "Институт динамики систем и теории управления",
        "Matrosov Institute for System Dynamics and Control Theory of Siberian Branch of Russian Academy of Sciences",
    ],
    ".icmm.ru": [
        "Institute of Continuous Media Mechanics of the Ural Branch of Russian Academy of Science",
        "ICMM UB RAS",
        "Федеральное государственное бюджетное учреждение науки Институт механики сплошных сред Уральского отделения Российской академии наук",
        "ИМСС УрО РАН",
    ],
    ".ieml.ru": [
        "Kazan Innovative University named after V. G. Timiryasov (IEML)"
    ],
    ".iet.ru": [
        "Institute for the Economy in Transition",
        "Institute for the Economy in Transition",
    ],
    ".ifaran.ru": ["A.M. Obukhov Institute of Atmospheric Physics RAS"],
    ".ifmo.ru": [
        "St. Petersburg State University of Information Technologies, Mechanics and Optics",
        "St. Petersburg State University of Information Technologies, Mechanics and Optics",
    ],
    ".igps.ru": [
        "Санкт-Петербургский университет ГПС МЧС России",
        "Saint Petersburg university of State fire service of EMERCOM of Russia",
    ],
    ".iitp.ru": ["Institute for Information Transmission Problems"],
    ".ime.ru": [
        "Institute of Management and Economy",
        "Institute of Management and Economy",
    ],
    ".imi-samara.ru": [
        "\ufeffАНО ВО Самарский университет государственного управления «Международный институт рынка»"
    ],
    ".imiit.ru": [
        "Institute of Management and Information Technologies of RUT (MIIT)",
        "Институт Управления и Информационных Технологий РУТ (МИИТ)",
    ],
    ".indi.ru": [
        "Ivanovo State Academy of Medicine",
        "Ivanovo State Academy of Medicine",
    ],
    ".indsi.ru": ['МАУ "Институт развития стратегических инициатив"'],
    ".informatics.ru": ["Mytishy Programming School"],
    ".informika.ru": [
        'State Institute of Information Technologies and Telecommunications (SIIT&T "Informika")'
    ],
    ".inggu.ru": [
        "ФГБОУ ВО Ингушский государственный университет",
        "Ingush state university",
    ],
    ".innolyceum.ru": [
        'Государственное автономное общеобразовательное учреждение "Лицей Иннополис"',
        "Innopolis Lyceum",
    ],
    ".innopolis.ru": ["Innopolis University"],
    ".interun.ru": ["International University in Moscow"],
    ".inueco.ru": [
        "South Ural Institute of Management and Economics",
        "Южно-Уральский институт Управления и Экономики",
    ],
    ".iptmuran.ru": [
        "Institute of Precision Mechanics and Control",
        "Институт проблем точной механики и управления Российской академии наук",
    ],
    ".ipu.ru": [
        "Федеральное государственное бюджетное учреждение науки Институт проблем управления им. В. А. Трапезникова Российской академии наук"
    ],
    ".irgups.ru": ["Irkutsk State Transport University", "IrGUPS", "IrIIT"],
    ".irk.ru": [
        "Irkutsk State Academy of Economics",
        "Irkutsk State Technical University",
        "Irkutsk State Academy of Economics",
        "Irkutsk State Technical University",
    ],
    ".irkat.ru": ["Irkutsk aviation technical school"],
    ".isea.ru": [
        "Baikal National University of Economics and Law",
        "Baikal National University of Economics and Law",
    ],
    ".ispras.ru": [
        "Ivannikov Institute for System Programming of the Russian Academy of Sciences"
    ],
    ".ispu.ru": [
        "Ivanovo State Power University",
        "Ivanovo State Power University",
    ],
    ".istu.ru": [
        "Izhevsk State Technical University",
        "Izhevsk State Technical University",
    ],
    ".isu.ru": ["Irkutsk State University", "Irkutsk State University"],
    ".isuct.ru": [
        "Ivanovo State University of Chemistry and Technology",
        "Ivanovo State University of Chemistry and Technology",
    ],
    ".ithub.ru": ["IT HUB College"],
    ".itmo.ru": [
        "Санкт-Петербургский национальный исследовательский университет информационных технологий, механики и оптики",
        "ITMO University",
    ],
    ".iwp.ru": [
        "Институт водных проблем РАН",
        "Water Problems Institute of RAS (WPI RAS)",
    ],
    ".jum.ru": ["Jewish University in Moscow", "Jewish University in Moscow"],
    ".kaf65.ru": [
        "Kafedra 65 Concurrent systems analysis of MEPhI (Moscow Engineering Physics Institute)"
    ],
    ".kai.ru": [
        "Kazan State University of Technology",
        "Kazan State University of Technology",
    ],
    ".kait20.ru": [
        "GBPOU KAIT N 20, GBU, Moscow, Russia",
        "In Russian, short: ГБПОУ КАИТ №20",
        'In Russian, full official: Государственное бюджетное профессиональное образовательное учреждение города Москвы "Колледж автоматизации и информационных технологий № 20"',
    ],
    ".kalmsu.ru": ["Kalmyk State University", "Kalmyk State University"],
    ".kspu.kaluga.ru": [
        "Kaluga State Pedagogical University",
        "Kaluga State Pedagogical University",
    ],
    ".kamchatgtu.ru": [
        "Kamchatka State Technical University",
        "Kamchatka State Technical University",
    ],
    ".kamgu.ru": [
        "Kamchatka State University Vitus Bering",
        "Kamchatka State University Vitus Bering",
    ],
    ".kansk-tc.ru": [
        "Канский технологический колледж",
        "Kansk college of technology",
    ],
    ".kantiana.ru": [
        "Immanuel Kant State University of Russia",
        "Immanuel Kant State University of Russia",
    ],
    ".cs.karelia.ru": [
        "Petrozavodsk State University, Computer Science department"
    ],
    ".dims.karelia.ru": [
        "Petrozavodsk State University, Department of Information Measurement Systems"
    ],
    ".psu.karelia.ru": ["PetrSU", "Petrozavodsk State University"],
    ".www.karelia.ru": [
        "Petrozavodsk State University",
        "Petrozavodsk State University",
    ],
    ".kaviat.ru": [
        "Kazan Aviation of Technology College",
        "Kazan Aviation of Technology College",
    ],
    ".kazanconservatory.ru": [
        "Kazan State Music Conservatory",
        "Kazan State Music Conservatory",
    ],
    ".kbgtk07.ru": [
        "Кабардино-Балкарский гуманитарно-технический колледж",
        "Государственное бюджетное профессиональное образовательное учреждение  «Кабардино-Балкарский гуманитарно-технический колледж»",
    ],
    ".kbsu.ru": [
        "Kabardino-Balkarian State University",
        "Kabardino-Balkarian State University",
    ],
    ".kcn.ru": [
        "Kazan State University of Medicine",
        "Kazan State University of Medicine",
    ],
    ".kemerovorea.ru": [
        "РОССИЙСКИЙ ЭКОНОМИЧЕСКИЙ УНИВЕРСИТЕТ ИМЕНИ Г.В. ПЛЕХАНОВА КЕМЕРОВСКИЙ ИНСТИТУТ",
        "RUSSIAN ECONOMIC UNIVERSITY NAMED AFTER GV PLEKHANOVA KEMER INSTITUTE",
    ],
    ".kemsu.ru": [
        "Kemerovo State University",
        "Kemerovo State University",
        "Kemerovo State University",
    ],
    ".kgasu.ru": [
        "Казанский Государственный Архитектурно-Строительный Университет",
        "Kazan State University of Architecture and Engineering",
    ],
    ".kgau.ru": [
        "Красноярский государственный аграрный университет",
        "Krasnoyarsk State Agrarian University",
    ],
    ".kgeu.ru": ["Kazan State Power Engineering University"],
    ".kgpu.ru": [
        "Kazan State Pedagogical University",
        "Kazan State Pedagogical University",
    ],
    ".kgsha.ru": [
        "КУРСКАЯ ГОСУДАРСТВЕННАЯ СЕЛЬСКОХОЗЯЙСТВЕННАЯ АКАДЕМИЯ ИМЕНИ И. И. ИВАНОВА",
        "KURSK STATE AGRICULTURAL ACADEMY NAMED AFTER I. I. IVANOV",
    ],
    ".kgsu.ru": [
        "Курганский государственный университет",
        "Kurgan State University",
    ],
    ".khpk.ru": [
        "Khakas State Polytechnic College",
        "Хакасский политехнический колледж",
    ],
    ".khstu.ru": [
        "Khabarovsk State University of Technology",
        "Khabarovsk State University of Technology",
    ],
    ".khsu.ru": ["Khakas State University"],
    ".khtk27.ru": ["Хабаровский технологический колледж"],
    ".festu.khv.ru": [
        "Федеральное государственное бюджетное образовательное учреждение высшего образования «Дальневосточный государственный университет путей сообщения»",
        'Federal State Budget Educational Institution of Higher Education "Far Eastern State Transport University" ',
    ],
    ".kipu-rc.ru": [
        "Крымский инженерно-педагогический университет",
        "Crimean Engineering and Pedagogical University",
    ],
    ".kiu.ru": [
        "Kurgan International University",
        "Kurgan International University",
    ],
    ".klgtu.ru": [
        "Kaliningrad State Technical University",
        "Kaliningrad State Technical University",
    ],
    ".knastu.ru": [
        "Komsomolsk-on-Amur State Technical University",
        "Komsomolsk-on-Amur State Technical University",
    ],
    ".kfti.knc.ru": [
        "Kazan E. K. Zavoisky Physical-Technical Institute of KSC RAS",
        "Kazan E. K. Zavoisky Physical-Technical Institute of KSC RAS",
    ],
    ".komitent.ru": [
        "Автономная некоммерческая организация профессионального образования Челябинский колледж «Комитент»",
        'Autonomous non-profit organization of vocational education Chelyabinsk College "Komient"',
    ],
    ".koziz.ru": [
        "Кафедра общественного здоровья и здравоохранения МГМСУ им. А.И. Евдокимова"
    ],
    ".corp.kp11.ru": [
        "ГАПОУ «Колледж предпринимательства № 11»",
        'SAPEUI "College of Entrepreneurship No. 11"',
    ],
    ".kpfu.ru": ["Kazan Federal University"],
    ".krasgmu.ru": [
        "Красноярский государственный медицинский университет",
        "Krasnoyarsk State Medical University",
    ],
    ".icm.krasn.ru": [
        "ИНСТИТУТ ВЫЧИСЛИТЕЛЬНОГО МОДЕЛИРОВАНИЯ СО РАН",
        "Institute of Computational Modeling SB RAS",
    ],
    ".krstc.ru": ["Красногорский Колледж", "Krasnogorskiy College"],
    ".ksaba.ru": [
        "Kazan State Academy of Architecture and Civil Engineering",
        "Kazan State Academy of Architecture and Civil Engineering",
    ],
    ".ksai.ru": [
        "Федеральное государственное бюджетное образовательное учреждение высшего образования «Кузбасская государственная сельскохозяйственная академия»"
    ],
    ".ksfei.ru": [
        "Kazan State Finance and Economics Institute ",
        "Kazan State Finance and Economics Institute ",
    ],
    ".kspeu.ru": ["Kazan state power engineering university"],
    ".mail.kspu.ru": [
        "Krasnoyarsk state pedagogical university named after V.P. Astafyev",
        "In Russian, short: \t\tКрасноярский государственный педагогический университет имени В.П. Астафьева",
        "In Russian, full official: \tГосударственное образовательное учреждение высшего профессионального образования «Красноярский государственный педагогический университет имени В.П. Астафьева»",
    ],
    ".kspu.ru": [
        "Krasnoyarsk state pedagogical university named after V.P. Astafyev",
        "In Russian, short: \t\tКрасноярский государственный педагогический университет имени В.П. Астафьева",
        "In Russian, full official: \tГосударственное образовательное учреждение высшего профессионального образования «Красноярский государственный педагогический университет имени В.П. Астафьева»",
    ],
    ".kstu.ru": [
        "Казанский национальный исследовательский технологический университет",
        "Kazan National Research Technological University",
    ],
    ".ksu.ru": ["Kazan State University", "Kazan State University"],
    ".kubagro.ru": [
        "Kuban State University of Agriculture",
        "Kuban State University of Agriculture",
    ],
    ".tim.kubannet.ru": [
        "ГКОУ КШИ «Тимашевский казачий кадетский корпус»",
        "GKOU KSHI «Timashevskij kazachij kadetskij korpus»",
    ],
    ".kubsau.ru": [
        "Kuban State Agrarian University",
        "Kuban State Agrarian University",
    ],
    ".kubstu.ru": [
        "Kuban State University of Technology",
        "Kuban State University of Technology",
    ],
    ".kubsu.ru": ["Kuban State University", "Kuban State University"],
    ".kstu.kursk.ru": [
        "Kursk State Technical University",
        "Kursk State Technical University",
    ],
    ".kursk-uni.ru": ["Kursk State University", "Kursk State University"],
    ".kursknet.ru": [
        "Kursk State Medical University",
        "Kursk State Medical University",
    ],
    ".kursksu.ru": ["Kursk State University", "Kursk State University"],
    ".kuzmk.ru": ["Kuzneckiy college", "КУЗНЕЦКИЙ МНОГОПРОФИЛЬНЫЙ КОЛЛЕДЖ"],
    ".kuzstu.ru": ["Kuzbass State Technical University"],
    ".labore.ru": ["МАОУ Гимназия № 56 г. Ижевск", "Izhevsk school №56"],
    ".letovo.ru": ['ОНАО "Школа "Летово"', "Letovo"],
    ".liceum8.ru": ["Liceum 8, Electrostal", "МОУ «Лицей 8», г. Электросталь"],
    ".licey84.ru": [
        "Liceum No. 84 named in honor of Gali Akysh, Nabarezhnye Chelny, Republic of Tatarstan",
        'Набережные Челны "Лицей-интернат №84 имени Гали Акыша" Республики Татарстан. ',
    ],
    ".linguanet.ru": ["Moscow State Linguistic University"],
    ".stu.lipetsk.ru": [
        "Lipeck State Technical University",
        "Lipeck State Technical University",
    ],
    ".lit1533.ru": [
        'Государственное бюджетное общеобразовательное учреждение города Москвы "Школа № 1533 "ЛИТ" ',
        'State Budget General Educational Institution of Moscow "School № 1533" LIT"',
        "Лицей информационных технологий 1533",
        "Lyceum of Information Technologies 1533",
        "Mail domain: lit1533.ru (scolars and teachers has e-mails at this domain)",
        "Web-site (with forward from lit1533.ru): https://www.lit.msu.ru",
        "Web-site at Moscow Department of Education and Science: https://lyc1533.mskobr.ru",
    ],
    ".lit1537.ru": ["Лицей 1537", "Lyceum 1537"],
    ".litsey2.ru": ['МАОУ "Лицей-интернат №2" г. Казани'],
    ".litsey79.ru": ['МБОУ "Лицей-интернат №79"'],
    ".lkpfu.ru": [
        "Лицей имени Н.И. Лобачевского КФУ",
        "Secondary Boarding School “Lyceum named after N. Lobachevsky” of Kazan (Volga region) Federal University",
    ],
    ".lrmk.ru": [
        "Государственное бюджетное профессиональное образовательное учреждение «Лермонтовский региональный многопрофильный колледж»"
    ],
    ".lschool5.ru": [
        'МБОУ "Лянторская СОШ № 5"',
        'MBOU "Lyantorskaya SOSh N 5"',
    ],
    ".madi.ru": [
        "Moscow State Automobile and Road Technical University",
        "Moscow State Automobile and Road Technical University",
    ],
    ".magtu.ru": ["Magnitogorsk State Technical University"],
    ".mai.ru": ["Moscow Aviation Institute"],
    ".marstu.mari.ru": [
        "Marij State Technical University",
        "Marij State Technical University",
    ],
    ".marsu.ru": ["МарГУ", "MarSU"],
    ".s.masi.ru": ["Московский информационно-технологический университет"],
    ".mcag.ru": ["Moscow College of Architecture and Urban Planning"],
    ".mck-ktits.ru": [
        "international competence center Kazan technical school of information technologies and communications",
        'ГАПОУ "Международный Центр Компетенций - Техникум Информационных Технологий и Связи"',
        "МЦК-КТИТС",
    ],
    ".megpk.ru": ['Бюджетное учреждение "Мегионский политехнический колледж"'],
    ".campus.mephi.ru": ['National Research Nuclear University "MEPhI"'],
    ".mephi.ru": ["National Research Nuclear University MEPhi"],
    ".mes.ru": ["Moscow Economic School"],
    ".mesi.ru": [
        "Moscow State University of Economics, Statistics and Informatics",
        "Moscow State University of Economics, Statistics and Informatics",
    ],
    ".mfmgutu.ru": [
        "Московский Государственный Университет Технологий и Управления имени К.Г. Разумовского (Первый казачий университет) Башкирский институт технологий и управления (филиал)"
    ],
    ".mfua.ru": ["Moscow Financial and Law University (MFUA)"],
    ".mgavm.ru": [
        "Skrjabin Moscow State Academy of Veterinary Medicine and Biotechnology",
        "Skrjabin Moscow State Academy of Veterinary Medicine and Biotechnology",
    ],
    ".mgimo.ru": [
        "Moscow State Institute of International Relations MFA Russia (MGIMO-University)",
        "Moscow State Institute of International Relations MFA Russia (MGIMO-University)",
    ],
    ".mgotu.ru": [
        "Государственное бюджетное образовательное учреждение высшего образования Московской области «Технологический университет» имени дважды Героя Советского Союза, летчика-космонавта А. А. Леонова»",
        'State Budgetary Educational Institution of Higher Education of the Moscow Region "Technological University" named after twice Hero of the Soviet Union, cosmonaut A. A. Leonov"',
        "МГОТУ",
        "MGOTU",
    ],
    ".mgou.ru": [
        "Московский государственный областной университет (МГОУ)",
        "Moscow Region State University (MRSU)",
    ],
    ".mgppu.ru": ["Moscow city university of psychology and pedagogy"],
    ".mgpu.ru": ["Moscow City University"],
    ".mgri.ru": [
        "Российский государственный геологоразведочный университет им. Серго Орджоникидзе",
        "Sergo Ordzhonikidze Russian State University for Geological Prospecting",
    ],
    ".mgsu.ru": ["НИУ МГСУ", "MSU of civil engineering"],
    ".ba.mgubs.ru": ["Moscow State University Business school"],
    ".mgup.ru": ["Moscow State University of Printing Arts"],
    ".mgupp.ru": ["Moscow State University of Food Production"],
    ".mgutm.ru": [
        "«Московский государственный университет технологий и управления имени К.Г. Разумовского (ПКУ)»",
        "МГУТУ им. К.Г. Разумовского (ПКУ)",
        "MGUTU",
        "Moscow State University of Technology and Management named after K.G. Razumovsky (PKU)",
        "Education programm: http://www.mgutm.ru/about/chairs/it.php",
    ],
    ".edu.midis.ru": [
        "МИДиС",
        "INTERNATIONAL INSTITUTE OF DESIGN AND SERVICE",
    ],
    ".miet.ru": ["National Research University of Electronic Technology"],
    ".mihppk.ru": ['ГБПОУ "МППК им.В.В.Арнаутова"'],
    ".miigaik.ru": [
        "Moscow State University of Geodesy and Cartography",
        "Moscow State University of Geodesy and Cartography",
    ],
    ".miit.ru": [
        "Russian University of Transport (MIIT)",
        "Российский университет транспорта (МИИТ)",
    ],
    ".mininuniver.ru": [
        "Нижегородский государственный педагогический университет имени Козьмы Минина",
        "Nizhny Novgorod State Pedagogical University named after Kozma Minin",
    ],
    ".mipt.ru": [
        "Moscow Institute of Physics and Technology",
        "Moscow Institute of Physics and Technology",
    ],
    ".mirbis.ru": [
        "Moscow International Higher Business School (MIRBIS)",
        "Moscow International Higher Business School (MIRBIS)",
    ],
    ".mirea.ru": [
        "Moscow State Institute of Radiotechnics, Electronics and Automation (Technical University)",
        "Moscow State Institute of Radiotechnics, Electronics and Automation (Technical University)",
    ],
    ".mirschool.ru": ['ГАНО "Школа и детский сад "МИР"'],
    ".misis.ru": [
        "Moscow State Institute of Steel and Alloys",
        "Moscow State Institute of Steel and Alloys",
    ],
    ".mitht.ru": [
        "Moscow Technologilac University (ITHT)",
        "Moscow State University of Fine Chemical Technologies",
    ],
    ".mkgtu.ru": ["Maikop State Technological University"],
    ".mma.ru": [
        "I.M. Sechenov Moscow Medical Academy",
        "I.M. Sechenov Moscow Medical Academy",
    ],
    ".mmamos.ru": [
        "Moscow International Academy",
        "Московская Международная Академия",
    ],
    ".edu.mos.ru": [
        "ГБОУ Школа им.Полбина",
        "Hero of the Soviet Union I.S. Polbina",
    ],
    ".mosconsv.ru": [
        "Moscow P. I. Tchaikovsky Conservatory",
        "Moscow P. I. Tchaikovsky Conservatory",
    ],
    ".mosgu.ru": [
        "Московский гуманитарный университет",
        "Moscow University for the Humanities",
    ],
    ".mosmetod.ru": [
        'State budgetary educational institution of the city of Moscow "Digital school"'
    ],
    ".mospolytech.ru": ["Moscow Polytechnic University"],
    ".mpei.ru": ["Moscow Power Engineering Institute"],
    ".mpt.ru": [
        "Moscow Instrument-Making College at the Russian Economic University named after G.V. Plekhanova"
    ],
    ".mrsu.ru": ["Mordovian State University", "Mordovian State University"],
    ".msaab.ru": [
        "Moscow State Academy of Applied Biotechnology",
        "Moscow State Academy of Applied Biotechnology",
    ],
    ".msiu.ru": [
        "Moscow State Industrial University",
        "Moscow State Industrial University",
    ],
    ".1543.msk.ru": ["ГБОУ Школа №1543"],
    ".sch-mr.msk.ru": [
        'Государственное бюджетное общеобразовательное учреждение города Москвы "Школа Марьина Роща имени В.Ф. Орлова"'
    ],
    ".msmsu.ru": [
        "Moscow State University of Medicine and Dentistry",
        "Moscow State University of Medicine and Dentistry named after A.I.Evdokimov",
    ],
    ".mstuca.ru": [
        "Moscow State Technical University of Civil Aviation",
        "Moscow State Technical University of Civil Aviation",
    ],
    ".msu.ru": [
        "Moscow State University",
        "Moscow State University M.V. Lomonosov",
        "Moscow State University",
        "Moscow State University M.V. Lomonosov",
    ],
    ".msuee.ru": [
        "Moscow State University of Environmental Engineering",
        "Moscow State University of Environmental Engineering",
    ],
    ".msuie.ru": [
        "Moscow State University of Ecological Engineering",
        "Moscow State University of Ecological Engineering",
    ],
    ".msun.ru": ["Maritime State University"],
    ".mtuci.ru": [
        "Moscow Technical University of Informatics and Communication",
        "Moscow Technical University of Informatics and Communication",
    ],
    ".mubint.ru": ["Академия МУБиНТ", "Academy MUBiNT"],
    ".muctr.ru": ["Dmitry Mendeleev University"],
    ".muh.ru": [
        "Modern University for the Humanities",
        "Modern University for the Humanities",
    ],
    ".muiv.ru": ["Moscow Witte University"],
    ".mveu.ru": [
        "Международный Восточно-Европейский Университет",
        "Международный Высший Европейский колледж",
        "International Higher European College",
    ],
    ".nadip.ru": [
        "Novosibirsk Academy of Design and Programming",
        "Новосибирская академия дизайна и программирования",
    ],
    ".napks.ru": ["Vernadsky Academy of Constructuion and Architecture"],
    ".narfu.ru": [
        "Northern (Arctic) Federal University",
        "Northern (Arctic) Federal University",
    ],
    ".narhoz-chita.ru": [
        'Chita Institute (branch) SEI HPE "Baikal State University of Economics and Law"'
    ],
    ".ncfu.ru": [
        "Северо-Кавказский Федеральный Университет",
        "North-Caucasus Federal University",
    ],
    ".ncshta.ru": [
        "North-Caucasian State Humanities and Technological Academy"
    ],
    ".ncstu.ru": [
        "Stavropol State Technical University",
        "Stavropol State Technical University",
    ],
    ".nes.ru": ["New Economic School", "New Economic School"],
    ".net-ustu.ru": ["Ural State Technical University"],
    ".neva.ru": [
        "St. Petersburg State Technical University",
        "St. Petersburg State Technical University",
    ],
    ".nfbgu.ru": [
        "Башкирский государственный университет, Нефтекамский филиал",
        "Bashkir state university, Neftekamsk filial",
    ],
    ".nggpc.ru": [
        'Краевое государственное бюджетное профессиональное образовательное учреждение "Находкинский Государственный Гуманитарно-Политехнический Колледж".',
        "Kraevoe gosudarstvennoe byudzhetnoe professional'noe obrazovatel'noe uchrezhdenie \"Nahodkinskij Gosudarstvennyj Gumanitarno-Politekhnicheskij Kolledzh\"",
    ],
    ".ngiei.ru": [
        "Нижегородский государственный инженерно-экономический университет",
        "Nizhny Novgorod State Engineering and Economic University",
    ],
    ".ngknn.ru": [
        "Нижегородский Губернский колледж",
        "Nizhny Novgorod Gubernskiy College",
    ],
    ".nieup.ru": ["Невинномысский институт экономики, управления и права"],
    ".nirhtu.ru": [
        'Новомосковский институт (филиал) федерального государственного бюджетного образовательного учреждения высшего образования "Российский химико-технологический университет имени Д.И. Менделеева"',
        'Novomoskovsk Institute (branch) of the Federal state budgetary educational institution of higher education "Dmitry Mendeleev University of Chemical Technology of Russia"',
    ],
    ".niuitmo.ru": [
        "St. Petersburg State University of Information Technologies, Mechanics and Optics",
        "St. Petersburg State University of Information Technologies, Mechanics and Optics",
    ],
    ".nke.ru": [
        "Новосибирский колледж электроники и вычислительной техники",
        "Novosibirsk College of Electronics and Computer Engineering",
    ],
    ".nngasu.ru": [
        "Nizhniy Novgorod State University of Architecture and Civil Engineering"
    ],
    ".nntc.nnov.ru": ["Radio Engineering College Nizhny Novgorod"],
    ".uic.nnov.ru": ["Lobachevsky State University of Nizhni Novgorod"],
    ".nntu.ru": [
        "Nizhny Novgorod State Technical University named after R.E. Alekseev"
    ],
    ".norna.ru": [
        "Moscow State University of Civil Engineering",
        "Moscow State University of Civil Engineering",
    ],
    ".norvuz.ru": ["Norilsk State Industrial Institute"],
    ".nosu.ru": [
        "North Ossetian State University",
        "North Ossetian State University",
    ],
    ".novsu.ru": ["Novgorod State University of Yaroslav the Wise"],
    ".npi-tu.ru": [
        "Южно-Российский государственный политехнический университет (НПИ) имени М.И. Платова",
        "Platov South-Russian State Polytechnic University (NPI)",
    ],
    ".nsc.ru": [
        "Novosibirsk State Medical Academy",
        "Novosibirsk State Medical Academy",
    ],
    ".nsmu.ru": [
        "Northern State Medical University",
        "Northern State Medical University",
    ],
    ".nspu.ru": [
        "Новосибирский государственный педагогический университет",
        "Novosibirsk State Pedagogical University",
    ],
    ".stud.nstu.ru": [
        "NSTU - Novosibirsk State Technical University",
        "username@stud.nstu.ru",
        "http://www.nstu.ru/",
    ],
    ".nstu.ru": [
        "Novosibirsk State Technical University",
        "Novosibirsk State Technical University",
    ],
    ".g.nsu.ru": [
        "Novosibirsk State University",
        "Новосибирский государственный университет",
    ],
    ".nsu.ru": [
        "Novosibirsk State University",
        "Novosibirsk State University",
    ],
    ".nsuem.ru": [
        "  Novosibirsk State University of Economics and Management"
    ],
    ".nvsu.ru": [
        "Нижневартовский государственный университет",
        "NIZHNEVARTOVSK STATE UNIVERSITY (NVSU)",
    ],
    ".nwpi.ru": [
        "North-West State Technical University",
        "North-West State Technical University",
    ],
    ".oat.ru": [
        "Омский авиационный колледж имени Н.Е.Жуковского",
        "Omsk aviation College named after N. E.Zhukovsky",
    ],
    ".obninsk.ru": [
        "Obninsk State Technical University for Nuclear Power Engineering",
        "Obninsk State Technical University for Nuclear Power Engineering",
    ],
    ".og-ti.ru": ["Orsk humanitarian-technological Institute (branch) OSU"],
    ".oiate.ru": [
        "Obninsk Institute for Nuclear Power Engineering",
        "IATE MEPHI",
        "Обнинский институт атомной энергетики (ИАТЭ)",
        "ИАТЭ НИЯУ МИФИ",
    ],
    ".oksei.ru": [
        'ГАПОУ "Оренбургский колледж экономики и информатики"',
        "Orenburg College of Economics and Informatics",
    ],
    ".oktb.ru": [
        "\ufeff«Образовательный комплекс «Точка будущего»",
        'Educational complex "Point of future"',
    ],
    ".omgau.ru": [
        "Omsk State Agrarian University",
        "Omsk State Agrarian University",
    ],
    ".omgpu.ru": ["Omsk State Pedagogical Universtity"],
    ".omgtu.ru": [
        "Omsk State Technical University",
        "Omsk State Technical University",
    ],
    ".omgups.ru": [
        "Omsk State Transport University",
        "Omsk State Transport University",
    ],
    ".omsk-osma.ru": [
        "Omsk State Medicical Academy",
        "Omsk State Medicical Academy",
    ],
    ".omsu.ru": ["Omsk State University", "Omsk State University"],
    ".oreluniver.ru": ["Orel State University"],
    ".orun.ru": ["Oriental University", "Oriental University"],
    ".ostu.ru": ["Orel State Technical University"],
    ".osu.ru": ["Orenburg State University", "Orenburg State University"],
    ".pbrea.ru": ["Филиал РЭУ им. Г.В. Плеханова в г. Пятигорске"],
    ".penzgtu.ru": [
        'ФГБОУ ВО "Пензенский государственный технологический университет"',
        "Penza State Technological University",
    ],
    ".prk.perm.ru": ["Пермский Радиотехнический Колледж им. А. С. Попова"],
    ".permaviat.ru": [
        "КГАПОУ «Пермский авиационный техникум им. А.Д. Швецова»"
    ],
    ".petrocollege.ru": ["Петровский колледж", "Petrovsky college"],
    ".petrsu.ru": ["Petrozavodsk State University"],
    ".pfncfu.ru": ["Institute of service, tourism and design in Pyatigorsk"],
    ".pfur.ru": [" People Friendship University of Russia"],
    ".pgk63.ru": [
        "Государственное бюджетное образовательное учреждение среднего профессионального образования «Поволжский государственный колледж»",
        "Povolge state college",
    ],
    ".pglu.ru": [
        "Pjatigorsk State Linguistic University",
        "Pjatigorsk State Linguistic University",
    ],
    ".pgups.ru": ["ST. PETERSBURG STATE TRANSPORT UNIVERSITY"],
    ".phtt.ru": [
        "ГБПОУ «Пермский химико-технологический техникум»",
        'GBPOU "Permskij himiko-tehnologicheskij tehnikum"',
    ],
    ".pktm.ru": ["Povolzhsky College of Technologies and Management Balakovo"],
    ".pl36angarsk.ru": [
        "Angarsk College of Advertising and Industrial Technology"
    ],
    ".pml30.ru": [
        "\ufeffPhysics and Mathematics Lyceum No. 30, St. Petersburg"
    ],
    ".pnzgu.ru": ["Penza State University"],
    ".pomorsu.ru": [
        "Pomorsk State University",
        "Pomor State University",
        "Pomorsk State University",
        "Pomor State University",
    ],
    ".live.preco.ru": ["Уральский региональный колледж"],
    ".prgusa.ru": ["Sholem Aleichem Amur State University"],
    ".pro-college.ru": [
        "kolledzh prava ekonomiki i upravleniya",
        "College of Economics and Management Law",
    ],
    ".protonmos.ru": [
        '\ufeffГосударственное бюджетное общеобразовательное учреждение города Москвы "Образовательный центр "Протон"'
    ],
    ".psati.ru": [
        "Povolzhsky State University of Telecommunications and Informatics"
    ],
    ".psfa.ru": [
        "Perm State Pharmaceutical Academy",
        "Perm State Pharmaceutical Academy",
    ],
    ".pskgu.ru": ["Pskov state university"],
    ".psma.ru": ["Perm State Medical Academy", "Perm State Medical Academy"],
    ".psoh46.ru": ["V.P. Astafiev's Podtesovo School"],
    ".pspu.ru": ["Perm State Humanitarian-Pedagogical University"],
    ".pstu.ru": ["Perm National Research Polytechnic University"],
    ".psu.ru": ["Perm State University", "Perm State University"],
    ".psuti.ru": [
        "Povolzhsky State University of Telecommunications and Informatics"
    ],
    ".kspu.ptz.ru": [
        "Karelian State Pedagogical University",
        "Karelian State Pedagogical University",
    ],
    ".pu.ru": ["Saint Petersburg State University"],
    ".pushgu.ru": [
        "Пущинский государственный естественно-научный институт",
        "Pushchino State Institute of Natural Science",
    ],
    ".rah.ru": ["Russian Academy of Arts", "Russian Academy of Arts"],
    ".chph.ras.ru": [
        "ФИЦ химической физики им. Н.Н. Семенова Российской академии наук (ФИЦ ХФ РАН)",
        "N. N. Semenov Institute of Chemical Physics, Russian Academy of Science",
    ],
    ".rbiu.ru": [
        "Международный Институт Дизайна и Сервиса",
        "International Institute of Design & Service",
    ],
    ".rea.ru": [
        "Plekhanov Russian Academy of Economics",
        "Plekhanov Russian Academy of Economics",
    ],
    ".rfet.ru": [
        "Профессиональная образовательная организация ассоциация «Региональный финансово-экономический техникум»",
        "РФЭТ",
    ],
    ".rgau-msha.ru": [
        "Федеральное государственное бюджетное образовательное учреждение высшего образования «Российский государственный аграрный университет – МСХА имени К.А.Тимирязева» ФГБОУ ВО РГАУ-МСХА имени К.А. Тимирязева",
        "Russian State Agrarian University - Moscow Timiryazev Agricultural Academy",
    ],
    ".rggu.ru": ["Russian State University for the Humanities"],
    ".rgsu.ru": [
        "Rostov State University of Civil Engineering",
        "Ростовский Государственный Строительный Университет",
    ],
    ".rguk.ru": [
        "Kosygin Russian State University, Moscow",
        "Российский Государственный Университет имени А.Н.Косыгина, Москва",
    ],
    ".rgups.ru": [
        'ФГБОУ ВО "Ростовский государственный университет путей сообщения"',
        "Rostov State Transport University",
    ],
    ".it.rksi.ru": [
        "Государственное бюджетное профессиональное образовательное учреждение Ростовской области «Ростовский-на-Дону колледж связи и информатики» (ГБПОУ РО «РКСИ»)",
        'State Budgetary Professional Educational Institution "Rostov-on-Don College of Communication and Informatics»',
    ],
    ".stud.rksi.ru": [
        "Государственное бюджетное профессиональное образовательное учреждение Ростовской области «Ростовский-на-Дону колледж связи и информатики» (ГБПОУ РО «РКСИ»)",
        'State Budgetary Professional Educational Institution "Rostov-on-Don College of Communication and Informatics»',
    ],
    ".rosnou.ru": ["Russian New University (RosNOU)"],
    ".rsatu.ru": [
        "Рыбинский государственный авиационный технический университет имени П. А. Соловьева",
        "Rybinsky State Aviation Technical University named after P. A. Soloviev",
    ],
    ".rshu.ru": [
        "Russian State Hydrometeorological University",
        "Russian State Hydrometeorological University",
    ],
    ".rsmu.ru": [
        "Russian State Medical University",
        "Russian State Medical University",
    ],
    ".rsreu.ru": ["Ryazan State Radio Engineering University"],
    ".rsu.ru": ["Rostov State University", "Rostov State University"],
    ".rsue.ru": ["Rostov State University of Economics"],
    ".rsuh.ru": [
        "Russian State University for the Humanities",
        "Russian State University for the Humanities",
    ],
    ".rsvpu.ru": ["Russian State Vocational Pedagogical University"],
    ".rubinst.ru": [
        "Рубцовский индустриальный институт (филиал) Алтайского государственного технического университета им. Ползунова",
        "RII AltSTU",
    ],
    ".rucoop.ru": [
        "Russian University of Cooperation",
        "Автономная некоммерческая образовательная организация высшего образования Центросоюза Российской Федерации «Российский университет кооперации»",
    ],
    ".rudn.ru": ["Университет Дружбы Народов", "RUDN University"],
    ".runnet.ru": [
        "Krasnoyarsk State Technical University",
        "Saratov State Socio-Economic University",
        "Krasnoyarsk State Technical University",
        "Saratov State Socio-Economic University",
    ],
    ".edu.rut-miit.ru": [
        "Российский университет транспорта РУТ (МИИТ)",
        "Federal State Institution of Education «Russian University of Transport»",
    ],
    ".s-vfu.ru": [
        "North-Eastern Federal University",
        "North-Eastern Federal University",
    ],
    ".s1411.ru": ["School 1411", "Школа 1411"],
    ".s146.ru": ["МАОУ СОШ №146 с УИМФИ г.Перми"],
    ".sakhgu.ru": [
        "Сахалинский государственный университет",
        "Sakhalin State University",
    ],
    ".samgk.ru": ["Самарский государственный колледж", "Samara state college"],
    ".samgtu.ru": ["Samara State Technical University"],
    ".samgups.ru": [
        "\ufeffСамарский государственный университет путей сообщения",
        "Samara State University of Railway Engineering",
    ],
    ".samiit.ru": [
        "Samara State Academy for Railway Transportation",
        "Samara State Academy for Railway Transportation",
    ],
    ".samsmu.ru": [
        "Samara State Medical University",
        "Samara State Medical University",
    ],
    ".sano.ru": [
        "Siberian Institute of Business and Information Technologies"
    ],
    ".sao.ru": [
        "Специальная астрофизическая обсерватория Российской академии наук",
        "The Special Astrophysical Observatory of the Russian Academy of Sciences",
    ],
    ".sapanet.ru": [
        "Siberian Academy of Public Services",
        "Siberian Academy of Public Services",
    ],
    ".scamt-itmo.ru": [
        "SCAMT Institute of ITMO University, Saint-Petersburg",
        "https://scamt.ifmo.ru/",
    ],
    ".sch-int.ru": ['ГБОУ Школа "Интеллектуал"'],
    ".sch12.ru": ["School 12 of Petrozavodsk, Russia"],
    ".sch1550.ru": ["школа 1550 города Москвы it"],
    ".students.sch2.ru": ["Лицей Вторая Школа", "Lyceum Second School"],
    ".sch2.ru": [
        "Государственное бюджетное общеобразовательное учреждение города Москвы «Лицей «Вторая школа» имени В.Ф. Овчинникова»",
        "Lyceum Second School",
        'Лицей "Вторая школа"',
    ],
    ".sch290.ru": ["ГБОУ СОШ №290 Красносельского района Санкт-Петербурга"],
    ".sch508.ru": ["School 508, Moscow, Russia"],
    ".sch57.ru": [
        '\ufeffГосударственное бюджетное общеобразовательное учреждение города Москвы "Пятьдесят седьмая школа"',
        "School 57, Moscow, Russia",
    ],
    ".schelcol.ru": ["Schelkovsky college"],
    ".schmos444.ru": ["ГБОУ Школа №444", "School #444"],
    ".school1015.ru": [
        "ГБОУ г.Москвы Школа 1015",
        "Moscow State Budgetary Educational Institution School 1015",
    ],
    ".school548.ru": ["ГАОУ Школа №548", "Moscow School 548"],
    ".school603-spb.ru": [
        "ГБОУ г.Санкт-Петербурга Школа 603",
        "Saint-Petersburg State Budgetary Educational Institution School 603",
    ],
    ".school97.ru": ["Школа Гармония", "School Harmony"],
    ".schoolmail.ru": [
        "Школьный Портал Московской области",
        "School Portal of the Moscow Region",
    ],
    ".sci-nnov.ru": [
        "Linguistic University of Nizhny Novgorod",
        "Nizhny Novgorod State Architectural - Building University",
        "Nizhny Novgorod State Technical University",
        "Volga State Academy of Water Transport",
        "Linguistic University of Nizhny Novgorod",
        "Nizhny Novgorod State Architectural - Building University",
        "Nizhny Novgorod State Technical University",
        "Volga State Academy of Water Transport",
    ],
    ".elearn.sde.ru": ["Moscow State Industrial University"],
    ".sechenov.ru": [
        "ФГАОУ ВО Первый МГМУ им. И.М. Сеченова Минздрава России (Сеченовский Университет)",
        "Federal State Autonomous Educational Institution of Higher Education I.M. Sechenov First Moscow State Medical University of the Ministry of Health of the Russian Federation (Sechenov University)",
    ],
    ".secna.ru": [
        "Altai State Technical University",
        "Altai State Technical University",
    ],
    ".seschool.ru": [
        'ЧОУ ДПО "Школа программной инженерии"',
        "Software Engineering School",
    ],
    ".sever.ru": [
        "Ukhta State Technical University",
        "Ukhta State Technical University",
    ],
    ".sevsu.ru": ["Sevastopol State University"],
    ".sfedu.ru": ["Southern Federal University"],
    ".sfek.ru": [
        "RSBE Semey financial-economic college named after Rymbek Baiseitov"
    ],
    ".sfu-kras.ru": ["Siberian Federal University"],
    ".sgap.ru": [
        "Saratov State Academy of Law",
        "Saratov State Academy of Law",
    ],
    ".sgau.ru": [
        "Федеральное государственное бюджетное образовательное учреждение высшего образования «Саратовский государственный университет генетики, биотехнологии и инженерии имени Н.И. Вавилова»"
    ],
    ".sgspu.ru": [
        "Самарский государственный социально-педагогический университет",
        "Samara State Social and Pedagogical University",
    ],
    ".sgu.ru": [
        "Saratov State Medical University",
        "Saratov State University",
        "Saratov State Medical University",
        "Saratov State University",
    ],
    ".sgugit.ru": [
        "Сибирский государственный университет геосистем и технологий",
        "Siberian state university of geosystems and technologies",
    ],
    ".stud.sibguti.ru": [
        "Siberian State University of Telecommunications and Information Sciences"
    ],
    ".sibguti.ru": [
        "Siberian State University of Telecommunications and Information Sciences"
    ],
    ".sibsau.ru": ["Siberian State Aerospace University"],
    ".sibsiu.ru": [
        "Сибирский государственный индустриальный университет",
        "Siberian State Industrial University",
    ],
    ".edu.sibstrin.ru": [
        "NOVOSIBIRSK STATE UNIVERSITY OF ARCHITECTURE AND CIVIL ENGINEERING(SIBSTRIN) "
    ],
    ".sibstrin.ru": [
        "Novosibirsk State University Of Architecture And Civil Engineering (Sibstrin)"
    ],
    ".sibsutis.ru": [
        "Siberian State University of Telecommunications and Information Sciences"
    ],
    ".sielom.ru": ["Сургутский институт экономики, управления и права"],
    ".learn.siriusuniversity.ru": ["университет Сириус", "Sirius university"],
    ".skf-mtusi.ru": [
        "Северо-Кавказский филиал ордена Трудового Красного Знамени федерального государственного бюджетного образовательного учреждения высшего образования «Московский технический университет связи и информатики»",
        "North Caucasus branch of Moscow Technical University of Communications and Informatics",
    ],
    ".skolkovotech.ru": ["Skolkovo Institute of Science and Technology"],
    ".skoltech.ru": ["Skolkovo Institute of Science and Technology"],
    ".smolapo.ru": [
        "ОГБПОУ СмолАПО",
        "OGBPOU Smolensk academy of professional education",
    ],
    ".smolgu.ru": ["Smolensk State University"],
    ".smr.ru": [
        "Samara State Academy of Architecture and Civil Engineering",
        "Samara State Academy of Architecture and Civil Engineering",
    ],
    ".smtu.ru": [
        "St. Petersburg State Marine Technical University",
        "St. Petersburg State Marine Technical University",
    ],
    ".smuit.ru": [
        "Самарский государственный медицинский университет (СамГМУ)",
        "Samara State Medical University",
    ],
    ".sortavala-school1.ru": [
        "Муниципальное казенное общеобразовательное учреждение Сортавальского муниципального района Республики Карелия Средняя общеобразовательная школа №1",
        "MKOU Sortavalskogo MR Respubliki Kareliya SOSH No1",
    ],
    ".gym.271.spb.ru": [
        "Государственное бюджетное общеобразовательное учреждение Гимназия № 271 имени П. И. Федулова",
        "State budgetary educational institution Gymnasium No. 271 named after P. I. Fedulov",
    ],
    ".edu-frn.spb.ru": [
        "Государственное бюджетное общеобразовательное учреждение средняя общеобразовательная школа №368 с углубленным изучением английского языка Фрунзенского района Санкт-Петербурга"
    ],
    ".eu.spb.ru": [
        "European University at St.Petersburg",
        "European University at St.Petersburg",
    ],
    ".gti.spb.ru": [
        "St. Petersburg State Institute of Technology (Technological University)",
        "St. Petersburg State Institute of Technology (Technological University)",
    ],
    ".gturp.spb.ru": [
        "St. Petersburg State Technological University of Plant Polymers",
        "St. Petersburg State Technological University of Plant Polymers",
    ],
    ".herzen.spb.ru": [
        "Российский государственный педагогический университет им. А. И. Герцена",
        "The Herzen State Pedagogical University of Russia",
    ],
    ".ibi.spb.ru": [
        "International Banking Institute, St. Petersburg",
        "International Banking Institute, St. Petersburg",
    ],
    ".nilc.spb.ru": [
        "Nevsky Institute of Language and Culture",
        "Nevsky Institute of Language and Culture",
    ],
    ".school.spb.ru": [
        'ГБОУ Гимназия №642 "Земля и Вселенная"',
        "Gymnasium №642",
        "https://www.school.spb.ru",
        "http://theschool.spb.ru",
    ],
    ".school644.spb.ru": [
        "State Free Educational Institution School No. 644, Primorsky District Of Saint-Petersburg",
        "GBOU School No. 644, Primorsky District Of Saint-Petersburg",
    ],
    ".smolny-un.spb.ru": ["Smolny University", "Smolny University"],
    ".spbgau.spb.ru": [
        "St. Petersburg State Agrarian University",
        "St. Petersburg State Agrarian University",
    ],
    ".tart.spb.ru": [
        "St. Petersburg State Theatre Arts Academy",
        "St. Petersburg State Theatre Arts Academy",
    ],
    ".spb-rtk.ru": [
        "Санкт-Петербургское государственное бюджетное профессиональное образовательное учреждение `Радиотехнический колледж`"
    ],
    ".spbau.ru": ["SPB Academic University"],
    ".spbftu.ru": [
        "Санкт-Петербургский государственный лесотехнический университет имени С.М.Кирова",
        "Saint-Petersburg forest technical university",
    ],
    ".spbgasu.ru": [
        "St. Petersburg State University of Architecture and Civil Engineering",
        "St. Petersburg State University of Architecture and Civil Engineering",
    ],
    ".spbguki.ru": [
        "St. Petersburg State University of Culture and Arts",
        "St. Petersburg State University of Culture and Arts",
    ],
    ".spbgut.ru": [
        "The Bonch-Bruevich Saint - Petersburg State University of Telecommunications"
    ],
    ".spbstu.ru": [
        "St. Petersburg State Polytechnical University",
        "St. Petersburg State Polytechnical University",
    ],
    ".spbu.ru": [
        "St. Petersburg State University",
        "St. Petersburg State University",
    ],
    ".spbuwc.ru": [
        "St. Petersburg State University of Waterway Communications",
        "St. Petersburg State University of Waterway Communications",
    ],
    ".spcpa.ru": [
        "St. Petersburg State Chemical Pharmaceutical Academy",
        "St. Petersburg State Chemical Pharmaceutical Academy",
    ],
    ".spcras.ru": [
        "Санкт-Петербургский Федеральный исследовательский центр Российской академии наук",
        "St. Petersburg Federal Research Center of the Russian Academy of Sciences",
    ],
    ".sphti.ru": [
        "Снежинский физико-технический институт НИЯУ МИФИ (СФТИ НИЯУ МИФИ)"
    ],
    ".spmi.ru": ["National Mineral Resources University"],
    ".spo-ket.ru": [
        "Kostroma Energy College named after F.V. Chizhov",
        'We offer a three-year and four-year course with the title "Information systems and programming"',
        "our website:",
        "http://www.spo-ket.ru/",
    ],
    ".spobip-bel.ru": [
        "ЧАСТНОЕ УЧРЕЖДЕНИЕ ПРОФЕССИОНАЛЬНАЯ ОБРАЗОВАТЕЛЬНАЯ ОРГАНИЗАЦИЯ ТЕХНИКУМ “БИЗНЕС И ПРАВО”"
    ],
    ".spsu.ru": ["ПГУ им. Т.Г. Шевченко", "SPSU"],
    ".srshb.ru": ["Siberian regional business school"],
    ".ssaa.ru": [
        "Samara State Agricultural Academy",
        "Samara State Agricultural Academy",
    ],
    ".ssau.ru": [
        "Samara State Aerospace University",
        "Samara State Aerospace University",
    ],
    ".sseu.ru": [
        "Samara State University of Economics",
        "Samara State University of Economics",
    ],
    ".ssmu.ru": [
        "Siberian State Medical University",
        "Siberian State Medical University",
    ],
    ".sssu.ru": [
        "Институт сферы обслуживания и предпринимательства (филиала) ДГТУ в г. Шахты"
    ],
    ".sstu.ru": ["Saratov State Technical University"],
    ".ssuedu.ru": ["Syktyvkar State University"],
    ".stankin.ru": [
        "Moscow State University of Technology (Stankin)",
        "Moscow State University of Technology (Stankin)",
    ],
    ".stavsu.ru": ["Stavropol State University", "Stavropol State University"],
    ".stgau.ru": [
        "Stavropol State Agrarian University",
        "Stavropol State Agrarian University",
    ],
    ".strbsu.ru": ["Sterlitamak Branch of Bashkir State University"],
    ".stu.ru": [
        "Siberian State Transport University",
        "Siberian State Transport University",
    ],
    ".studklg.ru": [
        "Tsiolkovsky Kaluga State University",
        "Students email domain of Tsiolkovsky Kaluga State University",
    ],
    ".suai.ru": [
        "St. Petersburg State University of Aerospace Instrumentation",
        "St. Petersburg State University of Aerospace Instrumentation",
    ],
    ".suitd.ru": [
        "СПбГУПТД Высшая Школа Технологии и Энергетики",
        "SPbSUTD Higher School of Technology and Energy",
    ],
    ".surgu.ru": ["Surgut State University"],
    ".surpk.ru": ["Surgut Professional College"],
    ".sursau.ru": ["South Ural State Agrarian University"],
    ".susu.ru": ["South Ural State University"],
    ".sut.ru": [
        "St. Petersburg State University of Telecommunication",
        "St. Petersburg State University of Telecommunication",
    ],
    ".sutd.ru": [
        "St. Petersburg State University of Technology and Design",
        "St. Petersburg State University of Technology and Design",
    ],
    ".sutr.ru": [
        'ФГБОУ ВО "Сочинский государственный университет"',
        "Sochi State University",
    ],
    ".suz-ppk.ru": [
        'Краевое государственное автономное профессиональное образовательное учреждение "Приморский политехнический колледж"'
    ],
    ".edu.swissam.ru": [
        "Swissam Hospitality Business School",
        "Swissam Hospitality Business School",
    ],
    ".syktsu.ru": ["Syktyvkar State University named after Pitirim Sorokin"],
    ".synergy.ru": ["Университет Синергия", "Synergy University"],
    ".synergyedu.ru": [
        'Московский финансово-промышленный университет "Синергия"',
        "Synergy University",
    ],
    ".taom.ru": [
        "ТАУ тольяттинская академия управления ",
        "Togliatti Academy of Management (TAOM)",
    ],
    ".edu.tatar.ru": ["Schools of Tatarstan"],
    ".tatngpi.ru": [
        "The Naberezhnye Chelny Institute of Social and Educational Technologies and Resources"
    ],
    ".technolyceum.ru": [
        'Автономная некомерческая общеобразовательная организация "Областной технолицей им. В.И. Долгих"',
        "Vladimir Ivanovich Dolgikh Technolyceum",
    ],
    ".tfrggu.ru": [
        "Branch of Russian State University of Humanity in Togliatty"
    ],
    ".tgmu.ru": ["Pacific State Medical University"],
    ".theatrins-yar.ru": [
        "Yaroslavl State Theatre Institute",
        "Yaroslavl State Theatre Institute",
    ],
    ".tim-stud.ru": [
        "Российский государственный аграрный университет - МСХА им. К.А. Тимирязева",
        "Russian State Agrarian University - Moscow Timiryazev Agricultural Academy",
    ],
    ".timacad.ru": [
        "Timirjazev Moscow Academy of Agricultutre",
        "Timirjazev Moscow Academy of Agricultutre",
    ],
    ".tksu.ru": [
        "Tsiolkovsky Kaluga State University",
        "Tsiolkovsky Kaluga State University",
    ],
    ".tltsu.ru": ["Togliatti State University", "Togliatti State University"],
    ".tmn.ru": ["Tyumen State University", "Tyumen State University"],
    ".tolgas.ru": [
        "ПОВОЛЖСКИЙ ГОСУДАРСТВЕННЫЙ УНИВЕРСИТЕТ СЕРВИСА",
        "VOLGA REGION STATE UNIVERSITY OF SERVICE",
    ],
    ".tomintech.ru": [
        "Tomsk Industrial Technical School",
        "TomInTech",
        "Томский Индустриальный Техникум",
    ],
    ".school28.tomsk.ru": [
        "Municipal Autonomous Educational Institution Secondary School No. 28 of Tomsk",
        "https://school28.tomsk.ru/",
        "МАОУ СОШ №28 (Муниципальное Автономное Общеобразовательное Учреждение Средняя Общеобразовательная Школа № 28 г. Томска)",
    ],
    ".tib.tomsk.ru": [
        "Tomsk Institute of Business",
        "Томский институт бизнеса",
    ],
    ".tomtit.tomsk.ru": ["Tomsk College of Information Technologies"],
    ".t.top-academy.ru": ["Компьютерная Академия TOP", "TOP_academy"],
    ".top-academy.ru": [
        "Компьютерная Академия TOP",
        "username@top-academy.ru",
        "https://top-academy.ru/",
    ],
    ".touro.ru": ["Moscow University Touro", "Moscow University Touro"],
    ".tpu.ru": [
        "Tomsk Polytechnic University",
        "Tomsk Polytechnic University",
    ],
    ".tsma.ru": ["Tver State Medical Academy", "Tver State Medical Academy"],
    ".tsogu.ru": [
        "Tyumen State University of Gas and Oil",
        "Tyumen State University of Gas and Oil",
    ],
    ".tstu.ru": [
        "Tambov State Technical University",
        "Tambov State Technical University",
    ],
    ".tsu.ru": ["Tomsk State University", "Tomsk State University"],
    ".tsuab.ru": [
        "Tomsk State University of Architecture and Building",
        "Tomsk State University of Architecture and Building",
    ],
    ".tsure.ru": [
        "Taganrog State University of Radioengineering",
        "Taganrog State University of Radioengineering",
    ],
    ".tsutmb.ru": [
        "Тамбовский государственный университет имени Г.Р. Державина",
        "Derzhavin Tambov State University",
    ],
    ".ttn.ru": [
        "Taganrog State Pedagogical Institute",
        "Taganrog State Pedagogical Institute",
    ],
    ".tu-bryansk.ru": [
        "Brjansk State Technical University",
        "Brjansk State Technical University",
    ],
    ".tsu.tula.ru": [
        "Tula State University",
        "Tula State University",
        "Tula State University",
    ],
    ".tulatek.ru": ['ГПОУ ТО "ТЭК"', "ТУЛЬСКИЙ ЭКОНОМИЧЕСКИЙ КОЛЛЕДЖ"],
    ".tuvsu.ru": ["Tuva State University", "Tuva State University"],
    ".tstu.tver.ru": [
        "Tver State Technical University",
        "Tver State Technical University",
    ],
    ".tversu.ru": ["Tver State University", "Tver State University"],
    ".tyuiu.ru": ["Tyumen industrial University"],
    ".uac-icc.ru": [
        'ОБЛАСТНОЕ ГОСУДАРСТВЕННОЕ АВТОНОМНОЕ ПРОФЕССИОНАЛЬНОЕ ОБРАЗОВАТЕЛЬНОЕ УЧРЕЖДЕНИЕ "УЛЬЯНОВСКИЙ АВИАЦИОННЫЙ КОЛЛЕДЖ - МЕЖРЕГИОНАЛЬНЫЙ ЦЕНТР КОМПЕТЕНЦИЙ"',
        'REGIONAL STATE AUTONOMOUS PROFESSIONAL EDUCATIONAL INSTITUTION "ULYANOVSK AVIATION COLLEGE - INTERREGIONAL COMPETENCE CENTER"',
    ],
    ".uapa.ru": [
        "Ural Academy of Public Administration",
        "Ural Academy of Public Administration",
    ],
    ".uni.udm.ru": ["Udmurt State University", "Udmurt State University"],
    ".uef.ru": [
        "St. Petersburg State University of Economics and Finance",
        "St. Petersburg State University of Economics and Finance",
    ],
    ".uemc73.ru": ["Ulyanovsk Electromechanical College"],
    ".ugkp.ru": [
        "Ural State College named by Ivan Polzunov",
        "Уральский государственный колледж имени И. И. Ползунова",
    ],
    ".ugmt.ru": ["ГАПОУ УКГП", "GAPOU Uchalinsky College of Mining"],
    ".ugrafmsh.ru": [
        "Ugra Physics and Mathematics Lyceum",
        "Югорский физико-математический лицей-интернат",
    ],
    ".ugrasu.ru": ["Yugra State University"],
    ".uisi.ru": ["Ural Technical Institute of Communications and Informatics"],
    ".ukrtb.ru": [
        "Государственное бюджетное профессиональное образовательное учреждение Уфимский колледж радиоэлектроники, телекоммуникаций и безопасности",
        " State budgetary professional educational institution Ufa College of Radio Electronics, Telecommunications and Security",
    ],
    ".uksivt.ru": [
        "Уфимский колледж статистики, информатики и вычислительной техники",
        "УКСИВТ",
    ],
    ".ulstu.ru": [
        "Ulyanovsk State Technical University",
        "Ulyanovsk State Technical University",
    ],
    ".ulsu.ru": ["Ulyanovsk State University", "Ulyanovsk State University"],
    ".unecon.ru": [
        "SAINT-PETERSBURG STATE UNIVERSITY OF ECONOMICS",
        "SAINT-PETERSBURG STATE UNIVERSITY OF ECONOMICS",
    ],
    ".uni-dubna.ru": [
        "Dubna International University for Nature, Society and Man",
        "Dubna International University for Nature, Society and Man",
    ],
    ".unitech-mo.ru": ["Moscow region University of Technology"],
    ".universitas.ru": [
        "Moscow School of Social and Economic sciences",
        "Moscow School of Social and Economic sciences",
    ],
    ".unn.ru": ["LOBACHEVSKY STATE UNIVERSITY OF NIZHNI NOVGOROD (UNN)"],
    ".imm.uran.ru": [
        "Институт математики и механики им. Н.Н.Красовского УрО РАН",
        "N.N. Krasovskii Institute of Mathematics and Mechanics (IMM UB RAS)",
    ],
    ".urfu.ru": ["Ural Federal University"],
    ".urpc.ru": ['ГАПОУ СО "Уральский политехнический колледж - МЦК"'],
    ".ursmu.ru": [
        "Уральский Государственный Горный Университет",
        "The Ural State Mining University",
    ],
    ".urtt.ru": [
        "Уральский Радиотехнический Колледж имени А. С. Попова (УРТК)",
        "Ural Radio Technical College named after A.S. Popov (URTK)",
    ],
    ".usaaa.ru": [
        "Ural State Academy of Architecture and Arts",
        "Ural State Academy of Architecture and Arts",
    ],
    ".usart.ru": [
        "Ural State Academy of Railway Transport",
        "Ural State Academy of Railway Transport",
    ],
    ".usfea.ru": [
        "Ural State Forestry Technical Academy",
        "Ural State Forestry Technical Academy",
    ],
    ".usla.ru": ["Ural State Academy of Law", "Ural State Academy of Law"],
    ".usma.ru": [
        "ФГБОУ ВО УГМУ Минздрава России",
        "Ural State Medical University",
    ],
    ".usmga.ru": [
        "Ural State Academy of Mining and Geology",
        "Ural State Academy of Mining and Geology",
    ],
    ".usptu.ru": [
        'ФГБОУ ВО "Уфимский государственный нефтяной технический университет"',
        'Federal State Budgetary Educational Institution of Higher Education "Ufa State Petroleum Technological University"',
    ],
    ".uspu.ru": [
        "Уральский государственный педагогический университет",
        "Ural State Pedagogical University",
    ],
    ".ustu.ru": [
        "Ural State Technical University",
        "Ural State Technical University",
    ],
    ".usu.ru": [
        "Ural Gorkij State University",
        "Ural Gorkij State University",
    ],
    ".usue.ru": [
        "Ural State University of Economics",
        "Ural State University of Economics",
    ],
    ".student.usurt.ru": [
        "Уральский государственный Университет Путей Сообщения",
        "Ural State University of Railway Transport",
    ],
    ".usurt.ru": [
        "ФГБОУ ВО Уральский государственный университет путей сообщения",
        "Ural State University of Railway Transport",
    ],
    ".ut-mo.ru": ["Moscow region University of Technology"],
    ".utmn.ru": ["Tyumen State University"],
    ".uvauga.ru": [
        "Ulyanovsk Higher School of Civil Aviation",
        "Ulyanovsk Higher School of Civil Aviation",
    ],
    ".uven.ru": ["Ulyanovsk State University", "Ulyanovsk State University"],
    ".vavilovsar.ru": [
        "Федеральное государственное бюджетное образовательное учреждение высшего образования «Саратовский государственный университет генетики, биотехнологии и инженерии имени Н.И. Вавилова»"
    ],
    ".vavt.ru": ["ВАВТ Минэкономразвития РФ", "RFTA"],
    ".vemst.ru": [
        "Кировское  областное государственное профессиональное образовательное автономное учреждение  «Вятский электромашиностроительный техникум» ",
        'Kirov Regional State Vocational Educational Autonomous Institution "Vyatka Electric Engineering College"',
    ],
    ".vgafk.ru": [
        "Volgograd State Academy of Physical Education",
        "Volgograd State Academy of Physical Education",
    ],
    ".vgapkro.ru": [
        "Волгоградская государственная академия последипломного образования",
        "Volgograd state Academy Postgraduate Education",
    ],
    ".vgasa.ru": [
        "Volgograd State University of Architecture and Civil Engineering (VolgGASU)",
        "Volgograd State University of Architecture and Civil Engineering (VolgGASU)",
    ],
    ".vgppk.ru": ["Voronezh State Vocational and Pedagogical College"],
    ".vieup.ru": [
        "NGO Vladikavkaz Institute of Economics, Management, and Law",
        "NGO Vladikavkaz Institute of Economics, Management, and Law",
    ],
    ".vimvd.ru": [
        "Voronezh Institute of the Ministry of the Interior of Russia"
    ],
    ".viti-mephi.ru": [
        'Volgodonsk engineering technical Institute, branch of National Research Nuclear University "MEPhI"'
    ],
    ".vivt.ru": ["Voronezh Institute of High Technologies"],
    ".vke-edu.ru": [
        "ГБПОУ Владикавказский Колледж Электроники",
        "GBPOU Vladikavkaz College of Electronics",
    ],
    ".vlsu.ru": ["Vladimir State University", "Vladimir State University"],
    ".voenmeh.ru": ['Baltic State Technical University "Voenmeh"'],
    ".vogu35.ru": [
        "Вологодский государственный университет",
        "Vologda State University",
    ],
    ".volgmed.ru": ["Volgograd State Medical University"],
    ".volpi.ru": [
        "Volzhsky Polytechnic Institute",
        "Volzhsky Polytechnic Institute",
    ],
    ".volsu.ru": ["Volgograd State University", "Volgograd State University"],
    ".vgasu.vrn.ru": [
        "Voronezh State University of Architecture and Civil Engineering"
    ],
    ".vsau.ru": [
        "Voronezh State Agricultural University",
        "Voronezh State Agricultural University",
    ],
    ".vsiem.ru": [
        'НПОУ "Якутский колледж инновационных технологий"',
        'Non-state professional educational institution "Yakutsk College of Innovative Technologies"',
    ],
    ".vspu.ru": [
        "Volgograd State Pedagogical University",
        "Volgograd State Pedagogical University",
    ],
    ".vstu.ru": [
        "Volgograd State Technical University",
        "Volgograd State Technical University",
    ],
    ".vsu.ru": ["Voronezh State University", "Voronezh State University"],
    ".vtk-portal.ru": [
        "Volgograd College of Technology",
        "Волгоградский технологический колледж",
    ],
    ".vvsu.ru": [
        "Vladivostock State University of Economics",
        "Vladivostock State University of Economics",
    ],
    ".vyatsu.ru": ["Vyatka State University"],
    ".wsnet.ru": ["Surgut State University", "Surgut State University"],
    ".yakit.ru": [
        'НПОУ "Якутский колледж инновационных технологий"',
        'Non-state professional educational institution "Yakutsk College of Innovative Technologies"',
    ],
    ".do.yanao.ru": [
        "Государственное бюджетное профессиональное образовательное учреждение Ямало-Ненецкого автономного округа «Ямальский многопрофильный колледж»",
        'State Budgetary Professional Educational Institution of Yamalo-Nenets Autonomous Okrug "Yamal Multidisciplinary College"',
    ],
    ".yandexlyceum.ru": ["Yandex Lyceum", "Yandex Lyceum"],
    ".yar.ru": [
        "Yaroslavl International University of Business and New Technologies",
        "Yaroslavl State Pedagogical University",
        "Yaroslavl State Technical University",
        "Yaroslavl International University of Business and New Technologies",
        "Yaroslavl State Pedagogical University",
        "Yaroslavl State Technical University",
    ],
    ".yola15.ru": ["School 15 of Yoshkar-Ola, Russia"],
    ".ypat-salekhard.ru": [
        'ГБПОУ ЯНАО "Ямальский Полярный Агроэкономический Техникум"',
        "Yamal polar agro-economic College",
    ],
    ".ypec.ru": [
        "Ярославский промышленноэкономический колледж. ЯПЭК",
        "Yaroslavl Industrial and Economic College. YPEC",
    ],
    ".ikfia.ysn.ru": [
        "Институт космофизических исследований и аэрономии им. Ю.Г. Шафера Сибирского отделения Российской академии наук",
        "Yu.G. Shafer Institute of Cosmophysical Research and Aeronomy",
    ],
    ".ystu.ru": [
        "Yaroslavl State Technical University",
        "Yaroslavl State Technical University",
    ],
    ".ysu.ru": ["Yakutsk State University", "Yakutsk State University"],
    ".zabgc.ru": [
        "Забайкальский горный колледж им. М.И. Агошкова",
        "Zabaykalsky mining College named after M. I. Agoshkov",
    ],
    ".zabgu.ru": [
        "Забайкальский государственный университет",
        "Transbaikal State University",
    ],
    ".zau.ru": ["Zaoksky Christian Humanitarian-Economic Institute"],
    ".zhat.ru": ["ГБПОУ МО «Авиационный техникум имени В.А. Казакова»"],
    ".auca.ac.rw": ["Adventist University of Central Africa"],
    ".nur.ac.rw": ["National University of Rwanda"],
    ".uck.ac.rw": ["Kabgayi Catholic University"],
    ".ulk.ac.rw": ["Kigali Independent University"],
    ".maarif.com.sa": [
        "منارات الرياض الأهلية والعالمية",
        "Manarat Al Riyadh National & International Schools",
    ],
    ".api.alaqsa.edu.sa": ["Alaqsaa Schools"],
    ".alfarabischool.edu.sa": ["Alfarabi International School"],
    ".alkawthar.edu.sa": [
        "مدارس الكوثر العالمية ",
        "AlKawthar International Schools",
    ],
    ".alyamamah.edu.sa": ["Al-Yamamah College"],
    ".amc.edu.sa": ["كليات الريان", "Alrayan Medical Colleges"],
    ".aou.edu.sa": [
        "AOU - Arab Open University",
        "https://www.arabou.edu.sa/students/pages/student-email.aspx",
    ],
    ".as.edu.sa": [
        "Andalus International Schools",
        "Andalus International Schools",
    ],
    ".bmc.edu.sa": ["Batterjee Medical College"],
    ".bpc.edu.sa": ["Buraydah College for Applied Medical Sciences"],
    ".bu.edu.sa": ["Al-baha University"],
    ".cba.edu.sa": ["College of Busniess Admnistration"],
    ".cis.edu.sa": ["Cedar International School"],
    ".cti.edu.sa": ["College of Telecommunication &amp; Information "],
    ".dah.edu.sa": ["جامعة دار الحكمة", "Dar Al-Hekma University"],
    ".daralhekma.edu.sa": ["Dar al Hekma College"],
    ".dau.edu.sa": ["Dar Al-Uloom Colleges"],
    ".dcc.edu.sa": ["Dammam Community College"],
    ".effat.edu.sa": ["Effat University"],
    ".effatcollege.edu.sa": ["Effat College"],
    ".fbsc.edu.sa": ["Fahad Bin Sultan University"],
    ".fikr.edu.sa": ["Dar Alfikr Schools", "Dar Alfikr Schools"],
    ".fikrgs.edu.sa": [
        "Dar Alfikr Schools for Girls",
        "Dar Alfikr Schools for Girls",
    ],
    ".fip.edu.sa": ["Food Industries Institute, Saudi Arabia"],
    ".iau.edu.sa": ["Imam Abdulrahman Bin Faisal University"],
    ".ibnroshd.edu.sa": [
        "Ibn Roshd Schools",
        "Ibn Roshd International Schools",
    ],
    ".ibnsina.edu.sa": ["Ibn Sina National College for Medical Studies "],
    ".imamu.edu.sa": ["Al-Imam Mohamed Ibn Saud Islamic University"],
    ".ipa.edu.sa": ["Institute of Public Administration"],
    ".iu.edu.sa": ["Islamic University of Medinah"],
    ".jazanu.edu.sa": ["Jazan University"],
    ".jct.edu.sa": ["College of Technology at Jeddah"],
    ".jicollege.edu.sa": ["Jeddah International College", "كلية جدة العالمية"],
    ".ju.edu.sa": ["Aljouf University"],
    ".kau.edu.sa": ["King Abdul Aziz University"],
    ".kaust.edu.sa": ["King Abdullah University of Science and Technology "],
    ".kfsc.edu.sa": ["King Fahd Security College"],
    ".kfu.edu.sa": ["King Faisal University"],
    ".kfupm.edu.sa": ["King Fahad University of Petroleum and Minerals"],
    ".kku.edu.sa": ["King Khaled University"],
    ".ksau-hs.edu.sa": [
        "King Saud bin Abdulaziz University for Health Sciences "
    ],
    ".student.ksu.edu.sa": ["king saud university"],
    ".ksu.edu.sa": ["King Saud University"],
    ".ku.edu.sa": ["Alkharj University"],
    ".mcst.edu.sa": ["Knowledge College for Science and Technology"],
    ".miskschools.edu.sa": ["Misk Schools", "Misk Schools"],
    ".nauss.edu.sa": ["Naif Arab University for Security Sciences"],
    ".nbu.edu.sa": ["Northern Border University"],
    ".nu.edu.sa": ["Najran University"],
    ".oc.edu.sa": ["كليات عنيزة", "Onaizah Colleges"],
    ".pisk.edu.sa": [
        "Pakistan International School Al Khobar",
        "Pakistan International School Al Khobar",
    ],
    ".pnu.edu.sa": ["Princess Nourah bint Abdulrahman University"],
    ".psau.edu.sa": [
        "Prince Sattam bin Abdulaziz University",
        "Prince Sattam bin Abdulaziz University",
    ],
    ".psu.edu.sa": ["Prince Sultan University"],
    ".qc.edu.sa": ["Qassim Private College"],
    ".rcjy.edu.sa": ["كلية الجبيل الصناعية", "Jubail Industrial College"],
    ".rct.edu.sa": ["College of Technology at Riyadh"],
    ".stu.rcyci.edu.sa": ["Yanbu Industrial College"],
    ".riyadh.edu.sa": ["Riyadh College of Dentistry and Pharmacy"],
    ".seu.edu.sa": ["Saudi Electronic University"],
    ".students.su.edu.sa": ["Shaqra University"],
    ".su.edu.sa": ["Shaqra University"],
    ".taibahu.edu.sa": ["Taibah University"],
    ".tu.edu.sa": ["Taif University"],
    ".tuwaiq.edu.sa": ["اكاديمية طويق", "Tuwaiq Academy"],
    ".ub.edu.sa": ["Univeristy of Bisha"],
    ".ubt.edu.sa": [
        " جامعة الاعمال والتكنولوجيا",
        "University of Business and Technology, Jeddah, Saudi Arabia",
    ],
    ".ucj.edu.sa": ["Jubail University College"],
    ".ud.edu.sa": ["University of Dammam"],
    ".uj.edu.sa": ["University of Jeddah"],
    ".uoh.edu.sa": ["University of Hail"],
    ".uqu.edu.sa": ["Umm Al-Qura University"],
    ".ut.edu.sa": ["University of Tabuk"],
    ".yic.edu.sa": ["Yanbu Industrial College"],
    ".yu.edu.sa": ["جامعة اليمامة", "Al Yamamah University"],
    ".mkhb.moe.gov.sa": ["مدرسة عمورية الثانوية", "Amoria Secondary School"],
    ".tvtc.gov.sa": ["Technical and Vocational Training Corporation"],
    ".ngha.med.sa": ["College of Nursing and Allied Health Scinces"],
    ".arabou.org.sa": ["Arab Open University"],
    ".student.sek.sa": ["SEK International School Riyadh"],
    ".beaconsfield.school": ["The Beaconsfield School"],
    ".beaumont.school": ["Beaumont School"],
    ".bgt.school": ["British Gymnasium of Technology"],
    ".budapest.school": ["Budapest School"],
    ".students.campden.school": ["Chipping Campden School"],
    ".cchs.school": ["Clacton County High School"],
    ".cesar.school": ["CESAR School"],
    ".chepstow.school": ["Chepstow School, Chepstow"],
    ".coda-student.school": [
        "Coda - Ecole Informatique",
        "Coda - School of Computer Science",
    ],
    ".coda.school": ["Coda", "Coda"],
    ".student.csb.school": ["Cybersecurity Business School"],
    ".csb.school": ["Cybersecurity Business School"],
    ".dalet.school": ["עירוני ד", "Irony Dalet"],
    ".donkey.school": ["DonkeySchool"],
    ".ecisd.school": ["permian high school"],
    ".ecoledeturing.school": ["Ecole de Turing"],
    ".egs.school": ["Education Gaming School"],
    ".eis.school": ["Esbjerg International School"],
    ".estudiante.epsum.school": ["EPSUM"],
    ".fortismere.school": ["Fortismere school"],
    ".governors.school": [
        "South Carolina Governor's School For Science & Math"
    ],
    ".hei.school": ["HEI - Haute École en Informatique"],
    ".horo.school": ["Horoshkola, hi.horoshkola.ru"],
    ".ihsan.school": [
        "Ihsan International School",
        "Ihsan International School",
    ],
    ".iscod.school": ["ISCOD"],
    ".itismajo.school": ["ITI E. Majorana Grugliasco"],
    ".janapriya.school": ["Janapriya School"],
    ".laclick.school": ["ADEN Formations"],
    ".millhill.school": ["Mill Hill School"],
    ".miniemen.school": ["Miniemeninstituut"],
    ".n.school": ["New School", "New School, Moscow, Russia"],
    ".norlington.school": ["Norlington", "Norlington"],
    ".oclock.school": ["Ecole O'clock"],
    ".optima.school": ["Educational center Optima, Kiev, Ukraine"],
    ".orleanspark.school": ["Orleans Park School, England"],
    ".pcjy.school": ["Shenzhen Pengcheng Vocational Skills Training School"],
    ".primakov.school": [
        'Областная некоммерческая образовательная организация "Гимназия им. Е.М.Примакова"'
    ],
    ".sevenkings.school": ["Seven Kings School"],
    ".sfxghis.school": ["SFX Greenherald International School"],
    ".shamir.school": ["Shamir School, Israel"],
    ".sptech.school": ["São Paulo Tech School"],
    ".students-wbs.school": ["The West Bridgford School"],
    ".suttongrammar.school": ["Sutton Grammar School"],
    ".teneo.school": ["Teneo Online School"],
    ".wasd.school": ["Wilmington Area School District"],
    ".wilder.school": ["Wild Code School"],
    ".akbk.schule": ["Adolf Kolping Berufskolleg"],
    ".bbs-nrue.schule": ["Berufsbildende Schulen Neustadt a. Rbge"],
    ".bbs2.schule": ["Berufsbildende Schulen II Göttingen"],
    ".bknrd.schule": [
        "Berufskolleg Nord der StädteRegion Aachen, Standort Alsdorf und Herzogenrath",
        "https://berufskolleg-nord.de/",
    ],
    ".buessing.schule": [
        "Heinrich-Büssing-Schule Berufsbildende Schulen Technik Braunschweig"
    ],
    ".buhmann.schule": [
        "Dr. Buhmann Schule & Akademie Hannover",
        "Dr. Buhmann School & Academy Hanover",
    ],
    ".bw.schule": ["Schulportal des Landes Baden-Württemberg", ".group"],
    ".fds-limburg.schule": ["Friedrich-Dessauer-Schule Limburg"],
    ".georg-buechner.schule": ["Georg-Büchner Schule"],
    ".afs.gt.schule": [
        "Anne-Frank-Schule, Städtische Gesamtschule Gütersloh",
        "Anne Frank School, High School Guetersloh",
    ],
    ".ksh.hanau.schule": ["Kauffmännische Schulen Hanau"],
    ".hhrs.schule": ["Hermann Hesse Realschule"],
    ".juventus.schule": ["Juventus Technikerschule HF"],
    ".ebs.kbs.schule": ["Eugen-Bachmann-Schule"],
    ".ess.kbs.schule": ["Elisabeth-Selbert-Schule"],
    ".ggb.kbs.schule": ["Goethe-Gymnasium Bensheim"],
    ".kks.kbs.schule": [
        "Karl Kübel Schule Bensheim",
        "Karl Kübel Schule Bensheim",
    ],
    ".mls.kbs.schule": ["Martin Luther Schule Rimbach"],
    ".kgl.schule": ["KOPERNIKUS-GYMNASIUM LINTORF"],
    ".s.kkst.schule": ["Königin Katharina Stift Gymnasium"],
    ".agb.nrw.schule": ["Abtei-Gymnasium Brauweiler"],
    ".ema.nrw.schule": ["Ernst Moritz Arndt Gymnasium Bonn"],
    ".ovm.schule": ["Oskar-von-Miller-Schule"],
    ".rkm.schule": ["Realschule Korntal-Münchingen"],
    ".rsg-cham.schule": ["Robert-Schuman Gymnasium Cham"],
    ".sbsz-bamberg.schule": [
        "Staatliches Berufliches Schulzentrum Bamberg - Berufsschule 1"
    ],
    ".sg-l.schule": ["Sickingen-Gymnasium Landstuhl"],
    ".sge.schule": [
        "Städtisches Gymnasium Eschweiler",
        "Municipal High School Eschweiler",
    ],
    ".steinbeis.schule": [
        "Ferdinand-von-Steinbeis-Schule",
        "Ferdinand-von-Steinbeis-School",
    ],
    ".theokoch.schule": ["Theo-Koch-Schule"],
    ".re.glow.scot": ["Glow Scotland", ".group"],
    ".aau.edu.sd": ["Al-Zaiem Al-Azhari University"],
    ".ahfad.edu.sd": ["Ahfad University for Women"],
    ".ccs.edu.sd": ["Canadian College - Sudan"],
    ".dalanjuniversity.edu.sd": ["Dalanj University"],
    ".fashir.edu.sd": ["Al Fashir University"],
    ".gaduniv.edu.sd": ["University of Gadarif"],
    ".iua.edu.sd": ["International University of Africa (IUA)"],
    ".kassalauni.edu.sd": ["Kassala University"],
    ".kordofan.edu.sd": ["University of Kordofan"],
    ".neelain.edu.sd": ["Neelain University"],
    ".nilevalley.edu.sd": ["Nile Valley University"],
    ".oau.edu.sd": ["Omdurman Ahlia University"],
    ".oiu.edu.sd": ["Omdurman Islamic University"],
    ".ous.edu.sd": ["Open University of Sudan (OUS)"],
    ".quran-unv.edu.sd": ["University of Holy Quran and Islamic Siences"],
    ".ribat.edu.sd": ["National Ribat University"],
    ".rsu.edu.sd": ["Red Sea University"],
    ".uofd.edu.sd": ["University of Dongola"],
    ".ust.edu.sd": ["University of Science and Technology"],
    ".ush.sd": ["Shendi University"],
    ".abbindustrigymnasium.se": ["ABB Industrigymnasium"],
    ".arboga.se": ["Vasagymnasiet", " Vasa High School"],
    ".student.arenakoncernen.se": ["Arena Group students, Sweden"],
    ".edu.avesta.se": ["Avesta Karlfeldtgymnasium"],
    ".edu.boras.se": [
        "Almåsgymnasiet",
        "Bäckängsgymnasiet",
        "Sven Eriksonsgymnasiet",
        "Viskastrandsgymnasiet",
        "Tullengymnasiet",
        ".group",
    ],
    ".skola.boras.se": ["Sven Eriksonsgymnasiet"],
    ".botkyrka.se": ["Tumba Gymnasium", ".group"],
    ".bth.se": ["Blekinge Institute of Technology"],
    ".student.chalmers.se": [
        "Chalmers tekniska högskola",
        "Chalmers University of Technology",
    ],
    ".chalmers.se": ["Chalmers University of Technology"],
    ".chasacademy.se": ["Chas Academy"],
    ".cmeducations.se": ["Changemaker Educations AB"],
    ".cng.se": ["Curt Nicolin Gymnasiet"],
    ".elev.cybergymnasiet.se": ["Cybergymnasiet"],
    ".elev.danderyd.se": ["Danderyds gymnasium"],
    ".danderyd.se": ["Danderyds gymnasium"],
    ".elev.ga.dbgy.se": [
        "Drottning Blankas Gymansieskola",
        "https://www.drottningblanka.se/",
    ],
    ".du.se": ["Dalarna University College"],
    ".utb.ecutbildning.se": ["EC Utbildning"],
    ".ecutbildning.se": ["EC Utbildning"],
    ".edufalkenberg.se": [
        "Falkenbergs gymnasieskola",
        "Falkenberg high school",
    ],
    ".edu.edugrade.se": ["Edugrade Yrkeshögskolan"],
    ".skola.engelholm.se": ["Engelholms gymnasieskola students"],
    ".engelholm.se": ["Engelholms gymnasieskola"],
    ".engelska.se": ["Internationella Engelska Skolan"],
    ".elev.enjoygroup.se": ["Handelsakademin school, Enjoy Group"],
    ".falufri.se": ["Falu Frigymnasium"],
    ".axevalla.fhsk.se": ["Axevalla Folkhögskola"],
    ".sanktamaria.fhsk.se": ["S:ta Maria Folkhögskola"],
    ".svf.fhsk.se": ["Södra Vätterbygdens Folkhögskola"],
    ".student.forsbergsskola.se": ["Forsbergs Skola"],
    ".edu.futuregames.se": ["Futuregames", "Futuregames"],
    ".gavle.se": ["Gymnasieskolorna i Gävle (Teachers)"],
    ".gih.se": ["The Swedish School of Sport and Health Sciences"],
    ".educ.goteborg.se": ["Yrgo", ".groups", "yh", ".humanus"],
    ".skola.goteborg.se": [
        "Göteborgs stad Utbildning, Yrgo",
        ".group",
        "Humanus Yerkeshöghskolan",
    ],
    ".grillska.se": ["Grillska Gymnasiet Eskilstuna"],
    ".gritacademy.se": ["Grit Academy"],
    ".gritgames.se": ["Grit Academy"],
    ".gtg.se": ["Göteborgsgregionens Tekniska Gymnasium"],
    ".gti.se": [
        "Göteborgs Tekniska Institut",
        "Gothenburgs Institute of Technology",
    ],
    ".gu.se": ["Göteborg University", "School of Design and Crafts"],
    ".edu.habo.se": ["Fridegårdsgymnasiet"],
    ".edu.halmstad.se": ["Kattegattgymnasiet Halmstad"],
    ".ubf.haninge.se": [
        "Fredrika Bremergymnasiet ",
        "Kommunal gymnasieskola i Haninge",
    ],
    ".edu.harnosand.se": ["Härnösand Gymnasium", "Härnösand Gymnasium"],
    ".harryda.se": ["Hulebäcksgymnasiet"],
    ".hb.se": ["University College of Borås"],
    ".utb.helsingborg.se": ["Tycho Brahe"],
    ".skola.herrljunga.se": ["Kunskapskällan"],
    ".hgo.se": ["Gotland University College"],
    ".hh.se": ["Halmstad University College"],
    ".hhs.se": ["Stockholm School of Economics"],
    ".hig.se": ["University College of Gävle"],
    ".hik.se": ["Kalmar University College"],
    ".student.his.se": ["University of Skövde"],
    ".his.se": ["University College of Skövde"],
    ".hitachigymnasiet.se": ["Hitachigymnasiet", "Hitachi High School"],
    ".hj.se": [
        "Jönköping University College",
        "Jönköping University College of Health Sciences",
    ],
    ".hkr.se": ["University College of Kristianstad"],
    ".htu.se": ["University College of Trollhättan/Uddevalla"],
    ".hv.se": ["University West"],
    ".hyperisland.se": ["Hyper Island"],
    ".innovationsgymnasiet.se": [
        "Thoren Innovations Gymnasiet",
        "Thoren Innovation School",
    ],
    ".it-gymnasiet.se": ["IT College Sweden"],
    ".itggot.se": ["Göteborg - IT Gymnasiet"],
    ".iths.se": ["IT-Högskolan"],
    ".jenseneducation.se": ["Jensen Education"],
    ".jgy.se": ["Added Jämtlands Gymnasium, Sweden. ", "www.jgy.se"],
    ".edu.jonkoping.se": ["Sandagymnasiet", ".group"],
    ".ju.se": ["Jönköping University"],
    ".edu.karlskoga.se": ["Teknikcollege Karlskoga/Degerfors"],
    ".karlskogafhs.se": [
        "Karlskoga Folkhögskola ",
        "Country: Sweden.",
        "Official website: https://karlskogafolkhogskola.se/",
        "Web development course:",
        "https://karlskogafolkhogskola.se/utbildning/webbdesign/",
        "Official facebook page:",
        "https://sv-se.facebook.com/karlskogafolkhogskola/",
    ],
    ".skola.karlskrona.se": ["SFI"],
    ".edu.karlstad.se": [
        "Sundsta-Älvkullegymnasiet",
        "Nobelgymnasiet",
        "Tingvallagymnasiet",
    ],
    ".katedral.se": ["Katedralskolan Uppsala"],
    ".kau.se": ["Karlstad University"],
    ".kfvelev.se": ["Magnus Åbergsgymnasiet"],
    ".ki.se": ["Karolinska Institute Stockholm"],
    ".knuthahn.se": ["Gymnasieskolan Knut Hahn"],
    ".konstfack.se": ["University College of Arts, Crafts and Design"],
    ".kth.se": ["Royal Institute of Technology"],
    ".kulturama.se": ["Kulturama"],
    ".edu.kungalv.se": ["Kungälvs Kommun", "Kungalv Municipality"],
    ".elev.kungalv.se": ["Kungälvs Kommun", "Kungalv Municipality"],
    ".skola.kungalv.se": ["Kungälvs Kommun", "Kungalv Municipality"],
    ".kunskapsforbundet.se": ["Kunskapsförbundet väst"],
    ".student.kyh.se": ["KYH", "KYH"],
    ".lbs.se": ["LBS Kreativa Gymnasiet"],
    ".lerniastudent.se": ["Lernia utbildning", "Lernia education"],
    ".edu.lerum.se": ["Torpskolan"],
    ".lhs.se": ["Stockholm Institute of Education"],
    ".skola.lidingo.se": ["Källängens skola", "Kallangens school", ".group"],
    ".adm.linkoping.se": ["linkopings kommun"],
    ".edu.linkoping.se": ["Linkopings kommun"],
    ".liu.se": ["Linköping University"],
    ".lnu.se": ["Linnaeus University"],
    ".lth.se": ["Lund University"],
    ".ltu.se": ["Luleå University of Technology"],
    ".lunduniversity.lu.se": ["Lund University"],
    ".lu.se": ["Lund University"],
    ".skola.lund.se": [
        "Polhemskolan",
        "https://www.lund.se/en/polhemskolan/om-skolan/",
        "https://www.lund.se/polhemskolan/om-skolan/",
    ],
    ".luth.se": ["Lulea University of Technology"],
    ".mah.se": ["Malmö University College"],
    ".malardalenstekniska.se": ["Mälardalens Tekniska Gymnasium"],
    ".skola.malmo.se": ["Students in Malmoe"],
    ".mau.se": ["Malmo University"],
    ".student.mdu.se": ["Mälardalens University", "malardalen university"],
    ".mdu.se": ["Mälardalen University"],
    ".medborgarskolan.se": ["Medborgarskolan"],
    ".medieinstitutet.se": ["The Media Institute"],
    ".minervagymnasium.se": ["minervagynasium"],
    ".minervaskolan.se": ["Minervaskolan"],
    ".miun.se": ["Mid-Sweden University"],
    ".gafe.molndal.se": ["Campus Mölndal"],
    ".studerande.movant.se": ["Movant", "Movant"],
    ".edu.nacka.se": ["Nacka Gymnasium"],
    ".nackademin.se": ["Nackademins YH-utbildning"],
    ".nbi-handelsakademin.se": ["NBI / Handelsakademin"],
    ".nbi.se": ["NBI/Handelsakademin"],
    ".edu.newton.se": ["Newton Kompetensutveckling AB"],
    ".noblaskolan.se": ["Acedemedia, Noblaskolan, Solna", "Noblaskolan"],
    ".elev.norrkoping.se": ["Mosstorpsskolan"],
    ".umea.nti.se": ["NTI-Gymnasiet Umeå"],
    ".ntig.se": ["NTI College Sweden"],
    ".edu.nybro.se": ["Åkrahällskolan"],
    ".skola.nykoping.se": [
        "Campus YrkesHögskola Nyköping",
        "Campus Highschool Nykoping",
    ],
    ".edu.olofstrom.se": ["Nordenbergsskolan Olofström"],
    ".oru.se": ["Örebro University"],
    ".piggelinen.se": ["Friskolan Piggelinen"],
    ".stud.pitea.se": ["Strömbackaskolan", "Solanderskolan"],
    ".plushogskolan.se": ["Plushögskolan Higher Vocational Education school"],
    ".realgymnasiet.se": ["Realgymnasiet"],
    ".sh.se": ["Södertörns Högskola"],
    ".utb.sih.se": [
        "Stockholms Internationella Handelsskola AB",
        "Stockholm International school of commerce",
    ],
    ".elev.ga.sjolinsgymnasium.se": [
        "Sjölins Gymnasium Södermalm",
        "Sjolins Gymnasium",
    ],
    ".skolamoa.se": ["Mora High School", "http://www.moragymnasium.se/"],
    ".skolanskurup.se": [
        "Skurup Kommuns Skolor",
        "Schools Of Skurup Municipality",
    ],
    ".slu.se": ["Swedish University of Agricultural Sciences"],
    ".elev.snitz.se": ["Snitz Gymnasium"],
    ".snitz.se": ["Snitz Gymnasium (Teacher)"],
    ".edu.sollentuna.se": ["Rudbeck"],
    ".soltorgsgymnasiet.se": ["Soltorgsgymnasiet"],
    ".stud.sti.se": ["Stockholms Tekniska Institut"],
    ".elevmail.stockholm.se": ["Enskede Skola", "Enskede School"],
    ".stockholmscience.se": ["Stockholm Science & Innovation School"],
    ".storsjogymnasiet.se": [
        "High School of Great Lake of Jamtland",
        "Storsjögymnasiet, Östersund",
    ],
    ".su.se": ["Stockholm University"],
    ".skola.sundsvall.se": ["Sundsvalls Gymnasium"],
    ".suni.se": ["Södertörns Högskola"],
    ".skola.taby.se": ["Åva gymnasium", ".group"],
    ".student.tabyenskilda.se": ["Täby Enskilda Gymnasium"],
    ".thegameassembly.se": ["The Game Assembly"],
    ".theindiequest.se": ["The Indie Quest"],
    ".tucsweden.se": ["TUC Sweden"],
    ".utb.tyreso.se": ["TYRESÖ KOMMUN"],
    ".gapp.uddevalla.se": [
        "Uddevalla Yrkeshögskola",
        "Uddevalla Higher Vocational Education",
    ],
    ".edu.umea.se": ["Dragonskolan"],
    ".umu.se": ["Umea University"],
    ".uniarts.se": [
        "Stockholms konstnärliga högskola",
        "Stockholm University of the Arts (Uniarts)",
    ],
    ".uu.se": ["Uppsala University"],
    ".edu.varberg.se": [
        "Yrkeshögskolan Campus Varberg",
        "Vocational School Campus Varberg",
    ],
    ".utb.vaxjo.se": ["Växjö Technical College"],
    ".edu.vellinge.se": ["Sundsgymnasiet"],
    ".vrg.se": ["Viktor Rydberg gymnasium Odenplan"],
    ".vuxutb.se": ["Plushögskolan"],
    ".wendelahebbegymnasiet.se": ["Wendela Hebbegymnasiet"],
    ".wmu.se": ["World Maritime University"],
    ".ya.se": ["YrkesAkademin"],
    ".yaelev.se": ["Yrkesakademin AB"],
    ".student.42singapore.sg": ["42 Singapore", "42 Singapore"],
    ".adsc.com.sg": ["Advanced Digital Sciences Center"],
    ".sji-international.com.sg": ["SJI International School"],
    ".ais.edu.sg": ["Australian International School Singapore"],
    ".auston.edu.sg": ["Auston Institute of Management"],
    ".aventis.edu.sg": ["Aventis School of Management"],
    ".cis.edu.sg": ["Canadian International School Singapore"],
    ".learning.curtin.edu.sg": ["Curtin Singapore"],
    ".dovercourt.edu.sg": ["Dover Court International School"],
    ".fis.edu.sg": ["Furen International School"],
    ".giis.edu.sg": ["Global Indian International School"],
    ".student.hci.edu.sg": ["Hwa Chong Institution"],
    ".ics.edu.sg": ["International Community School (Singapore)"],
    ".ite.edu.sg": [
        "Institute of Technical Education",
        "Institute of Technical Education",
    ],
    ".kaplan.edu.sg": ["Kaplan Singapore Higher Education Academy"],
    ".lsbf.edu.sg": [
        "London School of Business & Finance Singapore",
        "London School of Business & Finance Singapore",
    ],
    ".mages.edu.sg": ["Mages Institute"],
    ".melis.edu.sg": ["Melbourne Specialist International School"],
    ".middleton.edu.sg": ["Middleton International School by Eton House"],
    ".temasekjc.moe.edu.sg": ["Temasek Junior College"],
    ".myrp.edu.sg": ["Republic Polytechnic"],
    ".nexus.edu.sg": [
        "Nexus International School (Singapore)",
        "Under Taylor's Schools Group",
        "https://www.nexus.edu.sg/",
        "https://www.nexus.edu.sg/secondary/",
        '- Scroll down and click "IGCSE" and "IB Diploma Programme"',
        '- Key word: "Computer Science"',
        "School email domain:",
        "[First name].[Last name].[Graduation year]@nexus.edu.sg",
    ],
    ".connect.np.edu.sg": ["Ngee Ann Polytechnic "],
    ".np.edu.sg": [
        "Ngee Ann Polytechnic",
        "Official Website URL: https://www.np.edu.sg",
        "URL of a page on the official website where a long-term (>1 year) IT related course is offered",
        "https://www.np.edu.sg/schools-courses/academic-schools/school-of-infocomm-technology",
        "https://www.np.edu.sg/schools-courses/full-time-courses",
    ],
    ".ntu.edu.sg": ["Nanyang Technological University"],
    ".nus.edu.sg": ["National University of Singapore"],
    ".nushigh.edu.sg": ["NUS High School of Math and Science"],
    ".nyjc.edu.sg": ["Nanyang Junior College"],
    ".nyp.edu.sg": ["Nanyang Polytechnic"],
    ".ofs.edu.sg": [
        "Overseas Family School Singapore",
        "OFS",
        "https://www.ofs.edu.sg/",
        "https://www.ofs.edu.sg/schools/hs/courses/descriptions/#ib-comp-science",
    ],
    ".prcss.edu.sg": ["Pasir Ris Crest Secondary School"],
    ".psba.edu.sg": ["Psb Academy"],
    ".ri.edu.sg": ["Raffles Institution"],
    ".rp.edu.sg": ["Republic Polytechnic"],
    ".sais.edu.sg": ["Stamford American International School"],
    ".sas.edu.sg": ["Singapore American School"],
    ".sim.edu.sg": ["Singapore Institute of Management (SIM)"],
    ".sit.singaporetech.edu.sg": ["Singapore Institute of Technology"],
    ".singaporetech.edu.sg": ["Singapore Institute of Technology"],
    ".sji.edu.sg": ["St. Joseph's Institution"],
    ".smu.edu.sg": ["Singapore Management University"],
    ".sp.edu.sg": ["Singapore Polytechnic"],
    ".sst.edu.sg": ["School of Science and Technology"],
    ".ssts.edu.sg": ["School of Science and Technology"],
    ".sthua.edu.sg": ["St.Hua Private School"],
    ".students.edu.sg": ["National Junior College"],
    ".suss.edu.sg": [
        "Singapore University of Social Science",
        "Singapore University of Social Science",
    ],
    ".sutd.edu.sg": ["Singapore University of Technology and Design"],
    ".tp.edu.sg": ["Temasek Polytechnic", "Temasek Polytechnic"],
    ".gapps.uwcsea.edu.sg": ["United World College"],
    ".uwcsea.edu.sg": ["United World College of South East Asia"],
    ".nlcssingapore.sg": ["North London Collegiate School (Singapore)"],
    ".panasia.org.sg": [
        "Qauid-e-Awam University of Engineering Sciences &amp; Technology"
    ],
    ".student.pathlight.org.sg": ["Pathlight School"],
    ".vjc.sg": ["Victoria Junior College"],
    ".school.sh": ["Centre for Arts and Technology"],
    ".academia.si": [
        "Academia, Višja strokovna sola",
        "Academia, College of Short-Cycle Higher Education",
    ],
    ".academiavss.si": [
        "Academia, Višja strokovna sola",
        "Academia, College of Short-Cycle Higher Education",
    ],
    ".almamater.si": ["Alma Mater Europaea - ECM"],
    ".druga.si": ["II. gimnazija Maribor"],
    ".esnm.si": ["Ekonomska sola Novo mesto"],
    ".fm-kp.si": ["University of Primorska, Faculty of Management"],
    ".gfml.si": ["Gimnazija Franca Miklošiča Ljutomer"],
    ".gimkr.si": ["Gimnazija Kranj"],
    ".gimnazija-skofjaloka.si": ["Gimnazija Škofja Loka"],
    ".gimvic.si": ["Gimnazija vič, Ljubljana, Slovenija"],
    ".dijak.gssk.si": ["Gimnazija in srednja šola Kočevje"],
    ".ijs.si": ["Jozef Stefan Institute"],
    ".os-hoce.si": ["Osnovna šola Dušana Flisa Hoče"],
    ".osbrod.si": ["Osnovna Šola Vižmarje-Brod"],
    ".ostrbovlje.si": ["Osnovna šola Trbovlje"],
    ".sc-celje.si": ["School Centre Celje"],
    ".sc-nm.si": ["School Center Novo mesto"],
    ".sts.sckr.si": [
        "Srednja tehniška šola Kranj",
        "Secondary technical school Kranj",
    ],
    ".vss.sckr.si": ["Višja strokovna šola ŠC Kranj"],
    ".sckr.si": ["Šolski center Kranj", "School centre Kranj"],
    ".ms.scng.si": [
        "Višja strokovna šola Nova Gorica",
        "Higher Vocational School of Nova Gorica",
    ],
    ".scng.si": ["Šolski Center Nova Gorica", "School Centre Nova Gorica"],
    ".scpet.si": [
        "Šolski center za pošto, ekonomijo in telekomunikacije Ljubljana"
    ],
    ".scptuj.si": ["Šolski center Ptuj, Elektro in računalniška šola"],
    ".scv.si": ["Šolski center Velenje"],
    ".sers.si": ["Srednja elektro-računalniška šola Maribor"],
    ".spletni-studij.si": [
        "B2 d.o.o. Višja strokovna šola Ljubljana",
        "B2 d.o.o. Vocational school Ljubljana",
    ],
    ".ssravne.si": ["Srednja šola Ravne"],
    ".ssts.si": ["Srednja Šola Tehniških Strok Šiška"],
    ".stps-trbovlje.si": ["Srednja tehniska in poklicna sola Trbovlje"],
    ".sts.si": ["Srednja tehniška sola Koper"],
    ".student-erudio.si": [
        "Erudio Izobraževalni Center",
        "Erudio Educational Center",
    ],
    ".szsce.si": [
        "Srednja zdravstvena in kozmetična šola Celje",
        "Medical and Cosmetic high school of Celje",
    ],
    ".tonetacufarja.si": ["OŠ Toneta Čufarja Ljubljana"],
    ".um.si": ["University of Maribor"],
    ".ung.si": ["University of Nova Gorica"],
    ".uni-lj.si": ["University of Ljubljana"],
    ".uni-mb.si": ["University of Maribor"],
    ".student.fis.unm.si": [
        "Fakulteta za informacijske študije v Novem mestu"
    ],
    ".fis.unm.si": [
        "Fakulteta za Informacijske Študije v Novem mestu",
        "Faculty for Information Sciences in Novo mesto",
    ],
    ".upr.si": ["University of Primorska"],
    ".vegova.si": ["Vegova Ljubljana"],
    ".student.adlerka.sk": [
        "Stredná priemyselná škola elektrotechnická, K. Adlera 5, 841 02 Bratislava"
    ],
    ".akademiapz.sk": [
        "Police Academy in Bratislava",
        "Police Academy in Bratislava",
    ],
    ".aku.sk": [
        "Academy of Arts in Banská Bystrica",
        "Academy of Arts in Banská Bystrica",
    ],
    ".animus.sk": ["Súkromná stredná odborná škola ANIMUS"],
    ".aos.sk": [
        "Armed Forces Academy of General Milan Rastislav Štefánik",
        "Armed Forces Academy of General Milan Rastislav Štefánik",
    ],
    ".bilgym.sk": ["Bilingválne Gymnázium C.S. Lewisa"],
    ".bisla.sk": [
        "Bratislava International School of Liberal Arts",
        "Bratislava International School of Liberal Arts",
    ],
    ".bivs.sk": ["Bank Institute High School in Banská Bystrica"],
    ".centrumnadania.sk": ["Centrum nadania, n.o., Slovensko"],
    ".dti.sk": [
        "Technical Institute of Dubnica in Dubnica nad Váhom",
        "Technical Institute of Dubnica in Dubnica nad Váhom",
    ],
    ".gpohkk.edu.sk": ["Gymnázium P. O. Hviezdoslava v Kežmarku"],
    ".spssnina.edu.sk": [
        "Stredná priemyselná škola, Partizánska 1059/23, Snina, Slovakia"
    ],
    ".elektrohradok.sk": [
        "Stredná odborná škola elektrotechnická Liptovský Hrádok"
    ],
    ".euba.sk": [
        "University of Economics in Bratislava",
        "University of Economics in Bratislava",
    ],
    ".evlyceum.sk": [" Evanjelické lýceum v Bratislave"],
    ".gabnam.sk": ["Gymnázium Antona Bernoláka Námestovo"],
    ".galeje.sk": ["Gymnázium Alejová 1"],
    ".gamca.sk": ["Gymnázium Grösslingová 18", "Gymnázium Grösslingová 18"],
    ".gjh.sk": ["Gymnázium Jura Hronca, Bratislava"],
    ".gkmke.sk": ["Spojená škola sv. Košických mučeníkov in Košice, Slovakia"],
    ".gmet.sk": ["GYMNÁZIUM, Metodova 2, Bratislava"],
    ".gsa.sk": ["Gymnazium sv. Andreja", "Gymnazium st. Andrews"],
    ".gymgolnr.sk": ["Gymnázium Golianova 68"],
    ".gymnaziumceska.sk": ["\ufeffGymnázium Česká"],
    ".gympos.sk": ["Gymnázium Poštová, Košice"],
    ".gymzv.sk": ["Gymnázium Ľudovíta Štúra Zvolen"],
    ".iaeste.sk": ["IAESTE Slovakia", "IAESTE Slovakia"],
    ".ismpo.sk": [
        "International School of Management in Prešov",
        "International School of Management in Prešov",
    ],
    ".ku.sk": [
        "Catholic University in Ruzomberok",
        "Catholic University in Ružomberok",
        "Catholic University in Ruzomberok",
        "Catholic University in Ružomberok",
    ],
    ".maraigimi.sk": [
        "MÁRAI SÁNDOR MAGYAR TANÍTÁSI NYELVŰ GIMNÁZIUM ÉS ALAPISKOLA KASSA",
        "Gymnázium a základná škola Sándora Máraiho s vyučovacím jazykom maďarským Košice",
    ],
    ".mediamatika.sk": ["University of Žilina", "University of Žilina"],
    ".piaristi-pd.sk": [
        "Piaristická spojená škola F. Hanáka v Prievidzi",
        "Piarist school of F. Hanák in Prievidza",
    ],
    ".selyeuni.sk": ["Janos Selye University", "Janos Selye University"],
    ".sevs.sk": [
        "University of Central Europe in Skalica",
        "University of Central Europe in Skalica",
    ],
    ".sjoroza.sk": ["SOŠ sv. Jozefa Robotníka"],
    ".sosha.sk": ["Stredná Odborná Škola Handlová"],
    ".sosholic.sk": [
        "Stredná odborná škola",
        "Stredná odborná škola, Námestie sv. Martina 5, Holíč",
        "SOS, Holíč",
        "SOSHolic",
        "High School Holic/Secondary school Holic",
    ],
    ".sosthe.sk": [
        "Stredná odborná škola technická Humenné",
        "Technical high school Humenné",
    ],
    ".spsbj.sk": ["SPŠT Bardejov"],
    ".spsdub.sk": ["Stredná priemyselná škola v Dubnici nad Váhom, Slovakia"],
    ".spse-po.sk": ["SPŠ Elektrotechnická"],
    ".spsehalova.sk": [
        "Stredná priemyselná škola elektrotechnická Hálova 16 Bratislava",
        "SPSE Halova Bratislava",
    ],
    ".spseke.sk": [
        "SPŠ elektrotechnická v Košiciach",
        "Secondary school of electrical engineering in Kosice",
    ],
    ".spsjm.sk": ["Stredná priemyselná škola Jozefa Murgaša, Banská Bystrica"],
    ".spsknm.sk": [
        "Stredná priemyselná škola informačných technológií, Nábrežná 1325, Kysucké Nové Mesto"
    ],
    ".spstsnv.sk": ["Stredná Priemyselná Škola Technická, Spišská Nová Ves"],
    ".spstt.sk": [
        "Stredna Priemyselna Skola Technicka Trnava",
        "Stredna Priemyselna Skola Technicka Trnava",
    ],
    ".ssnd.sk": ["Spojená škola sv. Jána Bosca v Novej Dubnici"],
    ".stuba.sk": [
        "Slovak University of Technology in Bratislava",
        "Slovak University of Technology in Bratislava",
    ],
    ".studentgymnaziumceska.sk": ["\ufeffGymnázium Česká"],
    ".svr.sk": ["Spojená škola Svätej Rodiny, Bratislava"],
    ".szu.sk": ["Slovak Medical University", "Slovak Medical University"],
    ".tnuni.sk": [
        "University of Alexandra Dubček in Trenčín",
        "University of Alexandra Dubček in Trenčín",
    ],
    ".truni.sk": ["University of Trnava", "University of Trnava"],
    ".tuke.sk": [
        "Technical University in Kosice",
        "Technical University in Kosice",
    ],
    ".tuzvo.sk": [
        "Technical University in Zvolen",
        "Technical University in Zvolen",
    ],
    ".tvu.sk": ["Trnavska Univerzita", "University of Trnava"],
    ".ucm.sk": [
        "University of St. Cyril and Methodius in Trnava",
        "University of SV Cyril and Methodius in Trnava",
        "University of St. Cyril and Methodius in Trnava",
        "University of SV Cyril and Methodius in Trnava",
    ],
    ".ujs.sk": ["J. Selye University"],
    ".ukf.sk": [
        "University Konstantina Filozov in Nitra",
        "University Konstantina Filozov in Nitra",
    ],
    ".umb.sk": [
        "Matej Bel University in Banská Bystrica",
        "Matej Bel University in Banská Bystrica",
    ],
    ".uniag.sk": [
        "Slovak University of Agriculture in Nitra",
        "Slovak University of Agriculture in Nitra",
    ],
    ".g.fmph.uniba.sk": [
        "Fakulta matematiky, fyziky a informatiky Univerzity Komenského v Bratislava - Google Educational Accounts"
    ],
    ".uniba.sk": [
        "Comenius University in Bratislava",
        "Comenius University in Bratislava",
    ],
    ".uninova.sk": [
        "Law University of Bratislava",
        "Law University of Bratislava",
    ],
    ".unipo.sk": ["University of Presov", "University of Presov"],
    ".uniza.sk": ["University of Žilina", "University of Žilina"],
    ".upjs.sk": [
        "Pavol Jozef Safarik University in Kosice",
        "Pavol Jozef Safarik University in Kosice",
    ],
    ".uvm.sk": [
        "University of Veterinary Medicine in Kosice",
        "University of Veterinary Medicine in Kosice",
    ],
    ".student.vazka.sk": ["Gymnázium Jána Papánka", "Ján Papánek's Gymnasium"],
    ".vsm.sk": ["School of Management", "School of Management"],
    ".vsmu.sk": [
        "University of Performing Arts in Bratislava",
        "University of Performing Arts in Bratislava",
    ],
    ".vssladkovicovo.sk": [
        "College in Sládkovičovo",
        "College in Sládkovičovo",
    ],
    ".vssvalzbety.sk": [
        "St. Elizabeth’s College of Health and Social Sciences in Bratislava",
        "St. Elizabeth’s College of Health and Social Sciences in Bratislava",
    ],
    ".vsvu.sk": [
        "Academy of Fine Arts and Design in Bratislava",
        "Academy of Fine Arts and Design in Bratislava",
    ],
    ".s.zochova.sk": ["SPŠE Zochova"],
    ".zskezmarska28.sk": [
        "Základna Škola Kežmarská 28 Košice ",
        "Base School Kezmarská 28 Kosice",
    ],
    ".zsstrba.sk": ["Základná škola v Štrbe", "Primary school Strba"],
    ".unirsm.sm": ["University of San Marino"],
    ".dit.sn": [
        "Dakar Institute of Technology",
        "Dakar Institute of Technology",
    ],
    ".cesag.edu.sn": [
        "Centre Africain des Etudes Supérieures en Gestion (CESAG), Sénégal"
    ],
    ".estm.edu.sn": [
        "\ufeffÉcole Supérieure de Technologie et de Management, Senegal"
    ],
    ".eua.edu.sn": [
        "Excellence Universitaire Africaine",
        "African University Excellence",
    ],
    ".isep-thies.edu.sn": [
        "institut supérieur d'enseignement professionnelle de thies",
        "institut supérieur d'enseignement professionnelle de thies",
    ],
    ".isepdiamniadio.edu.sn": [
        "ISEP de Diamniadio (Institut Supérieur Enseignement Professionnel de Diamniadio)"
    ],
    ".ism.edu.sn": ["Institut Supérieur de Management", "ISM"],
    ".mit.edu.sn": [
        "Institut Supérieur de Formation en Management Ingénierie et Télécommunication, Senegal"
    ],
    ".supdeco.edu.sn": ["Groupe Ecole Supérieur de Commerce Dakar"],
    ".uadb.edu.sn": ["Université Alioune Diop de Bambey"],
    ".uam.edu.sn": [
        "Université Amadou Mahtar Mbow",
        "Amadou Mahtar Mbow University",
    ],
    ".ucao.edu.sn": ["Saint Michel"],
    ".ugb.edu.sn": ["Université Gaston Berger Saint-Louis"],
    ".unchk.edu.sn": [
        "The digital university of Senegal Cheikh Hamidou Kane (UNCHK)"
    ],
    ".uvs.edu.sn": ["Virtual University of Senegal"],
    ".ept.sn": ["Ecole Polytechnique de Thiès ", "Thies Polytechnic School "],
    ".esmt.sn": [
        "Ecole Supérieure Multinationale des Télécommunications",
        "Multinational Higher School of Telecommunications",
        "ESMT",
        "www.esmt.sn",
    ],
    ".esp.sn": [
        "Ecole Supérieure Polytechnique de dakar",
        "École Supérieure Polytechnique de dakar",
        "ESP",
    ],
    ".ipd.sn": ["IPD Thomas Sankara", "Polytechnic Institute Thomas Sankara"],
    ".ucad.sn": ["ucad.edu.sn"],
    ".zig.univ.sn": ["Université Assane Seck de Ziguinchor"],
    ".univ-thies.sn": ["Universite de Thies"],
    ".univ-zig.sn": ["Université Assane Seck de Ziguinchor"],
    ".amoud.edu.so": ["Jaamacada Camuud", "Amoud University"],
    ".just.edu.so": ["Jamhuriya University of Science and Technology"],
    ".psu.edu.so": ["Puntland State University"],
    ".simad.edu.so": ["SIMAD UNIVERSITY"],
    ".harbour.space": ["Harbour Space University"],
    ".ptc.edu.sr": ["Polytechnic College Suriname"],
    ".student.natin.sr": [
        "Natuurtechnisch Instituut (NATIN-MBO)",
        "Institute of Nature and Technology",
    ],
    ".unasat.sr": ["University of Applied Science and Technology"],
    ".msun.study": [
        "МОРСКОЙ ГОСУДАРСТВЕННЫЙ УНИВЕРСИТЕТ ИМЕНИ АДМИРАЛА Г.И. НЕВЕЛЬСКОГО",
        "MARITIME STATE UNIVERSITY named after admiral G.I.Nevelskoy",
    ],
    ".sit.study": ["Schaffhausen Institute of Technology"],
    ".varsovia.study": [
        "Uczelnia Biznesu i Nauk Stosowanych „Varsovia”",
        "University Of Bussines and Applied Sciences Varsovia",
    ],
    ".kstu.su": [
        "Kamchatka State Technical University",
        "Kamchatka State Technical University",
    ],
    ".msu.su": [
        "Moscow State University",
        "Moscow State University M.V. Lomonosov",
        "Moscow State University",
        "Moscow State University M.V. Lomonosov",
    ],
    ".nsk.su": [
        "Siberian State University of Telecommunications and Informatics",
        "Siberian State University of Telecommunications and Informatics",
    ],
    ".omsk.su": ["Omsk State University", "Omsk State University"],
    ".radiotech.su": ["\ufeffЧелябинский Радиотехнический техникум"],
    ".ruc.su": [
        "Российский университет кооперации",
        "Russian University of Cooperation",
    ],
    ".sibupk.su": [
        "Siberian University of Consumer Cooperation (SibUCC)",
        "Сибирский университет потребительской кооперации (СибУПК)",
    ],
    ".ugatu.su": ["Ufa State Aviation Technical University"],
    ".uspu.su": [
        "Уральский государственный педагогический университет",
        "Ural State Pedagogical University",
    ],
    ".esfe.agape.edu.sv": ["Escuela Superior Franciscana Especializada"],
    ".catolica.edu.sv": ["Universidad Catolica de El Salvador"],
    ".cdb.edu.sv": ["Universidad Don Bosco"],
    ".cvirtualuees.edu.sv": ["Universidad Evangelica de El Salvador"],
    ".esen.edu.sv": ["Escuela Superior de Economía y Negocios (ESEN)"],
    ".itcha.edu.sv": ["Instituto Tecnológico de Chalatenango"],
    ".liveusam.edu.sv": [
        "Universidad Salvadoreña Alberto Masferrer",
        "Alberto Masferrer Salvadoran University",
    ],
    ".uae.edu.sv": ["Universidad Albert Einstein"],
    ".uca.edu.sv": ["Universidad Centroamericana José Simeón Canas"],
    ".ucad.edu.sv": ["Universidad Cristiana de las Asambleas de Dios"],
    ".udb.edu.sv": ["Don Bosco University"],
    ".uees.edu.sv": ["Universidad Evangélica de El Salvador"],
    ".ues.edu.sv": ["University of El Salvador"],
    ".ufg.edu.sv": ["Universidad Francisco Gavidia"],
    ".ugb.edu.sv": ["Universidad Capitain General Gerardo Barrios"],
    ".ujmd.edu.sv": ["Universidad Dr. Jose Matias Delgado"],
    ".uls.edu.sv": ["Universidad Luterana Salvadoreña"],
    ".uma.edu.sv": ["Universidad Modular Abierta"],
    ".umoar.edu.sv": ["Universidad Monsenor Oscar Arnulfo Romeo"],
    ".unab.edu.sv": ["Universidad Dr. Andreas Bello"],
    ".univo.edu.sv": ["Universidad de Oriente"],
    ".unssa.edu.sv": ["Universidad Nueva San Salvador"],
    ".upan.edu.sv": ["Universidad Panamericana de San Salvador"],
    ".uped.edu.sv": ["Universidad Pedagogica de El Salvador"],
    ".upes.edu.sv": ["Universidad Politécnica de El Salvador"],
    ".usam.edu.sv": ["Universidad Salvadorena Alberto Masferrer"],
    ".utec.edu.sv": ["Universidad Tecnologica de El Salvador"],
    ".utla.edu.sv": ["Universidad Técnica Latinoamericana"],
    ".siw.swiss": ["SIW Höhere Fachschule für Wirtschaft und Informatik"],
    ".albaath-univ.edu.sy": ["Al-Baath University"],
    ".alepuniv.edu.sy": ["University of Aleppo"],
    ".damascusuniversity.edu.sy": ["Damascus University"],
    ".hiba.edu.sy": ["Higher Institute of Business Administration"],
    ".iust.edu.sy": ["International University for Science &amp; Technology "],
    ".tishreen.edu.sy": ["Tishreen University"],
    ".uok.edu.sy": ["University of Kalamoon"],
    ".wiu.edu.sy": ["Wadi International University"],
    ".ypu.edu.sy": ["Yarmouk Private University "],
    ".uniswa.sz": ["University of Swaziland"],
    ".bts.tech": ["Barcelona Technology School"],
    ".iai-togo.tg": [
        "Institut Africain d'Informatique.",
        "English Name :",
        "Africa Institute of Technology",
    ],
    ".ucao-uut.tg": [
        "Université Catholique de l'Afrique de l'Ouest",
        "West Africa Catholique University",
    ],
    ".univ-lome.tg": ["Université de Lomé"],
    ".acr.ac.th": ["อัสสัมชัญระยอง", "Assumption College Rayong"],
    ".acsp.ac.th": [
        "โรงเรียนอัสสัมชัญสมุทรปราการ",
        "Assumption College Samutprakarn",
    ],
    ".student.act.ac.th": ["อัสสัมชัญธนบุรี", "Assumption College Thonburi"],
    ".teacher.act.ac.th": ["อัสสัมชัญธนบุรี", "Assumption College Thonburi"],
    ".aims.ac.th": ["Adventist International Mission School (AIMS)"],
    ".ait.ac.th": ["Asian Institute of Technology"],
    ".aru.ac.th": ["Phranakhon Si Ayutthaya Rajabhat University"],
    ".asb.ac.th": ["The American School of Bangkok"],
    ".ayw.ac.th": ["อยุธยาวิทยาลัย", "Ayutthaya Witthayalai"],
    ".bcc.ac.th": ["Bangkok Christian College", "bcc.ac.th"],
    ".bcisphuket.ac.th": ["BCIS Phuket International School"],
    ".bisphuket.ac.th": ["British International School Phuket"],
    ".bkkthon.ac.th": ["มหาวิทยาลัยกรุงเทพธนบุรี", "Bangkok Thonburi University"],
    ".bru.ac.th": ["มหาวิทยาลัยราชภัฏบุรีรัมย์", "Buriram Rajabhat University"],
    ".bsru.ac.th": ["Bansomdejchaopraya Rajabhat University"],
    ".bu.ac.th": ["Bangkok University"],
    ".buu.ac.th": ["Burapha University"],
    ".cdti.ac.th": [
        "โรงเรียนจิตรลดาวิชาชีพ สถาบันเทคโนโลยีจิตรลดา",
        "Chitralada Vocational School",
    ],
    ".chandra.ac.th": [
        "มหาวิทยาลัยราชภัฏจันทรเกษม",
        "CHANDRAKASEM RAJABHAT UNIVERSITY",
    ],
    ".chiangkham.ac.th": [
        "โรงเรียนเชียงคำวิทยาคม",
        "Chiangkhamwittayakhom School",
    ],
    ".chiangmai.ac.th": ["Chiang Mai University"],
    ".chonvc.ac.th": ["วิทยาลัยอาชีวศึกษาชลบุรี", "Chonburi Vocational College"],
    ".student.chula.ac.th": ["Chulalongkorn University"],
    ".cmkl.ac.th": ["CMKL University"],
    ".cmtc.ac.th": ["วิทยาลัยเทคนิคเชียงใหม่", "ChiangMai Technical College"],
    ".cmu.ac.th": ["www.cmu.ac.th", "Chiang Mai University"],
    ".cmvc.ac.th": ["Chiang Mai Vocational College"],
    ".cpc.ac.th": ["Rajamangala University of Technology Tawan-ok"],
    ".cpu.ac.th": ["Chaopraya University "],
    ".cra.ac.th": ["ราชวิทยาลัยจุฬาภรณ์", "chulabhorn royal academy"],
    ".damrong.ac.th": ["โรงเรียนดำรงราษฎร์สงเคราะห์ ", "Damrongratsongkroh"],
    ".debsirin.ac.th": ["เทพศิรินทร์", "Debsirin"],
    ".dkttc.ac.th": ["วิทยาลัยเทคนิคดอกคำใต้", "DOKKHAMTAI TECHNICAL COLLEGE"],
    ".dru.ac.th": ["มหาวิทยาลัยราชภัฎธนบุรี", "Dhonburi Rajabhat University"],
    ".dusit.ac.th": ["Suan Dusit Rajabhat University"],
    ".e-tech.ac.th": [
        "วิทยาลัยเทคโนโลยีภาคตะวันออก (อี.เทค)",
        "Eastern Technological College (E.TECH)",
    ],
    ".eau.ac.th": ["Eastern Asia University"],
    ".eis.ac.th": [
        "Ekamai International School",
        "Ekamai International School",
    ],
    ".ftu.ac.th": ["Fatoni University"],
    ".hcu.ac.th": ["Huachiew Chalermprakiet University"],
    ".htc.ac.th": ["วิทยาลัยเทคนิคหาดใหญ่", "Hatyai Technical College"],
    ".hu.ac.th": ["Hatyai University"],
    ".huaiyot.ac.th": [
        "วิทยาลัยการอาชีพห้วยยอด",
        "Huai Yot Industrial and Community Education College",
    ],
    ".hwp.ac.th": ["หอวัง ปทุมธานี", "Horwang Pathumthani"],
    ".irpct.ac.th": ["วิทยาลัยเทคโนโลยีไออาร์พีซี", "IRPC Technology College"],
    ".isb.ac.th": ["International School Thailand"],
    ".ives3.ac.th": [
        "สถาบันการอาชีวศึกษาภาคใต้ 3",
        "INSTITUTE OF VOCATIONAL EDUCATION : SOUTHERN REGION 3",
    ],
    ".jv.ac.th": ["โรงเรียนจักราชวิทยา", "ChakkaratWittaya School"],
    ".kbu.ac.th": ["Kasem Bundit University"],
    ".kitti.ac.th": ["Kitti Business Administration Technological College"],
    ".kktech.ac.th": ["วิทยาลัยเทคนิคขอนแก่น", "Khon Kaen Technical College"],
    ".kku.ac.th": ["Khon Kaen University"],
    ".kmutnb.ac.th": ["King Mongkut's University of Technology North Bangkok"],
    ".sit.kmutt.ac.th": [
        "School of Information Technology, King Mongkut’s University of Technology Thonburi",
        "King Mongkut’s University of Technology Thonburi",
        "KMUTT",
    ],
    ".kpru.ac.th": [
        "\ufeffKamphaeng Phet Rajabhat University",
        "Kamphaeng Phet Rajabhat University, Mae Sot Campus",
    ],
    ".krirk.ac.th": ["Krirk University"],
    ".kru.ac.th": [
        "โรงเรียนสาธิตมหาวิทยาลัยราชภัฏกาญจนบุรี",
        "the demonstration school of kanchanaburi rajabhat university",
    ],
    ".ksu.ac.th": ["มหาวิทยาลัยกาฬสินธุ์", "Kalasin University"],
    ".ku.ac.th": ["Kasetsart University"],
    ".kvis.ac.th": ["โรงเรียนกำเนิดวิทย์", "Kamnoetvidya Science Academy"],
    ".lampangvc.ac.th": ["Lampang Vocational College   "],
    ".lannaist.ac.th": ["Lanna International School"],
    ".lcat.ac.th": ["Lamphun College of Agriculture and Technology"],
    ".lcct.ac.th": ["Lampang College of Commerce and Technology"],
    ".lic.ac.th": [
        "วิทยาลัยการอาชีพลอง",
        "Long Industrial and Community Education College",
    ],
    ".lru.ac.th": ["Loei Rajabhat University", "Loei Rajabhat University"],
    ".mbu.ac.th": ["Mahamakut Buddhist University"],
    ".mcu.ac.th": ["Mahachulalongkorn Buddhist University"],
    ".mfu.ac.th": ["Mae Fah Luang University "],
    ".msu.ac.th": ["Mahasarakham University"],
    ".mut.ac.th": ["Mahanakorn University of Technology"],
    ".mwit.ac.th": [
        "Mahidol Wittayanusorn (Public Organization)",
        "Mahidol Wittayanusorn",
        "MWIT",
        "โรงเรียนมหิดลวิทยานุสรณ์",
    ],
    ".newton.ac.th": ["Newton School, Bangkok"],
    ".nida.ac.th": ["National Institute of Development Administration"],
    ".nmu.ac.th": ["มหาวิทยาลัยนวมินทราธิราช", "navamindradhiraj university"],
    ".northbkk.ac.th": ["North Bangkok University"],
    ".northcm.ac.th": ["North - Chiang Mai University"],
    ".webmail.npru.ac.th": [
        " มหาวิทยาลัยราชภัฏนครปฐม",
        "Nakhon Pathom Rajabhat University",
    ],
    ".nrru.ac.th": ["Nakhon Ratchasima Rajabhat University"],
    ".nsru.ac.th": ["Nakhon Sawan Rajabhat University"],
    ".gs.nts.ac.th": ["โรงเรียนนราธิวาส", "Narathiwat School"],
    ".onehope.ac.th": ["One Hope International School Mae Sai"],
    ".panyarathighschool.ac.th": ["Panyarat High School"],
    ".patana.ac.th": ["Bangkok Patana School"],
    ".payap.ac.th": ["Payap University Chaiang Mai"],
    ".mail.pbru.ac.th": [
        "มหาวิทยาลัยราชภัฏเพชรบุรี",
        "Phetchaburi Rajabhat University",
    ],
    ".pccchon.ac.th": [
        "โรงเรียนวิทยาศาสตร์จุฬาภรณราชวิทยาลัยชลบุรี",
        "Princess Chulabhorn's College Chon Buri",
    ],
    ".pccp.ac.th": [
        "โรงเรียนวิทยาศาสตร์จุฬาภรณราชวิทยาลัย ปทุมธานี",
        "Princess Chulabhorn Science High School PathumThaNi",
    ],
    ".pccst.ac.th": [
        "โรงเรียนวิทยาศาสตร์จุฬาภรณราชวิทยาลัย สตูล",
        "Princess Chulabhorn Science High School Satun",
    ],
    ".pcru.ac.th": ["Phetchabun Rajabhat University"],
    ".phothitham.ac.th": [
        "Phothithammasuwat School",
        "Phothithammasuwat School",
    ],
    ".phuketthaihua.ac.th": [
        "โรงเรียนภูเก็ตไทยหัวอาเซียนวิทยา",
        "Phuketthaihua Asean Wittaya School",
    ],
    ".phukhieo.ac.th": ["โรงเรียนภูเขียว", "Phukhieo School"],
    ".pim.ac.th": ["Panyapiwat Institute of Management"],
    ".piriyalai.ac.th": ["พิริยาลัยจังหวัดแพร่", "Piriyalai School Phrae"],
    ".pit365.pit.ac.th": [
        "สถาบันเทคโนโลยีปทุมวัน",
        " Pathumwan Institute of Technology",
    ],
    ".pkw.ac.th": ["โรงเรียนภูเก็ตวิทยาลัย", "Phuket Wittayalai School"],
    ".pmtc.ac.th": ["Phibunmangsaharn Technical College"],
    ".pnp.ac.th": [
        "วิทยาลัยการอาชีพพนมไพร",
        "Phanomphrai Industrial and Community Education College",
    ],
    ".pnru.ac.th": ["Phranakhon Rajabhat University"],
    ".pnu.ac.th": [
        "มหาวิทยาลัยนราธิวาสราชนครินทร์",
        "Princess of Naradhiwas University",
    ],
    ".pomnaka.ac.th": ["โรงเรียนป้อมนาคราชสวาทยานนท์"],
    ".pongsawadi.ac.th": [
        "วิทยาลัยเทคโนโลยีพงษ์สวัสดิ์",
        "Pongsawadi Technological College",
    ],
    ".ps.ac.th": ["Potisarnpittayakorn School", "Potisarnpittayakorn School"],
    ".psru.ac.th": ["Pibulsongkram Rajabhat university"],
    ".psuwit.ac.th": ["มอ. วิทยานุสรณ์", "PSU Wittayanusorn"],
    ".ptu.ac.th": ["Pathumthani University"],
    ".rayongwit.ac.th": ["โรงเรียนระยองวิทยาคม", "Rayongwittayakom School"],
    ".rb.ac.th": ["โรงเรียนวัดราชบพิธ", "Wat Rajabopit School"],
    ".reru.ac.th": ["Roi Et Rajabhat University"],
    ".mail.rmutk.ac.th": ["Rajamangala University of Technology Krungthep"],
    ".rmutp.ac.th": ["Rajamangala University of Technology, Phra Nakhon"],
    ".outlook.rmutr.ac.th": [
        "มหาวิทยาลัยเทคโนโลยีราชมงคลรัตนโกสินทร์",
        "Rajamangala University of Technology Rattanakosin",
    ],
    ".rmutsb.ac.th": [
        "rajamangala university of technology suvarnabhumi",
        "rajamangala university of technology suvarnabhumi",
    ],
    ".rmutsv.ac.th": ["Rajamangala University of Tecnology Srivijaya"],
    ".mail.rmutt.ac.th": [
        "Rajamangala University of Technology Thanyaburi",
        "RMUTT",
        "มหาวิทยาลัยเทคโนโลยีราชมงคลธัญบุรี",
    ],
    ".rmutt.ac.th": [
        "มหาวิทยาลัยเทคโนโลยีราชมงคลธัญบุรี",
        "Rajamangala University of Technology Thanyaburi ",
    ],
    ".roong-aroon.ac.th": ["Roong Aroon School", "โรงเรียนรุ่งอรุณ"],
    ".rpca.ac.th": ["โรงเรียนนายร้อยตำรวจ", "Royal Police Cadet Academy"],
    ".rpu.ac.th": ["มหาวิทยาลัยราชพฤกษ์", "Rajapruk University"],
    ".mail.rru.ac.th": [
        "มหาวิทยาลัยราชภัฏราชนครินทร์",
        "Rajabhat Rajanagarindra University",
    ],
    ".rsu.ac.th": ["Rangsit University"],
    ".rumail.ru.ac.th": ["Ramkhamhaeng University"],
    ".ru.ac.th": ["Ramkhamhaeng University"],
    ".saard.ac.th": ["Saard Praderm Wittaya"],
    ".satitpatumwan.ac.th": [
        "Patumwan Demonstration School",
        "Patumwan Demonstration School",
    ],
    ".satriwit.ac.th": ["Satriwithaya School", "satriwit.ac.th"],
    ".satriwit3.ac.th": [
        "Nawamintrachinutit Satriwitthaya3 Putthamonton School"
    ],
    ".sau.ac.th": ["South-East Asia University"],
    ".student.sd.ac.th": ["เซนต์ดอมินิก", "SaintDominic School"],
    ".sf.ac.th": ["เซนต์ฟรังซีสซาเวียร์คอนแวนต์"],
    ".sg.ac.th": [
        "Saint Gabriel's College School",
        "Saint Gabriel's College School",
    ],
    ".siamtech.ac.th": [
        "วิทยาลัยเทคโนโลยีสยาม (สยามเทค)",
        "Siam Technological College (Siamtech)",
    ],
    ".siamtechno.ac.th": [
        " วิทยาลัยเทคโนโลยีสยาม",
        "Siam Technology College (STC)",
    ],
    ".stu.sibs.ac.th": [
        "Satit International Bilingual School of Rangsit University Chiang Mai (SIBS)"
    ],
    ".sirin.ac.th": ["โรงเรียนสิรินธร", "Sirindhorn School"],
    ".sjmis.ac.th": ["Saint John Mary International School"],
    ".student.sk.ac.th": ["สวนกุหลาบวิทยาลัย", "Suankularb Wittayalai School"],
    ".snru.ac.th": ["Sakon Nakhon Rajabhat University"],
    ".song.ac.th": [
        "วิทยาลัยการอาชีพสอง",
        "Song Industrial and Community Education College",
    ],
    ".southeast.ac.th": ["วิทยาลัยเซาธ์อีสท์บางกอก", "Southeast Bangkok College"],
    ".spsm.ac.th": [
        "โรงเรียนสาธิต มศว ประสานมิตร (ฝ่ายมัธยม)",
        "Prasarnmit Demonstration School (Secondary)",
    ],
    ".spu.ac.th": ["Sripatum University"],
    ".sriyapai.ac.th": ["โรงเรียนศรียาภัย", "SriyapaiSchool"],
    ".srru.ac.th": ["มหาวิทยาลัยราชภัฏสุรินทร์"],
    ".sskru.ac.th": ["Sisaket Rajabhat University"],
    ".ssru.ac.th": ["Suan Sunandha Rajabhat University"],
    ".stjohn.ac.th": ["St. John's University"],
    ".stou.ac.th": ["Sukhothai Thammathirat Open University"],
    ".sut.ac.th": ["Suranaree University of Technology"],
    ".swu.ac.th": ["Srinakharinwirot University"],
    ".taweethapisek.ac.th": ["โรงเรียนทวีธาภิเศก", "Taweethapisek School"],
    ".tbs.ac.th": ["ธัญบุรี", "thanyaburi school"],
    ".tni.ac.th": [
        "สถาบันเทคโนโลยีไทย-ญี่ปุ่น",
        "Thai-Nichi Institute of Technology",
    ],
    ".student.triamudom.ac.th": [
        "โรงเรียนเตรียมอุดมศึกษา",
        "Triamudom Suksà School",
    ],
    ".tu.ac.th": ["Thammasat University"],
    ".ms.tup.ac.th": [
        "โรงเรียนเตรียมอุดมศึกษาพัฒนาการ",
        "Triam Udom Suksa Pattanakarn School",
    ],
    ".ubru.ac.th": [
        "มหาวิทยาลัยราชภัฏอุบลราชธานี",
        "Ubon Ratchathani Rajabhat University, Thailand",
    ],
    ".ubu.ac.th": ["Ubonratchathani University"],
    ".udontech.ac.th": ["วิทยาลัยเทคนิคอุดรธานี", "Udon Thani Technical College"],
    ".365.udru.ac.th": [
        "มหาวิทยาลัยราชภัฏอุดรธานี",
        "UDON THANI RAJABHAT UNIVERSITY",
    ],
    ".udru.ac.th": ["UDON THANI RAJABHAT UNIVERSITY", "มหาวิทยาลัยราชภัฏอุดรธานี"],
    ".uru.ac.th": ["Uttaradit Rajabhat University"],
    ".utc.ac.th": [
        "วิทยาลัยเทคนิคอุบลราชธานี",
        "Ubon Ratchathani Technical College",
    ],
    ".utcc.ac.th": ["University of the Thai Chamber of Commerce"],
    ".uttvc.ac.th": ["วิทยาลัยอาชีวศึกษาอุตรดิตถ์", "Uttaradit Vocational College"],
    ".varee.ac.th": ["Varee Chiang Mai International School"],
    ".vistec.ac.th": ["Vidyasirimedhi Institute of Science and Technology"],
    ".visut.ac.th": ["วิสุทธรังษี", "Visuttharangsi"],
    ".vru.ac.th": [
        "มหาวิทยาลัยราชภัฏวไลยอลงกรณ์ ในพระบรมราชูปถัมภ์",
        "Valaya Alongkorn Rajabhat University under the Royal Patronage",
    ],
    ".vu.ac.th": ["Vongchavalitkul University"],
    ".webster.ac.th": ["Webster University, Thailand"],
    ".western.ac.th": ["มหาวิทยาลัยเวสเทิร์น", "Western University"],
    ".wmk.ac.th": ["watmongkol kothawas school"],
    ".wmws.ac.th": ["เวียงมอกวิทยา", "weingmok wittaya school"],
    ".wu.ac.th": ["Walailak University"],
    ".ycpschool.ac.th": [
        "โรงเรียนยางชุมน้อยพิทยาคม",
        "Yangchumnoi Pittayakom school",
    ],
    ".yingyuad.ac.th": ["Yingyuadpittayanukul School"],
    ".yingyuadpit.ac.th": ["Yingyuadpittayanukul School"],
    ".yru.ac.th": ["Yala Rajabhat University", "Yala Rajabhat University"],
    ".ytc.ac.th": ["yala technical college", "yala technical college"],
    ".yupparaj.ac.th": ["ยุพราชวิทยาลัย", "Yupparaj wittayalai"],
    ".shrewsbury.in.th": ["Shrewsbury International School Bangkok"],
    ".ku.th": ["Kasetsart University"],
    ".dtmik.tj": [
        "Innovation and Technology Management Institute in Kulob City"
    ],
    ".hgu.tj": [
        "Худжандский государственный университет",
        "Khujand State University",
    ],
    ".polytech.tj": [
        "Донишкадаи политехникии Донишгоҳи техникии Тоҷикистон ба номи академик М.Осимӣ дар ш. Хуҷанд",
        "Khujand Polytechnic Institute of Tajik Technical University",
    ],
    ".tajagroun.tj": ["Tajik Agrarian University"],
    ".tajmedun.tj": [
        "Таджикский государственный медицинский университет имени Абуали ибни Сино",
        "Avicenna Tajik State Medical University",
    ],
    ".tarena.tj": ["Tajik National University"],
    ".tnu.tj": ["Донишгоҳи миллии Тоҷикистон", "Tajik National University"],
    ".ttu.tj": [
        "Донишгоҳи техникии Тоҷикистон  ба номи академик М.С.Осимӣ",
        "Tajik Technical University  named after academic M.S.Osimi",
    ],
    ".itit.edu.tm": [
        "Institute of Telecommunications and Informatics of Turkmenistan"
    ],
    ".edu.tm": ["International Turkmen Turkish University"],
    ".SESAME.com.tn": [
        "SESAME : École supérieure des sciences appliquées et de management "
    ],
    ".episousse.com.tn": [
        "EPI Sousse : Ecole Pluridisciplinaire Internationale",
        " ",
    ],
    ".enis.tn": ["National Engineering School of Sfax"],
    ".iit.ens.tn": [
        "Institut International de Technologie",
        "North American Private University ",
    ],
    ".unat.ens.tn": ["University of Aviation and Technology"],
    ".ensi-uma.tn": ["National School of Computer Science"],
    ".esen.tn": [
        "\ufeffESEN Manouba, Ecole Supérieure d'Economie Numérique",
        "Higher School of Digital Economy, Tunisia",
    ],
    ".esgitech.tn": [
        "L’École Supérieure de Génie Informatique et de Technologie, ESGI-TECH, Tunisia"
    ],
    ".esprim.tn": [
        "Ecole Supérieure Privée d'Ingénieurs de Monastir - Esprim",
        "Private Higher School of Engineers of Monastir - Esprim",
    ],
    ".esprit.tn": ["Ecole Superieure Privee d'Ingenierie et de Technologies"],
    ".fsegs.tn": [
        "Faculté des Sciences Économiques et de Gestion de Sfax",
        "Faculty of Economics and Management of Sfax",
    ],
    ".horizon-tech.tn": ["Horizon School of Digital Technologies"],
    ".iit.tn": ["Institut International de Technologie, Tunis"],
    ".imset.tn": [
        "IMSET",
        "institut maghrébin des sciences économiques et de technologie",
    ],
    ".infoplus.tn": ["Centre de formation privé Infoplus"],
    ".ipsas.tn": [
        "Institut Polytechnique privé des Sciences Avancées de Sfax"
    ],
    ".isetcom.tn": [
        "Institut supérieur des études technologiques en communications de Tunis (Iset'com)"
    ],
    ".isimg.tn": [
        "Institut Supérieur d'Informatique et de Multimédia de Gabès"
    ],
    ".itbs.tn": ["IT Business School, Tunisia"],
    ".iteam-univ.tn": ["ITeam University"],
    ".medtech.tn": ["Mediterranean Institute of Technology"],
    ".pi.tn": ["Ecole Polytechnique Internationale Privée de Tunis "],
    ".polytechnicien.tn": ["Polytechnique Sousse"],
    ".polytecsousse.tn": ["Polytechnique Sousse"],
    ".pristini-international.tn": ["Pristini School of AI"],
    ".beja.r-iset.tn": [
        "Institut Supérieur des Etudes Technologiques de Béja",
        "Higher Institute of Technological Studies Beja",
    ],
    ".bizerte.r-iset.tn": [
        "Institut Supérieur Des Etudes Technologiques De Bizerte",
        "Higher Institute Of Technological Studies Of Bizerte",
    ],
    ".charguia.r-iset.tn": [
        "institut supérieur des études technologiques de charguia"
    ],
    ".gafsa.r-iset.tn": [
        "institut supérieur des études technologiques de Gafsa"
    ],
    ".kelibia.r-iset.tn": [
        "Institut Supérieur des Etudes Technologiques de Kélibia",
        "Higher Institute of Technological Studies of Kélibia",
    ],
    ".mahdia.r-iset.tn": [
        "Institut Supérieur des Etudes Technologiques de Mahdia",
        "Higher Institute of Technological Studies of Mahdia",
    ],
    ".nabeul.r-iset.tn": [
        "Institut Supérieur d'Etudes Technologiques de Nabeul",
        "Higher Institute of Technological Studies of Nabeul",
    ],
    ".rades.r-iset.tn": [
        "ISET Rades",
        " Higher Institute of Technological Studies of Rades",
    ],
    ".seliana.r-iset.tn": [
        "Institut Supérieur d'Etudes Technologiques de Seliana",
        "Higher Institute of Technological Studies of Seliana",
    ],
    ".sfax.r-iset.tn": [
        "\ufeffInstituts Supérieurs des Etudes Technologiques de Sfax"
    ],
    ".sousse.r-iset.tn": [
        "Institut Supérieur des Etudes Technologiques de Sousse"
    ],
    ".tozeur.r-iset.tn": [
        "Institut Supérieur des Etudes Technologiques de Tozeur",
        "Higher Institute of Technological Studies of Tozeur",
    ],
    ".zaghouan.r-iset.tn": [
        "iset Zaghouan (Institut Supérieur des Etudes Technologiques de Zaghouan)",
        "iset Zaghouan (Higher Institute of Technological Studies of Zaghouan)",
    ],
    ".crns.rnrt.tn": [
        "Centre de Recherche en Numériques de Sfax",
        "Digital Research Center of Sfax",
    ],
    ".disfm.rnu.tn": ["Instituts Supérieurs de Formation des Maîtres"],
    ".enicarthage.rnu.tn": [
        "École Nationale d'ingénieurs de Carthage",
        "National Engineering School of Carthage",
    ],
    ".enis.rnu.tn": ["National Engineering School of Sfax"],
    ".enit.rnu.tn": ["National Engineering School of Tunis"],
    ".fsg.rnu.tn": ["Faculty of Sciences of Gabes"],
    ".fsm.rnu.tn": [
        "Faculté des sciences de Monastir",
        "Faculty of sciences of Monastir",
    ],
    ".fss.rnu.tn": ["Faculté des Sciences de Sfax"],
    ".insat.rnu.tn": ["national institute of applied science and technology"],
    ".isbm.rnu.tn": [
        "Institut superieur de biotechnologie Monastir",
        "High institute of biotechnology of Monastir",
    ],
    ".iseahz.rnu.tn": [
        "Institut Supérieur des Etudes Appliquées en Humanités de Zaghouan - ISEAHZ",
        "Higher Institute of Applied Studies in Humanities of Zaghouan",
    ],
    ".isetch.rnu.tn": [
        "Institut Supérieur des études Technologiques",
        "higher Institute of Technological Studies of Nabeul",
        ".group",
        "http://www.isetn.rnu.tn/fra/departements/TI/5/technologie-de-l-informatique",
        "http://www.cck.rnu.tn/newcck/index.php",
    ],
    ".isetj.rnu.tn": [
        "Instituts Supérieurs des Etudes Technologiques de Jendouba"
    ],
    ".isetjb.rnu.tn": [
        "Institut Supérieur des Etudes Technologiques de Djerba",
        "Higher Institute of Technological Studies of Djerba",
    ],
    ".isetkl.rnu.tn": [
        "Institut supérieur des études technologiques de Kélibia",
        "Higher Institute of technology studies of kélibia",
    ],
    ".isetn.rnu.tn": [
        "Institut Supérieur des Etudes Technologiques de Nabeul",
        "Higher Institute of Technological Studies of Nabeul",
    ],
    ".isetr.rnu.tn": ["Instituts Supérieurs des Etudes Technologiques"],
    ".isetso.rnu.tn": [
        "Instituts Supérieurs des Etudes Technologiques de Sousse"
    ],
    ".isg.rnu.tn": ["Institut Supérieur de Gestion de Tunis"],
    ".isim.rnu.tn": [
        "Institut Supérieur de l'Informatique de Médenine (ISIMed)",
        "Higher Institute of Informatics of Medenine",
    ],
    ".isimsf.rnu.tn": [
        "Institut Supérieur d'Informatique et du Multimédia de Sfax"
    ],
    ".issatso.rnu.tn": [
        "Higher Institute of Applied Sciences and Technology of Sousse"
    ],
    ".uc.rnu.tn": ["Université du Centre, Sousse"],
    ".ugaf.rnu.tn": ["Université de Gafsa"],
    ".uj.rnu.tn": ["Université de Jendouba"],
    ".um.rnu.tn": ["Université de Monastir"],
    ".uma.rnu.tn": ["Université de la Manouba"],
    ".univ-k.rnu.tn": ["Université de Kairouan"],
    ".univgb.rnu.tn": ["Université de Gabès"],
    ".uss.rnu.tn": ["Université de Sfax"],
    ".utm.rnu.tn": ["Université de Tunis El Manar"],
    ".utunis.rnu.tn": ["Université de Tunis"],
    ".uvt.rnu.tn": [
        "Université de 7 Novembre à Carthage",
        "Université Virtuelle de Tunis",
    ],
    ".uz.rnu.tn": ["Université Ez-Zitouna"],
    ".supcom.tn": ["Ecole Supérieure des Communications de Tunis (Sup'Com)"],
    ".suptech.tn": ["Private Higher School of Technology and Management"],
    ".tarbia.tn": [
        "معهد ابو القاسم الشابي بالشابة",
        "abou kacem chebbi school mahdia",
    ],
    ".tek-up.tn": [
        "Tek-Up private higher school of technologies and ingineering"
    ],
    ".ESAMT.u-carthage.tn": [
        "ECOLE SUPÉRIEURE D’AGRICULTURE DE MATEUR - ESAMT -UNIVERSITÉ DE CARTHAGE",
        "HIGHER SCHOOL OF AGRICULTURE - UNIVERSITY OF CARTHAGE",
    ],
    ".enicar.u-carthage.tn": [
        "École Nationale d'ingénieurs de Carthage",
        "National Engineering School of Carthage",
    ],
    ".ensta.u-carthage.tn": [
        "Ecole Nationale des Sciences et Technologies Avancées de Borj Cédria - ENSTAB"
    ],
    ".fsb.u-carthage.tn": [
        "Faculté des Sciences de Bizerte - Université de Carthage",
        "Faculty of Sciences of Bizerte  - University of Carthage",
    ],
    ".fsegn.u-carthage.tn": [
        "fseg Nabeul",
        "Faculty of Economics and Management of Nabeul",
    ],
    ".insat.u-carthage.tn": [
        "institut national des sciences appliquées et de technologie"
    ],
    ".islt.u-carthage.tn": [
        "Institut supérieur des langues de Tunis",
        "Higher Institute of Languages of Tunis",
    ],
    ".issatm.u-carthage.tn": [
        "institut supérieur de sciences appliquées et de technologies de mateur",
        "higher institute of applied sciences and technologies",
    ],
    ".istic.u-carthage.tn": [
        "The Higher Institute of Information Technologies and Communications",
        "The Higher Institute of Information Technologies and Communications",
    ],
    ".supcom.u-carthage.tn": [
        "Ecole supérieure des communications de Tunis",
        "Higher School of Communication of Tunis",
    ],
    ".u-gabes.tn": [
        "Institut Superieur des Sciences Appliquees et de Technologie de Gabes"
    ],
    ".fsgf.u-gafsa.tn": [
        "Faculté des Sciences de Gafsa",
        "Faculty of Sciences of Gafsa",
    ],
    ".isikef.u-jendouba.tn": [
        "Institut Supérieur de l'Informatique du Kef",
        "Higher Institute of Computer Science of Kef",
    ],
    ".fstsbz.u-kairouan.tn": [
        "Faculty of Science and Technology in Sidi Bouzid"
    ],
    ".isigk.u-kairouan.tn": [
        "Institut Supérieur d'Informatique et de Gestion de Kairouan",
        "Higher Institute of Informatics and Management of Kairouan",
    ],
    ".issatkas.u-kairouan.tn": [
        "Institut Supérieur des Sciences Appliquées et de Technologie de Kasserine",
        "Higher Institute of Applied Science and Technology Kasserine",
    ],
    ".isamm.u-manouba.tn": [
        "institut superieur d'art de multimedia de manouba",
        "ISAMM",
    ],
    ".enim.u-monastir.tn": [
        "ENIM - Ecole Nationale d'Ingénieurs de Monastir",
        "National School of Engineers of Monastir",
    ],
    ".fsegma.u-monastir.tn": [
        "Faculté des Sciences Economiques et Gestion de Mahdia",
        "faculty of economics and management of mahdia",
    ],
    ".fsm.u-monastir.tn": [
        "Faculté des sciences Monastir FSM",
        "Monastir sciences university",
    ],
    ".ipeim.u-monastir.tn": [
        "Institut préparatoire aux études d'ingénieur de Monastir",
        "Monastir Preparatory Engineering Institute",
    ],
    ".isbm.u-monastir.tn": [
        "Institut superieur de biotechnologie Monastir",
        "High institute of biotechnology of Monastir",
    ],
    ".iseahm.u-monastir.tn": [
        "Institut Supérieur des Sciences Appliquées et de Technologies de Mahdia"
    ],
    ".isima.u-monastir.tn": [
        "Higher Institute of Computer Science, Mahdia, Tunisia (ISI Mahdia)"
    ],
    ".isimm.u-monastir.tn": [
        "L'Institut Supérieur d'Informatique et de Mathématiques de l’Université de Monastir",
        "Higher Institute of Computer Science and Mathematics of Monastir",
    ],
    ".enetcom.u-sfax.tn": [
        "المدرسة الوطنية للإلكترونيك والإتصالات بصفاقس",
        "National School of Electronics and Telecoms of Sfax",
    ],
    ".escs.u-sfax.tn": ["école supérieure de commerce de Sfax"],
    ".fsegs.u-sfax.tn": [
        "Faculté des Sciences Economiques et de Gestion de Sfax",
        "Faculty of Economics and Management of Sfax",
    ],
    ".fss.u-sfax.tn": ["Faculte de Science de Sfax"],
    ".ipeis.u-sfax.tn": [
        "Institut Préparatoire aux Etudes d'Ingénieur de Sfax",
        "Sfax Preparatory Engineering Institute",
    ],
    ".isgis.u-sfax.tn": ["institut supérieur de gestion industrielle de sfax"],
    ".isimsf.u-sfax.tn": [
        "Institut Supérieur d'Informatique et de Multimédia de Sfax"
    ],
    ".eniso.u-sousse.tn": ["Ecole Nationale d'Ingénieurs de Sousse"],
    ".essths.u-sousse.tn": [
        "HIGHER SCHOOL OF SCIENCE AND TECHNOLOGY OF HAMMAM SOUSSE"
    ],
    ".isgs.u-sousse.tn": [
        "Institut supérieur de gestion de Sousse",
        "Sousse Higher Institute of Management",
    ],
    ".isitc.u-sousse.tn": [
        "L'Institut Superieur d'Informatique et des Techniques de Communication de Hammam Sousse"
    ],
    ".issatso.u-sousse.tn": [
        "Higher Institute of Applied Sciences and Technology of Sousse"
    ],
    ".ensit.u-tunis.tn": ["Higher National Engineering School of Tunis "],
    ".essect.u-tunis.tn": [
        "École Supérieure des Sciences Economiques et Commerciales de Tunis"
    ],
    ".fshst.u-tunis.tn": [
        "Faculté des Sciences Humaines et Sociales de Tunis",
        "Faculty of Humanities and Social Sciences of Tunis",
    ],
    ".isg.u-tunis.tn": ["Institut Supérieur de Gestion"],
    ".tbs.u-tunis.tn": ["Tunis Business School"],
    ".enib.ucar.tn": [
        "Ecole Nationale d’Ingénieurs de Bizerte",
        "The National Engineering School of Bizerte",
    ],
    ".enicar.ucar.tn": [
        "Ecole nationale d'ingénieur de carthage",
        "National Engineering school of Carthage",
    ],
    ".enstab.ucar.tn": [
        "Ecole Nationale des Sciences et Technologies Avancées de Borj Cédria"
    ],
    ".ept.ucar.tn": [
        "Ècole polytechnique de tunisie",
        "Tunisia Polytechnic School",
    ],
    ".fsb.ucar.tn": [
        "Faculté des Sciences de Bizerte",
        "Faculty of Sciences of Bizerte",
    ],
    ".fsegn.ucar.tn": [
        "Faculté des Sciences Economiques et de Gestion de Nabeul, Université de carthage Tunisie",
        "Faculty of Economics and Management of Nabeul, University of Carthage Tunisia",
    ],
    ".ihec.ucar.tn": ["Institut des hautes études commerciales de carthage"],
    ".insat.ucar.tn": [
        "institut national des sciences appliquées et de technologie",
        "insat",
    ],
    ".isepbg.ucar.tn": [
        "Institut Supérieur des Etudes Préparatoires en Biologie et Geologie La Soukra"
    ],
    ".isgb.ucar.tn": [
        "institut supérieur de gestion de bizerte",
        "Higher Institute of Management Bizerte",
    ],
    ".islt.ucar.tn": [
        "Institut Supérieur des Langues de Tunis",
        "Higher Institute of Languages \u200b\u200bof Tunis",
    ],
    ".istic.ucar.tn": [
        "Institut Supérieur des Technologies de l’Information et de la Communication",
        "The Higher Institute of Information Technologies and Communication",
    ],
    ".uit.tn": ["Université Internationale de Tunis - UIT"],
    ".isamm.uma.tn": [
        "Institut Supérieur des Arts Multimédia de la Manouba - ISAMM "
    ],
    ".myu.universitecentrale.tn": ["Université Centrale"],
    ".enetcom.usf.tn": [
        "Ecole nationale d'Electronique et des Télécommunications de Sfax"
    ],
    ".fsegs.usf.tn": [
        "University of Sfax, Tunisia",
        "Faculty of Economic Sciences and Management, University of Sfax, Tunisia",
    ],
    ".isims.usf.tn": [
        "Institut Supérieur d'Informatique et de Multimédia de Sfax",
        "Higher Institute of Computer Science and Multimedia of Sfax",
        "www.isimsf.rnu.tn",
        "https://isimsf.rnu.tn/fra/s174/pages/59/licences",
    ],
    ".etudiant-enit.utm.tn": [
        "National Engineering School of Tunis",
        "Students Email Domain",
    ],
    ".etudiant-fsegt.utm.tn": [
        "faculté des sciences economiques et de gestion de tunis"
    ],
    ".etudiant-fst.utm.tn": ["Faculty of sciences of Tunis"],
    ".etudiant-isi.utm.tn": ["Institut Supérieur d'informatique"],
    ".utm.tn": ["Université de Tunis El Manar"],
    ".uvt.tn": [
        "Université Virtuelle de Tunis",
        "Virtual University Of Tunis",
    ],
    ".student.42kocaeli.com.tr": ["42 Kocaeli"],
    ".29mayis.edu.tr": [
        "İstanbul 29 Mayıs Üniversitesi",
        "İstanbul 29 Mayıs University",
    ],
    ".acibadem.edu.tr": ["Acıbadem Üniversitesi", "Acıbadem University"],
    ".adanabtu.edu.tr": [
        "Adana Bilim ve Teknoloji Üniversitesi",
        "Adana Science and Technology University",
    ],
    ".student.adiguzel.edu.tr": [
        "\ufeffTC Ataşehir Adıgüzel Vocational School"
    ],
    ".adiguzel.edu.tr": ["Adıgüzel Meslek Yüksekokulu"],
    ".adiyaman.edu.tr": ["Adıyaman Üniversitesi", "Adıyaman University"],
    ".adu.edu.tr": [
        "Adnan Menderes Üniversitesi",
        "Adnan Menderes University",
    ],
    ".afsu.edu.tr": [
        "Afyon Sağlık Bilimleri Üniversitesi",
        "Afyonkarahisar Health Sciences University",
    ],
    ".agri.edu.tr": [
        "Ağrı İbrahim Çeçen Üniversitesi",
        "Ibrahim Çeçen University of Ağrı",
    ],
    ".agu.edu.tr": ["Abdullah Gül Üniversitesi", "Abdullah Gül University"],
    ".ahievran.edu.tr": ["Ahi Evran Üniversitesi", "Ahi Evran University"],
    ".akev.edu.tr": ["Antalya Akev Üniversitesi", "Antalya Akev University"],
    ".aksaray.edu.tr": ["Aksaray Üniversitesi", "Aksaray University"],
    ".aku.edu.tr": [
        "Afyon Kocatepe Üniversitesi",
        "Afyon Kocatepe University",
    ],
    ".akun.edu.tr": [
        "AKDENIZ KARPAZ UNIVERSITESI",
        "UNIVERSITY OF MEDITERRENEAN KARPASIA",
    ],
    ".alanya.edu.tr": [
        "Alanya Alaaddin Keykubat Üniversitesi",
        "Alanya Alaaddin Keykubat University",
    ],
    ".alanyauniversity.edu.tr": ["Alanya Üniversitesi", "Alanya University"],
    ".alparslan.edu.tr": [
        "Muş Alparslan Üniversitesi",
        "Muş Alparslan University",
    ],
    ".amasya.edu.tr": ["T.C. Amasya Üniversitesi", "T.C. Amasya University"],
    ".anadolu.edu.tr": ["Anadolu Üniversitesi", "Anadolu University"],
    ".anka.edu.tr": [
        "ANKA Teknoloji Üniversitesi",
        "ANKA University of Technology",
    ],
    ".ankara.edu.tr": ["Ankara Üniversitesi", "Ankara University"],
    ".ankarabilim.edu.tr": [
        "Ankara Bilim Üniversitesi",
        "Ankara Science University",
    ],
    ".ankaramedipol.edu.tr": ["Ankara Medipol University"],
    ".antalya.edu.tr": ["Antalya University"],
    ".aoa.edu.tr": ["Atatürk Öğretmen Akademisi", "Atatürk Teacher Academy"],
    ".ardahan.edu.tr": ["Ardahan Üniversitesi", "Ardahan University"],
    ".arel.edu.tr": ["İstanbul Arel Üniversitesi", "Istanbul Arel University"],
    ".artuklu.edu.tr": [
        "Mardin Artuklu Üniversitesi",
        "Mardin Artuklu University",
    ],
    ".artvin.edu.tr": ["Artvin Çoruh Üniversitesi", "Artvin Çoruh University"],
    ".asbu.edu.tr": [
        "Ankara Sosyal Bilimler Üniversitesi",
        "Ankara University of Social Sciences",
    ],
    ".asu.edu.tr": ["Aksaray Üniversitesi", "Aksaray University"],
    ".atauni.edu.tr": ["Atatürk Üniversitesi", "Atatürk University"],
    ".atilim.edu.tr": ["Atılım Üniversitesi", "Atılım University"],
    ".atlas.edu.tr": [
        "İSTANBUL ATLAS ÜNİVERSİTESİ",
        "ISTANBUL ATLAS UNIVERSITY",
    ],
    ".atu.edu.tr": [
        "Adana Alparslan Türkeş Bilim ve Teknoloji Üniversitesi",
        "Adana Alparslan Türkeş Science and Technology University",
    ],
    ".avrasya.edu.tr": ["Avrasya Üniversitesi", "Avrasya University"],
    ".aybu.edu.tr": [
        "Ankara Yıldırım Beyazıt Üniversitesi",
        "Ankara Yildirim Beyazit University",
    ],
    ".aydin.edu.tr": [
        "İstanbul Aydın Üniversitesi",
        "İstanbul Aydın University",
    ],
    ".ayvansaray.edu.tr": [
        "İstanbul Ayvansaray Üniversitesi",
        "Istanbul Ayvansaray University",
    ],
    ".bahcesehir.edu.tr": [" Bahcesehir University"],
    ".bakircay.edu.tr": [
        "İzmir Bakırçay Üniversitesi",
        "Izmir Bakircay University",
    ],
    ".balikesir.edu.tr": ["Balıkesir Üniversitesi", "Balıkesir University"],
    ".bandirma.edu.tr": [
        "Bandırma Onyedi Eylül Üniversitesi",
        "Bandırma Onyedi Eylül University",
    ],
    ".bartin.edu.tr": ["Bartın Üniversitesi", "Bartın University"],
    ".baskent.edu.tr": ["Başkent Üniversitesi", "Başkent University"],
    ".batman.edu.tr": ["Batman Üniversitesi", "Batman University"],
    ".alumni.bau.edu.tr": ["Bahçeşehir Üniversitesi", "BAU"],
    ".cons.bau.edu.tr": ["Bahçeşehir Üniversitesi", "Bahcesehir University"],
    ".bau.edu.tr": ["Bahcesehir University"],
    ".baucyprus.edu.tr": [
        "Bahçeşehir Kıbrıs Üniversitesi",
        "Bahçeşehir Cyprus University",
    ],
    ".baun.edu.tr": ["Balıkesir Üniversitesi", "Balikesir University"],
    ".bavu.edu.tr": ["Bezmialem Vakıf Üniversitesi", "Bezmialem University"],
    ".bayar.edu.tr": ["Celal Bayar Üniversitesi", "Celal Bayar University"],
    ".bayburt.edu.tr": ["Bayburt Üniversitesi", "Bayburt University"],
    ".beu.edu.tr": ["Bitlis Eren Üniversitesi", "Bitlis Eren University"],
    ".beun.edu.tr": ["Bülent Ecevit Üniversitesi", "Bülent Ecevit University"],
    ".beykent.edu.tr": ["Beykent Üniversitesi", "Beykent University"],
    ".beykoz.edu.tr": ["Beykoz Üniversitesi", "Beykoz University"],
    ".bezmialem.edu.tr": [
        "Bezmialem Vakıf Üniversitesi",
        "Bezmialem University",
    ],
    ".bilecik.edu.tr": ["Bilecik Üniversitesi", "Bilecik University"],
    ".bilgi.edu.tr": [
        "İstanbul Bilgi Üniversitesi",
        "İstanbul Bilgi University",
    ],
    ".bilkent.edu.tr": ["Bilkent Üniversitesi", "Bilkent University"],
    ".bingol.edu.tr": ["Bingöl Üniversitesi", "Bingöl University"],
    ".biruni.edu.tr": ["Biruni Üniversitesi", "Biruni University"],
    ".bogazici.edu.tr": ["Boğaziçi Üniversitesi", "Boğaziçi University"],
    ".bozok.edu.tr": ["Bozok Üniversitesi", "Bozok University"],
    ".btu.edu.tr": ["Bursa Teknik Üniversitesi", "Bursa Technical University"],
    ".cag.edu.tr": ["Çağ Üniversitesi", "Çağ University"],
    ".cankaya.edu.tr": ["Çankaya Üniversitesi", "Çankaya University"],
    ".ciu.edu.tr": [
        "Uluslararası Kıbrıs Üniversitesi",
        "Cyprus International University",
    ],
    ".comu.edu.tr": [
        "Çanakkale 18 Mart Üniversitesi",
        "Çanakkale 18 Mart University",
    ],
    ".cu.edu.tr": ["Çukurova Üniversitesi", "Çukurova University"],
    ".cumhuriyet.edu.tr": ["Cumhuriyet Üniversitesi", "Cumhuriyet University"],
    ".deu.edu.tr": ["Dokuz Eylül Üniversitesi", "Dokuz Eylul University"],
    ".dho.edu.tr": ["Deniz Harp Okulu", "Turkish Naval Academy"],
    ".dicle.edu.tr": ["Dicle Üniversitesi", "Dicle University"],
    ".dogus.edu.tr": ["Doğuş Üniversitesi", "Doğuş University"],
    ".dpu.edu.tr": ["Dumlupınar Üniversitesi", "Dumlupınar University"],
    ".dumlupinar.edu.tr": ["Dumlupınar Üniversitesi", "Dumlupınar University"],
    ".duzce.edu.tr": ["Düzce Üniversitesi", "Düzce University"],
    ".ogr.ebyu.edu.tr": [
        "Erzincan Binali Yıldırım Üniversitesi",
        "Erzincan Binali Yıldırım University",
    ],
    ".ege.edu.tr": ["Ege Üniversitesi", "Ege University"],
    ".emu.edu.tr": [
        "Doğu Akdeniz Üniversitesi",
        "Eastern Mediterranean University",
    ],
    ".ogr.erbakan.edu.tr": [
        "Necmettin Erbakan Üniversitesi",
        "Necmettin Erbakan University",
    ],
    ".erbakan.edu.tr": [
        "Necmettin Erbakan Üniversitesi",
        "Necmettin Erbakan University",
    ],
    ".erciyes.edu.tr": ["Erciyes Üniversitesi", "Erciyes University"],
    ".erdogan.edu.tr": [
        "Recep Tayyip Erdoğan Üniversitesi",
        "Recep Tayyip Erdoğan University",
    ],
    ".erzincan.edu.tr": ["Erzincan Üniversitesi", "Erzincan University"],
    ".erzurum.edu.tr": [
        "Erzurum Teknik Üniversitesi",
        "Erzurum Technical University",
    ],
    ".esenyurt.edu.tr": [
        "İstanbul Esenyurt Üniversitesi",
        "İstanbul Esenyurt University",
    ],
    ".eskisehir.edu.tr": ["\ufeffEskişehir Technical University"],
    ".eul.edu.tr": [
        "European University of Lefke",
        "Lefke Avrupa Üniversitesi",
    ],
    ".fatihsultan.edu.tr": [
        "Fatih Sultan Mehmet Vakıf Üniversitesi",
        "Fatih Sultan Mehmet Waqf University",
    ],
    ".stu.fbu.edu.tr": ["Fenerbahçe Üniversitesi", "Fenerbahce University"],
    ".fbu.edu.tr": ["Fenerbahçe Üniversitesi", "Fenerbahçe University"],
    ".final.edu.tr": [
        "Uluslararası Final Üniversitesi",
        "Final International University",
    ],
    ".firat.edu.tr": ["Fırat Üniversitesi", "Fırat University"],
    ".stu.fsm.edu.tr": [
        "Fatih Sultan Mehmet Vakıf Üniversitesi",
        "Fatih Sultan Mehmet University",
    ],
    ".fsm.edu.tr": [
        "Fatih Sultan Mehmet Vakıf Üniversitesi",
        "Fatih Sultan Mehmet Foundation University",
    ],
    ".galata.edu.tr": [
        "İstanbul Galata Üniversitesi",
        "İstanbul Galata University",
    ],
    ".gantep.edu.tr": ["Gaziantep Üniversitesi", "Gaziantep University"],
    ".gau.edu.tr": [
        "Girne Amerikan Üniversitesi",
        "Girne American University",
    ],
    ".gazi.edu.tr": ["Gazi Üniversitesi", "Gazi University"],
    ".student.gaziantep.edu.tr": [
        "Gaziantep Universitesi",
        "Gaziantep University",
    ],
    ".gedik.edu.tr": [
        "İstanbul Gedik Üniversitesi",
        "İstanbul Gedik University",
    ],
    ".gelisim.edu.tr": [
        "İstanbul Gelişim Üniversitesi",
        "İstanbul Gelişim University",
    ],
    ".gibtu.edu.tr": ["Gaziantep Islam Science and Technology University"],
    ".gidatarim.edu.tr": [
        "Konya Gıda ve Tarım Üniversitesi",
        "Konya Food & Agriculture University",
    ],
    ".giresun.edu.tr": ["Giresun Üniversitesi", "Giresun University"],
    ".gop.edu.tr": ["Gaziosmanpaşa Üniversitesi", "Gaziosmanpaşa University"],
    ".gsu.edu.tr": ["Galatasaray Üniversitesi", "Galatasaray University"],
    ".gtu.edu.tr": ["Gebze Teknik Üniversitesi"],
    ".gumushane.edu.tr": ["Gümüşhane Üniversitesi", "Gümüşhane University"],
    ".gyte.edu.tr": ["Gebze Teknik Üniversitesi"],
    ".hacettepe.edu.tr": ["Hacettepe Üniversitesi", "Hacettepe University"],
    ".hakkari.edu.tr": ["Hakkari Üniversitesi", "Hakkari University"],
    ".halic.edu.tr": ["Haliç Üniversitesi", "Haliç University"],
    ".hbv.edu.tr": [
        "Ankara Hacı Bayram Veli Üniversitesi",
        "Ankara Haci Bayram Veli University",
    ],
    ".hho.edu.tr": ["Hava Harp Okulu", "Turkish Air Force Academy"],
    ".hitit.edu.tr": ["Hitit Üniversitesi", "Hitit University"],
    ".hku.edu.tr": [
        "Hasan Kalyoncu Üniversitesi",
        "Hasan Kalyoncu University",
    ],
    ".hun.edu.tr": ["Hacettepe Üniversitesi", "Hacettepe University"],
    ".ibnhaldun.edu.tr": ["İbn Haldun Üniversitesi", "Ibn Haldun University"],
    ".ibu.edu.tr": [
        "Abant İzzet Baysal Üniversitesi",
        "Abant İzzet Baysal University",
    ],
    ".ibun.edu.tr": [
        "İstanbul Bilgi Üniversitesi",
        "İstanbul Bilgi University",
    ],
    ".iesu.edu.tr": ["\ufeffİstanbul Esenyurt Üniversitesi"],
    ".ieu.edu.tr": [
        "İzmir Ekonomi Üniversitesi",
        "İzmir University of Economics",
    ],
    ".igdir.edu.tr": ["Iğdır Üniversitesi", "Iğdır University"],
    ".ihu.edu.tr": ["Ibn Haldun University", "İbn Haldun Üniversitesi"],
    ".ikc.edu.tr": [
        "İzmir Kâtip Çelebi Üniversitesi",
        "İzmir Kâtip Çelebi University",
    ],
    ".ogr.ikcu.edu.tr": [
        "İzmir Katip Çelebi Üniversitesi",
        "Izmir Katip Celebi University",
    ],
    ".ikcu.edu.tr": [
        "İzmir Katip Çelebi Üniversitesi",
        "Izmir Katip Celebi University",
    ],
    ".iku.edu.tr": [
        "Istanbul Kültür Üniversitesi",
        "Istanbul Kültür University",
    ],
    ".inonu.edu.tr": ["İnönü Üniversitesi", "İnönü University"],
    ".isikun.edu.tr": ["Işık Üniversitesi", "Işık University"],
    ".ismu.edu.tr": [
        "İstanbul Medeniyet Üniversitesi",
        "Istanbul Medeniyet University",
    ],
    ".isparta.edu.tr": [
        "Isparta Uygulamalı Bilimler Üniversitesi",
        "Isparta University of Applied Sciences",
    ],
    ".istanbul.edu.tr": ["İstanbul Üniversitesi", "Istanbul University"],
    ".istanbularel.edu.tr": ["Arel Üniversitesi", "Arel University"],
    ".istanbulbilim.edu.tr": [
        "İstanbul Bilim Üniversitesi",
        "İstanbul Bilim University",
    ],
    ".istanbulticaret.edu.tr": [
        "İstanbul Ticaret Üniversitesi",
        "Istanbul Commerce University",
    ],
    ".iste.edu.tr": [
        "İskenderun Teknik Üniversitesi",
        "İskenderun Technical University",
    ],
    ".istiklal.edu.tr": [
        "Kahramanmaraş İstiklal Üniversitesi",
        "Kahramanmaras Istiklal University",
    ],
    ".istinye.edu.tr": ["İstinye Üniversitesi", "İstinye University"],
    ".istun.edu.tr": ["İstanbul Sağlık ve Teknoloji Üniversitesi"],
    ".iszu.edu.tr": [
        "İstanbul Sabahattin Zaim Üniversitesi",
        "İstanbul Sabahattin Zaim University",
    ],
    ".iticu.edu.tr": [
        "İstanbul Ticaret Üniversitesi",
        "İstanbul Ticaret University",
    ],
    ".itu.edu.tr": [
        "İstanbul Teknik Üniversitesi",
        "İstanbul Technical University",
    ],
    ".iu.edu.tr": ["İstanbul Üniversitesi", "University of Istanbul"],
    ".iuc.edu.tr": [
        "İstanbul Üniversitesi Cerrahpaşa",
        "Istanbul Universitesi Cerrahpasa",
    ],
    ".iyte.edu.tr": [
        "İzmir Yüksek Teknoloji Enstitüsü",
        "İzmir Institute of Technology",
    ],
    ".izmirekonomi.edu.tr": [
        "İzmir Ekonomi Üniversitesi",
        "İzmir University of Economics",
    ],
    ".izu.edu.tr": [
        "İstanbul Sabahattin Zaim Üniversitesi",
        "İstanbul Sabahattin Zaim University",
    ],
    ".jsga.edu.tr": [
        "JANDARMA VE SAHİL GÜVENLİK AKADEMİSİ",
        "GENDARMERIE AND COAST GUARD ACADEMY",
    ],
    ".kafkas.edu.tr": ["\ufeffKafkas Üniversitesi"],
    ".kapadokya.edu.tr": ["Kapadokya Üniversitesi"],
    ".karabuk.edu.tr": ["Karabük Üniversitesi", "Karabük University"],
    ".karaelmas.edu.tr": [
        "Zonguldak Karaelmas Üniversitesi",
        "Zonguldak Karaelmas University",
    ],
    ".karatay.edu.tr": ["KTO Karatay Üniversitesi", "KTO Karatay University"],
    ".karatekin.edu.tr": [
        "Çankırı Karatekin Üniversitesi",
        "Çankırı Karatekin University",
    ],
    ".ogr.kastamonu.edu.tr": [
        "KASTAMONU ÜNİVERSİTESİ",
        "Kastamonu University",
    ],
    ".kastamonu.edu.tr": ["Kastamonu University"],
    ".kavram.edu.tr": ["İzmir Kavram Meslek Yüksekokulu"],
    ".kayseri.edu.tr": ["Kayseri Üniversitesi", "Kayseri Univercity"],
    ".kemerburgaz.edu.tr": [
        "İstanbul Kemerburgaz Üniversitesi",
        "İstanbul Kemerburgaz University",
    ],
    ".kent.edu.tr": ["İstanbul Kent Üniversitesi", "Istanbul KENT UNIVERSITY"],
    ".khas.edu.tr": ["Kadir Has Üniversitesi", "Kadir Has University"],
    ".kilis.edu.tr": [
        "Kilis 7 Aralık Üniversitesi",
        "Kilis 7 Aralık University",
    ],
    ".kirikkale.edu.tr": ["Kırıkkale Üniversitesi", "Kırıkkale University"],
    ".kirklareli.edu.tr": ["Kırklareli Üniversitesi", "Kırklareli University"],
    ".klu.edu.tr": ["Kırklareli Üniversitesi", "Kırklareli University"],
    ".kocaeli.edu.tr": ["Kocaeli üniversitesi", "Kocaeli University"],
    ".kocaelisaglik.edu.tr": [
        "Kocaeli Sağlık ve Teknoloji Üniversitesi",
        "Kocaeli Healt and Technology University",
    ],
    ".konya.edu.tr": [
        "Necmettin Erbakan Üniversitesi",
        "Necmettin Erbakan University",
    ],
    ".ksbu.edu.tr": [
        "Kütahya Sağlık Bilimleri Üniversitesi",
        "Kütahya University of Health Sciences ",
    ],
    ".ksu.edu.tr": [
        "Kahramanmaraş Sütçü İmam Üniversitesi",
        "Kahramanmaraş Sütçü İmam University",
    ],
    ".ktu.edu.tr": [
        "Karadeniz Teknik Üniversitesi",
        "Karadeniz Technical University",
    ],
    ".ktun.edu.tr": [
        "Konya Teknik Üniversitesi",
        "Konya Technical University",
    ],
    ".ku.edu.tr": ["Koç Üniversitesi", "Koç University"],
    ".kun.edu.tr": ["Kapadokya Üniversitesi", "Cappadocia University"],
    ".kyrenia.edu.tr": ["Girne Üniversitesi"],
    ".lefke.edu.tr": [
        "Lefke Avrupa Üniversitesi",
        "European University of Lefke",
    ],
    ".lhu.edu.tr": ["Lokman Hekim University"],
    ".maltepe.edu.tr": [
        "T.C. Maltepe Üniversitesi",
        "T.C. Maltepe University",
    ],
    ".marmara.edu.tr": ["Marmara Üniversitesi", "Marmara University"],
    ".marun.edu.tr": ["Marmara Üniversitesi", "Marmara University"],
    ".medeniyet.edu.tr": [
        "İstanbul Medeniyet Üniversitesi",
        "İstanbul Medeniyet University",
    ],
    ".medipol.edu.tr": [
        "İstanbul Medipol Üniversitesi",
        "İstanbul Medipol University",
    ],
    ".mef.edu.tr": ["MEF Üniversitesi", "MEF University"],
    ".mehmetakif.edu.tr": [
        "T.C. Mehmet Akif Ersoy Üniversitesi",
        "T.C. Mehmet Akif Ersoy University",
    ],
    ".mersin.edu.tr": ["Mersin Üniversitesi", "Mersin University"],
    ".metu.edu.tr": [
        "Orta Doğu Teknik Üniversitesi",
        "Middle East Technical University",
    ],
    ".mku.edu.tr": ["Mustafa Kemal Üniversitesi", "Mustafa Kemal University"],
    ".msu.edu.tr": [
        "Milli Savunma Üniversitesi",
        "National Defence University",
    ],
    ".mu.edu.tr": [
        "Muğla Sıtkı Koçman Üniversitesi",
        "Muğla Sıtkı Koçman University",
    ],
    ".mudanya.edu.tr": ["MUDANYA ÜNİVERSİTESİ"],
    ".munzur.edu.tr": ["Munzur Üniversitesi", "Munzur University"],
    ".campus.netkent.edu.tr": [
        "Netkent Akdeniz Araştırma ve Bilim Üniversitesi",
        "Netkent Mediterranean Research and Science University",
    ],
    ".neu.edu.tr": ["Yakın Doğu Üniversitesi", "Near East University"],
    ".nevsehir.edu.tr": [
        "Nevşehir Hacı Bektaş Veli Üniversitesi",
        "Nevşehir Hacı Bektaş Veli University",
    ],
    ".nisantasi.edu.tr": ["Nişantaşı Üniversitesi", "Nişantaşı University"],
    ".nku.edu.tr": ["Namık Kemal Üniversitesi", "Namık Kemal University"],
    ".nny.edu.tr": [
        "T.C. Nuh Naci Yazgan Üniversitesi",
        "T.C. Nuh Naci Yazgan University",
    ],
    ".odtu.edu.tr": [
        "Orta Doğu Teknik Üniversitesi",
        "Middle East Technical University",
    ],
    ".odu.edu.tr": ["Ordu Üniversitesi", "Ordu University"],
    ".ogu.edu.tr": ["Osmangazi Üniversitesi", "Osmangazi University"],
    ".ohu.edu.tr": [
        "Niğde Ömer Halisdemir Üniversitesi",
        "Nigde Omer Halisdemir University",
    ],
    ".okan.edu.tr": ["Okan Üniversitesi", "Okan University"],
    ".ogr.oku.edu.tr": [
        "Osmaniye Korkut Ata Üniversitesi",
        "Osmaniye Korkut Ata University",
    ],
    ".omu.edu.tr": ["Ondokuz Mayıs Üniversitesi", "Ondokuz Mayıs University"],
    ".osmaniye.edu.tr": [
        "Osmaniye Korkut Ata Üniversitesi",
        "Osmaniye Korkut Ata University",
    ],
    ".ostimteknik.edu.tr": [
        "Ostim Teknik Üniversitesi",
        "Ostim Technical University",
    ],
    ".ozal.edu.tr": [
        "Malatya Turgut Özal Üniversitesi",
        "Malatya Turgut Özal University",
    ],
    ".ozu.edu.tr": ["Özyeğin Üniversitesi", "Özyeğin University"],
    ".ozyegin.edu.tr": ["Özyeğin Üniversitesi", "Özyeğin University"],
    ".pa.edu.tr": ["Polis Akademisi", "Turkish National Police Academy"],
    ".pamukkale.edu.tr": ["Pamukkale Üniversitesi", "Pamukkale University"],
    ".pau.edu.tr": ["PAMUKKALE ÜNİVERSİTESİ", "PAMUKKALE UNIVERSITY"],
    ".pirireis.edu.tr": ["Pîrî Reis Üniversitesi", "Pîrî Reis University"],
    ".pru.edu.tr": ["Piri Reis Üniversitesi"],
    ".rdu.edu.tr": ["Rauf Denktas Universitesi", "Rauf Denktas University"],
    ".rumeli.edu.tr": [
        "T.C. İstanbul Rumeli Üniversitesi",
        "T.C. İstanbul Rumeli University",
    ],
    ".sabanciuniv.edu.tr": ["Sabancı Üniversitesi", "Sabancı University"],
    ".sakarya.edu.tr": ["Sakarya Üniversitesi", "Sakarya University"],
    ".samsun.edu.tr": ["Samsun University"],
    ".sanko.edu.tr": ["Sanko Üniversitesi", "Sanko University"],
    ".sau.edu.tr": ["Sakarya Üniversitesi", "Sakarya University"],
    ".sbu.edu.tr": [
        "Sağlık Bilimleri Üniversitesi",
        "University of Health Sciences",
    ],
    ".sdu.edu.tr": [
        "Süleyman Demirel Üniversitesi",
        "Süleyman Demirel University",
    ],
    ".sehir.edu.tr": [
        "İstanbul Şehir Üniversitesi",
        "İstanbul Şehir University",
    ],
    ".selcuk.edu.tr": ["Selçuk Üniversitesi", "Selçuk University"],
    ".siirt.edu.tr": ["Siirt Üniversitesi", "Siirt University"],
    ".sinop.edu.tr": ["Sinop Üniversitesi", "Sinop University"],
    ".sirnak.edu.tr": ["Şırnak Üniversitesi", "Şırnak University"],
    ".sivas.edu.tr": ["Sivas Science and Technology University"],
    ".subu.edu.tr": ["Sakarya University of Applied Sciences"],
    ".tarsus.edu.tr": ["Tarsus Üniversitesi", "Tarsus University"],
    ".tau.edu.tr": ["Türk-Alman Üniversitesi", "Turkish-German University"],
    ".tedu.edu.tr": ["Türk Eğitim Derneği Üniversitesi"],
    ".thk.edu.tr": [
        "Türk Hava Kurumu Üniversitesi",
        "University of Turkish Aeronautical Association",
    ],
    ".ticaret.edu.tr": [
        "Istanbul Ticaret Universitesi",
        "Istanbul Commerce University",
    ],
    ".stu.tinaztepe.edu.tr": [
        "IZMIR TINAZTEPE ÜNİVERSİTESİ",
        "IZMIR TINAZTEPE UNIVERSITY",
    ],
    ".topkapi.edu.tr": ["İstanbul Topkapı Üniversitesi"],
    ".toros.edu.tr": ["Toros Üniversitesi", "Toros University"],
    ".trabzon.edu.tr": ["Trabzon Üniversitesi", "Trabzon University"],
    ".trakya.edu.tr": ["Trakya Üniversitesi", "Trakya University"],
    ".uludag.edu.tr": ["Uludağ Üniversitesi", "Uludağ University", ".ogr"],
    ".usak.edu.tr": ["Uşak Üniversitesi", "Uşak University"],
    ".uskudar.edu.tr": ["Üsküdar University"],
    ".yalova.edu.tr": ["Yalova Üniversitesi", "Yalova University"],
    ".yasar.edu.tr": ["Yaşar Üniversitesi", "Yaşar University"],
    ".yeditepe.edu.tr": ["Yeditepe Üniversitesi", "Yeditepe University"],
    ".yeniyuzyil.edu.tr": [
        "İstanbul Yeni Yüzyıl Üniversitesi",
        "İstanbul Yeni Yüzyıl University",
    ],
    ".kirikkale.yesevi.edu.tr": [
        "Kırıkkale Universitesi",
        "Kırıkkale University",
    ],
    ".ogr.yesevi.edu.tr": [
        "Hoca Ahmet Yesevi Üniversitesi",
        "Akhmet Yassawi University",
    ],
    ".yildiz.edu.tr": [
        "Yıldız Teknik Üniversitesi",
        "Yıldız Technical University",
    ],
    ".yiu.edu.tr": [
        "Yüksek İhtisas Üniversitesi",
        "Yüksek İhtisas University",
    ],
    ".yuksekihtisasuniversitesi.edu.tr": [
        "Yüksek İhtisas Üniversitesi",
        "Yüksek İhtisas University",
    ],
    ".yyu.edu.tr": ["Yüzüncü Yıl Üniversitesi", "Yüzüncü Yıl University"],
    ".my.aci.k12.tr": [
        "Özel İzmir Amerikan Koleji",
        "American Collegiate Institute",
    ],
    ".acibadem.k12.tr": [
        "ÖZEL ACIBADEM OKULLARI",
        "PRIVATE ACIBADEM SCHOOLS",
        "acibadem.k12.tr",
    ],
    ".stu.acischools.k12.tr": ["Açı Lisesi", "Aci High School"],
    ".acischools.k12.tr": ["Açı Lisesi", "Aci High School"],
    ".alkev.k12.tr": [
        "Alman Liseliler Kültür ve Eğitim Vakfı ALKEV Özel Okulları",
        "ALKEV Private Schools",
    ],
    ".almanlisesi.k12.tr": ["Deutsche Schule Istanbul"],
    ".anasehiranadolulisesi.k12.tr": [
        "Anaşehir Anadolu Lisesi",
        "Anaşehir High School",
    ],
    ".ayseabla.k12.tr": ["Başkent Üniversitesi Özel Ayşeabla Anadolu Lisesi"],
    ".bahcesehir.k12.tr": ["\ufeffBahçeşehir Koleji", "Bahçeşehir College"],
    ".stu.bilfen.k12.tr": ["Bilfen", "Bilfen"],
    ".bjkkabatasvakfiokullari.k12.tr": [" BJK - Kabataş Vakfı Okulları"],
    ".bornovakoleji.k12.tr": ["bornovakoleji", " bornova college"],
    ".dogaokullari.k12.tr": ["Doga Koleji"],
    ".enka.k12.tr": ["Özel Enka Teknik Okulları", "Enka Technical Schools"],
    ".evrim.k12.tr": ["Özel Evrim Okulları"],
    ".fmvisik.k12.tr": ["Feyziye Mektepleri", "Feyziye Schools"],
    ".cis.gokkusagi.k12.tr": ["Gokkusagi"],
    ".ielev.k12.tr": ["Istanbul Erkek Liseliler Egitim Vakfi"],
    ".ihlaskoleji.k12.tr": ["İhlas Koleji", "İhlas College"],
    ".isev.k12.tr": [
        "Özel İzmir SEV İlköğretim Kurumları",
        "İzmir SEV Schools",
    ],
    ".istek.k12.tr": ["İSTEK Antalya Okulları", "İSTEK Antalya College"],
    ".student.istmtal.k12.tr": [
        "Istanbul Havalimanı MTAL",
        "Istanbul Grand Airport MTAL",
    ],
    ".itugvo.k12.tr": ["ITU GVO Ekrem Elginkan High School"],
    ".std.kalev.k12.tr": ["Kalev Eğitim Kurumları", "Kalev Schools"],
    ".koc.k12.tr": ["Koç Okulu", "The Koç School"],
    ".konyabasakkoleji.k12.tr": ["Özel Konya Başak Koleji"],
    ".maya.k12.tr": ["Maya School"],
    ".mayaokullari.k12.tr": ["Maya Okulları", "Maya Schools"],
    ".meb.k12.tr": [
        "Süleyman Çelebi Anadolu Lisesi",
        "Süleyman Çelebi High School",
    ],
    ".nds.k12.tr": ["Notre Dame de Sion Özel Fransız Lisesi"],
    ".nesibeaydin.k12.tr": [
        "Nesibe Aydın Aydın Okulları",
        "Nesibe Aydın Educational Institutions Nesibe Aydın High School",
    ],
    ".odtugvo.k12.tr": [
        "ODTU GVO ÖZEL LİSESİ",
        "METU DFS PRIVATE HIGH SCHOOL",
    ],
    ".robcol.k12.tr": ["American Robert College of Istanbul"],
    ".sanliurfaeml.k12.tr": [
        "Urfa Mesleki ve Teknik Anadolu Lisesi",
        "Urfa Vocational and Technical Anatolian HighSchool",
    ],
    ".sb.k12.tr": ["Özel Saint Benoît Fransız Lisesi"],
    ".sezin.k12.tr": ["Özel Sezin Okulu", "The Sezin School"],
    ".sj.k12.tr": ["İstanbul Özel Saint-Joseph Fransız Lisesi"],
    ".sm.k12.tr": ["Saint Michel Fransız Lisesi"],
    ".sp.k12.tr": ["Saint Pulcherie Fransız Lisesi"],
    ".my.tac.k12.tr": [
        "Özel Tarsus Amerikan Koleji",
        "Tarsus American College",
    ],
    ".tac.k12.tr": ["Özel Tarsus Amerikan Koleji", "Tarsus American College"],
    ".tedankara.k12.tr": [
        "TED Ankara Koleji",
        "Ted Ankara College Foundation Schools",
    ],
    ".tedatakent.k12.tr": ["TED Atakent Koleji  ", "TED Atakent College"],
    ".tedbodrum.k12.tr": ["Ted Bodrum Koleji", "TED Bodrum College"],
    ".tedistanbul.k12.tr": ["Ted Istanbul Koleji", "Ted Istanbul College"],
    ".terakki.k12.tr": ["Terakki Vakfı Okulları"],
    ".tevitol.k12.tr": ["TEV Inanc Turkes Ozel Lisesi"],
    ".tubitakfenlisesi.k12.tr": [
        "Tübitak Fen Lisesi",
        "TÜBİTAK Science High School",
    ],
    ".uaa.k12.tr": [
        "Özel Üsküdar Amerikan Lisesi",
        "Uskudar American Academy",
    ],
    ".ugurokullari.k12.tr": ["Ugur Okullari", "Ugur High schools"],
    ".yenilikciogrenme.k12.tr": [
        "Yenilikci Ogrenme Merkezi, Istanbul, Turkey"
    ],
    ".yeninesil.k12.tr": ["Yeninesil2000"],
    ".cowenhamilton.edu.tt": ["Cowen Hamilton Secondary, Trinidad"],
    ".nesc.edu.tt": [
        "NESC Technical Institute",
        "National Energy Skills Centre",
    ],
    ".usc.edu.tt": ["University of the Southern Caribbean"],
    ".utt.edu.tt": ["University of Trinidad and Tobago"],
    ".uwi.tt": ["University of the West Indies St. Augustine"],
    ".hcas.com.tw": ["新竹縣康乃薾美國學校", "Hsinchu County American School"],
    ".kcis.com.tw": [
        "Kang Chiao International School",
        "Kang Chiao International School",
    ],
    ".as.edu.tw": ["中央研究院", "Academia Sinica"],
    ".live.asia.edu.tw": [
        "Asia University, Taiwan",
        "Asia University, Taiwan",
    ],
    ".au.edu.tw": ["Aletheia University"],
    ".gm.ccut.edu.tw": [
        "中洲科技大學",
        "Chung Chou University of Science and Technology",
    ],
    ".cgu.edu.tw": ["Chang Gung University"],
    ".chgsh.chc.edu.tw": [
        "國立彰化女子高級中學",
        "National Changhua Girl's Senior High School",
    ],
    ".chsh.chc.edu.tw": [
        "國立彰化高級中學",
        "National Changhua Senior High School",
    ],
    ".chihlee.edu.tw": ["Chihlee University of Technology", "致理科技大學"],
    ".chu.edu.tw": ["Chung Hua University"],
    ".mailst.cjcu.edu.tw": ["Chang Jung Christian University"],
    ".cku.edu.tw": ["Ching Kuo Institue of Management &amp; Health"],
    ".gm.cnu.edu.tw": [
        "嘉南藥理大學",
        "Chia Nan University of Pharmacy ＆ Science",
    ],
    ".o365.cnu.edu.tw": [
        "嘉南藥理大學",
        "Chia Nan University of Pharmacy ＆ Science",
    ],
    ".cpu.edu.tw": ["Central Police University"],
    ".csmu.edu.tw": ["CHUNG SHAN MEDICAL UNIVERSITY"],
    ".gcloud.csu.edu.tw": ["正修科技大學", "CHENG SHIU UNIVERSITY"],
    ".ctbc.edu.tw": ["中信金融管理學院", "CTBC BUSINESS SCHOOL"],
    ".stu.ctu.edu.tw": ["建國科技大學", "Chienkuo Technology University"],
    ".ms3.ctust.edu.tw": [
        "中臺科技大學",
        "Central Taiwan University of Science and Technology",
    ],
    ".cufa.edu.tw": [
        "崇右影藝科技大學",
        "CHUNGYU UNIVERSITY OF FILM AND ARTS",
    ],
    ".gms.cust.edu.tw": [
        "中華科技大學",
        "China University of Science and Technology",
    ],
    ".stu.cute.edu.tw": ["中國科技大學", "China University of Technology"],
    ".cute.edu.tw": ["中國科技大學", "China University of Technology"],
    ".cycu.edu.tw": ["Chung Yuan Christian University"],
    ".cyut.edu.tw": ["Chao Yang University of Science and Technology"],
    ".dila.edu.tw": ["法鼓文理學院", "Dharma Drum Institute of Liberal Arts"],
    ".gms.dyhu.edu.tw": [
        "德育學校財團法人德育護理健康學院",
        "Deh Yu College of Nursing and Health",
    ],
    ".ms.dyhu.edu.tw": [
        "德育學校財團法人德育護理健康學院",
        "Deh Yu College of Nursing and Health",
    ],
    ".dyu.edu.tw": ["Da-Yeh University"],
    ".fcu.edu.tw": ["Feng Chia University"],
    ".mail.fgu.edu.tw": ["佛光大學", "Fo Guang University"],
    ".live.fy.edu.tw": ["輔英科技大學", "Fooyin University"],
    ".stu.hgsh.hc.edu.tw": [
        "国立新竹女子高级中学",
        "Hsinchu Girls Senior High School",
    ],
    ".hcu.edu.tw": ["Hsuan Chuang University"],
    ".mail.hdut.edu.tw": [
        "宏國德霖科技大學",
        "Hungkuo Delin University of Technology",
    ],
    ".student.hdut.edu.tw": [
        "宏國德霖科技大學",
        "Hungkuo Delin University of Technology",
    ],
    ".hfu.edu.tw": ["Huafan University"],
    ".hk.edu.tw": [
        "弘光科技大學",
        "HungKuang University",
        "http://www.hk.edu.tw",
    ],
    ".tcsh.hlc.edu.tw": [
        "慈濟大學附屬高級中學",
        "Tzu Chi Senior High School Affiliated with Tzu Chi University",
    ],
    ".hsc.edu.tw": [
        "新生醫護管理專科學校",
        "Hsin Sheng Junior College of Medical Care and Management",
    ],
    ".hust.edu.tw": [
        "修平科技大學",
        "Hsiuping University of Science and Technology",
    ],
    ".ms.hwai.edu.tw": [
        "中華醫事科技大學",
        "Chung Hwa University of Medical Technology",
    ],
    ".go.hwh.edu.tw": ["華夏科技大學", "Hwa Hsia University of Technology"],
    ".mail.hwu.edu.tw": ["醒吾科技大學", "Hsing Wu University"],
    ".isu.edu.tw": ["I-Shou University"],
    ".mail2.ccvs.kh.edu.tw": [
        "高雄市立中正高級工業職業學校",
        "Kaohsiung Municipal Chung-Cheng Industrial High School",
    ],
    ".fxm.kh.edu.tw": ["鳳西國中", "Fong-si Junior High School"],
    ".hcvs.kh.edu.tw": [
        "高雄市立海青高級工商職業學校",
        "Kaohsiung Municipal Haiching Vocational High School of Technology and Commerce",
    ],
    ".student.kshs.kh.edu.tw": [
        "高雄市立高雄高級中學",
        "Kaohsiung Municipal Kaohsiung Senior High School",
    ],
    ".ksvcs.kh.edu.tw": [
        "高雄市立高雄高級商業職業學校",
        "Kaohsiung Municipal Kaohsiung Commercial High School",
    ],
    ".student.ksvs.kh.edu.tw": [
        "高雄市立高雄高級工業職業學校",
        "KAOHSIUNG MUNICIPAL KAOHSIUNG INDUSTRIAL HIGH SCHOOL",
    ],
    ".mail.kh.edu.tw": [
        "高雄市教育局",
        "Education Bureau, Kaohsiung City Government",
        ".group",
    ],
    ".spec.kh.edu.tw": [
        "高雄市政府教育局特殊教育科",
        "Special Education of Kaohsiung City",
        "https://www.spec.kh.edu.tw/",
    ],
    ".cysh.khc.edu.tw": [
        "高雄市私立正義高級中學",
        "Cheng Yi Senior High School",
    ],
    ".fssh.khc.edu.tw": [
        "國立鳳山高級中學",
        "National Feng-Shan Senior High School",
    ],
    ".gm.kl.edu.tw": [
        "基隆市立銘傳國中",
        "Keelung Municipal Ming Chwan Junior High School",
    ],
    ".kmu.edu.tw": ["高雄醫學大學", "Kaohsiung Medical University"],
    ".knu.edu.tw": [
        "開南大學",
        "Kainan University",
        "https://www.knu.edu.tw/",
    ],
    ".ksu.edu.tw": ["Kun Shan University"],
    ".kuas.edu.tw": ["National Kaohsiung University of Applied Sciences"],
    ".mail.kyu.edu.tw": ["高苑科技大學", "Kao Yuan University"],
    ".stumail.kyu.edu.tw": ["高苑科技大學", "Kao Yuan University"],
    ".kyu.edu.tw": ["高苑科技大學", "Kao Yuan University"],
    ".lhu.edu.tw": ["LungHwa University of Science and Technology"],
    ".mail.lit.edu.tw": ["黎明技術學院", "lee ming institute of technology"],
    ".ltugmail.ltu.edu.tw": ["嶺東科技大學", "Ling Tung University"],
    ".stumail.ltu.edu.tw": ["嶺東科技大學", "Ling Tung University"],
    ".teamail.ltu.edu.tw": ["嶺東科技大學", "Ling Tung University"],
    ".mcu.edu.tw": ["Ming Chuan University"],
    ".mail.mcut.edu.tw": ["明志科技大學", "MING CHI UNIVERSITY OF TECHNOLOGY"],
    ".mail2.mcut.edu.tw": [
        "明志科技大學",
        "MING CHI UNIVERSITY OF TECHNOLOGY",
    ],
    ".o365.mcut.edu.tw": ["明志科技大學", "MING CHI UNIVERSITY OF TECHNOLOGY"],
    ".go.meiho.edu.tw": ["美和科技大學", "MeiHo University"],
    ".ms.mingdao.edu.tw": ["明道高級中學", "Mingdao High School"],
    ".mmc.edu.tw": ["馬偕醫學院", "MacKay Medical College"],
    ".std.must.edu.tw": [
        "明新科技大學",
        "MUST(Minghsin University of Science and Technology)",
    ],
    ".nchu.edu.tw": ["National Chung Hsing University, Taichung"],
    ".ncnu.edu.tw": ["National Chi Nan University"],
    ".nctu.edu.tw": ["National Chiao Tung University"],
    ".ncu.edu.tw": ["National Central University"],
    ".ncue.edu.tw": ["National Changhua University of Education"],
    ".ncut.edu.tw": [
        "國立勤益科技大學",
        "National Chin-Yi University of Technology",
    ],
    ".ncyu.edu.tw": ["National Chiayi University"],
    ".ndhu.edu.tw": ["National Dong Hwa University"],
    ".mail.ndmctsgh.edu.tw": ["國防醫學院", "National Defense Medical Center"],
    ".ndmc.ndmctsgh.edu.tw": ["國防醫學院", "National Defense Medical Center"],
    ".ndu.edu.tw": [
        "國防大學理工學院",
        "National Defense University Chung Cheng Institute of Technology",
    ],
    ".nfu.edu.tw": ["National Formosa University"],
    ".nhu.edu.tw": ["Nanhua University"],
    ".nknu.edu.tw": ["National Kaohsiung Normal University"],
    ".nkuht.edu.tw": [
        "National Kaohsiung University of Hospitality and Tourism",
        "國立高雄餐旅大學",
    ],
    ".nkust.edu.tw": [
        "國立高雄科技大學",
        "National Kaohsiung University of Science and Technology",
    ],
    ".nkut.edu.tw": [],
    ".nou.edu.tw": ["National Open University"],
    ".nptu.edu.tw": ["National Pingtung University"],
    ".ems.npu.edu.tw": ["國立澎湖科技大學", "National Penghu University"],
    ".gms.npu.edu.tw": [
        "國立澎湖科技大學",
        "National Penghu University of Science and Technology",
    ],
    ".npust.edu.tw": [
        "National Pingtung University of Science and Technology"
    ],
    ".nqu.edu.tw": ["國立金門大學", "National Quemoy University"],
    ".nsysu.edu.tw": ["National Sun Yat-Sen University"],
    ".gm.ntcu.edu.tw": ["National Taichung University of Education"],
    ".ntcu.edu.tw": ["National Taichung University of Education"],
    ".nthu.edu.tw": ["National Tsinghua University"],
    ".ntou.edu.tw": ["National Taiwan Ocean University"],
    ".mail2.chshs.ntpc.edu.tw": [
        "新北市立中和高級中學",
        "New Taipei Municipal Zhonghe Senior High School",
    ],
    ".clsh.ntpc.edu.tw": ["新北市私立竹林中學", "Chu-Lin Private High School"],
    ".hshs.ntpc.edu.tw": [
        "New Taipei Municipal Banqiao Senior High School",
        "New Taipei Municipal Banqiao Senior High School",
    ],
    ".jdjh.ntpc.edu.tw": ["正德國中", "ZhengDe Junior high school"],
    ".stdmail.nssh.ntpc.edu.tw": [
        "私立南山高中",
        "Private Nanshan Senior High School",
    ],
    ".g.ntsh.ntpc.edu.tw": [
        "新北市立新北高級中學",
        "NewTaipei City Municpal NewTaipei Senior High School",
    ],
    ".ms.tcjh.ntpc.edu.tw": [
        "新北市立土城國民中學",
        "New Taipei Municipal Tucheng Junior High School",
    ],
    ".ntpu.edu.tw": ["National Taipei University"],
    ".ms104.nttu.edu.tw": ["National Taitung University"],
    ".ms109.nttu.edu.tw": ["國立台東大學", "National Taitung University"],
    ".ms93.nttu.edu.tw": ["國立臺東大學", "National Taitung University"],
    ".ms99.nttu.edu.tw": ["國立臺東大學", "National Taitung University"],
    ".nttu.edu.tw": ["國立臺東大學", "National Taitung University"],
    ".ntu.edu.tw": ["National Taiwan University"],
    ".mail.ntua.edu.tw": [
        "國立台灣藝術大學",
        "National Taiwan University of Arts",
    ],
    ".ntub.edu.tw": [
        "國立臺北商業大學",
        "National Taipei University of Business",
    ],
    ".ntue.edu.tw": [
        "國立台北教育大學",
        "national taipei university of education",
    ],
    ".ntunhs.edu.tw": [
        "National Taipei University of Nursing and Health Sciences"
    ],
    ".ntupes.edu.tw": [
        "國立臺灣體育運動大學",
        "National Taiwan University of Sport",
    ],
    ".ntus.edu.tw": [
        "國立臺灣體育運動大學",
        "National Taiwan University of Sport",
    ],
    ".ntust.edu.tw": ["National Taiwan University of Science and Technology"],
    ".ntut.edu.tw": ["National Taipei University of Technology"],
    ".nuk.edu.tw": ["National University of Kaohsiung"],
    ".nutc.edu.tw": [
        "國立臺中科技大學",
        "National Taichung University of Science and Technology",
    ],
    ".gm2.nutn.edu.tw": ["國立臺南大學", "National University of Tainan"],
    ".ps.nutn.edu.tw": [
        "國立臺南大學附設實驗國民小學",
        "National University of Tainan Affiliated Primary School",
    ],
    ".stumail.nutn.edu.tw": ["國立臺南大學", "National University of Tainan"],
    ".gm.nuu.edu.tw": ["國立聯合大學", "National United University"],
    ".nuu.edu.tw": ["國立聯合大學", "National United University"],
    ".nycu.edu.tw": [
        "National Yang Ming Chiao Tung University",
        "國立陽明交通大學",
    ],
    ".ocu.edu.tw": ["僑光科技大學", "Oversea Chinese University"],
    ".mail.oit.edu.tw": ["亞東技術學院", "Oriental Institute of Technology"],
    ".ouk.edu.tw": ["Kaohsuing Open University"],
    ".pccu.edu.tw": ["Chinese Culture University"],
    ".mksh.phc.edu.tw": ["National Magong High School"],
    ".pths.ptc.edu.tw": [
        "國立屏東高中",
        "National Pingtung Senior High School",
    ],
    ".pu.edu.tw": ["Providence University"],
    ".school.saihs.edu.tw": [
        "臺北市立松山高級工農職業學校",
        "Songshan High School of Agriculture and Industry",
    ],
    ".scu.edu.tw": ["Soochow University"],
    ".shu.edu.tw": ["Shih Hsin University"],
    ".gate.sinica.edu.tw": ["Academia Sinica"],
    ".iis.sinica.edu.tw": [
        "中央研究院資訊科學研究所",
        "Institute of Information Science, Academia Sinica",
    ],
    ".stud.sju.edu.tw": ["聖約翰科技大學", "St. John's University"],
    ".stu.edu.tw": ["SHU-TE University"],
    ".stust.edu.tw": [
        "南台科技大學",
        "Southern Taiwan University of Science and Technology",
    ],
    ".stut.edu.tw": ["Southern Taiwan University of Technology"],
    ".student.tajen.edu.tw": ["Tajen University"],
    ".cc.takming.edu.tw": [
        "德明財經科技大學",
        "Takming University of Science and Technology",
    ],
    ".gs.takming.edu.tw": [
        "德明財經科技大學",
        "takming university of science and technology",
    ],
    ".takming.edu.tw": [
        "德明財金科技大學",
        "Takming University of Science and Technology",
    ],
    ".tas.edu.tw": ["Taipei American School"],
    ".gs.cgsh.tc.edu.tw": [
        "臺中市立中港高級中學",
        "Taichung Municipal Chung Gang Senior High School",
    ],
    ".cshs.tc.edu.tw": [
        "臺中市立清水高級中等學校",
        "Taichung Municipal Cingshuei Senior High School",
    ],
    ".stu.ctas.tc.edu.tw": ["臺中市私立僑泰高級中學", "Chiao-Tai High School"],
    ".ddjhs.tc.edu.tw": [
        "臺中市立大道國民中學",
        "Taichung Municipal Da-Dau Junior High School",
    ],
    ".ms1.fhbes.tc.edu.tw": [
        "台中市私立明道普霖斯頓雙語小學",
        "Future-Heir Bilingual Elementary School",
    ],
    ".mail.hwsh.tc.edu.tw": ["臺中市立惠文高級中學"],
    ".mdhs.tc.edu.tw": ["明德中學", "Ming-der senior high school"],
    ".st.tc.edu.tw": [
        "臺中市立光復國民中小學",
        "Taichung Municipal Kuang-Fu Junior high and Elementary School",
    ],
    ".tcfsh.tc.edu.tw": [
        "臺中市立臺中第一高級中等學校",
        "Taichung Municipal Taichung First Senior High School",
    ],
    ".tcivs.tc.edu.tw": [
        "臺中市立臺中工業高級中等學校",
        "Taichung Municipal Taichung Industrial High School",
    ],
    ".mail.tcvs.tc.edu.tw": [
        "臺中市立大甲工業高級中等學校",
        "Taichung Municipal Dajia Industrial Senior High School",
    ],
    ".vtsh.tc.edu.tw": ["St.Viator Catholic High School"],
    ".whs.tc.edu.tw": ["華盛頓高中", "washington high school"],
    ".wufai.tc.edu.tw": [
        "臺中市立霧峰農業工業高級中等學校",
        "Taichung Municipal Wufeng Agricultural and Industrial High School",
    ],
    ".gm.youth.tc.edu.tw": ["臺中市青年高級中學", "Youth Senior High School"],
    ".gms.tcu.edu.tw": ["Tzu Chi University"],
    ".tcu.edu.tw": ["Tzu Chi College of Medicine and Humanities"],
    ".ems.tcust.edu.tw": [
        "慈濟科技大學",
        "Tzu Chi University of Science and Technology",
    ],
    ".tcust.edu.tw": [
        "慈濟學校財團法人慈濟科技大學",
        "Tzu Chi University of Science and Technology",
    ],
    ".thu.edu.tw": ["Tunghai University"],
    ".tku.edu.tw": ["Tamkang University"],
    ".tmu.edu.tw": ["臺北醫學大學", "TAIPEI MEDICAL UNIVERSITY"],
    ".csjhs.tn.edu.tw": [
        "臺南市立中山國民中學",
        "Jhongshan Junior High School",
    ],
    ".nnkieh.tn.edu.tw": [
        "國立南科國際實驗高級中學",
        "National Nanke International Experimental High School",
    ],
    ".gm.ptivs.tn.edu.tw": [
        "國立台南高級工業職業學校",
        "National Tainan Industrial High School",
    ],
    ".stu.ssvs.tn.edu.tw": [
        "天主教慈幼高級工商職業學校",
        "Salesian Technical School Tainan Taiwan",
    ],
    ".tnfsh.tn.edu.tw": ["Tainan First Senior High School"],
    ".stu.tnssh.tn.edu.tw": [
        "國立台南第二高級中學",
        "National Tainan Second Senior High School",
    ],
    ".yrhs.tn.edu.tw": ["臺南市立永仁高級中學", "https://www.yrhs.tn.edu.tw"],
    ".tnnua.edu.tw": ["Tainan National University of the Arts"],
    ".mail2u.tnu.edu.tw": ["東南科技大學", "TUNGNAN UNIVERSITY"],
    ".tnu.edu.tw": ["東南科技大學", "Tungnan University"],
    ".gmcc.tnua.edu.tw": ["Taipei Nation University of Arts"],
    ".newmedia.tnua.edu.tw": [
        "國立臺北藝術大學",
        "Taipei National University of the Arts",
    ],
    ".tnua.edu.tw": ["Taipei National University of the Arts"],
    ".gl.ck.tp.edu.tw": [
        "臺北市立建國高級中學",
        "Taipei Municipal Jianguo High School",
    ],
    ".gafe.cksh.tp.edu.tw": [
        "臺北市立成功高級中學",
        "Taipei Municipal Chenggong High School",
    ],
    ".st.fhjh.tp.edu.tw": [
        "臺北市私立復興實驗高級中學",
        "Taipei Fuhsing Private School",
    ],
    ".ms2.hssh.tp.edu.tw": [
        "台北市立西松高級中學",
        "Taipei Municipal XiSong Senior High School",
    ],
    ".mail.nihs.tp.edu.tw": ["Taipei Munucipal Nei-Hu Vocational High School"],
    ".im.tpcu.edu.tw": [
        "臺北城市科技大學",
        "Taipei City University of Science & Technology",
    ],
    ".tpcu.edu.tw": [
        "台北城市科技大學",
        "Taipei City University of Science and Technology",
    ],
    ".tpec.edu.tw": ["Taipei Physical Education College"],
    ".ttu.edu.tw": ["TaTung University "],
    ".twu.edu.tw": ["TransWorld University"],
    ".gm.clhs.tyc.edu.tw": [
        "國立中央大學附屬中壢高級中學",
        "The Affiliated Zhongli Senior High School of National Central University",
    ],
    ".gm2.fxsh.tyc.edu.tw": ["振聲高中"],
    ".nksh.tyc.edu.tw": ["桃園市立南崁高級中學"],
    ".phsh.tyc.edu.tw": ["\ufeffPaul Hsu Senior High School"],
    ".email.wlsh.tyc.edu.tw": ["桃園市立武陵高級中等學校"],
    ".uch.edu.tw": [
        "健行科技大學",
        "Chien Hsin University of Science and Technology",
    ],
    ".g2.usc.edu.tw": ["實踐大學", "Shih Chien University"],
    ".gm.usc.edu.tw": ["實踐大學", "Shih Chien University"],
    ".gm1.usc.edu.tw": ["實踐大學", "Shih Chien University"],
    ".gm2.usc.edu.tw": ["實踐大學", "Shih Chien University"],
    ".gm7.usc.edu.tw": ["實踐大學", "Shih Chien University"],
    ".utaipei.edu.tw": ["\ufeffUniversity of Taipei"],
    ".vnu.edu.tw": ["Vanung University"],
    ".wfu.edu.tw": ["吳鳳科技大學", "WuFeng University"],
    ".wzu.edu.tw": ["文藻外語大學", "Wenzao Ursuline University of Languages"],
    ".pjes.ylc.edu.tw": ["Pijiao National Primary School"],
    ".ym.edu.tw": ["National Yang Ming Medical College"],
    ".yuntech.edu.tw": [
        "National Yunlin University of Science and Technology"
    ],
    ".yzu.edu.tw": ["Yuan Ze University"],
    ".ctschool.org.tw": [
        "臺北市運算思維實驗教育機構",
        "Taipei Computational Thinking School",
    ],
    ".cycu.org.tw": ["Chung Yuan Christian University"],
    ".ntut.org.tw": ["NTUT", "National Taipei University of Technology"],
    ".yuntech.org.tw": [
        "國立雲林科技大學",
        "National Yunlin University of Science and Technology",
    ],
    ".yphs.tw": [
        "新北市立永平高級中學",
        "New Taipei Municipal Yongping Senior High School",
    ],
    ".aims.ac.tz": ["African Institute for Mathematical Sciences (AIMS)"],
    ".almaktoum.ac.tz": ["Al-Maktoum College of Engineering and Technology"],
    ".aru.ac.tz": ["ardhi university"],
    ".atc.ac.tz": ["Arusha Technical College"],
    ".dit.ac.tz": ["Dares Salaam Institute of Technology"],
    ".eastc.ac.tz": ["Eastern Africa Statistical Training Centre"],
    ".hkmu.ac.tz": ["Hubert Kairuki Memorial University"],
    ".iaa.ac.tz": ["Institute of Accountancy Arusha"],
    ".ifm.ac.tz": ["The Institute of Finance Management, Tanzania"],
    ".ilboru.ac.tz": ["Ilboru High School"],
    ".jriit.ac.tz": ["Jr Institute Of Information Technology"],
    ".kcmc.ac.tz": ["Kilimanjaro Christian Medical College"],
    ".mnma.ac.tz": ["Mwalimu Nyerere Memorial Academy"],
    ".muchs.ac.tz": [
        "Muhimbili University of Health and Allied Sciences (MUHAS)"
    ],
    ".mustnet.ac.tz": ["Mbeya University of Science and Technology"],
    ".mustudent.ac.tz": ["Mzumbe University (Chuo Kikuu Mzumbe)"],
    ".mzumbe.ac.tz": ["Mzumbe University (Chuo Kikuu Mzumbe)"],
    ".nm-aist.ac.tz": [
        "Nelson Mandela African Institution of Science and Technology",
        "Nelson Mandela African Institution of Science and Technology",
    ],
    ".nyaishozicollege.ac.tz": [
        "Nyaishozi College of Health and Allied Sciences"
    ],
    ".openuniversity.ac.tz": ["Open University of Tanzania"],
    ".student.out.ac.tz": [
        "Open University Of Tanzania",
        "Open University Of Tanzania",
    ],
    ".saut.ac.tz": ["St. Augustine University of Tanzania"],
    ".suanet.ac.tz": ["Sokoine University of Agriculture"],
    ".tumaini.ac.tz": ["Tumaini University - Iringa University College"],
    ".udom.ac.tz": ["University of Dodoma"],
    ".udsm.ac.tz": ["University of Dar Es Salaam"],
    ".uoi.ac.tz": ["University of Iringa", "University of Iringa"],
    ".ROBOCODE.ua": ["ROBOCODE", "ROBOCODE"],
    ".phymly.ck.ua": ['Fyzyko-Matematycheskyy Lytsey "PHYMLY"', "PHYMLY"],
    ".stu.cn.ua": ["Chernihiv National University of Technology"],
    ".kvpu.co.ua": ["Конотопське вище професійне училище"],
    ".178.com.ua": ["Гімназія №178 міста Києва", "Gymnasium №178 of Kyiv"],
    ".boiko.com.ua": [
        'Харківський приватний навчально-виховний комплекс "Авторська школа Бойка" Харківської області',
        'Kharkiv educational complex institution "Boiko English Private School"',
    ],
    ".bpedk.com.ua": ["Бердичівський педагогічний коледж"],
    ".knutd.com.ua": [
        "Київський національний університет технологій та дизайну",
        "Kyiv National University of Technologies and Design",
    ],
    ".kpk-lp.com.ua": [
        "Коломийський політехнічний фаховий коледж Національного університету «Львівська політехніка»"
    ],
    ".lnvk22.com.ua": [
        "Луцький ліцей №22 Луцької міської ради",
        "Lutsk Lyceum No. 22 of the Lutsk City Council",
    ],
    ".lpml.com.ua": [
        "Львівський фізико-математичний ліцей",
        "Lviv Physics and Matematics lyceum",
    ],
    ".lutsk-ntu.com.ua": [
        "Луцький Національний Технічний Університет",
        "Lutsk National Technical University",
    ],
    ".maup.com.ua": [
        "Міжрегіональна Академія Управління Персоналом",
        "Interregional Academy of Personnel Management",
    ],
    ".novoshkola.com.ua": ["Новопечерська Школа", "Novopecherska School"],
    ".sclnau.com.ua": [
        "Стрийський коледж Львівського національного аграрного університету",
        "Stryi College of Lviv National Agrarian University",
    ],
    ".sevntu.com.ua": ["Sevastopol National Technical University"],
    ".tyachivlicey.com.ua": [
        'Municipal Institution "Tyachiv Vocational Lyceum"',
        "Tyachiv Vocational Lyceum of Transcarpathian region",
    ],
    ".zap-construct.com.ua": [
        "Запорізький Будівельний Фаховий Коледж",
        "Zaporizhzhya Construction Vocational College",
    ],
    ".zcollage.com.ua": [
        "Золочівський фаховий коледж Національного університету Львівська політехніка",
        "Zolochiv Vocational College of the National University of Lviv Polytechnic",
    ],
    ".zski.com.ua": ["Січовий колегіум", "Sich colegium"],
    ".tnu.crimea.ua": ["Taurida National V.I.Vernadsky University"],
    ".chic.cv.ua": [
        "Чернівецький індустріальний фаховий коледж",
        "Chernivtsi Industrial Vocational College",
    ],
    ".chnu.cv.ua": ["Chernivci National University"],
    ".chtei-knteu.cv.ua": [
        "Чернівецький торговельно-економічний інститут",
        "Chernivtsi Institute of Trade and Economics",
    ],
    ".g2s.cv.ua": ["Чернівецький ліцей №11", "Chernivtsi lyceum №11"],
    ".lyceum1.cv.ua": ["Чернівецький ліцей №1", "Chernivtsi Lyceum No 1"],
    ".polytech.cv.ua": [
        "Чернівецький політехнічний фаховий коледж",
        "Chernivtsi Polytechnic Applied College",
    ],
    ".dgma.donetsk.ua": [
        "Донбаська державна машинобудівна академія",
        "Donbas State Machine-Building Academy",
    ],
    ".dlit.dp.ua": [
        "Dnipro Lyceum of Information Technologies at DNU (LIT)",
        "Дніпровський ліцей інформаційних технологій при ДНУ (ЛІТ)",
    ],
    ".dnu.dp.ua": ["Dnepropetrovsk National University"],
    ".ef.dnulive.dp.ua": [
        "Дніпропетровський національний університет імені Олеся Гончара ",
        "Dnipropetrovsk national university Oles Honchar",
    ],
    ".ffeks.dnulive.dp.ua": [
        "Дніпропетровський національний університет імені Олеся Гончара ",
        "Dnipropetrovsk national university Oles Honchar",
    ],
    ".fpm.dnulive.dp.ua": [
        "Дніпропетровський національний університет імені Олеся Гончара ",
        "Dnipropetrovsk national university Oles Honchar",
    ],
    ".ftf.dnulive.dp.ua": [
        "Дніпропетровський національний університет імені Олеся Гончара ",
        "Dnipropetrovsk national university Oles Honchar",
    ],
    ".dolifmp.dp.ua": ["Liceum in Dnepr"],
    ".student.dsau.dp.ua": [
        "Дніпровський державний аграрно-економічний університет",
        "Dnipro State Agrarian and Economic University",
    ],
    ".dsma.dp.ua": [
        'ДЗ "Дніпропетровська медична академія МОЗ України"',
        'State Establishment "Dnipropetrovsk Medical Academy of Health Ministry of Ukraine" (SE "DMA")',
    ],
    ".dstu.dp.ua": ["Dneprodzerzhinsk State Technical University"],
    ".kneu.dp.ua": [
        "Державний університет економіки і технологій",
        "State university of economics and technology",
    ],
    ".kre.dp.ua": [
        "Дніпровський фаховий коледж радіоелектроніки",
        "Dnipro Applied College of Radio Electronics",
    ],
    ".365.pgasa.dp.ua": [
        "Приднепровская государственная академия строительства и архитектуры",
        "Prydniprovska State Academy of Civil Engineering and Architecture",
    ],
    ".umsf.dp.ua": [
        "Університет митної справи та фінансів",
        "University of Customs and Finance",
    ],
    ".auk.edu.ua": ["American University Kyiv"],
    ".bsmu.edu.ua": ["Bukovinian State Medical University"],
    ".btsau.edu.ua": [
        "Білоцерківський Державний Аграрний Університет",
        "Bila Tserkva National Agrarian University",
    ],
    ".bukuniver.edu.ua": [
        'ПВНЗ "Буковинський університет"',
        "Bukovinian university",
    ],
    ".cdu.edu.ua": [
        "The Bohdan Khmelnytsky National University of Cherkasy",
        "Черкаський національний університет імені Богдана Хмельницького",
    ],
    ".chdtu.edu.ua": [
        "Cherkasy State Technological University",
        "Черкаський Державний Технологічний Університет",
    ],
    ".chmnu.edu.ua": [
        "Чорноморський національний університет імені Петра Могили",
        "Petro Mohyla Black Sea National University",
    ],
    ".chnu.edu.ua": ["Chernivtsi National University"],
    ".chpt.edu.ua": [
        "Черкаський політехнічний фаховий коледж",
        "Cherkasy Polytechnic Applied College",
    ],
    ".csbc.edu.ua": ["Cherkasy State Business College"],
    ".cuspu.edu.ua": [
        "Центральноукраїнський державний педагогічний університет імені Володимира Винниченка",
        "Volodymyr Vynnychenko Central Ukrainian State Pedagogical University",
    ],
    ".dakkkim.edu.ua": [
        "Національна академія керівних кадрів культури і мистецтв",
        "National Academy of Culture and Arts Management",
    ],
    ".ddpu.edu.ua": [
        "Донбаський державний педагогічний університет",
        "Donbas State Pedagogical University",
    ],
    ".diit.edu.ua": [
        "Dnepropetrovsk National University of Railway Transport"
    ],
    ".ef.dnu.edu.ua": [
        "Дніпровський національний університет ім. Олеся Гончара",
        "Oles Honchar Dnipro National University",
    ],
    ".ffeks.dnu.edu.ua": [
        "Дніпровський національний університет імені Олеся Гончара",
        "Dnipro National University ",
    ],
    ".fpm.dnu.edu.ua": [
        "Дніпровський національний університет імені Олеся Гончара",
        "Dnipro National University ",
    ],
    ".ftf.dnu.edu.ua": [
        " Дніпровський національний університет імені Олеся Гончара",
        "Oles Honchar Dnipro National University",
    ],
    ".dnu.edu.ua": [
        "Дніпровський національний університет імені Олеся Гончара",
        "Dnipro National University ",
    ],
    ".donntu.edu.ua": ["Donetsk National Technical University"],
    ".donnu.edu.ua": ["Donetsk National University"],
    ".donnuet.edu.ua": [
        "Донецький національний університет економіки і торгівлі імені Михайла Туган-Барановського",
        "Donetsk National University of Economics and Trade named after Michael Tugan-Baranovsky",
    ],
    ".donuu.edu.ua": [
        "Vasyl' Stus Donetsk National University",
        "Vasyl' Stus Donetsk National University",
    ],
    ".dspu.edu.ua": [
        "Дрогобицький Державний Педагогічний Університет імені Івана Франка",
        "Drohobych Ivan Franko State Pedagogical Univercity",
    ],
    ".inbox.dsum.edu.ua": [
        "Donetsk State University of Management",
        "Донецкий Государственный Университет Управления",
    ],
    ".duan.edu.ua": [
        "Университет имени Альфреда Нобеля (Днепр,Украина)",
        "Alfred Nobel University",
    ],
    ".duet.edu.ua": [
        "Державний університет економіки і технологій",
        "State university of economics and technology",
    ],
    ".duikt.edu.ua": [
        "Державний університет інформаційно-комунікаційних технологій",
        "State University of Information and Communication Technologies",
    ],
    ".duit.edu.ua": [
        "Державний університет інфраструктури та технологій",
        "State University of infrastructure and technologies",
    ],
    ".students.dut.edu.ua": [
        "Державний Університет Телекомунікацій ",
        "State University of Telecommunication",
    ],
    ".dut.edu.ua": [
        "Державний університет телекомунікацій",
        "State University of Telecommunications",
    ],
    ".e-u.edu.ua": [
        'Приватний вищий навчальний заклад "Європейський університет"',
        'Private Higher Education Establishment "European University"',
    ],
    ".gi.edu.ua": [
        "Галицький фаховий коледж імені В'ячеслава Чорновола",
        "Halytsky applied college named Vyacheslav Chornovil",
    ],
    ".hneu.edu.ua": ["Kharkiv National University of Economics"],
    ".hnpu.edu.ua": [
        "H.S. Skovoroda Kharkiv National  Pedagogical University",
        "Харьковский национальный педагогический университет им. Г.С. Сковороды",
    ],
    ".hpk.edu.ua": [
        'Хмельницький політехнічний фаховий коледж Національного університету "Львівська політехніка"',
        "Khmelnytskyi Polytechnic College by Lviv Polytechnic National University",
    ],
    ".iapm.edu.ua": [
        "Міжрегіональна Академія Управління Персоналом",
        "Interregional Academy of Personnel Management",
    ],
    ".ieu.edu.ua": [
        "Міжнародний Європейський Університет",
        "International European University",
    ],
    ".ifnmu.edu.ua": [
        "Івано-Франківський національний медичний університет",
        "Ivano-Frankivsk National Medical University",
    ],
    ".iir.edu.ua": [
        "Інститут міжнародних відносин Київського національного університету імені Тараса Шевченка",
        "Institute of international relations, Taras Shevchenko National University of Kyiv",
    ],
    ".ipk.edu.ua": [
        "Інститут підготовки кадрів державної служби зайнятості України",
        "Ukrainian State Employment Service Training Institute",
    ],
    ".istu.edu.ua": [
        "Міжнародний науково-технічний університет академіка Юрія Бугая",
        "Academician Yuriy Bugay International Scientific and Technical University",
    ],
    ".kai.edu.ua": [
        "Київський Авіаційний Інститут",
        "Kyiv Aviation Institute",
    ],
    ".kart.edu.ua": [
        "The Ukrainian State University of Railway Transport",
        "The Ukrainian State University of Railway Transport",
    ],
    ".kau.edu.ua": [
        "Київський академічний університет (КАУ)",
        "KIYV ACADEMIC UNIVERSITY",
    ],
    ".kdpu.edu.ua": ["State Pedagogical University in Kryvyi Rih"],
    ".kdu.edu.ua": ["Kremenchuk Mykhailo Ostrohradskyi National University"],
    ".student.khai.edu.ua": [
        'Національний аерокосмічний університет ім. М.Є. Жуковського "Харківський авіаційний інститут"',
        'National Aerospace University "Kharkiv Aviation Institute", NAU "KhAI"',
    ],
    ".khmnu.edu.ua": [
        "Хмельницький національний університет",
        "Khmelnytsky National University",
    ],
    ".khpi.edu.ua": [
        "Харьковский политехнический институт",
        "Kharkiv Polytechnic Institute",
    ],
    ".kibit.edu.ua": [
        "Київський Інститут Бізнесу та Технологій",
        "Kyiv Institute of Business and Technology",
    ],
    ".kmu.edu.ua": [
        "Private higher educational establishment Kyiv Medical University"
    ],
    ".kname.edu.ua": [
        "Харківський національний університет міського господарства імені О. М. Бекетова",
        "O.M. Beketov National University of Urban Economy in Kharkiv",
    ],
    ".kneu.edu.ua": [
        "Київський національний економічний університет імені Вадима Гетьмана",
        "Kyiv National Economic University named after Vadym Hetman",
    ],
    ".knmu.edu.ua": [
        "Kharkiv National Medical University",
        "Kharkiv National Medical University",
    ],
    ".kntu.edu.ua": ["Kherson National Technical University"],
    ".knu.edu.ua": ["Kryvyi Rih National University"],
    ".knuba.edu.ua": [
        "Kiev National University of Construction and Architecture"
    ],
    ".knukim.edu.ua": [
        "Київський Національний Університет Культури і Мистецтв",
        "Kyiv National University of Culture and Arts",
    ],
    ".knutd.edu.ua": ["Kyiv National University of Technologies and Design"],
    ".knute.edu.ua": [
        "KYIV NATIONAL UNIVERSITY OF TRADE AND ECONOMICS",
        "Web-site: https://knute.edu.ua//",
        "old domain: knteu.kiev.ua",
    ],
    ".knutkt.edu.ua": [
        "Київський національний університет театру, кіно і телебачення імені Івана Карпенка-Карого",
        "Kyiv National I. K. Karpenko-Karyi Theatre, Cinema and Television University",
    ],
    ".kpnu.edu.ua": [
        "Кам'янець-Подільський національний університет імені Івана Огієнка",
        "Kamianets-Podіlskyi National Ivan Ohiienko University",
    ],
    ".krok.edu.ua": ["KROK Economics and Law University"],
    ".krpd.edu.ua": [
        "Державний Університет Економіки і Технологій",
        "State University of Economics and Technology",
    ],
    ".ksu.edu.ua": ["Kiev Slavonic University"],
    ".kubg.edu.ua": [
        "Київський Університет імені Бориса Грінченка",
        "Borys Hrinchenko University of Kyiv",
    ],
    ".ldubgd.edu.ua": ["Lviv State University of Life Safety"],
    ".lnam.edu.ua": [
        "Львівська національна академія мистецтв",
        "Lviv National Academy of Arts",
    ],
    ".lnau.edu.ua": [
        "Львівський національний аграрний університет",
        "Lviv National Agrarian University",
    ],
    ".lnma.edu.ua": ["The Mykola Lysenko Lviv National Music Academy"],
    ".lntu.edu.ua": [
        "ЛУЦЬКИЙ НАЦІОНАЛЬНИЙ ТЕХНІЧНИЙ УНІВЕРСИТЕТ",
        "Lutsk National Technical University (Lutsk NTU)",
    ],
    ".lnu.edu.ua": [
        "Львівський національний університет імені Івана Франка",
        "Lviv National University",
        "Ivan Franko National University of Lviv",
    ],
    ".lnup.edu.ua": [
        "Львівський національний університет природокористування",
        "Lviv National University of Nature Management",
    ],
    ".lp.edu.ua": ["Lviv Polytechnic National University"],
    ".luguniv.edu.ua": [
        "Луганський національний університет імені Тараса Шевченка",
        "Luhansk Taras Shevchenko National University",
    ],
    ".lvet.edu.ua": [
        "Львівський національний університет ветеринарної медицини та біотехнологій імені Степана Ґжицького",
        "Stepan Gzhytskyi National University of Veterinary Medicine and Biotechnologies of Lviv",
    ],
    ".megu.edu.ua": [
        "Міжнародний економіко-гуманітарний університет імені академіка Степана Дем'янчука",
        "Academician Stepan Demianchuk international university of economics and humanities",
    ],
    ".mgu.edu.ua": [
        "\ufeffМіжнародний гуманітарний університет",
        "International Humanitarian Universiy, Odessa",
    ],
    ".mkkm.edu.ua": ["МИКОЛАЇВСЬКИЙ ФАХОВИЙ КОЛЕДЖ КУЛЬТУРИ І МИСТЕЦТВ"],
    ".mku.edu.ua": [
        'Приватний заклад вищої освіти "Міжнародний класичний університет імені Пилипа Орлика"',
        'Private higher educational institution "Pylyp Orlyk International Classical University"',
    ],
    ".mnau.edu.ua": [
        "Николаевский национальный аграрный университет",
        "Mykolayiv National Agrarian University",
    ],
    ".mspu.edu.ua": [
        "Мелітопольский державний педагогічний університет імені Богдана Хмельницького",
        "Bogdan Khmelnitsky Melitopol State Pedagogical University",
    ],
    ".mu.edu.ua": ["Mariupol State University "],
    ".nasbu.edu.ua": [
        "Національна академія Служби безпеки України",
        "National Academy of the Security Service of Ukraine",
    ],
    ".nasoa.edu.ua": [
        "The National Academy of Statistics, Accounting and Audit",
        "The National Academy of Statistics, Accounting and Audit",
    ],
    ".kitu.nau.edu.ua": ["Коледж Інженерії та Управління НАУ"],
    ".kitz.nau.edu.ua": [
        'Фаховий коледж інженерії, управління та землевпорядкування Державного некомерційного підприємства "Державний університет "Київський авіаційний інститут"'
    ],
    ".npp.nau.edu.ua": [
        "Національний Авіаційний Університет",
        "National Aviation University",
    ],
    ".sfk.nau.edu.ua": [
        "Слов’янський фаховий коледж Державного некомерційного підприємства «Державний університет «Київський авіаційний інститут»",
        "Slovyansk Professional College of the State Non-Commercial Enterprise “State University ‘Kyiv Aviation Institute’”",
    ],
    ".nltu.edu.ua": [
        "Український національний лісотехнічний Університет",
        "UKRAINIAN NATIONAL FORESTRY UNIVERSITY",
    ],
    ".nlu.edu.ua": [
        "Національний юридичний університет імені Ярослава Мудрого",
        "Yaroslav Mudryi National Law University",
    ],
    ".nmetau.edu.ua": ["National Metallurgical Academy of Ukraine"],
    ".npu.edu.ua": ["National Pedagogical University M. Dragomanov "],
    ".ntu.edu.ua": [
        "Національний транспортний університет",
        "National Transport University",
    ],
    ".it.nubip.edu.ua": [
        "Національний університет біоресурсів і природокористування України",
        "National University of Life and Environmental Sciences of Ukraine",
    ],
    ".nubip.edu.ua": [
        "Національний університет біоресурсів і природокористування України",
        "National University of Life and Environmental Sciences of Ukraine",
    ],
    ".nuft.edu.ua": ["Національний університет харчових технологій"],
    ".nung.edu.ua": [
        "Івано-Франківський національний технічний університет нафти і газу",
        "Ivano-Frankivsk National Technical University of Oil and Gas",
    ],
    ".nuos.edu.ua": [
        "\ufeffНаціональний Університет кораблебудування імені адмірала Макарова"
    ],
    ".nuph.edu.ua": [
        "Національний фармацевтичний університет",
        "National University of Pharmacy",
    ],
    ".nupp.edu.ua": [
        "Національний університет «Полтавська політехніка імені Юрія Кондратюка»",
        "The National University «Yuri Kondratyuk Poltava Polytechnic»",
    ],
    ".nusta.edu.ua": [
        "Державний податковий університет",
        "State tax university",
    ],
    ".nuwm.edu.ua": [
        "Національний університет водного господарства та природокористування",
        "National University of Water Management and Environmental Sciences",
    ],
    ".oa.edu.ua": [
        'National University "Ostroh Academy"',
        'Національний університет "Острозька академія"',
    ],
    ".onaft.edu.ua": [
        "Одесская национальная академия пищевых технологий",
        "Odessa National Academy of Food Technologies",
    ],
    ".onat.edu.ua": [
        "ODESSA NATIONAL ACADEMY OF TELECOMMUNICATIONS named after O.S.POPOV",
        "ОДЕССКАЯ НАЦИОНАЛЬНАЯ АКАДЕМИЯ СВЯЗИ им. А.С.ПОПОВА",
    ],
    ".onmedu.edu.ua": ["Odessa National Medical University"],
    ".ontu.edu.ua": [
        "Одеський національний технологічний університет",
        "Odesa National University of Technology",
    ],
    ".onu.edu.ua": ["Odessa National I.I. Mecnikov University"],
    ".onua.edu.ua": [
        'Національний університет "Одеська юридична академія"',
        "National University Odesa Law Academy",
    ],
    ".stud.op.edu.ua": [
        "Одесская Политехника",
        "Odessа Polytechnic State University",
    ],
    ".op.edu.ua": [
        "Національний університет «Одеська політехніка»",
        "Odesа Polytechnic National University",
    ],
    ".pdaa.edu.ua": [
        "Полтавський державний аграрний університет",
        "Poltava State Agrarian University",
    ],
    ".pdatu.edu.ua": [
        "ПОДІЛЬСЬКИЙ ДЕРЖАВНИЙ УНІВЕРСИТЕТ",
        "PODILLIA STATE UNIVERSITY",
    ],
    ".pdau.edu.ua": [
        "Полтавський аграрний університет",
        "Poltava State Agrarian University",
    ],
    ".pdpu.edu.ua": [
        "Південноукраїнський національний педагогічний університет імені К. Д. Ушинського"
    ],
    ".pntu.edu.ua": ["Poltava National Technical University"],
    ".pnu.edu.ua": [
        "Прикарпатський національний університет імені Василя Стефаника",
        "Vasyl Stefanyk Precarpathian National University",
    ],
    ".polissiauniver.edu.ua": [
        "Поліський Національний Університет",
        "Polisʹkyy Natsionalʹnyy Universytet",
    ],
    ".puet.edu.ua": ["Poltava University of Economics and Trade"],
    ".putped.edu.ua": [
        "Путивльский педагогІчний колледж",
        "Putivl Pedagogical college",
    ],
    ".rkepk.edu.ua": [
        "Рівненський Кооперативний Економіко-Правовий Фаховий коледж",
        "Rivne Cooperative Economic and Legal College",
    ],
    ".rshu.edu.ua": [
        "Рівненський Державний Гуманітарний Університет ",
        "Rivne State Humanities University",
    ],
    ".setuniversity.edu.ua": [
        "Університет науки, підприємництва та технологій",
        "SET University",
    ],
    ".snu.edu.ua": ["East Ukrainian National University"],
    ".ssu.edu.ua": ["Сумський державний університет", "Sumy State University"],
    ".suem.edu.ua": [
        "Східноєвропейський університет імені Рауфа Аблязова",
        "Rauf Ablyazov East European University",
    ],
    ".suitt.edu.ua": [
        "Державний університет інтелектуальних технологій і зв'язку",
        "State University of Information Technologies and Telecommunications",
    ],
    ".sumdu.edu.ua": ["Sumy State University"],
    ".tane.edu.ua": ["Ternopil Academy of National Economy"],
    ".tdmu.edu.ua": [
        "ТЕРНОПІЛЬСЬКИЙ НАЦІОНАЛЬНИЙ МЕДИЧНИЙ УНІВЕРСИТЕТ",
        "TERNOPIL NATIONAL MEDICAL UNIVERSITY",
    ],
    ".elr.tnpu.edu.ua": [
        "ТЕРНОПІЛЬСЬКИЙ НАЦІОНАЛЬНИЙ ПЕДАГОГІЧНИЙ УНІВЕРСИТЕТ імені ВОЛОДИМИРА ГНАТЮКА",
        "VOLODYMYR HNATYUK NATIONAL PEDAGOGICAL UNIVERSITY",
    ],
    ".fizmat.tnpu.edu.ua": [
        "Фізико-математичний факультет Тернопільського педагогічного університету"
    ],
    ".ipf.tnpu.edu.ua": [
        "Інженерно-педагогічний факультет ТЕРНОПІЛЬСЬКОГО НАЦІОНАЛЬНОГО ПЕДАГОГІЧНОГО УНІВЕРСИТЕТУ імені ВОЛОДИМИРА ГНАТЮКА ",
        "Inzhenerno-Pedahohichnyy Fakulʹtet VOLODYMYR HNATYUK NATIONAL PEDAGOGICAL UNIVERSITY",
    ],
    ".tntu.edu.ua": [
        "Тернопільський національний технічний університет імені Івана Пулюя",
        "Ternopil Ivan Puluj National Technical University",
        "Web-site: https://tntu.edu.ua/",
    ],
    ".tnu.edu.ua": [
        "Таврический национальный университет имени В. И. Вернадского"
    ],
    ".tsatu.edu.ua": [
        "Таврійський державний агротехнологічний університет",
        "Tavria State Agrotechnological University",
    ],
    ".uacu.edu.ua": [
        "Україно-Американський університет Конкордія",
        "Ukrainian-American Concordia University",
    ],
    ".ucu.edu.ua": ["Ukrainian Catholic University", "UCU"],
    ".udhtu.edu.ua": [
        "Украинский государственный Химико-Технологический университет",
        " Ukrainian State Chemical-Technological University",
    ],
    ".udpu.edu.ua": [
        "УМАНСЬКИЙ ДЕРЖАВНИЙ ПЕДАГОГІЧНИЙ УНІВЕРСИТЕТ імені Павла Тичини",
        "PAVLO TYCHYNA UMAN STATE Pedagogical University",
    ],
    ".std.udu.edu.ua": [
        "Український державний університет імені Михайла Драгоманова",
        "The Dragomanov Ukrainian State University",
    ],
    ".udu.edu.ua": [
        "Український державний університет імені Михайла Драгоманова"
    ],
    ".ugi.edu.ua": [
        "Український Гуманітарний Інститут",
        "Ukrainian Institute of Arts and Sciences",
    ],
    ".uhsp.edu.ua": [
        "Університет Григорія Сковороди в Переяславі",
        "Grigory Skovoroda University in Pereyaslav",
    ],
    ".uipa.edu.ua": ["Ukrainian Engineering Pedagogics Academy "],
    ".ukd.edu.ua": ["Университет Короля Данила"],
    ".ukma.edu.ua": [
        "Національний університет «Києво-Могилянська академія»",
        "National University of Kyiv-Mohyla Academy",
    ],
    ".univd.edu.ua": ["National University of Internal Affairs"],
    ".usmtu.edu.ua": ["National University of Shipbuilding"],
    ".ust.edu.ua": [
        "Днепровский национальный университет железнодорожного транспорта имени академика В. Лазаряна",
        "Ukrainian State University of Science and Technologies",
    ],
    ".uzhnu.edu.ua": ["Uzhhorod National University"],
    ".viti.edu.ua": [
        "Військовий інститут телекомунікацій та інформатизації імені Героїв Крут",
        "Military institute of telecomunication and information technologies named after Heroes of Kruty",
    ],
    ".vnmu.edu.ua": ["Vinnitsa National Pirogov Medical University", "VNMU"],
    ".vntu.edu.ua": ["Vinnytsia National Technical University"],
    ".vnu.edu.ua": [
        "Волинський національний університет імені Лесі Українки",
        "Lesya Ukrainka Volyn National University",
    ],
    ".vspu.edu.ua": [
        "Вінницький державний педагогічний університет імені Михайла Коцюбинського",
        "Vinnytsia Mykhailo Kotsiubynskyi State Pedagogical University",
    ],
    ".wunu.edu.ua": [
        "Західноукраїнський національний університет",
        "West Ukrainian National University",
    ],
    ".zieit.edu.ua": [
        "Zaporizhzhya Institute of Economics and Information Technology"
    ],
    ".zntu.edu.ua": ["Zaporizhzhe National Technical University"],
    ".znu.edu.ua": ["Zaporizhzhe National University"],
    ".zp.edu.ua": [
        "Запорізька Політехніка Національний Університет",
        'National University "Zaporizhzhia Polytechnic"',
    ],
    ".stu.zsea.edu.ua": [
        "Запорожский национальный университет",
        "Zaporizhzhia National University",
    ],
    ".zsmu.edu.ua": [
        "Запорізький державний медичний університет",
        "Zaporizhzhia State Medical University",
    ],
    ".student.ztu.edu.ua": [
        'Державний університет "Житомирська політехніка"',
        "Zhytomyr Polytechnic State University",
    ],
    ".ztu.edu.ua": [
        'Державний університет "Житомирська політехніка"',
        "Zhytomyr Polytechnic State University",
    ],
    ".zu.edu.ua": [
        "Житомирський державний університет імені Івана Франка",
        "Zhytomyr Ivan Franko State University",
    ],
    ".goit.ua": ["GoIT Neoversity"],
    ".hups.mil.gov.ua": ["Kharkiv national Air Force university"],
    ".comp-sc.if.ua": [
        "Прикарпатський національний університет імені Василя Стефаника"
    ],
    ".ifdtung.if.ua": ["Ivano-Frankivsk National University of Oli and Gas"],
    ".pu.if.ua": ["Precarpathian University"],
    ".school16.if.ua": ["Ivano-Frankovsk secondary school No 16"],
    ".school3.if.ua": ["School 3 of Ivano-Frankovsk, Ukraine"],
    ".e-u.in.ua": [
        'Приватний вищий навчальний заклад "Європейський Університет"',
        'Privatniy vischiy navchalniy zaklad "Evropeyskiy Universitet"',
    ],
    ".kpi.in.ua": [
        "National Technical University (Kiev Politechnical Institute)"
    ],
    ".mschool5.in.ua": ["\ufeffСпециализированная школа №5 Мариуполь"],
    ".vvak.in.ua": [
        "Володимир-Волинський фаховий коледж",
        "Volodymyr-Volynskyi Vocational College",
    ],
    ".karazin.ua": ["V. N. Karazin Kharkov National University"],
    ".btu.kharkov.ua": [
        "ДЕРЖАВНИЙ БІОТЕХНОЛОГІЧНИЙ УНІВЕРСИТЕТ",
        "STATE BIOTECHNOLOGICAL UNIVERSITY",
    ],
    ".khadi.kharkov.ua": ["Kharkiv State Transport Technical University"],
    ".kpi.kharkov.ua": [
        "National Technical University (Kharkiv Polytechnical Institute)"
    ],
    ".ksmu.kharkov.ua": ["Kharkiv State Medical University"],
    ".kstuca.kharkov.ua": [
        "Kharkiv State Technical University of Construction and Architecture"
    ],
    ".kture.kharkov.ua": ["Kharkiv National University of Radio Electronics"],
    ".ukrfa.kharkov.ua": ["Ukrainian Academy of Pharmacy"],
    ".univer.kharkov.ua": ["Kharkiv National University"],
    ".ksaeu.kherson.ua": [
        "Kherson State Agrarian and Economic University",
        "Херсонський державний аграрно-економічний університет",
    ],
    ".university.kherson.ua": ["Kherson State University"],
    ".iao.kiev.ua": [
        'International Center "Institute of applied optics" NAS of Ukraine'
    ],
    ".kemk.kiev.ua": ["Kiev Electromechanical College"],
    ".kmrf.kiev.ua": [
        "Коледж морського і річкового флоту Державного університету інфраструктури та технологій",
        "College of Marine and River Fleet of State University of Infrastructure and Technologies",
    ],
    ".kneu.kiev.ua": ["Kiev National Economic University"],
    ".knteu.kiev.ua": ["Kyiv National University of Trade and Economics"],
    ".ktgg.kiev.ua": [
        "Київський фаховий коледж туризму та готельного господарства",
        "The Kyiv Applied College of Tourism and Hospitality",
    ],
    ".lic145.kiev.ua": [
        "Київський Природничо-Науковий Ліцей №145",
        "Kyiv Natural-Scientific Lyceum No. 145",
    ],
    ".lyceum-intellect.kiev.ua": ["Ліцей Інтеллект", "Lyceum Intellect"],
    ".naiau.kiev.ua": [
        "Національна академія внутрішніх справ",
        "National academy of internal affairs",
    ],
    ".new.naukova-zmina.kiev.ua": [
        "Ліцей Наукова Зміна ",
        "lyceum Naukova Zmina",
    ],
    ".nauu.kiev.ua": ["National Agricultural University"],
    ".ortlyceum.kiev.ua": ["Educational Complex 141 ORT"],
    ".rl.kiev.ua": [
        "Україна, Русанівський ліцей м.Києва",
        "Rusanovskiy liceum",
    ],
    ".sch3.kiev.ua": ["Спеціалізована школа №3", "Specialized school #3"],
    ".socosvita.kiev.ua": [
        "Academy of Labour, Social Relations and Tourism",
        "Academy of Labour, Social Relations and Tourism",
    ],
    ".tl-kpi.kiev.ua": ["Технічний ліцей НТУУ “КПІ”"],
    ".ukma.kiev.ua": ["National University of Kiev-Mohyla Academy"],
    ".unicyb.kiev.ua": [
        "Cybernetics Faculty, National Taras Shevchenko University of Kiev"
    ],
    ".univ.kiev.ua": ["National Taras Shevchenko University of Kiev"],
    ".usuft.kiev.ua": ["National University of Food Technologies"],
    ".khnu.km.ua": [
        "Khmelnitsky National University",
        "Хмельницький Національний Університет",
    ],
    ".kneu.ua": [
        "Kyiv National Economic University named after Vadym Hetman (KNEU)"
    ],
    ".knu.ua": [
        "Київський національний університет імені Тараса Шевченка",
        "Taras Shevchenko National University of Kyiv",
    ],
    ".kpi.ua": [
        "National Technical University (Kiev Politechnical Institute)"
    ],
    ".kic.kr.ua": [
        "ЕКОНОМІКО-ТЕХНОЛОГІЧНИЙ ІНСТИТУТ ІМЕНІ РОБЕРТА ЕЛЬВОРТІ",
        "ROBERT ELVORTI ECONOMICS AND TECHNOLOGY INSTITUTE",
    ],
    ".kntu.kr.ua": ["Central Ukrainian National Technical University"],
    ".kspu.kr.ua": ["Kirovograd State Pedagogical University"],
    ".ptu16.kr.ua": [
        "Професійно-технічне училище №16 м. Мала Виска",
        "Vocational school №16 Mala Vyska",
    ],
    ".ksma.ks.ua": [
        "Херсонська Морська Державна Академія",
        "Kherson State Maritime Academy",
    ],
    ".ksu.ks.ua": [
        "Kherson State University",
        "Херсонський державний університет",
    ],
    ".nkpfk.ks.ua": [
        "Новокаховський Приладобудівний Фаховий Колледж ",
        "Novokakhov Instrument-Making Professional College",
    ],
    ".university.ks.ua": ["Kherson State University"],
    ".ktepcknute.kyiv.ua": [
        "Відокремлений структурний підрозділ «Київський торговельно-економічний фаховий коледж Державного торговельно-економічного університету",
        "Separate Structural Subdivision 'Kyiv Trade and Economic Professional College of the State University of Trade and Economics",
    ],
    ".leader171.kyiv.ua": ["Києво-Печерський ліцей №171 “Лідер”"],
    ".ortlyc.kyiv.ua": [
        "Ліцей №141 ОРТ міста Києва",
        "Lyceum #141 ORT of Kyiv",
    ],
    ".lnau.lg.ua": ["Lugansk National Agrarian University"],
    ".lpnu.ua": ["Lviv Polytechnic National University"],
    ".gimn14.lutsk.ua": ["LUTSKY LYCEUM № 14 AFTER VASIL SUKHOMLYNSKY"],
    ".gymnasia21.lutsk.ua": ["Lutsk Gymnasium #  21 after Mikhail Kravchuk "],
    ".forest.lviv.ua": ["Ukrainian National Forestry University"],
    ".itcollege.lviv.ua": [
        "Відокремлений структурний підрозділ “Фаховий коледж інформаційних технологій Національного університету “Львівська політехніка”"
    ],
    ".lute.lviv.ua": ["Lviv University of Trade and Economics"],
    ".meduniv.lviv.ua": [
        "Lviv Medical University",
        "Lviv National Medical Univeristy",
    ],
    ".nltu.lviv.ua": ["Ukrainian National Forestry University"],
    ".lyceum3.mk.ua": ["Миколаївський ліцей №3"],
    ".mfknukim.mk.ua": ["МФ КНУКіМ", "MF KNUKiM"],
    ".school3.mk.ua": [
        "\ufeffМиколаївська загальноосвітня школа І-ІІІ ступенів №3"
    ],
    ".kkz.net.ua": [
        "Kyiv College of Communication",
        "KCC",
        "Київський фаховий Колледж Зв'язку",
        "ККЗ",
        "Киевский Колледж Связи",
        "ККС",
    ],
    ".kntu.net.ua": ["Kherson National Technical University"],
    ".ktbp.net.ua": [
        "Фаховий коледж технологій, бізнесу та права Волинського національного університету імені Лесі Українки",
        "Professional College of Technologies, Business and Law of Lesya Ukrainka Volyn National University",
    ],
    ".univ.net.ua": ["Taras Shevchenko National University of Kyiv"],
    ".nmu.ua": ["Bogomolets National Medical University"],
    ".nure.ua": ["Kharkiv National University of Radio Electronics, Ukraine"],
    ".ma.odessa.ua": ["Odessa National Maritime Academy"],
    ".onu.odessa.ua": ["Odessa National I.I. Mecnikov University"],
    ".osmu.odessa.ua": ["Odessa National Marine University"],
    ".rl.odessa.ua": ["Ришельевский лицей", "Richelieu Lyceum"],
    ".opu.ua": ["Odessa national polytechnic university"],
    ".dtdgma.org.ua": [
        'Відокремлений структурний підрозділ "Дружківський фаховий коледж Донбаської державної машинобудівної академії"',
        'Subdivision "Druzhkivka professional college of Donbass state engineering Academy"',
    ],
    ".gymnasia-npu.org.ua": ["Гімназія НПУ ім. М.П. Драгоманова"],
    ".intec.org.ua": ["International Economy Department PSACEA"],
    ".kgemt.org.ua": [
        'ВСП Гірничо-електромеханічний фаховий коледж "КНУ"',
        'VSP Mining and Electromechanical Vocational College "KNU"',
    ],
    ".kse.org.ua": ["Kiev School Of Economics"],
    ".mdpu.org.ua": [
        "Мелітопольський державний педагогічний університет імені Богдана Хмельницького",
        "Bogdan Khmelnitsky Melitopol State Pedagogical University",
    ],
    ".nmu.org.ua": ["National Mining University"],
    ".ogasa.org.ua": [
        "Odessa State Academy of Civil Engeneering and Architecture"
    ],
    ".pu.org.ua": [
        " Комунальний заклад вищої освіти «Кременчуцька гуманітарно-технологічна академія» Полтавської обласної ради"
    ],
    ".saceit.org.ua": [
        "Самбірський фаховий коледж економіки та інформаційних технологій.",
        "SACEIT Sambir College of Economics and Informatics",
    ],
    ".sfa.org.ua": [
        "Flight Academy of National Aviation",
        "Flight Academy of National Aviation",
    ],
    ".uhmi.org.ua": [
        "Ukrainian Hydrometeorological Institute",
        "Ukrainian Hydrometeorological Institute",
    ],
    ".zac.org.ua": [
        "Авіаційний коледж імені О. Г. Івченка",
        "Zaporizhzhya Aviation College Named After A. G. Ivchenko.",
    ],
    ".class.ztk.org.ua": [
        "ВСП ЖТК КНУБА Відокремлений Структурний Підрозділ Житомирський Технологічний Фаховий Коледж Київського Національного Університету Будівництва і Архітектури",
        "VSP ZhTK KNUBA Separate Structural Unit Zhytomyr Technological College of Kyiv National University of Construction and Architecture",
    ],
    ".ztkolegium.org.ua": [
        "Житомирський міський колегіум",
        "Zhytomyr City Collegium",
    ],
    ".polytechnic.poltava.ua": [
        "PPC NTU 'KhPI'",
        "Poltava Polytechnic College by National Technical University 'Kharkiv Polytechnical Institute'",
    ],
    ".lyceum81.pp.ua": ["Одеський ліцей 81", "Odesa Lyceum 81"],
    ".regi.rovno.ua": [
        "International University of Economics and Humanities named after academician Stepan Demianchuk"
    ],
    ".elitar.rv.ua": ['"Elitar" High School'],
    ".lider.rv.ua": [
        'Рівненський ліцей "Лідер" Рівненської міської ради',
        'Rivne Lyceum "Leader" of the Rivne City Council',
    ],
    ".dn-sau.sumy.ua": ["Сумський національний аграрний університет"],
    ".sau.sumy.ua": ["Sumy National Agrarian University"],
    ".stpp.sumy.ua": [
        'Відокремлений структурний підрозділ "Сумський фаховий коледж Національного університету харчових технологій"',
        "Subdivision “Sumy Professional College, National University of Food Technologies”",
    ],
    ".tk.te.ua": [
        "Technical college of Ternopil Ivan Puluj National Technical University"
    ],
    ".unit.ua": ["UNIT Factory"],
    ".univ.uzhgorod.ua": ["Uzhgorod National University"],
    ".vnmu.vn.ua": ["National Pirogov Memorial Medical University"],
    ".vntu.vn.ua": [
        "Вінницький Національний Технічний Університет",
        "Vinnytsia National Technical University",
    ],
    ".college.zp.ua": [
        "Запорізький електротехнічний фаховий коледж",
        "Zaporizhzhia Electrotechnical Professional College",
    ],
    ".econom.zp.ua": [
        "Zaporizhzhya Institute of Economics and Information Technology"
    ],
    ".licey34.zp.ua": [
        "Запорізький академічний ліцей № 34 Запорізької міської ради",
        "Zaporizhia Academic Lyceum No. 34 of the Zaporizhia City Council",
    ],
    ".vybor.zp.ua": [
        'Запорізький академічний ліцей "Вибір"',
        'Zaporizhia Academic Lyceum "Vybir"',
    ],
    ".zgia.zp.ua": ["Zaporizhzhya State Engineering Academy"],
    ".zhatk.zt.ua": ["Zhytomyr Agrotechnical College"],
    ".bugemauniv.ac.ug": ["Bugema University"],
    ".busitema.ac.ug": ["Busitema University"],
    ".students.cavendish.ac.ug": ["Cavendish Uniniversity Uganda"],
    ".ciu.ac.ug": ["Clarke International University"],
    ".gu.ac.ug": ["Gulu University"],
    ".iuiu.ac.ug": ["Islamic University in Uganda"],
    ".kab.ac.ug": ["Kabale University"],
    ".kiu.ac.ug": ["Kampala International University"],
    ".ku.ac.ug": ["Kampala University"],
    ".kyu.ac.ug": ["Kyambogo University"],
    ".mak.ac.ug": ["Makerere University"],
    ".miu.ac.ug": ["Metropolitan International University"],
    ".mmu.ac.ug": ["Mountains of the Moon University"],
    ".mru.ac.ug": ["Mutesa 1 Royal University"],
    ".bach16.mubs.ac.ug": ["Makerere University Business School"],
    ".muni.ac.ug": ["Muni University"],
    ".musph.ac.ug": ["Makerere University School of Public Health"],
    ".must.ac.ug": ["Mbarara University of Science and Technology"],
    ".ndejjeuniversity.ac.ug": ["Ndejje University"],
    ".niu.ac.ug": ["NEXUS INTERNATIONAL UNIVERSITY"],
    ".nkumbauniversity.ac.ug": ["Nkumba University"],
    ".sun.ac.ug": ["Soroti University"],
    ".ucu.ac.ug": ["Uganda Christian University"],
    ".uict.ac.ug": [
        "Uganda Institute of Information and Communications Technology"
    ],
    ".students.umi.ac.ug": [
        "Uganda Management Institute",
        "Uganda Management Institute",
    ],
    ".umu.ac.ug": ["Uganda Martyr's University"],
    ".unik.ac.ug": ["University of Kisubi"],
    ".ush.ac.ug": [
        "Name: \tUniversity of the Sacred Heart Gulu",
        "\t\t\t\t\t\t\t",
        "Location:\tGulu, Uganda",
        "Website:\twww.ush.ac.ug",
    ],
    ".usj.ac.ug": ["University of Saint Joseph Mbarara"],
    ".student.utamu.ac.ug": [
        "Uganda Technology and Management University",
        "Uganda Technology and Management University",
    ],
    ".students.vu.ac.ug": ["Victoria University Kampala"],
    ".aaschool.ac.uk": [
        "Architecture Association School of Architecture",
        "Architecture Association School of Architecture",
    ],
    ".abbeygatesfc.ac.uk": ["Abbeygate Sixth Form College"],
    ".abdn.ac.uk": ["University of Aberdeen"],
    ".aber.ac.uk": ["Prifysgol Aberystwyth University"],
    ".abertay.ac.uk": ["University of Abertay Dundee"],
    ".abingdon-witney.ac.uk": ["Abingdon Witney College"],
    ".accesscreative.ac.uk": ["Access Creative College"],
    ".accesstomusic.ac.uk": ["Access Creative College"],
    ".my.acm.ac.uk": ["Academy of Contemporary Music"],
    ".acm.ac.uk": ["Academy of Contemporary Music"],
    ".activatelearning.ac.uk": [
        "Activate Learning - Banbury and Bicester College, City of Oxford College & Reading College"
    ],
    ".ada.ac.uk": ["Ada. National College for Digital Skills"],
    ".altech.ac.uk": ["Academy of Live Technology"],
    ".anglia.ac.uk": ["Anglia Ruskin University"],
    ".aquinas.ac.uk": ["Aquinas College"],
    ".arden.ac.uk": ["Arden University"],
    ".ardenuniversity.ac.uk": ["Arden University"],
    ".arts.ac.uk": ["University of the Arts London"],
    ".aru.ac.uk": ["Anglia Ruskin University"],
    ".asfc.ac.uk": ["Ashton Sixth Form College"],
    ".aston.ac.uk": ["Aston University"],
    ".atomix.ac.uk": ["atomix.ac.uk"],
    ".my.aub.ac.uk": ["Arts University Bournemouth"],
    ".ayrshire.ac.uk": ["Ayrshire College"],
    ".bangor.ac.uk": ["Prifysgol Bangor University"],
    ".barnsley.ac.uk": ["Barnsley College"],
    ".barton.ac.uk": ["Barton Peveril College"],
    ".bath.ac.uk": ["University of Bath"],
    ".bathspa.ac.uk": ["Bath Spa University"],
    ".bbk.ac.uk": ["Birkbeck College, University of London"],
    ".bcom.ac.uk": ["British College of Osteopathic Medicine"],
    ".student.bcot.ac.uk": ["Basingstoke College of Technology"],
    ".bcu.ac.uk": ["Birmingham City University"],
    ".beds.ac.uk": ["University of Bedfordshire"],
    ".belfastmet.ac.uk": ["Belfast Metropolitan College"],
    ".bexhillcollege.ac.uk": ["Bexhill College"],
    ".bham.ac.uk": ["University of Birmingham"],
    ".bhasvic.ac.uk": ["Brighton Hove & Sussex Sixth Form College"],
    ".bilborough.ac.uk": [
        "Bilborough College",
        "Bilborough College Sixth Form",
    ],
    ".live.blackburn.ac.uk": [
        "Blackburn University Centre",
        "University Centre at Blackburn College",
    ],
    ".blackpool.ac.uk": ["Blackpool and The Fylde College"],
    ".bmet.ac.uk": ["Birmingham Metropolitan College"],
    ".bolton.ac.uk": ["University of Bolton "],
    ".bournemouth.ac.uk": ["Bournemouth University"],
    ".student.bpc.ac.uk": ["bournemouth and poole college"],
    ".brad.ac.uk": ["University of Bradford"],
    ".bradford.ac.uk": ["University of Bradford"],
    ".bradfordcollege.ac.uk": ["Bradford College"],
    ".brighton.ac.uk": ["The University of Brighton"],
    ".bris.ac.uk": ["University of Bristol"],
    ".bristol.ac.uk": ["University of Bristol"],
    ".brookes.ac.uk": ["Oxford Brookes University"],
    ".brooklands.ac.uk": ["Brooklands College"],
    ".bruford.ac.uk": ["Rose Bruford College"],
    ".brunel.ac.uk": ["Brunel University Uxbridge"],
    ".bsdc.ac.uk": ["Burton and South Derbyshire College"],
    ".bsms.ac.uk": ["Brighton and Sussex Medical School"],
    ".btc.ac.uk": ["Bridgwater & Taunton College"],
    ".bton.ac.uk": ["University of Brighton"],
    ".buck.ac.uk": ["University of Buckingham"],
    ".buckingham.ac.uk": ["Buckingham University"],
    ".bucks.ac.uk": ["Buckinghamshire New University"],
    ".student.buckscollegegroup.ac.uk": ["Buckinghamshire College Group"],
    ".burycollege.ac.uk": ["Bury College"],
    ".cadburycollege.ac.uk": ["Cadbury Sixth Form College", "Sandwell.group"],
    ".callywith.ac.uk": ["Callywith College", "Callywith College"],
    ".cam.ac.uk": ["University of Cambridge"],
    ".cambria.ac.uk": ["+ Coleg Cambria"],
    ".students.camre.ac.uk": ["cambridge regional college"],
    ".candi.ac.uk": ["City and Islington College"],
    ".canterbury.ac.uk": ["Canterbury Christ Church University"],
    ".capitalccg.ac.uk": ["Westminster Kingsway College"],
    ".cardiff.ac.uk": ["Cardiff University"],
    ".cardiffmet.ac.uk": [
        "Cardiff Metropolitan University",
        "Prifysgol Metropolitan Caerdydd",
    ],
    ".cardinalnewman.ac.uk": ["Cardinal Newman College"],
    ".carlisle.ac.uk": ["Carlisle College", "Carlisle College"],
    ".students.carmel.ac.uk": ["Carmel College"],
    ".student.cavc.ac.uk": ["Cardiff and vale college"],
    ".student.ccn.ac.uk": ["City College Norwich", "City College Norwich"],
    ".student.ccsw.ac.uk": ["Cheshire College South & West"],
    ".chester.ac.uk": ["University of Chester"],
    ".chesterfield.ac.uk": ["The Chesterfield College Group"],
    ".stu.chi.ac.uk": ["University of Chichester"],
    ".cirencester.ac.uk": ["Cirencester College"],
    ".city-of-portsmouth-college.ac.uk": ["City of Portsmouth College"],
    ".city.ac.uk": ["City University"],
    ".student.cityofbristol.ac.uk": ["City of Bristol College"],
    ".cityofbristol.ac.uk": ["City of Bristol College"],
    ".cityofglacol.ac.uk": ["City of Glasgow College"],
    ".cityofglasgowcollege.ac.uk": ["City of Glasgow College"],
    ".cityplym.ac.uk": ["City College Plymouth"],
    ".student.cnwl.ac.uk": ["College of North West London"],
    ".col-westanglia.ac.uk": [
        "The College of West Anglia",
        "The College of West Anglia",
    ],
    ".colchester.ac.uk": ["University Centre Colchester"],
    ".coleggwent.ac.uk": ["Coleg Gwent"],
    ".colegsirgar.ac.uk": ["Coleg Sir Gar"],
    ".collyers.ac.uk": ["The College of Richard Collyer"],
    ".confetti.ac.uk": ["Confetti Institute of Creative Technologies"],
    ".cornwall.ac.uk": ["Cornwall College"],
    ".courtauld.ac.uk": ["Courtauld Institute of Art, University of London"],
    ".coventry.ac.uk": ["Coventry University"],
    ".coventrycollege.ac.uk": ["Coventry College"],
    ".cranfield.ac.uk": ["Cranfield University"],
    ".crawley.ac.uk": ["Crawley College"],
    ".crick.ac.uk": ["The Francis Crick Institute"],
    ".uni.cumbria.ac.uk": ["University of Cumbria"],
    ".edu.cwa.ac.uk": [
        "The College of West Anglia",
        "The College of West Anglia",
    ],
    ".cymoedd.ac.uk": ["Coleg y Cymoedd"],
    ".darlington.ac.uk": ["Darlington College"],
    ".dbsinstitute.ac.uk": ["dBs Institute of Sound & Digital Technologies"],
    ".derby.ac.uk": ["University of Derby"],
    ".disc.ac.uk": ["Digital Independent Specialist College"],
    ".dmu.ac.uk": ["De Montfort University Leicester"],
    ".don.ac.uk": ["Doncaster College"],
    ".dudleycol.ac.uk": [
        "Dudley College Institute of Technology",
        "Dudley College Institute of Technology",
    ],
    ".dudleylearners.ac.uk": ["Dudley College of Technology"],
    ".student.dumgal.ac.uk": [
        "Dumfries and Galloway College",
        "Dumfries and Galloway College",
    ],
    ".dundee.ac.uk": ["University of Dundee"],
    ".dundeeandangus.ac.uk": ["Dundee and Angus College"],
    ".dur.ac.uk": ["University of Durham"],
    ".durham.ac.uk": ["Durham University in the UK"],
    ".earlham.ac.uk": ["Earlham Institute"],
    ".easterneducationgroup.ac.uk": ["West Suffolk College"],
    ".ebi.ac.uk": [
        "European Molecular Biology Laboratory - European Bioinformatics Institute"
    ],
    ".sms.ed.ac.uk": ["University of Edinburgh"],
    ".ed.ac.uk": ["University of Edinburgh"],
    ".edgehill.ac.uk": ["Edge Hill University"],
    ".edinburghcollege.ac.uk": ["Edinburgh College", "Edinburgh College"],
    ".student.ekcgroup.ac.uk": ["Ashford College"],
    ".ekcgroup.ac.uk": ["East Kent College Group"],
    ".esc.ac.uk": ["East Surrey College"],
    ".escapestudios.ac.uk": [
        "Escape Studios | School of Animation, Games and VFX"
    ],
    ".escg.ac.uk": ["East Sussex College Group"],
    ".eselondon.ac.uk": ["European School of Economics"],
    ".essex.ac.uk": ["University of Essex"],
    ".ex.ac.uk": ["University of Exeter"],
    ".exe-coll.ac.uk": ["Exeter College"],
    ".exeter.ac.uk": ["University of Exeter"],
    ".falmouth.ac.uk": ["Falmouth University"],
    ".fareham.ac.uk": ["Fareham College"],
    ".farnborough.ac.uk": ["The Sixth Form College Farnborough"],
    ".fife.ac.uk": ["Fife College"],
    ".fra.ac.uk": ["Fashion Retail Academy"],
    ".franklin.ac.uk": ["Franklin Sixth Form College"],
    ".gateshead.ac.uk": ["Gateshead College"],
    ".student.gbmc.ac.uk": [
        "Greater Brighton Metropolitan College (GB MET) for Students."
    ],
    ".gcal.ac.uk": ["Glasgow Caledonian University"],
    ".gcs.ac.uk": ["Gower College Swansea"],
    ".gcu.ac.uk": ["Glasgow Caledonian University"],
    ".student.gla.ac.uk": ["University of Glasgow"],
    ".gla.ac.uk": ["University of Glasgow"],
    ".glam.ac.uk": ["University of Glamorgan"],
    ".glasgow.ac.uk": ["University of Glasgow"],
    ".glasgowclyde.ac.uk": ["Glasgow Clyde College"],
    ".glasgowkelvin.ac.uk": ["Glasgow Kelvin College"],
    ".gllm.ac.uk": ["\ufeffGrŵp Llandrillo Menai"],
    ".globalbanking.ac.uk": [],
    ".glos.ac.uk": ["University of Gloucestershire"],
    ".gloscol.ac.uk": ["Gloucestershire College"],
    ".mail.glyndwr.ac.uk": ["Wrexham Glyndwr University"],
    ".glyndwr.ac.uk": ["Wrexham Glyndwr University"],
    ".gold.ac.uk": ["Goldsmiths College, University of London"],
    ".campus.goldsmiths.ac.uk": ["Goldsmiths, University of London"],
    ".gre.ac.uk": ["University of Greenwich"],
    ".greenhead.ac.uk": ["Greenhead College"],
    ".grimsby.ac.uk": [
        "Grimsby Institute of  Further and Higher Education ",
        "Grimsby Institute of  Further and Higher Education",
    ],
    ".gsa.ac.uk": ["Glasgow School of Art"],
    ".live.harper.ac.uk": ["Harper Adams University, Shropshire England"],
    ".hcfe.ac.uk": ["Hartlepool College of Further Education"],
    ".hcuc.ac.uk": ["Uxbridge College", "Uxbridge College"],
    ".heartofyorkshire.ac.uk": [
        "Selby College",
        "Wakefield College",
        "Castleford College",
        ".group",
    ],
    ".henleycol.ac.uk": ["The Henley College"],
    ".hereford.ac.uk": ["Hereford Sixth Form College"],
    ".herts.ac.uk": ["University of Hertfordshire"],
    ".heythrop.ac.uk": ["Heythrop College, University of London"],
    ".hlcollege.ac.uk": ["Herefordshire, Ludlow and North Shropshire College"],
    ".hlnsc.ac.uk": ["Herefordshire, Ludlow and North Shropshire College"],
    ".hope.ac.uk": ["Liverpool Hope University College"],
    ".hopwood.ac.uk": ["Hopwood Hall College"],
    ".howcollege.ac.uk": ["Heart Of Worcestershire College"],
    ".hrsfc.ac.uk": ["Hills Road Sixth Form College"],
    ".student.hsdc.ac.uk": ["Havant and South Downs College"],
    ".hud.ac.uk": ["University of Huddersfield"],
    ".hull-college.ac.uk": ["Hull College"],
    ".hull.ac.uk": ["University of Hull"],
    ".hw.ac.uk": ["Heriot-Watt University"],
    ".ic.ac.uk": [
        "Imperial College London",
        "Imperial College School of Medicine",
    ],
    ".iconcollege.ac.uk": [
        "ICON College of Technology and Management",
        "ICON College of Technology and Management",
    ],
    ".icr.ac.uk": ["Institute of Cancer Research"],
    ".imperial.ac.uk": ["Imperial College London"],
    ".ioe.ac.uk": ["Institute of Education, University of London"],
    ".iwcollege.ac.uk": ["The Isle of Wight College"],
    ".jcc.ac.uk": ["Joseph Chamberlain Sixth Form College"],
    ".johnruskin.ac.uk": ["John Ruskin College"],
    ".kcl.ac.uk": ["King's College London, University of London"],
    ".ke6n.ac.uk": ["King Edwards VI College Nuneaton"],
    ".kedst.ac.uk": ["King Edward VI College"],
    ".keele.ac.uk": ["Keele University"],
    ".kendal.ac.uk": ["Kendal College", "Kendal College"],
    ".kent.ac.uk": ["University of Kent"],
    ".kingston.ac.uk": ["Kingston University"],
    ".knowsleycollege.ac.uk": ["Knowsley College"],
    ".lamp.ac.uk": ["University of Wales, Lampeter"],
    ".lancaster.ac.uk": ["Lancaster University"],
    ".lancs.ac.uk": ["University of Lancaster"],
    ".law.ac.uk": ["University of Law", "University of Law"],
    ".lboro.ac.uk": ["Loughborough University"],
    ".le.ac.uk": ["University of Leicester"],
    ".leeds-art.ac.uk": ["Leeds Arts University"],
    ".leeds.ac.uk": ["University of Leeds"],
    ".student.leedsbeckett.ac.uk": ["Leeds Beckett University"],
    ".leedsbeckett.ac.uk": ["Leeds Beckett University"],
    ".my.leedscitycollege.ac.uk": ["Leeds City College"],
    ".leedstrinity.ac.uk": [
        "Leeds Trinity University",
        "Leeds Trinity University",
    ],
    ".leicester.ac.uk": ["University of Leicester"],
    ".my.leicestercollege.ac.uk": ["Leicester College"],
    ".leyton.ac.uk": ["Leyton Sixth Form College"],
    ".lgu.ac.uk": ["London Guildhall University"],
    ".libf.ac.uk": ["London Institute of Banking and Finance"],
    ".lincoln.ac.uk": ["University of Lincoln"],
    ".lincolncollege.ac.uk": ["Lincoln College"],
    ".linst.ac.uk": [
        "Camberwell College of Arts",
        "Central Saint Martins College of Art &amp; Design",
        "Chelsea College of Art and Design",
    ],
    ".lis.ac.uk": ["London Interdisciplinary School"],
    ".liv-coll.ac.uk": ["The City of Liverpool College"],
    ".liv.ac.uk": ["University of Liverpool"],
    ".liverpool.ac.uk": ["University of Liverpool"],
    ".livjm.ac.uk": ["Liverpool John Moores University"],
    ".ljmu.ac.uk": ["Liverpool John Moores University"],
    ".lma.ac.uk": ["LMA Liverpool", "LMA London"],
    ".lmas.ac.uk": ["Leeds Maths School", "Leeds Maths School"],
    ".lmc.ac.uk": ["Lancaster & Morecambe College"],
    ".lmu.ac.uk": ["Leeds Metropolitan University"],
    ".lon.ac.uk": [
        "British Institute in Paris, University of London",
        "London Business School",
        "University of London",
    ],
    ".student.london.ac.uk": ["University of London"],
    ".london.ac.uk": ["University of London"],
    ".londonmet.ac.uk": ["London Metropolitan University"],
    ".longroad.ac.uk": [],
    ".student.loreto.ac.uk": ["Loreto Sixth Form College"],
    ".loreto.ac.uk": ["Loreto Sixth Form College"],
    ".student.loucoll.ac.uk": ["Loughborough College"],
    ".lsbu.ac.uk": ["London South Bank University"],
    ".lse.ac.uk": [
        "London School of Economics and Political Science, University of London"
    ],
    ".lshtm.ac.uk": [
        "London School of Hygiene &amp; Tropical Medicine, University of London"
    ],
    ".macclesfield.ac.uk": ["macclesfield college"],
    ".man.ac.uk": ["University of Manchester"],
    ".manchester.ac.uk": ["University of Manchester"],
    ".mbro.ac.uk": ["Middlesbrough College"],
    ".mdx.ac.uk": ["Middlesex University"],
    ".midkent.ac.uk": ["MidKent College"],
    ".mkcollege.ac.uk": ["Milton Keynes College Group"],
    ".mmu.ac.uk": ["The Manchester Metropolitan University"],
    ".morley.ac.uk": ["Morley College London"],
    ".lms.mrc.ac.uk": [
        "MRC London institute of Medical Sciences (Imperial College London)"
    ],
    ".myclyde.ac.uk": ["Glasgow Clyde College"],
    ".myport.ac.uk": ["University of Portsmouth"],
    ".napier.ac.uk": ["Napier University"],
    ".natmatsci.ac.uk": ["The National Mathematics and Science College"],
    ".natstar.ac.uk": ["National Star College"],
    ".ncclondon.ac.uk": ["Tower Hamlets - New City College"],
    ".students.nchlondon.ac.uk": [
        "Northeastern University London (New College of the Humanities)"
    ],
    ".students.ncl-coll.ac.uk": ["Newcastle College"],
    ".ncl.ac.uk": [
        "Newcastle University, Medicine Malaysia ",
        "University of Newcastle-upon-Tyne",
        '"Newcastle Univeristy" ',
    ],
    ".my.nclan.ac.uk": ["New College Lanarkshire (Motherwell Campus)"],
    ".nescol.ac.uk": ["North East Scotland College"],
    ".student.newbury-college.ac.uk": ["Newbury College"],
    ".newcastle.ac.uk": ["Newcastle University"],
    ".newcollege.ac.uk": ["New College Swindon"],
    ".newdur.ac.uk": ["New College Durham"],
    ".newman.ac.uk": ["Birmingham Newman University"],
    ".newport.ac.uk": ["University of Wales, Newport"],
    ".students.newvic.ac.uk": ["Newham Sixth Form College"],
    ".newvic.ac.uk": ["Newvic Sixth Form College"],
    ".students.nhc.ac.uk": ["North Hertfordshire College"],
    ".nkc.ac.uk": ["North Kent College"],
    ".northampton.ac.uk": ["University of Northampton"],
    ".northlindsey.ac.uk": ["North Lindsey College"],
    ".northumbria.ac.uk": ["Northumbria University"],
    ".student.norwichuni.ac.uk": ["Norwich University Of The Arts"],
    ".notredamecoll.ac.uk": [" Notre Dame Catholic Sixth Form College"],
    ".nottingham.ac.uk": ["University of Nottingham"],
    ".nottinghamcollege.ac.uk": ["Nottingham College"],
    ".nscg.ac.uk": ["NSCG Newcastle College"],
    ".ntu.ac.uk": ["Nottingham Trent University"],
    ".student.nua.ac.uk": ["Norwich University of the Arts"],
    ".nulondon.ac.uk": [" New College of the Humanities"],
    ".student.onesfc.ac.uk": ["One Sixth Form College"],
    ".open.ac.uk": ["Open University"],
    ".ou.ac.uk": ["The Open University"],
    ".kellogg.ox.ac.uk": ["Kellogg College"],
    ".worc.ox.ac.uk": ["Worcester College, University of Oxford"],
    ".ox.ac.uk": ["University of Oxford"],
    ".paisley.ac.uk": ["University of Paisley"],
    ".peterborough.ac.uk": ["Peterborough Regional College"],
    ".pirbright.ac.uk": ["The Pirbright Institute"],
    ".plymouth.ac.uk": ["University of Plymouth"],
    ".pointblankmusicschool.ac.uk": ["pointblank Music School"],
    ".port.ac.uk": ["University of Portsmouth"],
    ".portsmouth-college.ac.uk": ["Portsmouth College"],
    ".primarygoal.ac.uk": ["Primary Goal"],
    ".psc.ac.uk": ["Peter Symonds College"],
    ".pursglove.ac.uk": ["Prior Pursglove College, Guisborough"],
    ".student.qmc.ac.uk": ["Queen Mary's College"],
    ".qmu.ac.uk": ["Queen Margaret University"],
    ".qmul.ac.uk": ["Queen Mary, University of London"],
    ".qmw.ac.uk": ["Queen Mary and Westfield College, University of London"],
    ".qub.ac.uk": ["The Queen's University Belfast"],
    ".ram.ac.uk": ["Royal Academy of Music, University of London"],
    ".rau.ac.uk": ["Royal Agriculture University"],
    ".rave.ac.uk": ["Ravensbourne Uni in London"],
    ".rca.ac.uk": ["Royal College of Art"],
    ".student.rcl.ac.uk": ["Regent College London"],
    ".rcm.ac.uk": ["Royal College of Music, University of London"],
    ".rcs.ac.uk": ["Royal Conservatoire Scotland"],
    ".rdg.ac.uk": ["University of Reading"],
    ".student.reading.ac.uk": ["University of Reading"],
    ".reading.ac.uk": ["University of Reading"],
    ".regents.ac.uk": ["Regent's University London"],
    ".rfi.ac.uk": ["The Rosalind Franklin Institute"],
    ".rgu.ac.uk": ["The Robert Gordon University"],
    ".rhacc.ac.uk": ["Richmond and Hillcroft Adult Community College"],
    ".rhbnc.ac.uk": ["Royal Holloway and Bedford New College"],
    ".rhul.ac.uk": ["Royal Holloway, University of London"],
    ".richmond.ac.uk": [
        "Richmond University - The American International University in London"
    ],
    ".student.riversidecollege.ac.uk": ["Riverside College"],
    ".rncm.ac.uk": ["The Royal Northern College of Music", "RNCM"],
    ".student.rnngroup.ac.uk": ["Rotherham College", "Rotherham College"],
    ".rochdalesfc.ac.uk": ["Rochdale sixth form college"],
    ".roehampton.ac.uk": ["Roehampton University of Surrey"],
    ".rvc.ac.uk": ["Royal Veterinary College"],
    ".salford.ac.uk": ["University of Salford"],
    ".student.salfordcc.ac.uk": ["Salford City College", "Future Skills"],
    ".sandwellcollege.ac.uk": ["Sandwell College"],
    ".sanger.ac.uk": ["Wellcome Sanger Institute"],
    ".sas.ac.uk": [
        "Institue of Historical Research, University of London",
        "Institute of Advanced Legal Studies, University of London",
        "Institute of Classical Studies, University of London",
        "Institute of Commonwealth Studies, University of London",
        "Institute of Germanic Studies, University of London",
        "Institute of Latin American Studies, University of London",
        "Warburg Institute, University of London",
    ],
    ".scarboroughtec.ac.uk": ["Scarborough TEC"],
    ".selby.ac.uk": ["Selby College"],
    ".serc.ac.uk": ["South Eastern Regional College"],
    ".sghms.ac.uk": [
        "Saint George's Hospital Medical School, University of London"
    ],
    ".sgscol.ac.uk": ["South Gloucestershire and Stroud College"],
    ".sgul.ac.uk": ["St George's, University of London"],
    ".stu.shc.ac.uk": ["Shooters Hill Sixth Form College"],
    ".shef.ac.uk": ["University of Sheffield"],
    ".student.sheffcol.ac.uk": ["Sheffield College (S2 2R)"],
    ".sheffcol.ac.uk": ["The Sheffield College"],
    ".sheffield.ac.uk": ["The University of Sheffield"],
    ".shipley.ac.uk": ["Shipley College"],
    ".shrewsbury.ac.uk": ["Shrewsbury Colleges Group"],
    ".shu.ac.uk": ["Sheffield Hallam University"],
    ".student.sirm.ac.uk": ["School of Information Risk Management"],
    ".slc.ac.uk": ["South Lanarkshire College"],
    ".smu.ac.uk": ["Swansea Metropolitan University"],
    ".soas.ac.uk": [
        "School of Oriental and African Studies, University of London"
    ],
    ".solent.ac.uk": ["Southampton Solent University"],
    ".solihull.ac.uk": ["Solihull College & University Centre"],
    ".solihullsfc.ac.uk": ["Solihull Sixth Form College"],
    ".somerset.ac.uk": [
        "Taunton and Bridgwater College, Somerset, UK.",
        "University of Somerset.",
        "http://www.somerset.ac.uk/",
        "http://www.somerset.ac.uk/courses/lbw622t-hm1-bsc-hons-computing-internet-technologies-3-years.html",
    ],
    ".soton.ac.uk": ["University of Southampton"],
    ".student.southdevon.ac.uk": ["South Devon College"],
    ".student.southessex.ac.uk": ["South Essex College"],
    ".southport.ac.uk": ["Southport College"],
    ".southstaffs.ac.uk": ["South Staffs College- Lichfeild"],
    ".southwales.ac.uk": ["University of South Wales"],
    ".src.ac.uk": ["Southern Regional College, the U.K."],
    ".ssees.ac.uk": [
        "School of Slavonic and East European Studies, University of London"
    ],
    ".ssfc.ac.uk": ["Shrewsbury Colleges Group"],
    ".st-and.ac.uk": ["University of St. Andrews"],
    ".st-andrews.ac.uk": ["University of St Andrews"],
    ".st-patricks.ac.uk": ["St.Patrick's International College, London"],
    ".staffs.ac.uk": ["Staffordshire University"],
    ".stamford.ac.uk": ["New College Stamford"],
    ".stanmore.ac.uk": ["Stanmore College"],
    ".stbrn.ac.uk": ["St. Brendan's Sixth Form College"],
    ".stcg.ac.uk": ["South Thames Colleges Group"],
    ".stdavidscollege.ac.uk": ["St David's Catholic Sixth Form College"],
    ".stdoms.ac.uk": ["St. Dominic's Sixth Form College"],
    ".stephenson.ac.uk": ["Stephenson College"],
    ".stephensoncoll.ac.uk": ["Stephenson College"],
    ".students.sthelens.ac.uk": ["St Helens College"],
    ".stir.ac.uk": ["University of Stirling"],
    ".live.stmarys.ac.uk": ["St Mary's University Twickenham"],
    ".stmarys.ac.uk": ["St Mary's University, Twickenham London"],
    ".stockport.ac.uk": ["Stockport College"],
    ".strath.ac.uk": [
        "University of Strathclyde",
        "uka tarsadia university,bardoli",
        "Pune university (INDIA)",
    ],
    ".student.strode-college.ac.uk": ["Strode College"],
    ".suffolk.ac.uk": ["Suffolk New College"],
    ".sunderland.ac.uk": ["University of Sunderland"],
    ".my.sunderlandcollege.ac.uk": ["Sunderland College"],
    ".surrey.ac.uk": ["University of Surrey"],
    ".sussex.ac.uk": ["University of Sussex"],
    ".swan.ac.uk": ["University of Wales, Swansea"],
    ".swansea.ac.uk": ["Swansea University"],
    ".student.swc.ac.uk": ["South West College"],
    ".tameside.ac.uk": ["Tameside College"],
    ".stockport.tcg.ac.uk": ["Stockport College"],
    ".tcm.ac.uk": ["Trinity College of Music"],
    ".tedi-london.ac.uk": ["TEDI-London"],
    ".tees.ac.uk": ["University of Teesside"],
    ".telfordcollege.ac.uk": ["Telford College"],
    ".tmc.ac.uk": ["The Manchester College"],
    ".trinity-cm.ac.uk": ["Trinity College Carmarthen"],
    ".truro-penwith.ac.uk": ["Truro & Penwith College"],
    ".trurocollege.ac.uk": ["Truro College"],
    ".ghs.truropenwith.ac.uk": ["Truro and Penwith College"],
    ".tvc.ac.uk": ["Tees Valley Collaborative Trust"],
    ".tvu.ac.uk": ["Thames Valley University"],
    ".bootcamps.ua92.ac.uk": ["University Academy 92"],
    ".uad.ac.uk": ["abertay university"],
    ".ual.ac.uk": ["University of the Arts London"],
    ".uca.ac.uk": ["University for the Creative Arts"],
    ".ucb.ac.uk": ["University College Birmingham"],
    ".ucem.ac.uk": ["University College of Estate Management"],
    ".ucl.ac.uk": ["University College London, University of London"],
    ".uclan.ac.uk": ["University of Central Lancashire"],
    ".students.ucreative.ac.uk": ["University for the Creative Arts"],
    ".ucs.ac.uk": ["University Campus Suffolk"],
    ".uea.ac.uk": ["University of East Anglia"],
    ".uel.ac.uk": ["University of East London"],
    ".uhi.ac.uk": ["University of the Highland and Islands Perth College"],
    ".ukc.ac.uk": [
        "Brussels School of International Studies",
        "University of Kent at Canterbury",
    ],
    ".ulster.ac.uk": ["University of Ulster"],
    ".umds.ac.uk": ["United Medical and Dental Schools, University of London"],
    ".unl.ac.uk": ["University of North London"],
    ".unn.ac.uk": ["University of Northumbria at Newcastle"],
    ".uos.ac.uk": ["University of Suffolk"],
    ".uwe.ac.uk": ["University of the West of England, Bristol"],
    ".uwic.ac.uk": ["University of Wales Institute, Cardiff"],
    ".student.uwl.ac.uk": ["University of West London"],
    ".uwl.ac.uk": ["University of West London"],
    ".uws.ac.uk": [
        "University Of The West Of Scotland",
        "University Of The West Of Scotland",
    ],
    ".uwtsd.ac.uk": ["University of Wales Trinity Saint David"],
    ".uxbridgecollege.ac.uk": ["Uxbridge College"],
    ".varndean.ac.uk": ["Varndean College"],
    ".waes.ac.uk": ["Westminster Adult Education Service"],
    ".wakefield.ac.uk": ["Wakefield College"],
    ".wales.ac.uk": ["University of Wales"],
    ".warwick.ac.uk": ["University of Warwick"],
    ".warwickshire.ac.uk": ["Warwickshire College Group"],
    ".mail.wbs.ac.uk": ["Warwick Business School"],
    ".live.wcs.ac.uk": ["West College Scotland", "West College Scotland"],
    ".westdean.ac.uk": ["West Dean College"],
    ".student.westherts.ac.uk": ["West Herts College, Watford"],
    ".westminster.ac.uk": ["University of Westminster"],
    ".weston.ac.uk": ["Weston College"],
    ".wimbledon.ac.uk": ["Wimbledon School of Art"],
    ".winchester.ac.uk": ["University of Winchester"],
    ".windsor-forest.ac.uk": [
        "Windsor College",
        "Langley College",
        "Strodes College",
        ".group",
    ],
    ".wlc.ac.uk": ["West London College"],
    ".wlv.ac.uk": ["University of Wolverhampton"],
    ".students.wnc.ac.uk": ["Vision West Nottinghamshire College"],
    ".wnc.ac.uk": ["West Nottinghamshire College "],
    ".woking.ac.uk": ["Woking College"],
    ".wolvcoll.ac.uk": ["City of Wolverhampton College"],
    ".woodhouse.ac.uk": ["Woodhouse College"],
    ".worc.ac.uk": ["University of Worcester"],
    ".worthing.ac.uk": ["Worthing College"],
    ".wqe.ac.uk": ["Wyggeston & Queen Elizabeth I College"],
    ".wsfc.ac.uk": ["Worcester Sixth Form College"],
    ".wyke.ac.uk": [
        "Wyke Sixth Form College",
        "Link to course https://www.wyke.ac.uk/course/computer-science",
        'Email of recognised email domain in footer "office@wyke.ac.uk"',
    ],
    ".yeovil.ac.uk": ["Yeovil College"],
    ".york.ac.uk": ["University of York"],
    ".student.yorkcollege.ac.uk": ["York College & University Centre"],
    ".yorksj.ac.uk": ["York St John University"],
    ".adamsgs.uk": ["Haberdashers' Adams"],
    ".arete.uk": ["Richmond School & Sixth Form College"],
    ".avonvalleyschool.uk": ["The Avon Valley School"],
    ".clf.uk": ["Cabot Learning Federation"],
    ".tas.318education.co.uk": ["Thomas Adams Sixth Form"],
    ".aberdareschool.co.uk": ["Aberdare Community School"],
    ".accesstomusic.co.uk": ["Access Creative College"],
    ".aesessex.co.uk": ["Ango European School"],
    ".agsb.co.uk": ["Altrincham Grammar School for Boys"],
    ".albanyacademy.co.uk": ["Albany Academy"],
    ".archapprentices.co.uk": ["Arch Apprentices"],
    ".ashbournecollege.co.uk": ["Ashbourne College"],
    ".ashville.co.uk": ["Ashville College"],
    ".auea.co.uk": ["Aston University Engineering Academy"],
    ".aycliffecpschool.co.uk": ["Aycliffe Community Primary School"],
    ".barrbeaconschool.co.uk": ["Barr Beacon School", "Barr Beacon School"],
    ".bb-hs.co.uk": ["Blythe Bridge High School", "Blythe Bridge High School"],
    ".bealhighschool.co.uk": ["Beal High School"],
    ".bedmod.co.uk": ["Bedford Modern School"],
    ".beverleyj6.co.uk": ["Beverley Joint Sixth Form"],
    ".bexleygs.co.uk": ["Bexley Grammar School"],
    ".biddulphhigh.co.uk": ["Biddulph High School"],
    ".boa-academy.co.uk": ["Birmingham Ormiston Academy"],
    ".bolnoreschool.co.uk": ["Bolnore Village Primary School"],
    ".bostongrammarschool.co.uk": ["Boston Grammar School"],
    ".broadway-academy.co.uk": ["Broadway Academy"],
    ".calday.co.uk": ["Calday Grange Grammar School"],
    ".caludoncastle.co.uk": ["Caludon Castle"],
    ".cardinalallen.co.uk": ["Cardinal Allen Catholic High School"],
    ".cardinalnewman.co.uk": [
        "Cardinal Newman Roman Catholic Comprehensive School"
    ],
    ".caterhamschool.co.uk": ["Caterham School"],
    ".cedarsupper.co.uk": ["Cedars Upper School"],
    ".centralfoundationboys.co.uk": ["Central Foundation Boys School"],
    ".chapeltown-mlt.co.uk": ["Chapeltown Academy"],
    ".chesterfieldhigh.co.uk": ["Chesterfield High School"],
    ".pchs.cheviotlt.co.uk": [
        "Prudhoe Community High School",
        "Prudhoe Community High School",
    ],
    ".cityacademy.co.uk": ["City of London Academy (6th Form)"],
    ".cliftonhigh.co.uk": ["Clifton High School"],
    ".clpt.co.uk": ["Central Learning Partnership Trust"],
    ".clrchs.co.uk": ["Cardinal Langley RC High School & Sixth Form College"],
    ".coombewoodschool.co.uk": ["Coombe Wood School - Sixth Form"],
    ".cowbridgecomprehensiveschool.co.uk": [
        "Cowbridge Comprehensive School Sixth Form"
    ],
    ".cowbridgecs.co.uk": ["Cowbridge Comprehensive School Sixth Form"],
    ".crgs.co.uk": ["Colchester Royal Grammar School"],
    ".cvms.co.uk": ["The Cardinal Vaughan Memorial School"],
    ".derbymanufacturingutc.co.uk": ["Derby Manufacturing UTC, Derby, UK"],
    ".eastlondonscienceschool.co.uk": [
        "East London Science School Sixth Form"
    ],
    ".ebbwfawr.co.uk": [
        "Ebbw Fawr Learning Community",
        "Ebbw Fawr Learning Community",
    ],
    ".edgbarrowschool.co.uk": ["Edgbarrow School"],
    ".elam.co.uk": ["East London Arts and Music"],
    ".ewellcastle.co.uk": ["Ewell Castle School"],
    ".georgemitchellschool.co.uk": ["George Mitchell School"],
    ".hallcrossacademy.co.uk": ["Hall Cross Academy"],
    ".hallifordschool.co.uk": ["Halliford School"],
    ".hbschool.co.uk": [
        "Henrietta Barnett School",
        "Henrietta Barnett School",
    ],
    ".heathfieldcc.co.uk": ["Heathfield Community College "],
    ".heckgrammar.co.uk": ["Heckmondwike Grammar School"],
    ".hendonschool.co.uk": ["Hendon School", "Hendon School"],
    ".highamlaneschool.co.uk": ["Higham Lane Sixth Form"],
    ".highstorrs-mlt.co.uk": ["High Storrs School"],
    ".hitchinboys.co.uk": ["Hitchin Boys' Academy"],
    ".hollandparkschool.co.uk": ["Holland Park School"],
    ".holmfirthhigh.co.uk": ["Holmfirth High School"],
    ".horizoncc.co.uk": ["Horizon Community College"],
    ".hppc.co.uk": ["Hurstpierpoint College"],
    ".hswv.co.uk": ["Highfields School"],
    ".ilford-school.co.uk": ["Ilford Grammar School"],
    ".ilkleygs.co.uk": ["Ilkley Grammar School"],
    ".interhigh.co.uk": [
        "InterHigh Education",
        "InterHigh School",
        "InterHigh",
    ],
    ".isaacnewtonsixthform.co.uk": ["Sir Isaac Newtown Sixth Form"],
    ".iscaexeter.co.uk": ["Isca Academy "],
    ".ivesheadschool.co.uk": ["Iveshead School"],
    ".josephleckieacademy.co.uk": ["Joseph Leckie Academy"],
    ".kdhigh.co.uk": [
        "King David High School",
        "King David High School Manchester",
    ],
    ".kennetschool.co.uk": ["Kennet School, Thatcham"],
    ".keswicksch.co.uk": ["Keswick School"],
    ".kingschester.co.uk": ["The King's School, Chester"],
    ".kingsinterhigh.co.uk": ["Kings Interhigh"],
    ".kingsolomonhigh.co.uk": ["Kantor King Solomon High School"],
    ".kirkbiekendal.co.uk": ["Kirkbie Kendal School"],
    ".kirkhamgrammar.co.uk": ["Kirkham Grammar School"],
    ".kps.co.uk": ["Kensington Park School", "Kensington Park School"],
    ".latymer.co.uk": ["Latymer School - Sixth Form"],
    ".limt.co.uk": ["London Institute of Management and Technology"],
    ".lincolnutc.co.uk": ["Lincoln UTC"],
    ".lordswoodtrust.co.uk": [
        "Lordswood Girl School",
        "King Edward VI Lordswood School for Girls",
    ],
    ".lsclondon.co.uk": [
        "London School of Commerce",
        "London School of Commerce",
    ],
    ".maidenerleghschools.co.uk": ["Maiden Erlegh School"],
    ".maynard.co.uk": ["Maynard School"],
    ".meole.co.uk": ["Meole Brace School Science College"],
    ".meolscophighschool.co.uk": ["Meols Cop High School"],
    ".mmhs.co.uk": ["Matthew Moss"],
    ".morehouseschool.co.uk": ["More House School"],
    ".mynsb.co.uk": ["Northampton School For Boys"],
    ".myton.co.uk": [
        "Myton School",
        "https://www.mytonschool.co.uk/",
        "https://www.mytonschool.co.uk/sixth-form/welcome-myton-sixth-form/",
        "https://www.mytonschool.co.uk/sixth-form/courses/computer-science-level/",
        "https://www.mytonschool.co.uk/sixth-form/courses/information-technology/",
        "https://www.mytonschool.co.uk/staff-by-department/",
    ],
    ".newhallstudent.co.uk": ["New Hall School"],
    ".newsteadwood.co.uk": ["Newstead Wood School"],
    ".nottinghamhigh.co.uk": ["Nottingham High School"],
    ".nwhsmail.co.uk": ["Nunnery Wood High School"],
    ".oatforge.co.uk": ["Ormiston Forge Academy"],
    ".olympustrust.co.uk": [
        "Bradley Stoke Community School (Olympus Academy Trust)"
    ],
    ".hallcross.elp.org.co.uk": ["Hall Cross Academy"],
    ".ormistonriversacademy.co.uk": ["Ormiston Rivers Academy"],
    ".perse.co.uk": ["The Perse School, Cambridge"],
    ".philipshigh.co.uk": ["Philips High School"],
    ".poolehigh.co.uk": ["Poole High School"],
    ".prioryacademies.co.uk": ["The Priory Academy"],
    ".pwhs.co.uk": ["Parrs Wood High School"],
    ".qerdp.co.uk": ["Queen Elizabeth's School, Barnet"],
    ".reading-school.co.uk": ["Reading Grammar School"],
    ".rgsg.co.uk": ["Royal Grammar School, Guildford"],
    ".rhymneycomprehensive.co.uk": ["Rhymney Comprehensive School"],
    ".roedean.co.uk": ["Roedean School"],
    ".roundhayschool.co.uk": ["Roundhay School"],
    ".saintsa.co.uk": ["Saint Augustine's Catholic High School"],
    ".students.salegrammar.co.uk": ["Sale Grammar School"],
    ".salegrammar.co.uk": ["Sale Grammar School"],
    ".scarboroughcollege.co.uk": ["Scarborough College"],
    ".sgse.co.uk": ["St George's School Edgbaston"],
    ".shaftesburyschool.co.uk": ["Shaftesbury School"],
    ".shepshedlearning.co.uk": ["Iveshead School"],
    ".sheringhamhigh.co.uk": ["Sheringham High School"],
    ".sheringhamsixthform.co.uk": ["Sheringham Sixth Form College"],
    ".sirhenryfloyd.co.uk": [
        "Sir Henry Floyd Grammar School",
        "https://www.sirhenryfloyd.co.uk/curriculum/curriculum-key-stage/",
    ],
    ".soas.co.uk": ["SOAS University"],
    ".sphcs.co.uk": ["St Philip Howard Sixth Form"],
    ".sspeterandpaulsschool.co.uk": [
        "SS Peter and Paul's Catholic Primary School"
    ],
    ".staldhelms-academy.co.uk": ["St Aldhelm's Academy"],
    ".stangelas-ursuline.co.uk": ["St Angela's Ursuline School"],
    ".stbarts.co.uk": ["St Bartholomew’s School"],
    ".stgabriels.co.uk": ["St Gabriel's"],
    ".stjos.co.uk": ["St. Joseph's College"],
    ".stokecollege.co.uk": ["Stoke College, Stoke by Clare, Sudbury, Suffolk"],
    ".stowe.co.uk": ["Stowe School"],
    ".tbgs.co.uk": ["Torquay Boys' Grammar School"],
    ".theangmeringschool.co.uk": ["The Angmering School"],
    ".thechalfontsgrammar.co.uk": [
        "The Chalfonts Independent grammar school",
        "The Chalfonts Independent grammar school",
        "Official school website: https://www.thechalfontsgrammar.co.uk/",
        "Official curriculum website, shows Computer Science as a registered course: https://www.ibo.org/en/school/050850",
        "Screenshot of domain: https://ibb.co/c879mjZ",
    ],
    ".thecotswoldschool.co.uk": ["The Cotswold School"],
    ".thefarnboroughacademy.co.uk": ["The Farnborough Academy"],
    ".thekingsschool.co.uk": ["The Kings School Gloucester"],
    ".theurswickschool.co.uk": ["The Urswick School"],
    ".thorpehouse.co.uk": ["thorpe house school"],
    ".tqacademy.co.uk": ["Torquay Academy"],
    ".twbs.co.uk": ["The Windsor Boys' School"],
    ".uclacademy.co.uk": ["The UCL Academy"],
    ".uptonhigh.co.uk": ["Upton-by-Chester High School"],
    ".utc-silverstone.co.uk": ["Silverstone UTC"],
    ".utcswindon.co.uk": ["UTC Swindon"],
    ".utcw.co.uk": ["UTC Warrington"],
    ".verulamschool.co.uk": ["Verulam School"],
    ".weston.co.uk": ["Weston College"],
    ".wg6.co.uk": ["Wilmington Grammar Schools Sixth Form"],
    ".windsorsixth.co.uk": ["Windsor High School and Sixth Form, Halesowen"],
    ".winstonwayschool.co.uk": ["Winston Way Primary School"],
    ".woacademy.co.uk": ["Wodensborough Ormiston Academy"],
    ".wolfreton.co.uk": ["Wolfreton School and Sixth Form College"],
    ".kps.woodard.co.uk": ["Kings Priory School"],
    ".wsnl.co.uk": ["Worksop College"],
    ".wycliffe.co.uk": ["Wycliffe College"],
    ".Kingsworcester.org.uk": [
        "King's School Worcester",
        "@kingsworcester.org.uk",
    ],
    ".Ksw.org.uk": ["King's School Worcester", "@ksw.org.uk"],
    ".abbeyparkschool.org.uk": ["Abbey Park School"],
    ".abingdon.org.uk": ["Abingdon School"],
    ".adalovelace.org.uk": ["Ada Lovelace C of E High School"],
    ".alleyns.org.uk": ["Alleyn's School"],
    ".arnoldhillspencer.org.uk": ["Arnold Hill Spencer Acadeny"],
    ".ashlawn.org.uk": ["Ashlawn School"],
    ".ballymenaacademy.org.uk": ["Ballymena Academy"],
    ".barneyschool.org.uk": ["Barnard Castle School"],
    ".bclschool.org.uk": ["Beis Chinuch Lebonos Girls School"],
    ".bcs.org.uk": ["British Computer Society"],
    ".beauchamp.org.uk": ["Beauchamp college"],
    ".beauchampcity.org.uk": ["Beauchamp City Sixth Form"],
    ".bedfordschool.org.uk": ["Bedford School"],
    ".beechencliff.org.uk": [
        "Beechen Cliff School",
        "@beechencliff.org.uk",
        "School offers A-Level in Computer Science",
    ],
    ".berkeleygreenutc.org.uk": [
        "SGS Berkeley Green UTC",
        "@berkeleygreenutc.org.uk",
    ],
    ".bestacademies.org.uk": ["Samuel Whitbread Academy"],
    ".carmelstudent.bhcet.org.uk": ["Carmel College", "Carmel College"],
    ".bicestertechstudio.org.uk": ["Bicester Technology Studio"],
    ".bishopluffa.org.uk": ["Bishop Luffa CofE Teaching School"],
    ".bl6.org.uk": ["Brine Leas Sixth Form", "BL6"],
    ".blandfordschool.org.uk": ["The Blandford School"],
    ".bluecoatstudent.org.uk": ["The Liverpool Blue Coat School"],
    ".ranelagh.bonitas.org.uk": ["Ranelagh School"],
    ".bradfieldcollege.org.uk": ["Bradfield College"],
    ".bramptonmanor.org.uk": ["Brampton Manor Academy"],
    ".brgsmail.org.uk": ["Bacup and Rawtenstall Grammar School"],
    ".bristolfreeschool.org.uk": ["Bristol Free School"],
    ".bryncelynnog.org.uk": ["Bryncelynnog Comprehensive School"],
    ".bucksgfl.org.uk": ["Bucks Grid for Learning"],
    ".burnhamgrammar.org.uk": ["Burnham Grammar School"],
    ".busheymeads.org.uk": ["Bushey Meads School"],
    ".cambridgeast.org.uk": [
        "Cambridge Academy for Science and Technology",
        "Cambridge Academy for Science and Technology",
    ],
    ".carmel.org.uk": ["Carmel RC College"],
    ".charteracademy.org.uk": ["Ark Charter Academy"],
    ".chartereastdulwich.org.uk": ["The Charter School East Dulwich"],
    ".charterhouse.org.uk": ["Charterhouse"],
    ".charternorthdulwich.org.uk": ["Charter School North Dulwich"],
    ".chartersschool.org.uk": ["Charters School", "Charters School"],
    ".chauncy.org.uk": ["Chauncy school"],
    ".chichesterfreeschool.org.uk": ["Chichester Free School"],
    ".chingfordfs.org.uk": ["Chingford Foundation School"],
    ".christofidelis.org.uk": ["Catholic High School, Chester"],
    ".clevedonschool.org.uk": ["Clevedon School"],
    ".clsg.org.uk": ["City of London School for Girls"],
    ".collegiateacademy.org.uk": ["Shireland Collegiate Academy"],
    ".cooperscoborn.org.uk": ["The Coopers' Company and Coborn School"],
    ".cotswold-chine.org.uk": ["Cotswold Chine School"],
    ".edu.creweutc.org.uk": ["Crewe UTC"],
    ".crossleyheath.org.uk": ["The Crossley Heath School"],
    ".dartfordgrammarschool.org.uk": [
        "Dartford Grammar School ",
        "Dartford Grammar School ",
    ],
    ".dunraven.det.org.uk": ["Dunraven School"],
    ".discoveryschool.org.uk": ["Discovery School"],
    ".dsfc.org.uk": ["Dereham Sixth Form College"],
    ".dulwich.org.uk": ["Dulwich College"],
    ".durhamjohnston.org.uk": ["Durham Johnston Comprehensive School"],
    ".ealingfields.org.uk": ["Ealing Fields High School"],
    ".edinburghacademy.org.uk": ["The Edinburgh Academy"],
    ".eduk.org.uk": ["\ufeffEDUK Qualifications "],
    ".egglescliffe.org.uk": ["Egglescliffe School & Sixth Form College"],
    ".ekotrust.org.uk": ["Pathway's School", "Pathway's School"],
    ".epsomcollege.org.uk": ["Epsom College"],
    ".esf-schools.org.uk": ["Emmanuel Schools Foundation"],
    ".etoncollege.org.uk": ["Eton College"],
    ".fairfield.excalibur.org.uk": ["Fairfield High School"],
    ".stjohns.excalibur.org.uk": [
        "St John's Marlborough",
        "St John's Marlborough",
    ],
    ".garstang.fcat.org.uk": ["Garstang Community Academy"],
    ".felpham.org.uk": ["Felpham Community College"],
    ".finchleycatholic.org.uk": ["Finchley Catholic High School"],
    ".forest.org.uk": ["Forest School London"],
    ".foxespiece.org.uk": ["Foxes Piece School"],
    ".gordanoschool.org.uk": ["Gordano School"],
    ".gordonstoun.org.uk": ["Gordonstoun School", "gordonstoun.org.uk"],
    ".gsal.org.uk": ["The Grammar School at Leeds"],
    ".gsm.org.uk": ["Greenwich School of Management\u200e"],
    ".habsboys.org.uk": ["Haberdashers' Aske's Boys' School"],
    ".hamptonschool.org.uk": ["Hampton School"],
    ".hanleycastlehs.org.uk": ["Hanley Castle High School"],
    ".harrisdulwichgirls.org.uk": ["harris girls' academy east dulwich"],
    ".harrissixthform.org.uk": [
        "Harris academy east Dulwich sixth form",
        "Harris academy east Dulwich sixth form",
    ],
    ".heanorgatespencer.org.uk": ["heanor gate spencer academy"],
    ".hethersettacademy.org.uk": ["Hethersett Academy"],
    ".highgateschool.org.uk": ["Highgate School, UK"],
    ".holmer.org.uk": ["Holmer Green Senior School "],
    ".huntington-ed.org.uk": ["Huntington School"],
    ".ivesheadschool.org.uk": ["Iveshead School"],
    ".jacsin.org.uk": ["Sir Isaac Newton Sixth Form"],
    ".jkhs.org.uk": ["John Kyrle High School"],
    ".kaa.org.uk": ["Kensington Aldridge Academy"],
    ".kcs.org.uk": ["King's College School Wimbledon"],
    ".kegs.org.uk": [
        "King Edward VI Grammar School",
        "King Edward VI Grammar School",
    ],
    ".kesacademy.org.uk": ["King Edward VII Academy"],
    ".kgs.org.uk": ["Kingston Grammar School"],
    ".kingsburyhigh.org.uk": ["Kingsbury High School"],
    ".kingsdalefoundationschool.org.uk": ["Kingsdale Foundation School"],
    ".kingsthorpecollege.org.uk": ["Kingsthorpe college"],
    ".kscs.org.uk": ["Ken Stimpson Community School"],
    ".ksnmail.ksn.org.uk": ["Kenilworth School and Sixth Form"],
    ".ksn.org.uk": ["Kenilworth School and Sixth Form"],
    ".lancing.org.uk": ["Lancing College"],
    ".landau-forte.org.uk": ["Landau Forte College Derby"],
    ".lat16.org.uk": ["Longfield Academy "],
    ".latimer.org.uk": ["The Latimer Arts College"],
    ".lccm.org.uk": ["London College of Creative Media"],
    ".lfatsf.org.uk": ["Landau Forte Academy Tamworth Sixth Form"],
    ".littleheath.org.uk": ["Little Heath School"],
    ".lpsb.org.uk": [
        "Langley Park School for Boys",
        "https://www.lpsb.org.uk",
        "https://www.lpsb.org.uk/1066/curriculum-1",
    ],
    ".student.lshs.org.uk": ["Long Stratton High School"],
    ".eleve.lyceefrancais.org.uk": ["Lycee Francais Charles de Gaulle"],
    ".macademy.org.uk": ["Macmillan Academy"],
    ".maschool.org.uk": ["Matthew Arnold School"],
    ".maslearner.org.uk": ["Mascalls academy"],
    ".ald.merciantrust.org.uk": ["The Aldridge School"],
    ".gbr.merciantrust.org.uk": ["Q3 Academy Great Barr"],
    ".qmgs.merciantrust.org.uk": ["Queen Mary's Grammar School"],
    ".qmhs.merciantrust.org.uk": ["Queen Mary's High School"],
    ".soa.merciantrust.org.uk": ["Shire Oak Academy"],
    ".studio.merciantrust.org.uk": ["Walsall Studio School & Sixth"],
    ".tls.merciantrust.org.uk": ["The Ladder School"],
    ".tpt.merciantrust.org.uk": ["Q3 Academy Tipton"],
    ".mhchs.org.uk": ["Mill Hill County High Scool"],
    ".millhill.org.uk": ["Mill Hill School"],
    ".mtsn.org.uk": ["Merchant Taylors' School"],
    ".mybest.org.uk": ["Samuel Whitbread Academy", "Samuel Whitbread Academy"],
    ".nbacademy.org.uk": ["North Birmingham Academy"],
    ".nbp16c.org.uk": ["North Bristol Post-16 Centre"],
    ".ndhs.org.uk": ["Notre Dame High School", "@ndhs.org.uk"],
    ".nlcs.org.uk": ["North London Collegiate School"],
    ".northstartrust.org.uk": ["North Star Community trust"],
    ".novalis-trust.org.uk": ["Novalis Trust"],
    ".nsix.org.uk": ["Hellesdon High School & Sixth Form Centre"],
    ".olab.org.uk": ["Our Lady's Abingdon"],
    ".olchfa.org.uk": ["Olchfa"],
    ".open-academy.org.uk": ["Open Academy"],
    ".oundleschool.org.uk": ["Oundle School"],
    ".parksidefederation.org.uk": [
        "Cambridge Academy for Science and Technology"
    ],
    ".penrice.org.uk": ["Penrice Accademy"],
    ".petcheyacademy.org.uk": ["The Petchey Academy"],
    ".plymstockschool.org.uk": ["Plymstock School"],
    ".pwsfc.org.uk": ["Parrs Wood Sixth Form College"],
    ".q3academy.org.uk": ["q3 academy"],
    ".qegsss.org.uk": ["Queen Elizabeth Grammar School"],
    ".qes.org.uk": ["Queen Elizabeth School"],
    ".rawlinsacademy.org.uk": ["Rawlins Academy", "@rawlinsacademy.org.uk"],
    ".rbcs.org.uk": ["Reading Blue Coat School"],
    ".reddamhouse.org.uk": ["Reddam House Berkshire"],
    ".rgsw.org.uk": ["Royal Grammar School Worcester"],
    ".rmgs.org.uk": ["Rainham Mark Grammar School", "rainhammark.com"],
    ".rochester-college.org.uk": ["Rochester Independent College"],
    ".rsat.org.uk": ["Royston Schools' Academy Trust"],
    ".rwba.org.uk": ["Royal Wootton Bassett Academy"],
    ".student.s6f.org.uk": ["Scarborough Sixth Form College"],
    ".s6f.org.uk": ["Scarborough Sixth Form College"],
    ".sackvilleschool.org.uk": ["Sackville School"],
    ".sandhurstschool.org.uk": ["Sandhurst School"],
    ".sbeschool.org.uk": ["Shenley Brook End School"],
    ".sbllearning.org.uk": ["Sir Bernard Lovell Academy"],
    ".shiplake.org.uk": ["Shiplake College"],
    ".shrewsbury.org.uk": ["Shrewsbury School"],
    ".shsb.org.uk": ["Southend High School for Boys"],
    ".sidcot.org.uk": ["Sidcot School"],
    ".smwca.org.uk": [
        "St. Margaret Ward Catholic Academy",
        "http://www.stmargaretward.co.uk/ [check bottom of page]",
    ],
    ".solsch.org.uk": ["Solihull School", "Solihull School"],
    ".southhunsley.org.uk": ["South Hunsley School"],
    ".st-ambrosecollege.org.uk": ["St Ambrose College"],
    ".stbens.org.uk": [
        "St Benedict's School Ealing",
        "54 Eaton Rise",
        "Ealing",
        "London ",
        "W5 2ES",
    ],
    ".steds.org.uk": ["St Edward’s Academy"],
    ".stmaryschesterfield.org.uk": [
        "St Marys Catholic High School and Sixth form (Chesterfield)",
        "https://www.st-maryshigh.derbyshire.sch.uk",
        "@stmaryschesterfield.org.uk",
    ],
    ".stpaulsschool.org.uk": ["St Pauls School"],
    ".stpetersyork.org.uk": ["St Peters School", "St Peters School, York"],
    ".svs.org.uk": ["Sutton Valence School"],
    ".tga.org.uk": ["The Glasgow Academy"],
    ".solihull.tgacademy.org.uk": ["Tudor Grange Academy Solihull"],
    ".thekingsacademy.org.uk": ["The King's Academy"],
    ".thelangton.org.uk": ["Simon Langton Grammar School for Boys"],
    ".thomasestley.org.uk": ["Thomas Estley Community College"],
    ".threerivers.thpt.org.uk": ["Three Rivers Academy"],
    ".ivc.tmet.org.uk": ["Impington International College"],
    ".townleygrammar.org.uk": ["Townley Grammar", "Townley Grammar"],
    ".tscacademy.org.uk": ["The Samworth Church Academy"],
    ".ucs.org.uk": ["University College School"],
    ".uhs.org.uk": ["Uxbridge High School"],
    ".utcderby.org.uk": ["UTC Derby Pride Park"],
    ".utcmediacityuk.org.uk": ["UTC@MediacityUK"],
    ".utcn.org.uk": ["University Technical College Norfolk"],
    ".utcoxfordshire.org.uk": ["UTC Oxfordshire", "UTC Oxfordshire"],
    ".utcreading.org.uk": ["UTC Reading"],
    ".utcsheffield.org.uk": ["The Sheffield UTC Academy Trust"],
    ".uvhs.org.uk": ["Ulverston Victoria High School"],
    ".valeacademy.org.uk": ["The Vale Academy"],
    ".invicta.viat.org.uk": ["invicta grammar school"],
    ".student.waylandacademy.org.uk": ["Wayland Academy Norfolk"],
    ".students.wellington-school.org.uk": ["Wellington School"],
    ".wellingtoncollege.org.uk": ["Wellington College"],
    ".westminster.org.uk": ["Westminster School"],
    ".william-morris.org.uk": ["William Morris College"],
    ".williamperkin.org.uk": ["William Perkin CofE High School"],
    ".greatwyrley.windsoracademytrust.org.uk": ["Great Wyrley Academy"],
    ".wmgacademy.org.uk": ["WMG Academy for Young Engineers"],
    ".woodham.org.uk": ["Woodham Academy"],
    ".Dovergramboys.Kent.sch.uk": [
        "format - username@dovergramboys.kent.sch.uk",
        "Dover grammar school for boys, kent, uk",
    ],
    ".bordengrammar.Kent.sch.uk": [
        "Borden Grammar School",
        "Borden Grammar School",
    ],
    ".danecourt.Kent.sch.uk": ["Dane Court Grammar"],
    ".folkestonegirls.Kent.sch.uk": ["Folkestone School for Girls"],
    ".judd.Kent.sch.uk": [
        "The Judd School, Tonbridge, Kent, UK",
        "format - username@judd.kent.sch.uk",
    ],
    ".mgs.Kent.sch.uk": [
        "Maidstone grammar school, Kent, UK",
        "format - username@mgs.kent.sch.uk",
    ],
    ".nks.Kent.sch.uk": ["Norton Knatchbull School"],
    ".st-james.barnet.sch.uk": ["St James' Catholic High School"],
    ".bishopveseys.bham.sch.uk": ["Bishop Vesey's Grammar School"],
    ".wheelerslane.bham.sch.uk": ["Wheelers Lane Technology College "],
    ".bsg.bournemouth.sch.uk": ["Bournemouth School for Girls"],
    ".jfs.brent.sch.uk": ["JFS School"],
    ".qpcs.brent.sch.uk": [
        "Queens Park Community School",
        "Queens Park Community School",
    ],
    ".bgs.bristol.sch.uk": ["Bristol Grammar School", "BGS"],
    ".cotham.bristol.sch.uk": ["Cotham School"],
    ".redlandgreen.bristol.sch.uk": ["North Bristol Post 16", "Redland Green"],
    ".jhgs.bucks.sch.uk": ["john hampden grammer school"],
    ".brineleas.cheshire.sch.uk": ["Brine Leas Academy"],
    ".poltair.cornwall.sch.uk": ["Poltair School"],
    ".barrshill.coventry.sch.uk": ["Barr's Hill School"],
    ".nts.cumbria.sch.uk": ["The Nelson Thomlinson School, Wigton"],
    ".williamhoward.cumbria.sch.uk": ["William Howard"],
    ".littleover.derby.sch.uk": ["Littleover Community School"],
    ".westpark.derby.sch.uk": ["West Park School"],
    ".hillhouse.doncaster.sch.uk": ["Hill House School"],
    ".fernup.dorset.sch.uk": ["Ferndown Upper School"],
    ".villiers.ealing.sch.uk": ["Villiers High School"],
    ".ea.edin.sch.uk": ["Liberton High School"],
    ".student.mayflowerhigh.essex.sch.uk": ["Mayflower High School"],
    ".flint.flintshire.sch.uk": ["Flint High School"],
    ".jordanhill.glasgow.sch.uk": ["Jordanhill School"],
    ".glow.sch.uk": ["Glow Scotland", ".group"],
    ".saintspeterandpaul.halton.sch.uk": [
        "Saints Peter and Paul Catholic High School"
    ],
    ".brookfield.hants.sch.uk": ["Brookfield Community School"],
    ".hayling.hants.sch.uk": ["The Hayling College"],
    ".horndeantc.hants.sch.uk": ["Horndean Technology College"],
    ".kes.hants.sch.uk": ["King Edward VI School (Southampton)"],
    ".mountbatten.hants.sch.uk": ["The Mountbatten School"],
    ".perins.hants.sch.uk": ["Perins School"],
    ".salesian.hants.sch.uk": ["salesian college farnborough"],
    ".canons.harrow.sch.uk": [
        "Canons High School, Shaldon Road, Edgware, HA87 6AN"
    ],
    ".nowerhill.harrow.sch.uk": ["Nower Hill High School"],
    ".highfield.herts.sch.uk": ["The Highfield School and Sixth Form"],
    ".monkswalk.herts.sch.uk": ["Monk's Walk School"],
    ".onslow.herts.sch.uk": [
        "Onslow St Audrey's School",
        "Onslow St Audrey's School",
    ],
    ".parmiters.herts.sch.uk": [
        "Parmiters School, High Elms Ln, Watford WD25 0UU"
    ],
    ".queens.herts.sch.uk": ["Queens' School"],
    ".rickmansworth.herts.sch.uk": ["Rickmansworth School, Croxley Green"],
    ".students.sjl.herts.sch.uk": [
        "Sir John Lawes School, Manland Way, Harpenden AL5 4QP"
    ],
    ".st-albans.herts.sch.uk": ["St Albans School"],
    ".stanborough.herts.sch.uk": ["Stanborough School"],
    ".holycross.kingston.sch.uk": ["The Holy Cross School"],
    ".tiffin.kingston.sch.uk": ["Tiffin School, Kingston upon Thames, Surrey"],
    ".hodgson.lancs.sch.uk": ["Hodgson Academy"],
    ".millfield.lancs.sch.uk": ["Millfield Science & Performing Arts College"],
    ".st-aidans.lancs.sch.uk": ["St Aidans Church of England High School"],
    ".bostonspa.leeds.sch.uk": ["Boston Spa Academy"],
    ".ruthgorse.leeds.sch.uk": ["The Ruth Gorse Academy"],
    ".delisle.leics.sch.uk": ["De Lisle College"],
    ".kings.lincs.sch.uk": [
        "The King's School Grantham",
        "The King's School Grantham",
    ],
    ".mhsg.manchester.sch.uk": ["Manchester High School For Girls"],
    ".ermysteds.n-yorks.sch.uk": ["Ermysted's Grammar School"],
    ".st-marys.newcastle.sch.uk": ["St Mary's Catholic School"],
    ".aan.norfolk.sch.uk": ["Attleborough Academy Norfolk"],
    ".ccs.northants.sch.uk": ["Caroline Chisholm School"],
    ".nsb.northants.sch.uk": ["Northampton School For Boys"],
    ".wark.northumberland.sch.uk": ["Wark C of E Primary School"],
    ".emmanuel.nottingham.sch.uk": ["Nottingham Emmanuel School"],
    ".elizabethan.notts.sch.uk": ["The Elizabethan Academy"],
    ".didcotgirls.oxon.sch.uk": ["Didcot Girls School", "DGS"],
    ".henrybox.oxon.sch.uk": ["The Henry Box School"],
    ".st-birinus.oxon.sch.uk": ["St Birinus School", "St Birinus"],
    ".warriner.oxon.sch.uk": ["The Warriner School"],
    ".poolehigh.poole.sch.uk": ["Poole High School"],
    ".ecgbert.sheffield.sch.uk": [
        "King Ecgbert School",
        "https://www.ecgbert.sheffield.sch.uk",
    ],
    ".forgevalley.sheffield.sch.uk": ["Forge Valley School"],
    ".meadowhead.sheffield.sch.uk": ["Meadowhead School"],
    ".kingsdale.southwark.sch.uk": ["Kingsdale Foundation School"],
    ".christscollege.surrey.sch.uk": [
        "Christ's College Guildford",
        "Christ's College Guildford",
    ],
    ".claremont.surrey.sch.uk": ["Claremont Fan Court School"],
    ".collingwood.surrey.sch.uk": ["Collingwood College"],
    ".stjohns.surrey.sch.uk": ["St John's School. Leatherhead, Surrey"],
    ".cheam.sutton.sch.uk": ["Cheam High School"],
    ".glenthorne.sutton.sch.uk": ["Glenthorne Highschool"],
    ".wilsonsschool.sutton.sch.uk": [
        "Wilson's School",
        "Wilson's School, Wallington",
    ],
    ".central.towerhamlets.sch.uk": [
        "Central Foundation Girls School",
        "Central Foundation Girls School",
    ],
    ".hardenhuish.wilts.sch.uk": ["Hardenhuish School"],
    ".droitwichspahigh.worcs.sch.uk": [
        "Droitwich Spa High School and Sixth Form Centre"
    ],
    ".haybridge.worcs.sch.uk": ["Haybridge High School and Sixth Form"],
    ".southbromsgrove.worcs.sch.uk": ["South Bromsgrove High"],
    ".tgs.starmat.uk": ["Tadcaster Grammar School"],
    ".atlasskilltech.university": ["Atlas Skilltech University"],
    ".constructor.university": ["Constructor University Bremen"],
    ".contech.university": ["Contemporary technology university"],
    ".innopolis.university": ["Innopolis University"],
    ".jala.university": ["Jala University"],
    ".miva.university": ["Miva Open University"],
    ".pdp.university": ["PDP University"],
    ".rudn.university": ["RUDN University"],
    ".satbayev.university": ["Satbayev University"],
    ".sit.university": ["Schaffhausen Institute of Technology"],
    ".stamford.university": ["Stamford University Bangladesh"],
    ".uit.university": [
        "Université Internationale de Tunis - UIT | UIT",
        "https://univ-internationale.com/fr",
    ],
    ".ahschools.us": ["Anoka-Hennepin School District"],
    ".mtnbrook.k12.al.us": [
        "Mountain Brook High School",
        "Mountain Brook Junior High",
    ],
    ".pickens.k12.al.us": ["Pickens County School District"],
    ".amly.us": ["AMLY School"],
    ".student.andoverma.us": ["Andover Public Schools"],
    ".apsva.us": ["Washington-Liberty High School", "Arlington Career Center"],
    ".args.us": ["Appomattox Regional Governor's School"],
    ".ausdg.us": ["Encinal JR/SR High School", "Alameda High School"],
    ".biu.us": ["Broward International University"],
    ".bubblers.us": ["South Middleton School District"],
    ".cjuhsd.k12.ca.us": ["Los Osos High School"],
    ".clovisusd.k12.ca.us": ["Clovis Unified School District", "cusd.com"],
    ".cv.k12.ca.us": ["Castro Valley High School"],
    ".delnorte.k12.ca.us": [
        "Del Norte County Office of Education",
        "Del Norte Unified School District",
    ],
    ".eduhsd.k12.ca.us": ["El Dorado Union High School District"],
    ".husd.k12.ca.us": ["Tennyson High School"],
    ".khsd.k12.ca.us": ["Kern High School District"],
    ".luhsd.k12.ca.us": [
        "Heritage High School",
        "https://hhs.luhsd.net/",
        "https://hhs.luhsd.net/academics/course-lists",
        "https://hhs.luhsd.net/student-info/micrsoft-office",
        ".group",
    ],
    ".nhusd.k12.ca.us": ["James Logan High School"],
    ".nohum.k12.ca.us": ["Arcata High School"],
    ".piedmont.k12.ca.us": ["Piedmont High School"],
    ".sbcusd.k12.ca.us": [
        "San Bernardino City Unified School District",
        "San Bernardino City USD",
    ],
    ".upland.k12.ca.us": ["Upland High School"],
    ".vcpusd.k12.ca.us": ["Valley Center-Pauma Unified"],
    ".jeffco.k12.co.us": ["Jefferson County Public Schools"],
    ".cpsd.us": ["Cambridge Rindge and Latin School"],
    ".bethel.k12.ct.us": ["Bethel Public Schools"],
    ".newtown.k12.ct.us": ["Newtown High School"],
    ".students.k12.dc.us": ["District of Columbia Public Schools"],
    ".appo.k12.de.us": ["Appoquinimink High School"],
    ".ncs.charter.k12.de.us": ["Newark Charter School"],
    ".colonial.k12.de.us": ["William Penn High School"],
    ".ncs.k12.de.us": ["Newark Charter School"],
    ".student.ecisd.us": ["Edinburg North High School"],
    ".ecisd.us": ["Edinburg North High School"],
    ".marion.k12.fl.us": ["Marion County Public Schools", ".group"],
    ".nassau.k12.fl.us": ["Fernandina Beach Middle School"],
    ".pasco.k12.fl.us": ["Pasco County Schools"],
    ".stjohns.k12.fl.us": ["Creekside High School"],
    ".walton.k12.fl.us": ["South Walton High School"],
    ".s.bryan.k12.ga.us": ["Richmond Hill High School", ".group"],
    ".cherokee.k12.ga.us": ["Cherokee County School District"],
    ".forsyth.k12.ga.us": ["Forsyth County School District"],
    ".heard.k12.ga.us": ["Heard County School District"],
    ".henry.k12.ga.us": ["Henry County School District"],
    ".students.rockdale.k12.ga.us": ["Salem High School"],
    ".greenvilleschools.us": ["Greer High School"],
    ".hartlandschools.us": ["Hartland Consolidated Schools"],
    ".hasd.us": ["Halifax Area School District"],
    ".kaimukims.k12.hi.us": ["Kaimuki Middle School"],
    ".notes.k12.hi.us": ["Hawaii State Department of Education", ".group"],
    ".ames.k12.ia.us": ["Ames Community School District"],
    ".baxter.k12.ia.us": ["Baxter Community School"],
    ".g.bettendorf.k12.ia.us": ["Bettendorf High School"],
    ".cr.k12.ia.us": ["Cedar Rapids Community School District"],
    ".davenport.k12.ia.us": ["West High School"],
    ".e-marshall.k12.ia.us": [
        "East Marshall High School",
        "East Marshall High School",
    ],
    ".nfv.k12.ia.us": ["North Fayette Valley Community School District"],
    ".north-scott.k12.ia.us": ["North Community School District"],
    ".rvc.cc.il.us": ["Rock Valley College"],
    ".auburn.k12.il.us": ["Auburn High School"],
    ".batesville.k12.in.us": ["Batesville High School"],
    ".ccs.k12.in.us": ["Clay middle school", "Clay middle school"],
    ".students.centergrove.k12.in.us": [
        "Center Grove Community School Corporation"
    ],
    ".clay.k12.in.us": ["Clay Community Schools"],
    ".elkhart.k12.in.us": ["Elkhart Community Schools"],
    ".gws.k12.in.us": ["Greenwood Middle School"],
    ".hse.k12.in.us": ["Hamilton Southeastern High School"],
    ".kv.k12.in.us": [
        "Kankakee Valley High School",
        "KVHS",
        "Kankakee Valley Middle School",
        "KVMS",
    ],
    ".student.msdwt.k12.in.us": ["North Central High School"],
    ".mvcsc.k12.in.us": ["Mount Vernon High School"],
    ".ngsc.k12.in.us": ["Princeton Community High School"],
    ".phm.k12.in.us": ["Penn Harris Maddison School Corporation"],
    ".warren.k12.in.us": ["MSD Warren Township Schools"],
    ".jdragonmail.us": ["Johnston High School"],
    ".jeffcoschools.us": ["Jefferson County Public Schools"],
    ".stu.anderson.kyschools.us": ["Anderson County High School"],
    ".stu.boone.kyschools.us": ["Boone County Schools"],
    ".stu.campbell.kyschools.us": ["Campbell County Schools"],
    ".campbell.kyschools.us": ["Campbell County Schools"],
    ".stu.fayette.kyschools.us": ["Fayette County Public Schools"],
    ".fayette.kyschools.us": ["Bryan Station High School"],
    ".stu.hardin.kyschools.us": ["Hardin County Schools"],
    ".stu.jefferson.kyschools.us": ["Jefferson County Public Schools"],
    ".jessamine.kyschools.us": ["West Jessamine High School"],
    ".kenton.kyschools.us": ["Kenton County Schools"],
    ".owensboro.kyschools.us": ["Owensboro Public Schools"],
    ".stu.warren.kyschools.us": ["Warren County Schools"],
    ".duxbury.k12.ma.us": ["Duxbury Public Schools"],
    ".longmeadow.k12.ma.us": ["Longmeadow High School"],
    ".lynnfield.k12.ma.us": [
        "Lynnfield Public Schools / Lynnfield High School"
    ],
    ".students.needham.k12.ma.us": ["Pollard Middle"],
    ".newton.k12.ma.us": ["Newton South High School", ".group"],
    ".north-reading.k12.ma.us": [
        "North Reading Public Schools / North Reading High School"
    ],
    ".norwood.k12.ma.us": ["Norwood High School"],
    ".student.plymouth.k12.ma.us": ["Plymouth Public Schools"],
    ".reading.k12.ma.us": [
        "Reading Public Schools / Reading Memorial High School"
    ],
    ".shrewsbury.k12.ma.us": [
        "Shrewsbury Public Schools / Shrewsbury High School"
    ],
    ".valleytech.k12.ma.us": [
        "Blackstone Valley Regional Vocational Technical High School"
    ],
    ".ware.k12.ma.us": ["Ware Public Schools"],
    ".wayland.k12.ma.us": ["Wayland High School"],
    ".sch.ci.lexington.ma.us": ["Lexington High School"],
    ".malad.us": ["Malad High School"],
    ".students.kent.k12.md.us": ["Kent County High School"],
    ".aaps.k12.mi.us": ["Pioneer High School - Ann Arbor"],
    ".clarkston.k12.mi.us": ["Clarkston Community Schools"],
    ".cvs.k12.mi.us": ["Chippewa Valley Schools"],
    ".haslett.k12.mi.us": ["Haslett High School"],
    ".student.oakland.k12.mi.us": ["Oakland Schools Technical Campus NW"],
    ".oakland.k12.mi.us": ["Oakland Schools Technical Campus NW"],
    ".rochester.k12.mi.us": [
        "Rochester Community School District",
        "Rochester Community Schools",
    ],
    ".roseville.k12.mi.us": ["Roseville High School"],
    ".troy.k12.mi.us": [
        "Troy Community School District",
        "Troy Community Schools",
        "Troy Public School District",
    ],
    ".edenpr.k12.mn.us": ["Eden Prairie School District - Teacher Email"],
    ".isd2142.k12.mn.us": ["St. Louis County Schools"],
    ".gapps.sartell.k12.mn.us": [
        "Sartell-St. Stephen ISD 748 (Google Apps for Education)"
    ],
    ".sartell.k12.mn.us": ["Sartell-St. Stephen ISD 748 (Teacher Email)"],
    ".stpaul.k12.mn.us": ["Highland Park Senior High"],
    ".eastbuchanan.k12.mo.us": ["East Buchanan C1"],
    ".monett.k12.mo.us": ["Monnett Schools"],
    ".smithville.k12.mo.us": ["Smithville Schools"],
    ".wrightcity.k12.mo.us": ["Wright City School District"],
    ".gfps.k12.mt.us": ["Great Falls Public School District"],
    ".sacoschools.k12.mt.us": ["Saco Public School District"],
    ".mtsdstudent.us": [
        "Montgomery High School ",
        "Montgomery Township School District",
        "Montgomery High",
        "Montgomery ",
    ],
    ".mycod.us": ["College of the Desert"],
    ".myhalifax.us": ["Halifax Area School District"],
    ".student.myscps.us": [
        "Seminole County Public Schools",
        "https://www.scps.k12.fl.us/",
        "The emails for students that are in schools in Seminole County are ID@student.myscps.us",
    ],
    ".students.abss.k12.nc.us": [
        "Alamance-Burlington School System - Student Emails"
    ],
    ".abss.k12.nc.us": ["Alamance-Burlington School System - Teacher Emails"],
    ".cabarrus.k12.nc.us": ["Cabarrus County school system"],
    ".students.chccs.k12.nc.us": [
        "Chapel Hill-Carrboro city schools-students"
    ],
    ".chccs.k12.nc.us": ["Chapel-Hill Carrboro City Schools"],
    ".cms.k12.nc.us": ["Charlotte-Mecklenburg Schools"],
    ".hcs.k12.nc.us": ["Hoke County High School"],
    ".lee.k12.nc.us": ["Lee County Schools"],
    ".student.ucps.k12.nc.us": ["Marvin Ridge Middle School"],
    ".k12.nd.us": ["Jamestown High School"],
    ".nicolet.us": ["Nicolet High School"],
    ".nisd.us": ["Navarro High School"],
    ".brrsd.k12.nj.us": ["Bridgewater Raritan School District, NJ"],
    ".dvrhs.k12.nj.us": ["Delaware Valley Regional High School"],
    ".ewrsd.k12.nj.us": ["Hightstown High School"],
    ".ns.greenwich.k12.nj.us": [
        "Greenwich Township School District",
        ".group",
    ],
    ".gtps.k12.nj.us": ["Galloway Township Public Schools"],
    ".mahwah.k12.nj.us": ["Mahwah Public School District"],
    ".students.monroe.k12.nj.us": ["Monroe Township Middle School"],
    ".nps.k12.nj.us": ["Newark Public Schools District"],
    ".paramus.k12.nj.us": ["Paramus Public School District"],
    ".ramsey.k12.nj.us": ["Ramsey Public School District"],
    ".ridgewood.k12.nj.us": ["Ridgewood High School"],
    ".students.somsd.k12.nj.us": [
        "South Orange Maplewood School District Student Domain",
        ".group",
    ],
    ".summit.k12.nj.us": ["Summit High School"],
    ".trenton.k12.nj.us": ["Trenton Public Schools"],
    ".njit.us": ["New Jersey Institute of Technology"],
    ".nmusd.us": ["Newport Harbor High School"],
    ".commack.k12.ny.us": ["Commack High School"],
    ".comsewogue.k12.ny.us": ["Comsewogue School District"],
    ".csh.k12.ny.us": [
        "Cold Spring Harbor Jr/Sr High School",
        "Cold Spring Harbor Central School District",
    ],
    ".gn.k12.ny.us": ["William A. Shine Great Neck South High School"],
    ".icsd.k12.ny.us": ["Ithaca City School District"],
    ".newpaltz.k12.ny.us": ["New Paltz High School"],
    ".northport.k12.ny.us": ["Northport High School"],
    ".smithtown.k12.ny.us": ["Smithtown High School West"],
    ".syosset.k12.ny.us": [
        "Syosset High School",
        "Syosset Central School District",
    ],
    ".wfsd.k12.ny.us": [
        "William Floyd High School",
        "William Floyd School District",
    ],
    ".ashland-city.k12.oh.us": ["Ashland City Schools"],
    ".elida.k12.oh.us": ["Elida Local Schools"],
    ".glenpool.k12.ok.us": ["Glenpool Public Schools"],
    ".norman.k12.ok.us": ["Norman Public Schools"],
    ".olsd.us": ["Olentangy High School"],
    ".student.bend.k12.or.us": ["Summit High school"],
    ".bend.k12.or.us": ["Summit High School"],
    ".cascade.k12.or.us": ["Cascade School District"],
    ".gresham.k12.or.us": ["Sam Barlow High School"],
    ".hoodriver.k12.or.us": ["Hood river valley high school"],
    ".hsd.k12.or.us": ["Hillsboro School District"],
    ".loswego.k12.or.us": ["Lake Oswego School District", "LOSD"],
    ".student.orecity.k12.or.us": ["Oregon City School District", "OCSD"],
    ".orecity.k12.or.us": ["Oregon City School District", "OCSD"],
    ".stu.ortrail.k12.or.us": ["Sandy High School"],
    ".iwms.wlwv.k12.or.us": ["Wood Middle School"],
    ".wlhs.wlwv.k12.or.us": ["West Linn High School"],
    ".wvhs.wlwv.k12.or.us": ["Wilsonville High School"],
    ".basd.k12.pa.us": ["Beaver Area School District"],
    ".franklinregional.k12.pa.us": ["Franklin Regional School District"],
    ".gmsd.k12.pa.us": ["Governor Mifflin School District"],
    ".hershey.k12.pa.us": ["Hershey High School"],
    ".hpsd.k12.pa.us": ["Hanover Public School District"],
    ".indians.k12.pa.us": ["Shamokin Area High School"],
    ".lasd.k12.pa.us": ["Littlestown Area School District"],
    ".mohawk.k12.pa.us": ["Mohawk High School"],
    ".wilmington.k12.pa.us": ["Wilmington Area School District"],
    ".wssd.k12.pa.us": ["West Shore School District"],
    ".pausd.us": ["Palo Alto Unified School District"],
    ".pusd.us": ["Pasadena High School", "Pasadena High School"],
    ".rcs-k12.us": [
        "Rochester Community School District",
        "Rochester Community Schools",
    ],
    ".rentonschools.us": ["Renton School District"],
    ".clover.k12.sc.us": ["Clover School District"],
    ".gssm.k12.sc.us": [
        "South Carolina Governor's School for Science and Mathematics"
    ],
    ".k12.sd.us": ["Brookings High School"],
    ".smusd.us": ["San Marino Unified School District"],
    ".soudertonsd.us": ["Souderton Area High School"],
    ".tri-county.us": ["Tri-County Regional Vocational Technical High School"],
    ".austin.cc.tx.us": ["Austin Community College"],
    ".davis.k12.ut.us": ["Davis School District"],
    ".weber.k12.ut.us": ["Weber School District"],
    ".bedford.k12.va.us": [
        "Forest Middle School",
        "http://bedfordfms.sharpschool.net/",
        ".group",
    ],
    ".gsgis.k12.va.us": ["Maggie L. Walker Governor's School"],
    ".harrisonburg.k12.va.us": [
        "Harrisonburg High School",
        "https://harrisonburg.k12.va.us/hhs/",
        ".group",
    ],
    ".nn.k12.va.us": ["Newport News Public Schools", ".group"],
    ".rockbridge.k12.va.us": ["Rockbridge County High School"],
    ".students.wcps.k12.va.us": ["Skyline High School"],
    ".msvl.k12.wa.us": ["Marysville Pilchuck high school"],
    ".westfordk12.us": ["Westford Academy"],
    ".bonduel.k12.wi.us": ["Bonduel School District"],
    ".dce.k12.wi.us": ["D.C. Everest Area District"],
    ".depere.k12.wi.us": ["de pere high school"],
    ".hudson.k12.wi.us": ["Hudson"],
    ".madison.k12.wi.us": [
        "James Madison Memorial High School",
        "Madison, WI  USA",
    ],
    ".students.mcpasd.k12.wi.us": ["Middleton High School"],
    ".neenah.k12.wi.us": ["Neenah High School"],
    ".randomlake.k12.wi.us": ["Random Lake School District"],
    ".shorewood.k12.wi.us": ["Shorewood School District"],
    ".waukesha.k12.wi.us": ["School District of Waukesha"],
    ".westosha.k12.wi.us": [
        "Central High School District of Westosha",
        "24617 75th St, Salem, WI 53168",
    ],
    ".k12.wv.us": ["South Branch Career & Technical Center"],
    ".yorkuniversity.us": ["York University"],
    ".anima.edu.uy": [
        "Ánima - Bachillerato Tecnológico",
        "Anima - Technological Baccalaureate",
    ],
    ".bios.edu.uy": ["Instituto BIOS Uruguay"],
    ".docente.ceibal.edu.uy": [
        "Administracion Nacional de Educacion Publica - Plan Ceibal"
    ],
    ".estudiante.ceibal.edu.uy": ["Plan Ceibal"],
    ".ceibal.edu.uy": ["Ceibal", "Ceibal"],
    ".cienciassociales.edu.uy": ["Universidad de la República Uruguay"],
    ".claeh.edu.uy": [
        "Insituto Universitario - Centro Latinoamericano de Economia Humana - IU Claeh"
    ],
    ".fcien.edu.uy": ["Facultad de Ciencias"],
    ".fic.edu.uy": [
        "Facultad de Información y Comunicación, Universidad de la República."
    ],
    ".fing.edu.uy": [
        "Facultad de Ingeniería, Universidad de la República",
        "https://www.fing.edu.uy/",
    ],
    ".kennedy.edu.uy": ["Colegio JF Kennedy", "School John F. Kennedy"],
    ".ort.edu.uy": ["Universidad ORT Uruguay"],
    ".pedeciba.edu.uy": [
        "Programa de Desarrollo de las Ciencias Básicas (PEDEClBA) "
    ],
    ".psico.edu.uy": ["Facultad de Psicología UDELAR", "psico.edu.uy"],
    ".rau.edu.uy": ["Universidad de la República"],
    ".seciu.edu.uy": [
        "Universidad de la Republica",
        "University of the Republic",
    ],
    ".alumnos.seminario.edu.uy": ["Colegio Seminario"],
    ".ucu.edu.uy": ["Universidad Católica del Uruguay"],
    ".ude.edu.uy": ["Universidad de la Empresa (UDE)"],
    ".udelar.edu.uy": ["Universidad de la República", ".group"],
    ".um.edu.uy": ["Universidad de Montevideo"],
    ".utec.edu.uy": [
        "UTEC (Universidad Tecnológica del Uruguay)",
        "UTEC (Technological University of Uruguay)",
    ],
    ".adti.uz": [
        "Andijon davlat tibbiyot instituti",
        "Andijan State Medical Institute",
    ],
    ".adu.uz": ["Andijon Davlat Universiteti", "Andizhan State University"],
    ".afu.uz": ["Alfraganus universiteti", "Alfraganus University"],
    ".ajou.uz": ["Ajou University in Tashkent"],
    ".akfauniversity.uz": ["Akfa University"],
    ".andmiedu.uz": [
        "Andijon Mashinasozlik Instituti",
        "Andijan Machine-building Institute",
    ],
    ".andqxai.uz": [
        "Andijon Qishloq xo'jaligi va agro texnologiyalar instituti",
        "Andijan Instute of Agriculture and Agrarian Technology",
    ],
    ".aut-edu.uz": ["American University of Technology, Uzbekistan"],
    ".bmu-edu.uz": ["British Management University"],
    ".buxdpi.uz": [
        "Buxoro Davlat Pedagogika Instituti",
        "Bukhara State Pedagogical Institute",
    ],
    ".buxdu.uz": ["Buxoro Davlat Universiteti", "Bukhara State University"],
    ".cambridge.uz": [
        "Cambridge International University in Tashkent",
        "Original website: cambridge.uz",
        "Main domain used by staff and teachers",
        "Subdomain student.cambridge.uz used by students and separate pull request has been created",
    ],
    ".centralasian.uz": [
        "Central Asian University",
        "Central Asian University",
    ],
    ".fdu.uz": ["Farg'ona Davlat Universiteti", "Fergana State University"],
    ".ferpi.uz": [
        "Farg'ona Politexnika Instituti",
        "Fergana Polytechnic Institute",
    ],
    ".gubkin.uz": ["National University of Oil and Gas «Gubkin University»"],
    ".ibs.uz": ["International Business School Kelajak ILMI"],
    ".idu.uz": [
        "Xalqaro Raqamli universitet",
        "International Digital University",
    ],
    ".iiau.uz": ["International Islamic Academy of Uzbekistan"],
    ".inha.uz": ["Inha University in Tashkent"],
    ".student.itpu.uz": ["IT Park University", "IT Park University"],
    ".itpu.uz": ["IT Park University", "IT Park University (ITPU),Uzbekistan"],
    ".iut.uz": ["Inha University in Tashkent"],
    ".jbnuu.uz": [
        "  MIRZO ULUG‘BEK NOMIDAGI O‘ZBEKISTON MILLIY UNIVERSITETI JIZZAX FILIALI",
        "  JIZZAKH BRANCH OF NATIONAL UNIVERSITY OF UZBEKISTAN NAMED AFTER MIRZO ULUGBEK",
    ],
    ".jdpu.uz": [
        "Jizzax davlat pedagogika universiteti",
        "jizzakh state pedagogical university",
    ],
    ".jdu.uz": ["Japan Digital University"],
    ".kiuf.uz": ["Korean International University in Ferghana"],
    ".kiut.uz": ["Kimyo International University in Tashkent"],
    ".mdis.uz": ["Management Development Institute of Singapore, Tashkent"],
    ".mdist.uz": ["Management Development Institute of Singapore in Tashkent"],
    ".msu.uz": [
        "Lomonosov Moscow State University in Tashkent",
        "Moscow State University in Tashkent",
    ],
    ".namdu.uz": ["Namangan davlat universiteti", "Namangan State University"],
    ".nbtuit.uz": [
        "Muhammad al-Xorazmiy nomidagi Toshkent Axborot Texnologiyalari Universiteti Nurafshon filiali",
        "Nurafshon branch of Tashkent University of Information Technologies named after Muhammad al-Khwarizmi",
    ],
    ".ndki.uz": [
        "Navoiy Davlat Konchilik Instituti",
        "Navoi State Mining Institute",
    ],
    ".newuu.uz": [
        "Yangi O'zbekiston Universiteti",
        "New Uzbekistan University",
    ],
    ".newuzbekistanuniversity.uz": [
        "New Uzbekistan University",
        "Yangi O'zbekiston Universiteti",
    ],
    ".nspi.uz": [
        "Navoiy Davlat Pedagogika Instituti",
        "Navoi State Pedagogical Institute",
    ],
    ".nukusii.uz": [
        "Нукусский инновационный институт",
        "Nukus innovation institute",
    ],
    ".nuu.uz": ["National University of Uzbekistan"],
    ".pdp.uz": ["PDP UNIVERSITY", "PDP UNIVERSITY"],
    ".pharmi.uz": ["Tashkent Pharmaceutical Institute"],
    ".polito.uz": ["Turin Polytechnic University in Tashkent"],
    ".qarshidu.uz": ["Qarshi davlat universiteti", "Qarshi State University"],
    ".qdpi.uz": ["Kokand State Pedagogical Institute"],
    ".qmii.uz": ["Karshi Engineering Economic Institute"],
    ".samdchti.uz": ["Samarkand State Institute of Foreign Languages"],
    ".samdu.uz": ["Samarkand State University"],
    ".samgasi.uz": [
        "Samarqand davlat arxitektura-qurilish Universiteti",
        "Samarkand State Architecture and Construction University",
    ],
    ".samtuit.uz": [
        "Samarkand branch of Tashkent University of Information Technologies"
    ],
    ".taqi.uz": [
        "Toshkent arxitektura-qurilish universiteti",
        "Tashkent University of Architecture and Construction",
    ],
    ".taqu.uz": [
        "Toshkent arxitektura-qurilish universiteti",
        "TASHKENT UNIVERSITY OF ARCHITECTURE AND CIVIL ENGINEERING",
    ],
    ".tatuff.uz": [
        "Tashkent University of Information Technologies, Ferghana branch"
    ],
    ".tatunf.uz": [
        "Muhammed Al-Xorezmiy atındaǵı Tashkent Informaciyalıq Texnologiyaları Universiteti Nókis filialı",
        "Nukus branch of Tashkent University of Information technologies named after Muhammad al-Khwarizmi",
    ],
    ".tayi.uz": ["Tashkent Automobile and Roads Institute"],
    ".tcti.uz": ["Tashkent Chemical Technological Institute"],
    ".tdau.uz": [
        "Toshkent davlat agrar universiteti",
        "Tashkent State Agrarian University",
    ],
    ".tdpu.uz": [
        "Toshkent Davlat Pedagogika Universiteti",
        "Tashkent State Pedagogical University",
    ],
    ".tdtu.uz": [
        "Tashkent State Technical University",
        "Ташкентский Государственный Технический Университет",
        "Toshkent Davlat Texnika Universiteti",
    ],
    ".teamuni.uz": ["TEAM University"],
    ".tersu.uz": ["Termiz Davlat Universiteti", "Termiz State University"],
    ".tfi.uz": ["Tashkent School of Finance"],
    ".tiiame.uz": [
        "“Toshkent irrigatsiya va qishloq xo‘jaligini mexanizatsiyalash muhandislari instituti” Milliy tadqiqot universiteti",
        'National Research University "Tashkent Institute of Irrigation and Agricultural Mechanization Engineers"',
    ],
    ".tiiamekb.uz": [
        "Karshi branch of the Tashkent Institute of Irrigation and Agricultural Mechanization Engineers"
    ],
    ".tiim.uz": ["Tashkent Institute of Irrigation and Melioration"],
    ".tiu.uz": ["Tashkent Islam University"],
    ".tiue.uz": ["Tashkent International University of education"],
    ".tma.uz": ["Tashkent Medical Academy"],
    ".tmci.uz": ["TMC Institute in Tashkent", "TMC Institute in Tashkent"],
    ".tstu.uz": ["Tashkent state trensport university"],
    ".tsue.uz": ["Tashkent State University of Economics"],
    ".tsul.uz": [
        "Ташкентский государственный юридический университет",
        "Tashkent State University of Law",
    ],
    ".tsuos.uz": [
        "Toshkent davlat sharqshunoslik universiteti",
        "Tashkent State University of Oriental Studies",
    ],
    ".tuit.uz": ["Tashkent University of Information Technologies"],
    ".tuitkf.uz": [
        "Karshi Branch of Tashkent University of Information Technologies"
    ],
    ".ubsu.uz": [
        "University of Business and Science",
        "University of Business and Science",
    ],
    ".ubtuit.uz": ["TATU Urgnch filiali", "Urgench branch of TUIT"],
    ".umft.uz": ["University of Management and Future Technologies"],
    ".urdu.uz": ["Urganch Davlat Universiteti", "Urgench State University"],
    ".utas.uz": ["University of Tashkent for Applied Science"],
    ".uwed.uz": ["University of World Economy &amp; Diplomacy"],
    ".uzpak.uz": ["Namangan Engineering-Pedagogical Institute"],
    ".uzswlu.uz": ["Uzbek State World Languages University"],
    ".wiut.uz": ["Westminster International University in Tashkent"],
    ".ytit.uz": [
        "Yeoju Technical Institute in Tashkent",
        "Yeoju Technical Institute in Tashkent",
    ],
    ".unifeso.com.vc": ["UNIFESO - Centro Universitário Serra dos Órgãos"],
    ".iutamaracay.com.ve": [
        "Instituto Universitario de tecnología de Administración Industrial"
    ],
    ".iutacaracas.edu.ve": [
        "Instituto Universitario de Tecnologia de Administracion Industrial"
    ],
    ".iutcm.edu.ve": [
        "Instituto Universitario de Tecnologia Cristobal Mendoza",
        "University Institute of Technology Cristobal Mendoza",
        "IUTCM",
    ],
    ".luz.edu.ve": [
        "La Universidad del Zulia",
        "The university of Zulia",
        "LUZ",
    ],
    ".uba.edu.ve": ["Universidad Bicentenaria de Aragua"],
    ".ubv.edu.ve": ["Universidad Bolivariana de Venezuela"],
    ".uc.edu.ve": ["Universidad de Carabobo"],
    ".ucab.edu.ve": ["Universidad Católica Andres Bello"],
    ".ucat.edu.ve": ["Universidad Católica del Táchira"],
    ".ucla.edu.ve": ["Universidad Centro Occidental Lisandro Alvarado"],
    ".udo.edu.ve": [
        "UNIVERSIDAD DE ORIENTE ",
        "ESCUELA DE INGENIERÍA Y CIENCIAS APLICADAS",
    ],
    ".uft.edu.ve": ["Universidad Fermin Toro"],
    ".ujap.edu.ve": [
        "Universidad José Antonio Páez",
        "Jose Antonio Paez University",
    ],
    ".una.edu.ve": ["Universidad Nacional Abierta"],
    ".une.edu.ve": ["Universidad Nueva Esparta", "Nueva Esparta University"],
    ".unefa.edu.ve": ["Universidad Nacional Experimental de la Fuerza Armada"],
    ".unefm.edu.ve": [
        "Universidad Nacional Experimental Francisco de Miranda",
        "https://unefm.net/",
        "http://estudiantes.unefm.edu.ve/",
        "https://mundoadi.net/formacion/",
    ],
    ".uneg.edu.ve": [
        "UNIVERSIDAD NACIONAL EXPERIMENTAL DE GUAYANA",
        "NATIONAL EXPERIMENTAL UNIVERSITY OF GUAYANA",
    ],
    ".unellez.edu.ve": [
        "Universidad Nacional Experimental de los Llanos Occidentales Ezequiel Zamora"
    ],
    ".unerg.edu.ve": ["Universidad Nacional Experimental Romulo Gallegos"],
    ".unermb.edu.ve": [
        "Universidad Nacional Experimental Rafael Maria Baralt"
    ],
    ".unesur.edu.ve": [
        "Universidad Nacional Experimental Sur del Lago Jesús Maria Semprum"
    ],
    ".unet.edu.ve": ["Universidad Nacional Experimental del Tachira"],
    ".uneti.edu.ve": [
        "Universidad Nacional Experimental de las Telecomunicaciones e Informática",
        "National Experimental University of Telecommunications And Computing",
    ],
    ".unexpo.edu.ve": [
        "Universidad Nacional Experimental Antonio Jose de Sucre"
    ],
    ".unica.edu.ve": ["Universidad Católica Cecilio Acosta"],
    ".unimar.edu.ve": [
        "Universidad de Margarita",
        "University of Margarita",
        "UNIMAR",
    ],
    ".unimet.edu.ve": ["Universidad Metropolitana"],
    ".unitec.edu.ve": ["Universidad Tecnológica del Centro"],
    ".uny.edu.ve": ["Universidad Yacambu"],
    ".uptamca.edu.ve": [
        "Universidad Politécnica Territorial de los Altos Mirandinos Cecilio Acosta",
        "Territorial Polytechnic University of Altos Mirandinos Cecilio Acosta",
    ],
    ".uptm.edu.ve": [
        "Universidad Politécnica Territorial del Estado Mérida Kléber Ramírez"
    ],
    ".uptos.edu.ve": [
        'Universidad Politécnica Territorial del Oeste de Sucre "Clodosbaldo Russián"',
        'Territorial Polytechnic University of Western Sucre "Clodosbaldo Russián"',
    ],
    ".uptvalencia.edu.ve": ["Universidad Politécnica Territorial de Valencia"],
    ".urbe.edu.ve": [
        "Universidad Privada Dr Rafael Belloso Chacin",
        "Private University Dr Rafael Belloso Chacin",
        "https://www.urbe.edu/",
        "http://urbe.edu.ve/",
    ],
    ".usm.edu.ve": ["Universidad Santa María", "Saint Mary University"],
    ".uvm.edu.ve": ["Universidad Valle del Momboy"],
    ".www.ucv.ve": ["Universidad Central de Venezuela"],
    ".ucv.ve": ["Universidad Central de Venezuela"],
    ".www.ula.ve": ["Universidad de Los Andes"],
    ".ula.ve": ["Universidad de Los Andes"],
    ".www.usb.ve": ["Universidad Simón Bolivar"],
    ".usb.ve": ["Simón Bolívar University"],
    ".hlscc.edu.vg": ["H. Lavity Stoutt Community College"],
    ".fpt.aptech.ac.vn": ["FPT Aptech", "FPT Aptech"],
    ".apcs.vn": [
        "Advanced Program in Computer Science - University of Science HCMC"
    ],
    ".aptech.vn": ["Hanoi-Aptech Computer Education"],
    ".datapot.vn": [
        "https://datapot.edu.vn/",
        "Datapot is an educational institute that provides data science courses for Universities and Companies in Vietnam.",
    ],
    ".actvn.edu.vn": ["Academy of cryptography techniques of VietNam"],
    ".agu.edu.vn": ["An Giang University"],
    ".ajc.edu.vn": [
        "Học viện Báo chí và Tuyên truyền",
        "Academy of journalism and communication Vietnam",
    ],
    ".apd.edu.vn": ["Academy of Policy and Development"],
    ".aptechlearning.edu.vn": [
        "Aprotrain-Aptech",
        "Aprotrain-Aptech",
        "Website: https://aptechvietnam.com.vn/",
        "Facebook: https://www.facebook.com/aptechvietnam.com.vn",
        "Wiki: https://vi.wikipedia.org/wiki/Aptech",
        "My student email: quyen.nh.404@aptechlearning.edu.vn",
    ],
    ".arena.edu.vn": ["FPT Arena Multimedia Education"],
    ".aschool.edu.vn": [
        "Trường THCS Archimedes Academy",
        "Archimedes Academy",
    ],
    ".bacgiang.edu.vn": [
        "BacGiang Specialized Upper Secondary School",
        "Website: http://thptchuyen.bacgiang.edu.vn/",
    ],
    ".bacninh.edu.vn": [
        "Bac Ninh Specialized High School",
        "Website: https://thptchuyenbacninh.bacninh.edu.vn/",
    ],
    ".bafu.edu.vn": [
        "TRƯỜNG ĐẠI HỌC NÔNG - LÂM BẮC GIANG",
        "BAC GIANG AGRICULTURE AND FORESTRY UNIVERSITY",
    ],
    ".banmaischool.edu.vn": ["BAN MAI SCHOOL", "BAN MAI SCHOOL"],
    ".bav.edu.vn": ["Học viện Ngân Hàng", "Banking Academy of Vietnam"],
    ".bctech.edu.vn": [
        "Trường Cao đẳng Kỹ thuật Công nghệ Bà Rịa - Vũng Tàu",
        "BCTECH",
    ],
    ".bdu.edu.vn": ["Binh Duong University"],
    ".binhnamphong.edu.vn": [
        "Trường Trung Học Cơ Sở Nam Phong",
        "Nam Phong junior high school",
    ],
    ".bkacad.edu.vn": [
        "Học viện Công nghệ BKACAD",
        "BKACAD Academy of Technology",
    ],
    ".bkc.edu.vn": [
        "CAO DANG BACH KHOA SAI GON (BKC)",
        "BACH KHOA SAI GON COLLEGE",
    ],
    ".ms.blu.edu.vn": ["Trường Đại Học Bạc Liêu", "Bac Lieu University"],
    ".buh.edu.vn": [
        "Trường Đại Học Ngân Hàng TPHCM",
        "Banking University TPHCM",
    ],
    ".st.buv.edu.vn": ["British University Vietnam"],
    ".buv.edu.vn": [
        "British University Vietnam",
        "British University Vietnam",
    ],
    ".bvu.edu.vn": ["Ba Ria - Vung Tau University"],
    ".c3longthanh.edu.vn": ["Trường THPT Long Thành"],
    ".c3lqdon-khanhhoa.edu.vn": [
        "Trung Học Phổ Thông Lê Quý Đôn Khánh Hoà",
        "Le Quy Don High School for gitfted",
    ],
    ".cantho.edu.vn": [
        "Sở GD&ĐT Cần Thơ",
        "Department of Education and Training of Can Tho City",
    ],
    ".caodangquoctehanoi.edu.vn": [
        "TRƯỜNG CAO ĐẲNG QUỐC TẾ HÀ NỘI",
        "HANOI INTERNATIONAL COLLEGE – VIET NAM",
    ],
    ".caodangvietmy.edu.vn": [
        "Cao đẳng Việt Mỹ",
        "American Polytechnic College-APC",
    ],
    ".caothang.edu.vn": ["Cao Đẳng Kĩ Thuật Cao Thắng"],
    ".caugiay.edu.vn": ["THCS Trương Công Giai"],
    ".cdythadong.edu.vn": ["Cao đẳng Y tế Hà Đông", "HA DONG MEDICAL COLLEGE"],
    ".chauvanliem.edu.vn": ["THPT Châu Văn Liêm", "Chau Van Liem High School"],
    ".chuyenthaibinh.edu.vn": [
        "Trung học phổ thông Chuyên Thái Bình",
        "Thai Binh Gifted High School",
    ],
    ".cis.edu.vn": ["Canadian International School Viet Nam"],
    ".st.cmc-u.edu.vn": ["CMC UNIVERSITY"],
    ".cmc.edu.vn": [
        "Đại Học CMC",
        "CMC University",
        "Website URL:https://cmc-u.edu.vn",
    ],
    ".st.cmcu.edu.vn": ["\ufeffĐại học CMC", "CMC University"],
    ".codienxaydungbacninh.edu.vn": [
        "Trường Cao đẳng Cơ điện và Xây Dựng Bắc Ninh",
        "Bac Ninh Vocationnal college of Electromechanics and Construction",
    ],
    ".cofer.edu.vn": [
        "Cao đẳng Kinh Tế Đối Ngoại",
        "College of Foreign Economy and Relations",
    ],
    ".ctd.edu.vn": [
        "Cao Đẳng Kinh Tế Kỹ Thuật Thủ Đức",
        "Thu Duc Economic and Technical College",
    ],
    ".cth.edu.vn": ["Con Tu Hoc", "CTH Edu"],
    ".ctim.edu.vn": [
        "Cao đẳng CTIM",
        "College of Technology and Industrial Management",
    ],
    ".ctu.edu.vn": ["Can-Tho University"],
    ".student.ctuet.edu.vn": [
        "Trường Đại học Kỹ thuật - Công nghệ Cần Thơ",
        "Can Tho University of Technology",
    ],
    ".ctuet.edu.vn": [
        "Trường Đại học Kỹ thuật - Công nghệ Cần Thơ",
        "Can Tho University of Technology",
    ],
    ".student.ctump.edu.vn": ["Can Tho University of Medicine and Pharmacy"],
    ".daihocthudo.edu.vn": [
        "Trường Đại học Thủ đô Hà Nội",
        "Hanoi Metropolitan University",
    ],
    ".dainam.edu.vn": ["Đại Học Đại Nam", "\x08Dai Nam University"],
    ".daivietsaigon.edu.vn": ["Trường Cao đẳng Đại Việt Sài Gòn"],
    ".danavtc.edu.vn": ["Danang Vocational Training College"],
    ".datapot.edu.vn": [
        "https://datapot.edu.vn/",
        "Datapot is an educational institute that provides data science courses for Universities and Companies in Vietnam.",
    ],
    ".dau.edu.vn": [
        "Đại học kiến trúc Đà Nẵng",
        "DANANG ARCHITECTURE UNIVERSITY",
    ],
    ".devcamp.edu.vn": ["OnSchool", "OnSchool"],
    ".dhcd.edu.vn": [
        "Trường Đại học Công Đoàn",
        "Trade union university from Viet Nam",
    ],
    ".dhcnhn.edu.vn": [
        "Đại học Công Nghiệp Hà Nội",
        "Hanoi University of Industry",
    ],
    ".dhhp.edu.vn": ["Đại học Hải Phòng", "Hai Phong University"],
    ".dhktyduocdn.edu.vn": [
        "Đại học kỹ thuật y dược Đà Nẵng",
        "DA NANG UNIVERSITY OF MEDICAL TECHNOLOGY AND PHARMACY",
    ],
    ".dhpd.edu.vn": ["Đại Học Phương Đông", "Phuong Dong University"],
    ".dhsphue.edu.vn": ["Đại học Sư Phạm Huế", "Hue University of Education"],
    ".dhtm.edu.vn": ["Trường Đại học Thương mại", "Thuongmai University"],
    ".discite.edu.vn": ["Nguyen Dinh Cung"],
    ".sv.dla.edu.vn": [
        "Đại học Kinh tế Công nghiệp Long An",
        "Long An University of Economics and Industry",
    ],
    ".dlu.edu.vn": ["University of Da Lat"],
    ".dmail.edu.vn": [
        "Truong Trung cap nghe Cu Chi",
        "Cu Chi Vocational School",
    ],
    ".dntu.edu.vn": [
        "ĐẠI HỌC CÔNG NGHỆ ĐỒNG NAI",
        "DONG NAI UNIVERSITY OF TECHNOLOGY",
    ],
    ".dnu.edu.vn": ["TRƯỜNG ĐẠI HỌC ĐẠI NAM", "DAI NAM UNIVERSITY"],
    ".donga.edu.vn": ["\ufeffĐại Học Đông Á", "Dong A University"],
    ".dtdl.edu.vn": [
        "Trường Cao Đẳng Điện Tử - Điện Lạnh Hà Nội",
        "HaNoi College of Electronic and Electro - Refrigeratory Technics",
    ],
    ".dthu.edu.vn": ["Đại Học Đồng Tháp", "Dong Thap University"],
    ".due.edu.vn": [
        "Đại học kinh tế Đà Nẵng",
        "Da Nang University of Economics",
    ],
    ".dut.edu.vn": ["Da Nang University of Technology and Science"],
    ".duytan.edu.vn": ["Trường Đại học Duy Tân", "Duy Tan university"],
    ".eaut.edu.vn": [
        "Trường Đại Học Công Nghệ Đông Á, Hà Nội, Việt Nam",
        "East Asia University of Technology, Hanoi, VietNam",
    ],
    ".edisonschools.edu.vn": [
        "Edison Schools Ecopark",
        "Edison Schools Ecopark",
    ],
    ".ehou.edu.vn": ["Trường đại học mở Hà Nội", "Hanoi Open University"],
    ".eiu.edu.vn": [
        "Eastern International University",
        "Eastern International University",
    ],
    ".epu.edu.vn": ["Đại học điện lực", "electric power university"],
    ".fe.edu.vn": ["FPT University"],
    ".fit-haui.edu.vn": [
        "Đại học Công Nghiệp Hà Nội",
        "Hanoi University Of Industry",
    ],
    ".apcs.fitus.edu.vn": ["VNUHCM - University of Science"],
    ".clc.fitus.edu.vn": ["VNUHCM - University of Science"],
    ".vp.fitus.edu.vn": ["Đại học Khoa học Tự Nhiên", "University of Science"],
    ".flss.edu.vn": [
        "Trường Trung Học Phổ Thông Chuyên Ngoại Ngữ",
        "Foreign language special school",
    ],
    ".fpt.edu.vn": ["FPT University"],
    ".fsb.edu.vn": ["FSB School Of Business And Technology"],
    ".fst.edu.vn": [
        "Trường Đại học Công Thương Thành phố Hồ Chí Minh",
        "Ho Chi Minh City University of Industry and Trade",
    ],
    ".student.fulbright.edu.vn": ["Fulbright University Vietnam"],
    ".fulbright.edu.vn": ["Fulbright University Vietnam"],
    ".funix.edu.vn": ["FUNiX Online University"],
    ".student.giadinh.edu.vn": ["Gia Dinh University"],
    ".giadinh.edu.vn": ["Gia Dinh University", "Gia Dinh University"],
    ".haha.edu.vn": ["Trường Tiểu học Haha", "Haha Primary School"],
    ".hanu.edu.vn": ["Ha Noi University"],
    ".hathitrannhien.edu.vn": ["THPT Võ Văn Kiệt", "Vo Van Kiet Highschool"],
    ".hau.edu.vn": ["Hanoi University of Architecture"],
    ".haugiang.edu.vn": [
        "Department of Education and Training of Hau Giang Province"
    ],
    ".haui.edu.vn": [
        " Đại học Công Nghiệp Hà Nội",
        "Hanoi University of Industry",
    ],
    ".giadinh.hcm.edu.vn": [
        "Trường Trung Học Phổ Thông Gia Định",
        "Gia Dinh High School",
    ],
    ".hocmon.hcm.edu.vn": [
        "Trường Trung Học Phổ Thông Hóc Môn",
        "Hoc Mon High School",
    ],
    ".hcm.edu.vn": ["hocmon"],
    ".hcmier.edu.vn": [
        "Viện Môi Trường và Tài Nguyên",
        "Institute for Environment and Resource",
    ],
    ".hcmuaf.edu.vn": [
        "Ho Chi Minh City University of Agriculture and Forestry"
    ],
    ".hcmuarc.edu.vn": ["Ho Chi Minh City University of Architecture"],
    ".hcmue.edu.vn": [
        "Trường Đại học Sư Phạm TP.HCM",
        "Ho Chi Minh City University of Education",
    ],
    ".hcmulaw.edu.vn": ["Ho Chi Minh City University of Law"],
    ".sv.hcmunre.edu.vn": ["Dai Hoc Tai Nguyen va Moi Truong TPHCM"],
    ".hcmuns.edu.vn": ["Ho Chi Minh City University of Natural Sciences"],
    ".student.hcmup.edu.vn": [
        "Đại Học Sư Phạm Thành Phố Hồ Chí Minh",
        "Ho Chi Minh City University of Pedagogy",
    ],
    ".hcmupeda.edu.vn": ["Ho Chi Minh City University of Pedagogics"],
    ".hcmus.edu.vn": [
        "Ho Chi Minh University of Science",
        "University of Science, VNU-HCM",
    ],
    ".hcmussh.edu.vn": [
        "Ho Chi Minh City University of Social Sciences and Humanities"
    ],
    ".hcmut.edu.vn": ["Ho Chi Minh City University of Technology"],
    ".hcmute.edu.vn": ["University of Technical Education Ho Chi Minh City"],
    ".hcmutrans.edu.vn": ["Ho Chi Minh City University of Transport"],
    ".hdu.edu.vn": ["Hong Duc University"],
    ".st.hlu.edu.vn": ["Đại học luật Hà Nội", "Hanoi Law University"],
    ".student.hlu.edu.vn": ["Đại học luật Hà Nội", "Hanoi Law University"],
    ".hluv.edu.vn": ["Hoa Lu University"],
    ".hmu.edu.vn": ["Hanoi Medical University"],
    ".hnue.edu.vn": ["Hanoi National University of Education"],
    ".hoasen.edu.vn": ["Hoa Sen University"],
    ".hou.edu.vn": ["Hanoi Open University"],
    ".hpmu.edu.vn": [
        "Đại học Y Dược Hải Phòng",
        "Hai Phong University of Medicine and Pharmacy",
    ],
    ".hpu2.edu.vn": [
        "Dai Hoc Su Pham Ha Noi",
        "Hanoi Pedagogical University 2",
    ],
    ".hsb.edu.vn": [
        "Trường Quản trị và Kinh doanh",
        "Hanoi School of Business and Management",
    ],
    ".htt.edu.vn": [
        "Trường Cao Đẳng Công nghệ và Thương Mại Hà Nội",
        "Hanoi College of Technology and Trading",
    ],
    ".hu.edu.vn": ["Ha Tinh University", "Ha Tinh University"],
    ".hua.edu.vn": ["Hanoi University of Agriculture"],
    ".huas.edu.vn": ["Nguyễn Xuân Nhật Trường"],
    ".hub.edu.vn": [
        "Trường Đại học Ngân hàng Thành phố Hồ Chí Minh (HUB)",
        "Ho Chi Minh University of Banking (HUB)",
    ],
    ".hubt.edu.vn": ["Hanoi University of Business and Technology"],
    ".huc.edu.vn": ["Hanoi University of Culture"],
    ".huce.edu.vn": ["Hanoi University of Civil Engineering"],
    ".hue.edu.vn": ["Sở GD&ĐT Thừa Thiên Huế", "Sở GD&ĐT Thừa Thiên Huế"],
    ".students.hueic.edu.vn": [
        "TRƯỜNG CAO ĐẲNG CÔNG NGHIỆP HUẾ",
        "HUE INDUSTRIAL COLLEGE",
    ],
    ".huemed-univ.edu.vn": ["Hue University of Medicine and Pharmacy"],
    ".hueuni.edu.vn": ["Hue University"],
    ".huflis.edu.vn": [
        "Trường Đại Học Ngoại Ngữ Huế",
        "University of Foreign Languages and International Studies, Hue University",
    ],
    ".huflit.edu.vn": [
        "Trường Đại học Ngoại ngữ - Tin học TP. HCM",
        "Ho Chi Minh City University of Foreign Languages and Information Technology",
    ],
    ".stu.hui.edu.vn": ["Trường Đại học Công Thương"],
    ".huit.edu.vn": [
        "Trường Đại Học Công Thương TP.HCM",
        "Ho Chi Minh ciy of industry and trade",
    ],
    ".humg.edu.vn": ["Hanoi University of Mining and Geology"],
    ".hunre.edu.vn": [
        "Đại học Tài nguyên và Môi trường Hà Nội",
        "Hanoi University of Natural Resources and Environment",
    ],
    ".huph.edu.vn": [
        "TRƯỜNG ĐẠI HỌC Y TẾ CÔNG CỘNG",
        "HANOI UNIVERSITY OF PUBLIC HEALTH",
    ],
    ".hus.edu.vn": ["Hanoi University of Science"],
    ".husc.edu.vn": [
        "Trường Đại học Khoa học Huế",
        "Hue University Of Sciences",
    ],
    ".students.hust.edu.vn": [
        "Đại Học Bách Khoa Hà Nội",
        "Hanoi University of Science and Technology",
    ],
    ".hust.edu.vn": [
        "Đại học Bách khoa Hà Nội",
        "Hanoi University of Science and Technology",
    ],
    ".hut.edu.vn": ["Hanoi University of Technology"],
    ".hutech.edu.vn": ["University of Technology"],
    ".hvnh.edu.vn": ["Học Viện Ngân Hàng", "Banking Academy"],
    ".hvtc.edu.vn": ["Học Viện Tài Chính", "Academy Of Finance"],
    ".hvu.edu.vn": [
        "\ufeffTrường đại học Hùng Vương",
        "Hung Vuong University",
    ],
    ".hwru.edu.vn": ["Water Resources University"],
    ".ibm.edu.vn": [
        "Viện quản lý kinh doanh quốc tế",
        "International Business Management Institute",
    ],
    ".ich.edu.vn": [
        "Trường Cao Đẳng Quốc Tế TP. HCM",
        "International College of Ho Chi Minh City",
    ],
    ".iei.edu.vn": [
        "VIET NAM INTERNATIONAL UNIVERSITY HOCHIMINH CITY - INTERNATIONAL EDUCATION INSTITUTE"
    ],
    ".ift.edu.vn": ["Trường Bồi dưỡng cán bộ tài chính"],
    ".ikids.edu.vn": ["International Kids"],
    ".ipmph.edu.vn": [
        "VIỆN ĐÀO TẠO Y HỌC DỰ PHÒNG VÀ Y TẾ CÔNG CỘNG",
        "SCHOOL OF PREVENTIVE MEDICINE AND PUBLIC HEALTH",
    ],
    ".student.isb.edu.vn": [
        "Viện đào tạo quốc tế - Trường Đại học Kinh tế Thành phố Hồ Chí Minh",
        "International School of Business - University of Economics, Ho Chi Minh city, Viet Nam",
    ],
    ".student.ischool.edu.vn": ["THPT ISCHOOL LONG XUYÊN"],
    ".ispace.edu.vn": [
        "Trường Cao đẳng An ninh mạng iSPACE",
        "iSPACE vocational training college",
    ],
    ".ict.jvn.edu.vn": ["John Von Neumann Institute"],
    ".jvn.edu.vn": [
        "JVN Institute - Vietnam National University HCMC",
        "JVN Institute - Vietnam National University HCMC",
    ],
    ".kgmc.edu.vn": [
        "Trường Cao đẳng Y tế Kiên Giang",
        "Kien Giang Medical College",
    ],
    ".khanhhoa.edu.vn": [
        "Trường THPT Nguyễn Văn Trỗi",
        "Nguyen Van Troi High School",
    ],
    ".khdt.edu.vn": ["Đại học Khoa học Dữ liệu", "University of Data Science"],
    ".ktkt-haiduong.edu.vn": [
        "Hai Duong University of  Economics and Technology"
    ],
    ".ldxh.edu.vn": [
        "Đại học Lao động - Xã hội cơ sở 2",
        "University of Labour Social Affairs 2",
    ],
    ".lhu.edu.vn": ["Đại học Lạc Hồng", "Lac Hong University"],
    ".lomonoxop.edu.vn": [
        "Trường THCS và THPT M.V.Lômônôxốp",
        "M.V Lomonosov secondary and high school",
    ],
    ".lqd.edu.vn": [
        "Trường THPT Chuyên Lê Quý Đôn",
        "Le Quy Don High School For The Gifted Students",
    ],
    ".lqddn.edu.vn": ["Le Quy Don", "Le Quy Don"],
    ".lqdtu.edu.vn": [
        "Le Quy Don Technical University",
        "Le Quy Don Technical University",
    ],
    ".lsts.edu.vn": ["Trường Đinh Thiện Lý", "Lawrence S.Ting School"],
    ".lumina.edu.vn": ["Lumina Academy", "Lumina Academy"],
    ".mayaschool.edu.vn": [
        "TRUÖNG PHÖ THÔNG LIÊN CÃP SONG NGÜ MAYA",
        "MAYA SCHOOL",
        "Maya Education for Peace",
    ],
    ".mindx.edu.vn": ["MindX Technology School"],
    ".mku.edu.vn": ["Đại học Cửu Long", "Mekong University"],
    ".muce.edu.vn": [
        "Trường Đại học Xây dựng Miền Trung",
        "Mien Trung University of Civil Engineering",
    ],
    ".naem.edu.vn": ["HỌC VIỆN QUẢN LÝ GIÁO DỤC"],
    ".naue.edu.vn": [
        "TRƯỜNG ĐẠI HỌC KINH TẾ NGHỆ AN",
        "NGHE AN UNIVERSITY OF ECONOMICS",
    ],
    ".student.nctu.edu.vn": ["Đại học Nam Cần Thơ", "Nam Can Tho University"],
    ".ndun.edu.vn": [
        "Trường Đại học Điều dưỡng Nam Định",
        "Nam Dinh University of Nursing",
    ],
    ".neu.edu.vn": ["Hanoi National Economics University"],
    ".nghean.edu.vn": [
        "Department of Education and Training in Nghe An",
        "Sở giáo dục và đào tạo Nghệ An",
        "THPT Thanh Chương 1 | Thanh Chuong 1 High School",
        ".group",
    ],
    ".ngoquyenhighschool.edu.vn": [
        "Trường Trung học Phổ thông Ngô Quyền - Đảo Phú Quý - Bình Thuận",
        "Ngo Quyen highschool",
    ],
    ".ngs.edu.vn": [
        "Hệ thống trường liên cấp Newton",
        "NEWTON GRAMMAR SCHOOL",
    ],
    ".nguyensieu.edu.vn": ["NGUYEN SIEU SCHOOL", "NGUYEN SIEU SCHOOL"],
    ".nkh.edu.vn": [
        "Trường trung học phổ thông Nguyễn Khuyến Tây Ninh",
        "Nguyen Khuyen Tay Ninh High School",
    ],
    ".ntt.edu.vn": [
        "Nguyen Tat Thanh University",
        "Nguyen Tat Thanh University",
    ],
    ".ntu-hn.edu.vn": ["Đại học Nguyễn Trãi", "Nguyen Trai University"],
    ".ntu.edu.vn": ["Trường Đại học Nha Trang", "Nha Trang University"],
    ".nuce.edu.vn": ["National University of Civil Engineering"],
    ".ou.edu.vn": ["Ho Chi Minh City Open University"],
    ".oude.edu.vn": ["Trường Đại Học Mở thành phố Hồ Chí Minh"],
    ".pace.edu.vn": ["PACE Institute of Management "],
    ".pdu.edu.vn": [
        "Trường Đại học Phạm Văn Đồng",
        "Pham Van Dong University",
    ],
    ".penphy.edu.vn": ["Trường THCS Thuận Hưng"],
    ".pgd-hoangmai.edu.vn": ["Trung học cơ sở Linh Đàm"],
    ".pgdanlao.edu.vn": ["Phòng GD&ĐT Huyện An Lão", "pgdanlao.edu.vn"],
    ".phanboichau.edu.vn": [
        "THPT Phan Boi Chau - Hoai Nhon",
        "Phan Boi Chau High Shool",
    ],
    ".phenikaa-uni.edu.vn": ["Phenikaa university", "Phenikaa university"],
    ".phs.edu.vn": ["PACIFIC PRIMARY AND HIGH SCHOOL"],
    ".pitagon.edu.vn": ["Pitagon Education Technology Institute"],
    ".pnt.edu.vn": [
        "Trường Đại học Y khoa Phạm Ngọc Thạch",
        "Pham Ngoc Thach University of Medicine (PNTU)",
    ],
    ".poly.edu.vn": ["Cao Đẳng FPT Polytechnic", "FPT Polytechnic"],
    ".pso.edu.vn": ["Western Sydney University Vietnam"],
    ".ptit.edu.vn": ["Posts & Telecommunications Institude of Technology"],
    ".ptithcm.edu.vn": [
        "Học viện Công nghệ Bưu chính viễn thông",
        "Posts and Telecommunications Institute of Technology",
    ],
    ".ptnk.edu.vn": [
        "VNU-HCM High School for the Gifted",
        "Trường Phổ Thông Năng Khiếu, ĐHQG-HCM",
    ],
    ".pvu.edu.vn": [
        "Trường Đại Học Dầu Khí Việt Nam",
        "Petrovietnam University",
    ],
    ".st.qnu.edu.vn": ["Quy Nhon University"],
    ".qnu.edu.vn": ["Đại học Quy Nhơn", "Quy Nhon University"],
    ".qui.edu.vn": ["Quang Ninh University of Industry"],
    ".quochocquynhon.edu.vn": ["Quoc Hoc Quy Nhon"],
    ".rdi.edu.vn": [
        "Viện Phát triển Nguồn lực - Đại học Trà Vinh",
        "Resource Development Institute - Tra Vinh University",
    ],
    ".ric.edu.vn": [
        "Trường Cao Đẳng Công Nghiệp Cao Su",
        "Rubber Industrial College",
    ],
    ".rmit.edu.vn": ["RMIT International University Vietnam"],
    ".saidiait.edu.vn": [
        "Trường Đại học Saidia Vietnam",
        "Saidia University of Vietnam",
    ],
    ".saigontech.edu.vn": ["Saigontech"],
    ".saodo.edu.vn": ["Trường Đại học Sao Đỏ", "Sao Do University"],
    ".sapp.edu.vn": ["SAPP Academy", "SAPP Academy"],
    ".sic.edu.vn": [
        "SaiGon International College ",
        "SaiGon International College",
    ],
    ".gamudagardens.sis.edu.vn": [
        "Trường Quốc Tế Singapore tại Gamuda Gardens (Hà Nội)",
        "Singapore International School @ Gamuda Gardens",
    ],
    ".saigonsouth.sis.edu.vn": [
        "Trường Quốc tế Singapore (SIS) tại Nam Sài Gòn",
        "Singapore International School @ Saigon South",
    ],
    ".sis.edu.vn": [
        "Đại học Bách khoa Hà Nội",
        "Hanoi University of Science and Technology",
    ],
    ".sitc.edu.vn": [
        "Trung cấp Công nghệ Thông tin Sài Gòn",
        "Saigon Information Technology College",
    ],
    ".siu.edu.vn": [
        "Đại học Quốc tế Sài Gòn",
        "Saigon International University",
    ],
    ".sjjs.edu.vn": [
        "Saint Joseph Jesuit Scholasticate",
        "Học Viện Thánh Giuse Dòng Tên",
    ],
    ".spkt.edu.vn": [
        "Trường Đại học Sư phạm Kỹ thuật Hưng Yên",
        "Hung Yen University of Technology and Education",
    ],
    ".ssis.edu.vn": ["SAIGON SOUTH INTERNATIONAL SCHOOL"],
    ".student.stu.edu.vn": [
        "Đại học công nghệ Sài Gòn",
        "Saigon Technology University",
    ],
    ".student-topica.edu.vn": [
        "Tổ hợp giáo dục Topica",
        "Topica Edtech Group",
    ],
    ".studenthuph.edu.vn": [
        "Đại học Y tế công cộng",
        "HANOI UNIVERSITY OF PUBLIC HEALTH",
    ],
    ".hs.taquangbuu-bk.edu.vn": [
        "Trường Trung học cơ sở và Trung học phổ thông Tạ Quang Bửu",
        "Ta Quang Buu Secondary and High School",
    ],
    ".taynguyenuni.edu.vn": ["Tay Nguyen University"],
    ".tbd.edu.vn": ["Đại học Thái Bình Dương", "Thai Binh Duong University"],
    ".tckt.edu.vn": [
        "Dai Hoc Tai Chinh Ke Toan",
        "University Of Finance and Accountancy",
    ],
    ".tcu.edu.vn": ["Đại Học Thông tin Liên Lạc", "University Communications"],
    ".tdc.edu.vn": ["Thu Duc College of Technology"],
    ".tdmu.edu.vn": ["Thu Dau Mot University"],
    ".tdt.edu.vn": ["Ton Duc Thang University"],
    ".student.tdtu.edu.vn": [
        "Đại Học Tôn Đức Thắng",
        "Ton Duc Thang University",
    ],
    ".tdtu.edu.vn": ["Ton Duc Thang University"],
    ".tdu.edu.vn": ["Tay Do University"],
    ".teky.edu.vn": [
        "Teky Holdings Young Technology Education JSc",
        "Teky Holdings Young Technology Education JSc",
    ],
    ".tgu.edu.vn": ["Tien Giang University", "Tien Giang University"],
    ".thanglong.edu.vn": ["Thang Long University"],
    ".thcs-doanthidiem.edu.vn": [
        "Trung học cơ sở Đoàn Thị Điểm",
        "Doan Thi Diem Secondary School",
    ],
    ".thcs-nguyentrai.edu.vn": ["THCS Nguyễn Trãi"],
    ".thcsthuanhung.edu.vn": ["Trường THCS Thuận Hưng"],
    ".thedeweyschools.edu.vn": ["The Dewey Schools", "The Dewey Schools"],
    ".mail.thitcholuoc.edu.vn": [
        "Trường Trung học Cơ sở Phúc Diễn",
        "Phuc Dien Secondary School",
    ],
    ".thmkhai-nuithanh.edu.vn": [
        "Truong TH Nguyen Thi Minh Khai",
        "Nguyen Thi Minh Khai School",
    ],
    ".thpt-lehongphong-tphcm.edu.vn": [
        "Trường THPT Chuyên Lê Hồng Phong - Tp. Hồ Chí Minh",
        "Le Hong Phong High School for The Gifted - Ho Chi Minh City",
    ],
    ".thptchuyenthainguyen.edu.vn": [
        "Trung học phổ thông chuyên Thái Nguyên",
        "Thai Nguyen gifted high school",
    ],
    ".thpthahuytaphatinh.edu.vn": [
        "Truong THPT Ha Huy Tap",
        "Ha Huy Tap High School ",
    ],
    ".thptkhuongdinh.edu.vn": ["THPT Khương Đình", "Khuong Dinh Highschool"],
    ".thptkrongana.edu.vn": ["THPT Krong Ana", "Krong Ana High School"],
    ".thptlythaito.edu.vn": ["THPT Ly Thai To", "Ly Thai To High School"],
    ".thptnguyenhuuhuan.edu.vn": [
        "Trường THPT Nguyễn Hữu Huân",
        "Nguyen Huu Huan High School",
    ],
    ".thptnxo.edu.vn": [
        "Trường phổ thông trung học Nguyễn Xuân Ôn",
        "Nguyen Xuan On High School",
    ],
    ".thptphuoclonghcm.edu.vn": [
        "TRƯỜNG THPT PHƯỚC LONG",
        "PHUOC LONG HIGH SCHOOL",
    ],
    ".thptsontra.edu.vn": ["THPT Sơn Trà", "Son Tra High School"],
    ".thptyenvien.edu.vn": [
        "Trung học phổ thông Yên Viên",
        "Yen Vien High School",
    ],
    ".thpt-aldong.thuathienhue.edu.vn": ["An Luong Dong High School"],
    ".thuathienhue.edu.vn": ["Hoang Thi Tram", "Vinh Loc High School"],
    ".thucnghiem.edu.vn": [
        " Trường TH, THCS, THPT Thực Nghiệm Khoa học Giáo dục"
    ],
    ".tieuhocbunho.edu.vn": ["Tieu hoc Bu Nho", "Bu Nho elementary"],
    ".tkh.edu.vn": [
        "Trường trung học phổ thông Thanh Khê, Đà Nẵng City, VietNam"
    ],
    ".tlu.edu.vn": ["Đại học thủy lợi Hà Nội", "Water Resources University"],
    ".tmu.edu.vn": ["Đại học Thương Mại", "Vietnam University of Commerce"],
    ".tnmc.edu.vn": [
        "TRƯỜNG ĐẠI HỌC Y DƯỢC - ĐẠI HỌC THÁI NGUYÊN",
        "Tamilnadu Medical Council University",
    ],
    ".tnu.edu.vn": ["Đại học Thái Nguyên", "Thai Nguyen University"],
    ".tnus.edu.vn": [
        "Đại Học Khoa Học Thái Nguyên",
        "Thai Nguyen University of Science",
    ],
    ".tnut.edu.vn": [
        "Đại Học Kỹ Thuật Công Nghiệp Thái Nguyên",
        "Thai Nguyen University of technology",
    ],
    ".topica.edu.vn": ["Tổ hợp Công nghệ giáo dục Topica"],
    ".tranvanbayst.edu.vn": ["Trần Văn Bảy"],
    ".trungvuongdanang.edu.vn": [
        "Trường THCS Trưng Vương Đà Nẵng",
        "Trung Vuong Da Nang Middle School",
    ],
    ".ttn.edu.vn": ["Đại học Tây Nguyên", "Tay Nguyen University"],
    ".std.ttu.edu.vn": ["Tan Tao University", "Tan Tao University"],
    ".tuaf.edu.vn": ["Thainguyen University of Agriculture and Forestry"],
    ".tuyenquang.edu.vn": ["Trường "],
    ".tvu-onschool.edu.vn": ["Trường Đại Học Trà Vinh", "Tra Vinh University"],
    ".tvu.edu.vn": ["Đại học Trà Vinh", "Tra Vinh University"],
    ".uah.edu.vn": [
        "Đại Học Kiến Trúc Ho Chi Minh City",
        "University of Architecture Ho Chi Minh City",
    ],
    ".ud.edu.vn": ["University of Da Nang"],
    ".ueb.edu.vn": [
        "Trường Đại học Kinh tế - Đại học Quốc gia Hà Nội",
        "University of Economics and Business - Vietnam National University",
    ],
    ".uef.edu.vn": [
        "Trường Đại học Kinh tế - Tài chính thành phố Hồ Chí Minh",
        "Ho Chi Minh City University of Economics and Finance - UEF",
    ],
    ".ueh.edu.vn": ["Ho Chi Minh City University of Economics"],
    ".st.uel.edu.vn": [
        "Trường Đại học Kinh tế - Luật",
        "University of Economics and Law",
    ],
    ".uel.edu.vn": [
        "Trường Đại học Kinh tế – Luật, Đại học Quốc gia Thành phố Hồ Chí Minh",
        "University of Economics and Law – UEL",
    ],
    ".uet.edu.vn": [
        "Trường Đại học Công nghệ - Đại học Quốc gia Hà Nội",
        "VNU University of Engineering and Technology",
    ],
    ".sv.ufm.edu.vn": ["University of finance - marketing"],
    ".ufm.edu.vn": [
        "University of Finance - Marketing",
        "University of Finance - Marketing",
    ],
    ".uit.edu.vn": ["University of Information Technology Ho Chi Minh City"],
    ".st.umt.edu.vn": [
        "Trường Đại học Quản lý và Công nghệ TP.HCM",
        "University of Management and Technology Ho Chi Minh City",
    ],
    ".umt.edu.vn": [
        "University of management and technology Ho Chi Minh City"
    ],
    ".uneti.edu.vn": [
        "Kinh tế kỹ thuật công nghiệp Hà Nội",
        "Uneti University",
    ],
    ".uphcm.edu.vn": [
        "Khoa Dược - Đại học Y Dược TP.Hồ Chí Minh",
        "Faculty of Pharmacy - University of Medicine and Pharmacy, Ho Chi Minh City",
    ],
    ".upt.edu.vn": ["Đại học Phan Thiết", "University of Phan Thiet"],
    ".uschool.edu.vn": ["Trường Trung Cấp Công Nghệ Tân Tiến"],
    ".st.usth.edu.vn": ["University of Science and Technology of Hanoi"],
    ".usth.edu.vn": ["University of Science and Technology of Hanoi"],
    ".ut.edu.vn": [
        "\ufeffTrường đại học Giao thông vận tải thành phố Hồ Chí Minh",
        "Ho Chi Minh City University of Transport",
    ],
    ".utb.edu.vn": ["Tay Bac University", "Tay Bac University"],
    ".st.utc.edu.vn": [
        "University of Transport and Communication",
        "www.utc.edu.vn",
    ],
    ".utc.edu.vn": ["University of Transport and Communications"],
    ".st.utc2.edu.vn": [
        "University of Transport and Communications – Campus in Ho Chi Minh City",
        "www.utc2.edu.vn",
    ],
    ".utehy.edu.vn": [
        "Trường Đại học Sư phạm Kĩ thuật Hưng Yên",
        "Hung Yen University of Technology and Education",
    ],
    ".utm.edu.vn": [
        "Trường Đại học Công nghệ và Quản lý Hữu Nghị",
        "Hanoi University Of Technology and Management",
    ],
    ".utschool.edu.vn": ["US Vietnam Talent International School"],
    ".utt.edu.vn": ["University Of Transport Technology"],
    ".vcam.edu.vn": [
        "Trường cao đẳng cơ khí nông nghiệp",
        "Vocational college of agricultural mecanics",
    ],
    ".student.vgu.edu.vn": [
        "Đại học Việt Đức",
        "Vietnamese German University",
    ],
    ".vhu.edu.vn": ["Đại Học Văn Hiến", "Van Hien University"],
    ".victoryschool.edu.vn": ["HỆ THỐNG GIÁO DỤC THỰC NGHIỆM VICTORY"],
    ".viendong.edu.vn": [
        "Cao Đẳng Viễn Đông",
        "VienDong College",
        "Website: https://www.viendong.edu.vn/",
        "Email Domain: viendong.edu.vn",
    ],
    ".vietbac.edu.vn": [
        "Trường Đại học Kinh tế - Công nghệ Thái Nguyên",
        "Tuetech University",
    ],
    ".vimaru.edu.vn": ["Vietnam Maritime University"],
    ".vinhphuc.edu.vn": [
        "Huong Canh A Primary School",
        "Huong Canh A Primary School",
    ],
    ".vinschool.edu.vn": ["VINGROUP school"],
    ".vinuni.edu.vn": ["VinUniversity", "VinUniversity"],
    ".viu.edu.vn": [
        "Trường Đại học Công nghiệp Việt Hung",
        "Viet - Hung Industrial University",
        "http://viu.edu.vn/",
    ],
    ".vjis.edu.vn": ["Truong Lien Cap Viet Nhat"],
    ".vku.edu.vn": [
        "Trường Đại học Công nghệ Thông tin và Truyền thông Việt - Hàn"
    ],
    ".vlu.edu.vn": ["Dai Hoc Van Lang", "Van Lang University"],
    ".vlute.edu.vn": [
        "Đại học Sư Phạm Kỹ Thuật Vĩnh Long",
        "Vinh Long University of Technology and Education",
    ],
    ".vmmu.edu.vn": ["Vietnam Military Medical University"],
    ".vnkgu.edu.vn": ["Truong Dai Hoc Kien Giang", "Kien Giang University"],
    ".vnp.edu.vn": [
        "Vietnam The Nerhetlands Progamme",
        "Vietnam The Nerhetlands Progamme",
    ],
    ".vnua.edu.vn": [
        "Học viện Nông nghiệp Việt Nam",
        "Vietnam National University of Agriculture",
    ],
    ".vnuhcm.edu.vn": ["Vietnam National University Ho Chi Minh City"],
    ".vnuhn.edu.vn": ["Vietnam National University", "Nguyễn Vũ Linh"],
    ".vnuis.edu.vn": [
        "Trường Quốc tế - Đại học Quốc gia Hà Nội",
        "International School, Vietnam National University, Hanoi",
    ],
    ".vnuk.edu.vn": [
        "Viện Nghiên cứu và Đào tạo Việt Anh",
        "The VNUK Institute for Research and Executive Education",
    ],
    ".vtc.edu.vn": [
        "VTC INFORMATION TECHNOLOGY AND DESIGN ACADEMY",
        "VTC ACADEMY",
    ],
    ".vtec.edu.vn": [
        "Trường Cao đẳng Kinh tế - Kỹ thuật Vĩnh Phúc",
        "Vinh Phuc Technology - Economic College",
    ],
    ".stu.vttu.edu.vn": [
        "Trường Đại học Võ Trường Toản",
        "Can Tho University of Medicine and Pharmacy",
    ],
    ".wass.edu.vn": [
        "Trường TiH - THCS - THPT Tây Úc (WASS)",
        "Western Australian International School System",
    ],
    ".wellspring.edu.vn": [
        "trường Phổ thông Song Ngữ Liên cấp Wellspring",
        "Wellspring International Bilingual School",
    ],
    ".wellspringsaigon.edu.vn": [
        "Trường Phổ thông Liên cấp Song Ngữ Quốc tế Wellspring Saigon",
        "Wellspring Saigon International Bilingual School",
    ],
    ".yds.edu.vn": ["Ho Chi Minh City University of Medicine and Pharmacy"],
    ".yersin.edu.vn": ["YERSIN UNIVERSITY DALAT", "YERSIN UNIVERSITY DALAT"],
    ".ytebacninh.edu.vn": ["Trường Cao đẳng Y tế Bắc Ninh"],
    ".hiu.vn": [
        "Hong Bang International University",
        "Hong Bang International University",
    ],
    ".itrithuc.vn": [
        "Digital Vietnamese Knowledge System Project of the Ministry of Science and Technology of Vietnam"
    ],
    ".mit.vn": ["student.mit.vn"],
    ".tmudaihoctuxa.vn": ["TRUONG DAI HOC THUONG MAI", "Thuongmai University"],
    ".sv1.dut.udn.vn": [
        "Trường Đại học Bách khoa - Đại học Đà Nẵng",
        "University of Science and Technology - The University of Da Nang",
    ],
    ".daotao.sict.udn.vn": [
        "Khoa Công nghệ thông tin và truyền thông - Đại học Đà Nẵng",
        "School of Information and Communication Technology - The University of Danang",
    ],
    ".sv.ute.udn.vn": [
        "Trường Đại học Sư Phạm Kỹ Thuật - Đại học Đà Nẵng",
        "University of Technology and Education - The University of Danang",
    ],
    ".student.utt.vn": [
        "Trường Đại học Công Nghệ Giao Thông Vận Tải",
        "University Of Transport Technology",
    ],
    ".vanlanguni.vn": ["Văn Lang University"],
    ".vnn.vn": [
        "Ho Chi Minh City University of Foreign Languages and Information Technology"
    ],
    ".coltech.vnu.vn": ["Vietnam National University Hanoi"],
    ".flinthighschool.wales": ["Flint High School"],
    ".hhc.world": [
        "Heilig-Hartcollege Tervuren Belgium",
        "College of the Sacred Heart Belgium",
    ],
    ".ucode.world": ["UNIT Factory ucode"],
    ".nus.edu.ws": ["National University of Samoa"],
    ".nouvellesimages.xyz": [
        "Ecole des Nouvelles Images",
        "School of New Images",
    ],
    ".adenuniversity.edu.ye": ["University of Aden"],
    ".eman-univ.edu.ye": ["Al-Eman University"],
    ".hoduniv.edu.ye": ["Hodeidah University"],
    ".hust.edu.ye": ["Hadhramout University of Science and Technology "],
    ".su.edu.ye": ["Sana'a University"],
    ".akademia.ac.za": ["Akademia MSW"],
    ".cput.ac.za": ["Cape Peninsula University of Technology"],
    ".cut.ac.za": ["Central University of Technology, Free State"],
    ".iie.ac.za": ["The Independent Institute of Education"],
    ".myuct.ac.za": ["University of Cape Town"],
    ".nmmu.ac.za": ["Nelson Mandela Metropolitan University"],
    ".nwu.ac.za": ["North-West University"],
    ".my.richfield.ac.za": ["Richfied Graduate Institute of Technology"],
    ".ru.ac.za": ["Rhodes University"],
    ".sun.ac.za": ["University of Stellenbosch"],
    ".tut.ac.za": ["Tshwane University of Technology"],
    ".uct.ac.za": ["University of Cape Town"],
    ".ufh.ac.za": ["University of Fort Hare"],
    ".uj.ac.za": ["University of Johannesburg"],
    ".ukzn.ac.za": ["University of KwaZulu-Natal"],
    ".ul.ac.za": ["University of Limpopo"],
    ".unisa.ac.za": ["University of South Africa"],
    ".univen.ac.za": ["University of Venda"],
    ".uniwest.ac.za": ["University of North West"],
    ".uovs.ac.za": ["University of the Free State"],
    ".up.ac.za": ["University of Pretoria"],
    ".uwc.ac.za": ["University of the Western Cape"],
    ".uzulu.ac.za": ["University of Zululand"],
    ".vut.ac.za": ["Vaal University of Technology"],
    ".wits.ac.za": ["University of Witwatersrand"],
    ".wsu.ac.za": ["Walter Sisulu University for Technology and Science"],
    ".akademiastudente.co.za": ["Akademia MSW"],
    ".almainternational.co.za": ["Alma Mater International School"],
    ".birnamcollege.co.za": ["Birnam College"],
    ".boston.co.za": ["Boston College"],
    ".cedarhouse.co.za": ["Cedar House"],
    ".ctucareer.co.za": ["CTU Training Solutions"],
    ".damelin.co.za": ["Damelin - Pretoria City Campus"],
    ".dsk.co.za": [
        "Deutsche Internationale Schule Kapstadt",
        "German International School Cape Town",
    ],
    ".educationgroup.co.za": ["CTI Education Group"],
    ".gibs.co.za": ["Gordon Institute of Business Science"],
    ".imconnect.co.za": ["Independent Institute of Education MSA"],
    ".kloofhigh.co.za": ["Kloof High School"],
    ".lynnies.co.za": ["Laerskool Lynnwood"],
    ".students.mancosa.co.za": ["Mancosa University"],
    ".myboston.co.za": ["Boston College"],
    ".redacademy.co.za": ["redAcademy"],
    ".redhill.co.za": ["Redhill School", "https://www.redhill.co.za/"],
    ".sabje.co.za": ["King David Victory Park"],
    ".saheti.co.za": ["SAHETI School"],
    ".sthenrys.co.za": ["St Henry's Marist College"],
    ".stjohnschool.co.za": ["St John's College"],
    ".stjohnscollege.co.za": ["St John's College", "St John's College"],
    ".tuks.co.za": ["University of Pretoria"],
    ".varsitycollege.co.za": ["varsity college "],
    ".vcconnect.co.za": ["Varsity College "],
    ".vegaconnect.co.za": ["Vega institute of Education"],
    ".virtualwindow.co.za": ["Open Window", "Open Window"],
    ".westerford.co.za": ["Westerford High School", "Westerford High School"],
    ".wethinkcode.co.za": ["WeThinkCode_"],
    ".connect.edu.za": ["Southdowns College, South Africa"],
    ".rcconnect.edu.za": ["IIE Rosebank College"],
    ".sae.edu.za": ["SAE Institute South Africa"],
    ".vcconnect.edu.za": ["Varsity College Westville"],
    ".vgconnect.edu.za": ["Vega School Cape Town"],
    ".bishops.org.za": ["Bishops Diocesan College"],
    ".mu.ac.zm": ["Mulungushi University"],
    ".unilus.ac.zm": ["University of Lusaka"],
    ".zambianopenuniversity.ac.zm": ["Zambian Open University"],
    ".cavendish.co.zm": ["Cavendish University Zambia"],
    ".cbu.edu.zm": ["Copperbelt University"],
    ".www.unza.zm": ["University of Zambia"],
    ".unza.zm": ["University of Zambia"],
    ".aju.ac.zw": ["Arrupe Jesuit University"],
    ".students.buse.ac.zw": ["Bindura University of Science Education"],
    ".cut.ac.zw": ["Chinhoyi University of Technology"],
    ".cuz.ac.zw": ["Catholic Univesity Of Zimbabwe"],
    ".elearning.gzu.ac.zw": ["Great Zimbabwe University"],
    ".hit.ac.zw": [
        "Harare Institute of Technology",
        "Harare Institute of Technology",
    ],
    ".msu.ac.zw": ["Midlands State University"],
    ".students.msuas.ac.zw": [
        "Manicaland State University of Applied Science"
    ],
    ".nust.ac.zw": ["National University of Science and Technology Bulawayo"],
    ".riversidecollege.ac.zw": ["Riverside College", "riversidecollege.ac.zw"],
    ".solusi.ac.zw": ["Solusi University"],
    ".trustacademy.ac.zw": ["Trust Academy"],
    ".uz.ac.zw": ["University of Zimbabwe"],
}
